(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    820959,      22494]*)
(*NotebookOutlinePosition[    821858,      22523]*)
(*  CellTagsIndexPosition[    821814,      22519]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Permanent Magnet Mulipoles", "Title"],

Cell["\<\
J. Chavanne, ESRF
June 1999\
\>", "Text"],

Cell[CellGroupData[{

Cell["Start Radia ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Radia`; \n<< \ Graphics`MultipleListPlot`; \n
    Off[General::"\<spell1\>"]; \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\("Radia Version: "\), "\[InvisibleSpace]", 
        StyleBox["4.09799999999999986`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", \(" is loaded"\)}],
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Function Radcylinder", "Section"],

Cell[CellGroupData[{

Cell[TextData[
"Function \
RadCylinder[pt3,r1,r2,\[Phi]1,\[Phi]2,lz,nr,n\[Phi],nz,mag4:{0,0,0,0}]"], 
  "Subsubsection"],

Cell[TextData[{
  "This function create a full cylinder or a  portion of cylinder with an \
axis along z. The imput parameters are as folow:\n",
  StyleBox["pt3 {x[mm],y[mm],{z[mm]}",
    FontWeight->"Bold"],
  ": origin of the cylinder correponding to the  intersection between the \
cylinder axis and the base of the cylinder\n",
  StyleBox["r1 [mm]",
    FontWeight->"Bold"],
  ": inner radius of the cylinder , radius of the circle tangent to the inner \
part of the cylinder\n",
  StyleBox["r2 [mm]",
    FontWeight->"Bold"],
  ": outer radius of the cylinder, radius of the circle tangent to the outer \
part of the cylinder\n",
  StyleBox["\[Phi]1[rad]",
    FontWeight->"Bold"],
  ": start angle\n",
  StyleBox["\[Phi]2 [rad]",
    FontWeight->"Bold"],
  ": end angle\n",
  StyleBox["lz [mm]",
    FontWeight->"Bold"],
  ": heigth of the cylinder\n",
  StyleBox["nr []",
    FontWeight->"Bold"],
  ": number of elements in the radial direction \n",
  StyleBox["n\[Phi] []",
    FontWeight->"Bold"],
  ": number of elements in the azimutal direction (number of segments)\n",
  StyleBox["nz []",
    FontWeight->"Bold"],
  ": number of elements in the vertical direction\n",
  StyleBox["mag4 {mx,my,mz,order}",
    FontWeight->"Bold"],
  ": define the easy axis of each azimutal segment of the cylinder\nmx,my amd \
mz define the easy axis of the first segment, the easy axis of the oher \
azimutal segments depend on the parameter ",
  StyleBox["order:\n",
    FontWeight->"Bold"],
  "with ",
  StyleBox["order ",
    FontWeight->"Bold"],
  "=0 the easy axis of all the segments is the same as in the first segments \
defined with the vector mx,my,mz, the cylinder has a constant easy axis.\n\
with ",
  StyleBox["order",
    FontWeight->"Bold"],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  ">=1the easy axis inside each azimutal segment",
  StyleBox[" ",
    FontWeight->"Bold"],
  " is constant but rotates by an angle of ",
  StyleBox["order*(\[Phi]i -\[Phi] 1) ",
    FontWeight->"Bold"],
  "around the z axis between segment number i and the first segment.\nThis \
allow the construction of general multipole stuctures such as dipole, \
quadrupole, sextupole (hexapoles) and so on. If mag4 is ommited, the default \
value {0,0,0,0} is applied.\nThe function return the handle of the container \
including all elements of the cylinder."
}], "Text",
  CellFrame->True,
  Background->RGBColor[0.97998, 0.850004, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Here is the function", "Subsubsection"],

Cell[BoxData[
    \(\(\t\n\t
    \(RadCylinder[pt_List, r1_, r2_, \[Phi]1_, \[Phi]2_, lz_, nr_, n\[Phi]_, 
        nz_, mag_List] := \n\t
      Module[{x, y, z, x1, y1, x2, y2, x3, y3, x4, y4, rint, rext, v1, v2, 
          v3, gc, m1, m2, m3}, \n\t\tx = pt[\([1]\)]; \n\t\ty = pt[\([2]\)]; 
        \n\t\tz = pt[\([3]\)]; \n\t\t
        If[\[Phi]2 - \[Phi]1 > 2\ Pi, d\[Phi] = 2\ Pi/n\[Phi], \n\ \ \ \ \ \ 
          d\[Phi] = \((\[Phi]2 - \[Phi]1)\)/n\[Phi]]; \n\t\t
        gc = radObjCnt[{}]; \n\t\trint = r1/Cos[d\[Phi]/2.]; \n\t\t
        rext = r2/Cos[d\[Phi]/2.]; \n\t\t
        If[r1 \[NotEqual] 0., \n\t\t
          Do[\n\t\t\tx1 = x + rint\ Cos[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n
            \t\t\ty1 = y + rint\ Sin[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n\t\t\t
            x2 = x + rext\ Cos[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n\t\t\t
            y2 = y + rext\ Sin[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n\t\t\t
            x3 = x + rext\ Cos[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            y3 = y + rext\ Sin[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            x4 = x + rint\ Cos[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            y4 = y + rint\ Sin[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            v1 = {\((x3 + x2)\)/2, \((y3 + y2)\)/2, 0}; \n\t\t\t
            v2 = {\(-v1[\([2]\)]\), v1[\([1]\)], 0}; \n\t\t\tv3 = {0, 0, 1}; 
            \n\t\t\tm1 = 
              mag[\([1]\)]\ Cos[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)] - 
                mag[\([2]\)]\ Sin[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)]; \n
            \t\t\tm2 = 
              mag[\([1]\)]\ Sin[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)] + 
                mag[\([2]\)]\ Cos[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)]; \n
            \t\t\tm3 = mag[\([3]\)]; \n\t\t\t
            poly = {{x1, y1}, {x2, y2}, {x3, y3}, {x4, y4}}; \n\t\t\t
            p = radObjMltExtPgn[{{poly, z}, {poly, z + lz}}, {m1, m2, m3}]; \n
            \t\t\tradObjDivMag[p, {nr, 1, nz}, {"\<pln\>", v1, v2, v3}, 
              kxkykz -> Numb, Frame -> Loc]; \n\t\t\t
            radObjAddToCnt[gc, {p}], {i, 1, n\[Phi]}], \n\t\t
          Do[\n\t\t\tx1 = 0; \n\t\t\ty1 = 0; \n\t\t\t
            x2 = x + rext\ Cos[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n\t\t\t
            y2 = y + rext\ Sin[\[Phi]1 + d\[Phi]\ \((i - 1)\)]; \n\t\t\t
            x3 = x + rext\ Cos[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            y3 = y + rext\ Sin[\[Phi]1 + d\[Phi]\ i]; \n\t\t\t
            v1 = {\((x3 + x2)\)/2, \((y3 + y2)\)/2, 0}; \n\t\t\t
            v2 = {\(-v1[\([2]\)]\), v1[\([1]\)], 0}; \n\t\t\tv3 = {0, 0, 1}; 
            \n\t\t\tm1 = 
              mag[\([1]\)]\ Cos[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)] - 
                mag[\([2]\)]\ Sin[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)]; \n
            \t\t\tm2 = 
              mag[\([1]\)]\ Sin[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)] + 
                mag[\([2]\)]\ Cos[mag[\([4]\)]\ d\[Phi]\ \((i - 1)\)]; \n
            \t\t\tm3 = mag[\([3]\)]; \n\t\t\t
            poly = {{x1, y1}, {x2, y2}, {x3, y3}}; \n\t\t\t
            p = radObjMltExtPgn[{{poly, z}, {poly, z + lz}}, {m1, m3, m3}]; \n
            \t\t\tradObjDivMag[p, {nr, 1, nz}, {"\<pln\>", v1, v2, v3}, 
              kxkykz -> Numb, Frame -> Loc]; \n\t\t\t
            radObjAddToCnt[gc, {p}], {i, 1, n\[Phi]}]]; \n\t\tgc\n\t]; 
    \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[CellGroupData[{

Cell["\<\
 A cylinder with constant magnetization along z,with 12 azimutal \
segments\
\>", "Subsection"],

Cell[BoxData[
    \(radUtiDelAll[]; \nnseg = 12; \nrint = 10; \nrext = 20; \nLz = 30; \n
    phi1 = 0; \nphi2 = phi1 + 2\ Pi; \nnz = 1; \nnr = {1, 1}; \n
    pt = {0, 0, 0}; \nbr = 1.2; \nmag = {0, 0, br, 0}; \n
    cyl1 = RadCylinder[pt, rint, rext, phi1, phi2, Lz, nr, nseg, nz, mag]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      RowBox[{"d1", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "cyl1", "]"}]}], ";", "\n", 
      \(Show[Graphics3D[d1]\n, ViewPoint -> {1, 1, 1}]\), ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.85374 .33636 0 -10.857 ]
[.85374 .33636 25 3.14304 ]
[.79069 .27316 0 -11.3211 ]
[.79069 .27316 25 2.6789 ]
[.71747 .19982 0 -11.9123 ]
[.71747 .19982 10 2.08775 ]
[.63139 .11367 0 -12.6908 ]
[.63139 .11367 16 1.30923 ]
[.52876 .01107 0 -13.7625 ]
[.52876 .01107 16 .23748 ]
[.76863 .16392 0 -11.9123 ]
[.76863 .16392 16 2.08775 ]
[.14626 .33636 -25 -10.857 ]
[.14626 .33636 0 3.14304 ]
[.20931 .27316 -25 -11.3211 ]
[.20931 .27316 0 2.6789 ]
[.28253 .19982 -10 -11.9123 ]
[.28253 .19982 0 2.08775 ]
[.36861 .11367 -16 -12.6908 ]
[.36861 .11367 0 1.30923 ]
[.47124 .01107 -16 -13.7625 ]
[.47124 .01107 0 .23748 ]
[.23137 .16392 -15 -11.9123 ]
[.23137 .16392 0 2.08775 ]
[.86567 .35282 0 -10.7531 ]
[.86567 .35282 10 3.24694 ]
[.89215 .44412 0 -10.2852 ]
[.89215 .44412 16 3.7148 ]
[.92282 .55001 0 -9.76194 ]
[.92282 .55001 16 4.23806 ]
[.95875 .67428 0 -9.17284 ]
[.95875 .67428 16 4.82716 ]
[.96426 .4702 0 -10.0311 ]
[.96426 .4702 14 3.96891 ]
[ 0 -0.00149 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.85283 .35243 m
.5 1e-05 L
s
.25 Mabswid
.84279 .34239 m
.83731 .34541 L
s
gsave
.85374 .33636 -61 -14.857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.78005 .27973 m
.77473 .28301 L
s
gsave
.79069 .27316 -61 -15.3211 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.70723 .207 m
.70212 .21059 L
s
gsave
.71747 .19982 -61 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62169 .12156 m
.61684 .1255 L
s
gsave
.63139 .11367 -61 -16.6908 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51977 .01976 m
.51528 .0241 L
s
gsave
.52876 .01107 -61 -17.7625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.83095 .33056 m
.82768 .3324 L
s
.81877 .3184 m
.81552 .32027 L
s
.80623 .30588 m
.803 .30778 L
s
.79333 .293 m
.79012 .29493 L
s
.76637 .26606 m
.7632 .26807 L
s
.75226 .25198 m
.74912 .25402 L
s
.73772 .23745 m
.7346 .23953 L
s
.72272 .22247 m
.71962 .22458 L
s
.69124 .19103 m
.6882 .19322 L
s
.67472 .17452 m
.67171 .17676 L
s
.65764 .15747 m
.65466 .15974 L
s
.63998 .13982 m
.63703 .14214 L
s
.60276 .10265 m
.59989 .10506 L
s
.58314 .08305 m
.58031 .08551 L
s
.56279 .06273 m
.56 .06524 L
s
.54169 .04165 m
.53894 .0442 L
s
gsave
.76863 .16392 -61 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
75.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.14717 .35243 m
.5 1e-05 L
s
.25 Mabswid
.15721 .34239 m
.16269 .34541 L
s
gsave
.14626 .33636 -86 -14.857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.21995 .27973 m
.22527 .28301 L
s
gsave
.20931 .27316 -86 -15.3211 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.29277 .207 m
.29788 .21059 L
s
gsave
.28253 .19982 -71 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.37831 .12156 m
.38316 .1255 L
s
gsave
.36861 .11367 -77 -16.6908 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.48023 .01976 m
.48472 .0241 L
s
gsave
.47124 .01107 -77 -17.7625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.16905 .33056 m
.17232 .3324 L
s
.18123 .3184 m
.18448 .32027 L
s
.19377 .30588 m
.197 .30778 L
s
.20667 .293 m
.20988 .29493 L
s
.23363 .26606 m
.2368 .26807 L
s
.24774 .25198 m
.25088 .25402 L
s
.26228 .23745 m
.2654 .23953 L
s
.27728 .22247 m
.28038 .22458 L
s
.30876 .19103 m
.3118 .19322 L
s
.32528 .17452 m
.32829 .17676 L
s
.34236 .15747 m
.34534 .15974 L
s
.36002 .13982 m
.36297 .14214 L
s
.39724 .10265 m
.40011 .10506 L
s
.41686 .08305 m
.41969 .08551 L
s
.43721 .06273 m
.44 .06524 L
s
.45831 .04165 m
.46106 .0442 L
s
gsave
.23137 .16392 -76 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.85283 .35243 m
.94973 .68811 L
s
.25 Mabswid
.85465 .35873 m
.84914 .36168 L
s
gsave
.86567 .35282 -61 -14.7531 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88084 .44943 m
.87518 .45209 L
s
gsave
.89215 .44412 -61 -14.2852 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.91119 .5546 m
.90538 .55689 L
s
gsave
.92282 .55001 -61 -13.7619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.94681 .67798 m
.94084 .67984 L
s
gsave
.95875 .67428 -61 -13.1728 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.8596 .37586 m
.85627 .3776 L
s
.86468 .39347 m
.86134 .39518 L
s
.86991 .41159 m
.86655 .41326 L
s
.87529 .43024 m
.87192 .43187 L
s
.88654 .4692 m
.88313 .47076 L
s
.89242 .48958 m
.88899 .49109 L
s
.89849 .51058 m
.89504 .51205 L
s
.90474 .53225 m
.90127 .53367 L
s
.91786 .57768 m
.91435 .579 L
s
.92474 .60151 m
.92121 .60279 L
s
.93185 .62615 m
.9283 .62737 L
s
.9392 .65163 m
.93564 .65279 L
s
gsave
.96426 .4702 -61 -14.0311 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.5 .54326 m
.5 .82467 L
s
.5 .82467 m
.94973 .68811 L
s
.94973 .68811 m
.85283 .35243 L
s
.85283 .35243 m
.5 .54326 L
s
.14717 .35243 m
.5 1e-05 L
s
.5 1e-05 m
.5 .38476 L
s
.5 .38476 m
.05027 .68811 L
s
.05027 .68811 m
.14717 .35243 L
s
.5 .54326 m
.5 .82467 L
s
.5 .82467 m
.05027 .68811 L
s
.05027 .68811 m
.14717 .35243 L
s
.14717 .35243 m
.5 .54326 L
s
.85283 .35243 m
.5 1e-05 L
s
.5 1e-05 m
.5 .38476 L
s
.5 .38476 m
.94973 .68811 L
s
.94973 .68811 m
.85283 .35243 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.43745 .77774 m .44825 .49324 L .35216 .46169 L p .946 .632 .558 r
F P
0 g
s
.44825 .49324 m .43745 .77774 L .56255 .77774 L p .776 .482 .568 r
F P
0 g
s
.44825 .49324 m .43745 .77774 L .46531 .73331 L p .1 .1 .247 r
F P
0 g
s
.56255 .77774 m .55175 .49324 L .44825 .49324 L p .776 .482 .568 r
F P
0 g
s
.47183 .43194 m .44825 .49324 L .55175 .49324 L p .704 .893 1 r
F P
0 g
s
.46531 .73331 m .47183 .43194 L .44825 .49324 L p .1 .1 .247 r
F P
0 g
s
.44825 .49324 m .47183 .43194 L .42117 .41363 L p .704 .893 1 r
F P
0 g
s
.42117 .41363 m .35216 .46169 L .44825 .49324 L p .704 .893 1 r
F P
0 g
s
.43745 .77774 m .44825 .49324 L .47183 .43194 L p .1 .1 .247 r
F P
0 g
s
.55175 .49324 m .56255 .77774 L .53469 .73331 L p 1 .754 .247 r
F P
0 g
s
.55175 .49324 m .52817 .43194 L .47183 .43194 L p .704 .893 1 r
F P
0 g
s
.53469 .73331 m .52817 .43194 L .55175 .49324 L p 1 .754 .247 r
F P
0 g
s
.56255 .77774 m .55175 .49324 L .52817 .43194 L p 1 .754 .247 r
F P
0 g
s
.55175 .49324 m .56255 .77774 L .68041 .75508 L p .558 .316 .558 r
F P
0 g
s
.68041 .75508 m .64784 .46169 L .55175 .49324 L p .558 .316 .558 r
F P
0 g
s
.52817 .43194 m .55175 .49324 L .64784 .46169 L p .704 .893 1 r
F P
0 g
s
.31959 .75508 m .35216 .46169 L .28073 .39965 L p 1 .78 .519 r
F P
0 g
s
.35216 .46169 m .31959 .75508 L .43745 .77774 L p .946 .632 .558 r
F P
0 g
s
.35216 .46169 m .31959 .75508 L .40237 .7197 L p .26 .1 .424 r
F P
0 g
s
.40237 .7197 m .42117 .41363 L .35216 .46169 L p .26 .1 .424 r
F P
0 g
s
.35216 .46169 m .42117 .41363 L .38758 .37971 L p .704 .893 1 r
F P
0 g
s
.38758 .37971 m .28073 .39965 L .35216 .46169 L p .704 .893 1 r
F P
0 g
s
.31959 .75508 m .35216 .46169 L .42117 .41363 L p .26 .1 .424 r
F P
0 g
s
.64784 .46169 m .68041 .75508 L .59763 .7197 L p 1 .681 .424 r
F P
0 g
s
.64784 .46169 m .57883 .41363 L .52817 .43194 L p .704 .893 1 r
F P
0 g
s
.59763 .7197 m .57883 .41363 L .64784 .46169 L p 1 .681 .424 r
F P
0 g
s
.68041 .75508 m .64784 .46169 L .57883 .41363 L p 1 .681 .424 r
F P
0 g
s
.64784 .46169 m .68041 .75508 L .77274 .70921 L p .244 .105 .519 r
F P
0 g
s
.77274 .70921 m .71927 .39965 L .64784 .46169 L p .244 .105 .519 r
F P
0 g
s
.57883 .41363 m .64784 .46169 L .71927 .39965 L p .704 .893 1 r
F P
0 g
s
.52817 .43194 m .53469 .73331 L .46531 .73331 L p .767 .453 .533 r
F P
0 g
s
.46531 .73331 m .47183 .43194 L .52817 .43194 L p .767 .453 .533 r
F P
0 g
s
.47183 .43194 m .46531 .73331 L .43745 .77774 L p .1 .1 .247 r
F P
0 g
s
.52817 .43194 m .53469 .73331 L .56255 .77774 L p 1 .754 .247 r
F P
0 g
s
.53469 .73331 m .52817 .43194 L .57883 .41363 L p .517 .262 .517 r
F P
0 g
s
.47183 .43194 m .46531 .73331 L .40237 .7197 L p .955 .619 .517 r
F P
0 g
s
.40237 .7197 m .42117 .41363 L .47183 .43194 L p .955 .619 .517 r
F P
0 g
s
.42117 .41363 m .40237 .7197 L .31959 .75508 L p .26 .1 .424 r
F P
0 g
s
.42117 .41363 m .40237 .7197 L .3593 .69409 L p 1 .768 .45 r
F P
0 g
s
.3593 .69409 m .38758 .37971 L .42117 .41363 L p 1 .768 .45 r
F P
0 g
s
.57883 .41363 m .59763 .7197 L .53469 .73331 L p .517 .262 .517 r
F P
0 g
s
.57883 .41363 m .59763 .7197 L .68041 .75508 L p 1 .681 .424 r
F P
0 g
s
.71927 .39965 m .61242 .37971 L .57883 .41363 L p .704 .893 1 r
F P
0 g
s
.59763 .7197 m .57883 .41363 L .61242 .37971 L p .138 .1 .45 r
F P
0 g
s
.28073 .39965 m .22726 .70921 L .31959 .75508 L p 1 .78 .519 r
F P
0 g
s
.22726 .70921 m .28073 .39965 L .38758 .37971 L p .623 .312 .482 r
F P
0 g
s
.71927 .39965 m .77274 .70921 L .6407 .69409 L p .867 .511 .482 r
F P
0 g
s
.6407 .69409 m .61242 .37971 L .71927 .39965 L p .867 .511 .482 r
F P
0 g
s
.22726 .70921 m .28073 .39965 L .25662 .31331 L p 1 .866 .395 r
F P
0 g
s
.28073 .39965 m .22726 .70921 L .3593 .69409 L p .623 .312 .482 r
F P
0 g
s
.3593 .69409 m .38758 .37971 L .28073 .39965 L p .623 .312 .482 r
F P
0 g
s
.28073 .39965 m .38758 .37971 L .38157 .33663 L p .704 .893 1 r
F P
0 g
s
.38157 .33663 m .25662 .31331 L .28073 .39965 L p .704 .893 1 r
F P
0 g
s
.77274 .70921 m .71927 .39965 L .61242 .37971 L p .867 .511 .482 r
F P
0 g
s
.71927 .39965 m .77274 .70921 L .81107 .64237 L p .1 .1 .395 r
F P
0 g
s
.81107 .64237 m .74338 .31331 L .71927 .39965 L p .1 .1 .395 r
F P
0 g
s
.61242 .37971 m .71927 .39965 L .74338 .31331 L p .704 .893 1 r
F P
0 g
s
.38758 .37971 m .3593 .69409 L .22726 .70921 L p .623 .312 .482 r
F P
0 g
s
.38758 .37971 m .3593 .69409 L .34974 .66078 L p .948 .792 .258 r
F P
0 g
s
.34974 .66078 m .38157 .33663 L .38758 .37971 L p .948 .792 .258 r
F P
0 g
s
.61242 .37971 m .6407 .69409 L .59763 .7197 L p .138 .1 .45 r
F P
0 g
s
.74338 .31331 m .61843 .33663 L .61242 .37971 L p .704 .893 1 r
F P
0 g
s
.61242 .37971 m .6407 .69409 L .77274 .70921 L p .867 .511 .482 r
F P
0 g
s
.6407 .69409 m .61242 .37971 L .61843 .33663 L p .1 .1 .258 r
F P
0 g
s
.46531 .73331 m .43745 .77774 L .31959 .75508 L p .542 .912 1 r
F P
0 g
s
.43745 .77774 m .46531 .73331 L .53469 .73331 L p .542 .912 1 r
F P
0 g
s
.53469 .73331 m .56255 .77774 L .43745 .77774 L p .542 .912 1 r
F P
0 g
s
.56255 .77774 m .53469 .73331 L .59763 .7197 L p .542 .912 1 r
F P
0 g
s
.59763 .7197 m .68041 .75508 L .56255 .77774 L p .542 .912 1 r
F P
0 g
s
.34974 .66078 m .38157 .33663 L .25662 .31331 L p .867 .511 .482 r
F P
0 g
s
.65026 .66078 m .61843 .33663 L .74338 .31331 L p .623 .312 .482 r
F P
0 g
s
.61843 .33663 m .65026 .66078 L .6407 .69409 L p .1 .1 .258 r
F P
0 g
s
.65026 .66078 m .61843 .33663 L .59091 .29541 L p 1 .691 .229 r
F P
0 g
s
.61843 .33663 m .65026 .66078 L .81107 .64237 L p .623 .312 .482 r
F P
0 g
s
.81107 .64237 m .74338 .31331 L .61843 .33663 L p .623 .312 .482 r
F P
0 g
s
.38157 .33663 m .34974 .66078 L .38314 .62805 L p .1 .1 .229 r
F P
0 g
s
.38314 .62805 m .40909 .29541 L .38157 .33663 L p .1 .1 .229 r
F P
0 g
s
.25662 .31331 m .38157 .33663 L .40909 .29541 L p .704 .893 1 r
F P
0 g
s
.25662 .31331 m .18893 .64237 L .22726 .70921 L p 1 .866 .395 r
F P
0 g
s
.38157 .33663 m .34974 .66078 L .18893 .64237 L p .867 .511 .482 r
F P
0 g
s
.18893 .64237 m .25662 .31331 L .38157 .33663 L p .867 .511 .482 r
F P
0 g
s
.69691 .22159 m .59091 .29541 L .61843 .33663 L p .704 .893 1 r
F P
0 g
s
.61843 .33663 m .74338 .31331 L .69691 .22159 L p .704 .893 1 r
F P
0 g
s
.74338 .31331 m .81107 .64237 L .65026 .66078 L p .623 .312 .482 r
F P
0 g
s
.74338 .31331 m .81107 .64237 L .75927 .56719 L p .932 .603 .1 r
F P
0 g
s
.75927 .56719 m .69691 .22159 L .74338 .31331 L p .932 .603 .1 r
F P
0 g
s
.25662 .31331 m .18893 .64237 L .34974 .66078 L p .867 .511 .482 r
F P
0 g
s
.40909 .29541 m .30309 .22159 L .25662 .31331 L p .704 .893 1 r
F P
0 g
s
.18893 .64237 m .25662 .31331 L .30309 .22159 L p .1 .1 .1 r
F P
0 g
s
.40237 .7197 m .31959 .75508 L .22726 .70921 L p .542 .912 1 r
F P
0 g
s
.31959 .75508 m .40237 .7197 L .46531 .73331 L p .542 .912 1 r
F P
0 g
s
.68041 .75508 m .59763 .7197 L .6407 .69409 L p .542 .912 1 r
F P
0 g
s
.6407 .69409 m .77274 .70921 L .68041 .75508 L p .542 .912 1 r
F P
0 g
s
.61686 .62805 m .59091 .29541 L .53424 .26974 L p .966 .571 .387 r
F P
0 g
s
.40909 .29541 m .38314 .62805 L .24073 .56719 L p 1 .681 .424 r
F P
0 g
s
.24073 .56719 m .30309 .22159 L .40909 .29541 L p 1 .681 .424 r
F P
0 g
s
.59091 .29541 m .61686 .62805 L .65026 .66078 L p 1 .691 .229 r
F P
0 g
s
.61686 .62805 m .59091 .29541 L .69691 .22159 L p .26 .1 .424 r
F P
0 g
s
.59091 .29541 m .61686 .62805 L .75927 .56719 L p .26 .1 .424 r
F P
0 g
s
.75927 .56719 m .69691 .22159 L .59091 .29541 L p .26 .1 .424 r
F P
0 g
s
.57674 .15928 m .53424 .26974 L .59091 .29541 L p .704 .893 1 r
F P
0 g
s
.59091 .29541 m .69691 .22159 L .57674 .15928 L p .704 .893 1 r
F P
0 g
s
.38314 .62805 m .40909 .29541 L .30309 .22159 L p 1 .681 .424 r
F P
0 g
s
.30309 .22159 m .40909 .29541 L .46576 .26974 L p .704 .893 1 r
F P
0 g
s
.40909 .29541 m .38314 .62805 L .45562 .60722 L p .387 .1 .387 r
F P
0 g
s
.45562 .60722 m .46576 .26974 L .40909 .29541 L p .387 .1 .387 r
F P
0 g
s
.53424 .26974 m .54438 .60722 L .61686 .62805 L p .966 .571 .387 r
F P
0 g
s
.46576 .26974 m .42326 .15928 L .30309 .22159 L p .704 .893 1 r
F P
0 g
s
.45562 .60722 m .46576 .26974 L .42326 .15928 L p 1 .754 .247 r
F P
0 g
s
.42326 .15928 m .46576 .26974 L .53424 .26974 L p .704 .893 1 r
F P
0 g
s
.46576 .26974 m .45562 .60722 L .39685 .51348 L p 1 .754 .247 r
F P
0 g
s
.39685 .51348 m .42326 .15928 L .46576 .26974 L p 1 .754 .247 r
F P
0 g
s
.54438 .60722 m .53424 .26974 L .57674 .15928 L p .1 .1 .247 r
F P
0 g
s
.46576 .26974 m .45562 .60722 L .54438 .60722 L p .736 .366 .426 r
F P
0 g
s
.54438 .60722 m .53424 .26974 L .46576 .26974 L p .736 .366 .426 r
F P
0 g
s
.53424 .26974 m .54438 .60722 L .60315 .51348 L p .1 .1 .247 r
F P
0 g
s
.60315 .51348 m .57674 .15928 L .53424 .26974 L p .1 .1 .247 r
F P
0 g
s
.53424 .26974 m .57674 .15928 L .42326 .15928 L p .704 .893 1 r
F P
0 g
s
.22726 .70921 m .3593 .69409 L .40237 .7197 L p .542 .912 1 r
F P
0 g
s
.69691 .22159 m .75927 .56719 L .61686 .62805 L p .26 .1 .424 r
F P
0 g
s
.69691 .22159 m .75927 .56719 L .60315 .51348 L p .959 .524 .28 r
F P
0 g
s
.60315 .51348 m .57674 .15928 L .69691 .22159 L p .959 .524 .28 r
F P
0 g
s
.30309 .22159 m .24073 .56719 L .38314 .62805 L p 1 .681 .424 r
F P
0 g
s
.30309 .22159 m .24073 .56719 L .18893 .64237 L p .1 .1 .1 r
F P
0 g
s
.24073 .56719 m .30309 .22159 L .42326 .15928 L p .28 .1 .28 r
F P
0 g
s
.3593 .69409 m .22726 .70921 L .18893 .64237 L p .542 .912 1 r
F P
0 g
s
.77274 .70921 m .6407 .69409 L .65026 .66078 L p .542 .912 1 r
F P
0 g
s
.65026 .66078 m .81107 .64237 L .77274 .70921 L p .542 .912 1 r
F P
0 g
s
.18893 .64237 m .34974 .66078 L .3593 .69409 L p .542 .912 1 r
F P
0 g
s
.42326 .15928 m .39685 .51348 L .45562 .60722 L p 1 .754 .247 r
F P
0 g
s
.57674 .15928 m .60315 .51348 L .54438 .60722 L p .1 .1 .247 r
F P
0 g
s
.57674 .15928 m .60315 .51348 L .39685 .51348 L p .705 .295 .339 r
F P
0 g
s
.39685 .51348 m .42326 .15928 L .57674 .15928 L p .705 .295 .339 r
F P
0 g
s
.42326 .15928 m .39685 .51348 L .24073 .56719 L p .28 .1 .28 r
F P
0 g
s
.24073 .56719 m .38314 .62805 L .34974 .66078 L p .542 .912 1 r
F P
0 g
s
.34974 .66078 m .18893 .64237 L .24073 .56719 L p .542 .912 1 r
F P
0 g
s
.81107 .64237 m .65026 .66078 L .61686 .62805 L p .542 .912 1 r
F P
0 g
s
.61686 .62805 m .75927 .56719 L .81107 .64237 L p .542 .912 1 r
F P
0 g
s
.75927 .56719 m .61686 .62805 L .54438 .60722 L p .542 .912 1 r
F P
0 g
s
.39685 .51348 m .45562 .60722 L .38314 .62805 L p .542 .912 1 r
F P
0 g
s
.38314 .62805 m .24073 .56719 L .39685 .51348 L p .542 .912 1 r
F P
0 g
s
.54438 .60722 m .60315 .51348 L .75927 .56719 L p .542 .912 1 r
F P
0 g
s
.60315 .51348 m .54438 .60722 L .45562 .60722 L p .542 .912 1 r
F P
0 g
s
.45562 .60722 m .39685 .51348 L .60315 .51348 L p .542 .912 1 r
F P
0 g
s
.001 w
[ .01 .01 ] 0 setdash
.14717 .35243 m
.5 1e-05 L
s
.5 1e-05 m
.5 .38476 L
s
.5 .38476 m
.05027 .68811 L
s
.05027 .68811 m
.14717 .35243 L
s
.85283 .35243 m
.5 1e-05 L
s
.5 1e-05 m
.5 .38476 L
s
.5 .38476 m
.94973 .68811 L
s
.94973 .68811 m
.85283 .35243 L
s
.003 w
[ ] 0 setdash
.85283 .35243 m
.5 1e-05 L
s
.25 Mabswid
.84279 .34239 m
.83731 .34541 L
s
gsave
.85374 .33636 -61 -14.857 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.78005 .27973 m
.77473 .28301 L
s
gsave
.79069 .27316 -61 -15.3211 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.70723 .207 m
.70212 .21059 L
s
gsave
.71747 .19982 -61 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.62169 .12156 m
.61684 .1255 L
s
gsave
.63139 .11367 -61 -16.6908 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.51977 .01976 m
.51528 .0241 L
s
gsave
.52876 .01107 -61 -17.7625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.83095 .33056 m
.82768 .3324 L
s
.81877 .3184 m
.81552 .32027 L
s
.80623 .30588 m
.803 .30778 L
s
.79333 .293 m
.79012 .29493 L
s
.76637 .26606 m
.7632 .26807 L
s
.75226 .25198 m
.74912 .25402 L
s
.73772 .23745 m
.7346 .23953 L
s
.72272 .22247 m
.71962 .22458 L
s
.69124 .19103 m
.6882 .19322 L
s
.67472 .17452 m
.67171 .17676 L
s
.65764 .15747 m
.65466 .15974 L
s
.63998 .13982 m
.63703 .14214 L
s
.60276 .10265 m
.59989 .10506 L
s
.58314 .08305 m
.58031 .08551 L
s
.56279 .06273 m
.56 .06524 L
s
.54169 .04165 m
.53894 .0442 L
s
gsave
.76863 .16392 -61 -15.9123 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
75.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00M`3IfMT4000000<0fMWI0`00
000F0=WIf@@000000`3IfMT3000007l0fMWI001g0=WIf@070000003IfMT0fMWI0=WIf@000000fMWI
000000030=WIf@030000003IfMT0fMWI01<0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT00000
00<0fMWI00<000000=WIf@3IfMT0O03IfMT007P0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000
fMWI0=WIf@3IfMT0000001H0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0
000007h0fMWI001i0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT00`000000fMWI0=WIf@0E
0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT00`000000fMWI0=WIf@1l0=WIf@00NP3IfMT0
10000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01H0fMWI00@000000=WIf@3IfMT00000
0`3IfMT00`000000fMWI0=WIf@1l0=WIf@00NP3IfMT010000000fMWI0=WIf@0000030=WIf@030000
003IfMT0fMWI01H0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@1l0=WIf@00
M`3IfMT010000000fMWI0=WIf@0000020=WIf@050000003IfMT0fMWI0=WIf@0000005@3IfMT01000
0000fMWI0=WIf@0000020=WIf@050000003IfMT0fMWI0=WIf@000000OP3IfMT007P0fMWI0P000004
0=WIf@<00000303IfMT00`000000fMWI0=WIf@080=WIf@800000103IfMT3000007l0fMWI002<0=WI
f@800000TP3IfMT008/0fMWI00@000000=WIf@0000000000T@3IfMT008X0fMWI00H000000=WIf@3I
fMT000000=WIf@00002@0=WIf@00R@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
08d0fMWI00280=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT008L0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI08/0fMWI
00260=WIf@030000003IfMT0000000@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000008`0
fMWI00250=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@290=WIf@00Q03IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT0R03IfMT008<0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@27
0=WIf@00PP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0QP3IfMT00840fMWI0P00000:0=WIf@030000003IfMT0fMWI00L0fMWI0P0000270=WIf@00
P03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
Q03IfMT007l0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI08<0fMWI001n0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0PP3IfMT0
07d0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@210=WIf@00O03IfMT00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0P03IfMT007/0fMWI
0P00000@0=WIf@030000003IfMT0fMWI00d0fMWI0P0000210=WIf@00NP3IfMT00`000000fMWI0=WI
f@0@0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0OP3IfMT007T0fMWI00<00000
0=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI07d0fMWI001g0=WI
f@800000:03IfMT2000007d0fMWI001f0=WIf@8000005@3IfMT00`000000fMWI0=WIf@0B0=WIf@80
0000O03IfMT005`0fMWI0`0000020=WIf@<000004@3IfMT2000001H0fMWI00<000000=WIf@3IfMT0
4`3IfMT200000100fMWI0`0000020=WIf@<00000H`3IfMT005d0fMWI00@000000=WIf@3IfMT00000
0`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0000001D0fMWI00<000000=WIf@3IfMT0
4`3IfMT200000140fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@1P0=WIf@00
G@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3I
fMT05P3IfMT00`000000fMWI0=WIf@0E0=WIf@8000003`3IfMT010000000fMWI0=WIf@0000030=WI
f@030000003IfMT0fMWI0600fMWI001M0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WI
f@3IfMT0303IfMT00`000000fMWI0=WIf@0`0=WIf@8000003P3IfMT010000000fMWI0=WIf@000003
0=WIf@030000003IfMT0fMWI0600fMWI001M0=WIf@040000003IfMT0fMWI000000<0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0b0=WIf@8000003@3IfMT010000000fMWI0=WIf@00
00030=WIf@030000003IfMT0fMWI0600fMWI001M0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01P0fMWI00<0
00000=WIf@3IfMT02`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0600fMWI
001M0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT02@3IfMT2000001/0fMWI
00<000000=WIf@3IfMT0603IfMT3000000/0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000
fMWI0=WIf@1P0=WIf@00G03IfMT2000000<0fMWI0`00000;0=WIf@030000003IfMT0fMWI01/0fMWI
00<000000=WIf@3IfMT06P3IfMT2000000T0fMWI0P0000030=WIf@<00000H`3IfMT006h0fMWI00<0
00000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0K0=WIf@800000L`3IfMT006d0fMWI00<00000
0=WIf@3IfMT0?03IfMT00`000000fMWI0=WIf@1a0=WIf@00K03IfMT00`000000fMWI0=WIf@0N0=WI
f@030000003IfMT0fMWI01d0fMWI0P00001a0=WIf@00J`3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00001`0=WIf@00JP3IfMT00`000000fMWI0000000P0=WIf@030000
003IfMT0fMWI01d0fMWI00@000000=WIf@0000000000K`3IfMT006T0fMWI00<000000=WIf@3IfMT0
8@3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI06d0fMWI001X0=WIf@030000003I
fMT0fMWI04H0fMWI0P00001]0=WIf@00>03IfMT3000002`0fMWI00<000000=WIf@3IfMT0B03IfMT0
0`000000fMWI0=WIf@0T0=WIf@<000000P3IfMT3000003l0fMWI000i0=WIf@030000003IfMT0fMWI
02X0fMWI0P00000U0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT09@3IfMT01000
0000fMWI0=WIf@0000110=WIf@00>@3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI
02D0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0T0=WIf@040000003IfMT0fMWI
00000440fMWI000i0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT09P3IfMT00`00
0000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI02@0fMWI0P0000120=WIf@00>03IfMT00`000000
fMWI0000000X0=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000
fMWI0=WIf@0S0=WIf@800000@P3IfMT003P0fMWI00<000000=WIf@0000009`3IfMT00`000000fMWI
0=WIf@1B0=WIf@030000003IfMT0fMWI0240fMWI00@000000=WIf@3IfMT00000@@3IfMT003L0fMWI
00D000000=WIf@3IfMT0fMWI0000000U0=WIf@8000004`3IfMT^000001<0fMWI0P00000R0=WIf@04
0000003IfMT0fMWI00000440fMWI000f0=WIf@<0000000@0fMWI00000000000000008`3IfMT00`00
0000fMWI0=WIf@0A0=WIf@80000000<0AaU70000002dBeH0502dBeH00`000000]4]F0;A;EP0B0;A;
EP040000003eQTL00000000001<0fMWI00<000000=WIf@3IfMT07@3IfMT300000080fMWI0`00000o
0=WIf@00G`3IfMT00`000000fMWI0=WIf@0@0=WIf@8000000`176DL00`000000]4]F0;A;EP0C0;A;
EP030000002dBeH0]4]F0180]4]F00@000000?F6A`3eQTL0mHI70P00000B0=WIf@030000003IfMT0
fMWI06<0fMWI001:0=WIf@<000004@3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@176DL00`00
0000]4]F0;A;EP0C0;A;EP030000002dBeH0]4]F0180]4]F00<000000?F6A`3eQTL00`3eQTL20000
0140fMWI00<000000=WIf@3IfMT03P3IfMT300000540fMWI00190=WIf@050000003IfMT0fMWI0=WI
f@0000003P3IfMT200000100fMWI0P00000704LIA`030000002dBeH0]4]F02P0]4]F00<000000?F6
A`3eQTL01@3eQTL200000100fMWI0P00000=0=WIf@050000003IfMT0fMWI0=WIf@000000D03IfMT0
04T0fMWI00D000000=WIf@3IfMT0fMWI0000000>0=WIf@8000003P3IfMT2000000T0AaU700<00000
0;A;EP2dBeH0:02dBeH00`000000mHI70?F6A`070?F6A`8000003P3IfMT2000000d0fMWI00D00000
0=WIf@3IfMT0fMWI0000001@0=WIf@00B@3IfMT01@000000fMWI0=WIf@3IfMT0000000d0fMWI00<0
00000=WIf@3IfMT0303IfMT2000000/0AaU700<000000;A;EP2dBeH04`2dBeH00`000000]4]F0;A;
EP0B0;A;EP030000003eQTL0mHI700T0mHI70P00000>0=WIf@030000003IfMT0fMWI00X0fMWI00D0
00000=WIf@3IfMT0fMWI0000001@0=WIf@00B@3IfMT01@000000fMWI0=WIf@3IfMT0000000`0fMWI
00<000000=WIf@3IfMT02`3IfMT2000000d0AaU700<000000;A;EP2dBeH04`2dBeH00`000000]4]F
0;A;EP0B0;A;EP030000003eQTL0mHI700/0mHI70P00000=0=WIf@030000003IfMT0fMWI00T0fMWI
00D000000=WIf@3IfMT0fMWI0000001@0=WIf@00B@3IfMT01@000000fMWI0=WIf@3IfMT0000000/0
fMWI00<000000=WIf@3IfMT02P3IfMT2000000h0AaU700<000000;A;EP2dBeH0502dBeH00`000000
]4]F0;A;EP0C0;A;EP030000003eQTL0mHI700`0mHI70P00000<0=WIf@030000003IfMT0fMWI00P0
fMWI00D000000=WIf@3IfMT0fMWI0000001@0=WIf@00B@3IfMT01@000000fMWI0=WIf@3IfMT00000
00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000AaU704LIA`0>04LIA`030000002dBeH0]4]F
01@0]4]F00<000000;A;EP2dBeH04`2dBeH00`000000mHI70?F6A`0>0?F6A`030000003IfMT0fMWI
00X0fMWI0P0000080=WIf@050000003IfMT0fMWI0=WIf@000000D03IfMT004X0fMWI0`00000:0=WI
f@030000003IfMT0000000T0fMWI0P00000A04LIA`030000002dBeH0]4]F02X0]4]F00<000000?F6
A`3eQTL03`3eQTL2000000X0fMWI0P0000090=WIf@<00000D@3IfMT005H0fMWI00<000000=WIf@3I
fMT0203IfMT2000001<0AaU700<000000;A;EP2dBeH0:P2dBeH00`000000mHI70?F6A`0A0?F6A`80
00002P3IfMT00`000000fMWI0=WIf@1J0=WIf@00E@3IfMT00`000000fMWI0=WIf@070=WIf@800000
5@176DL00`000000]4]F0;A;EP0D0;A;EP030000002dBeH0]4]F01<0]4]F00<000000?F6A`3eQTL0
4`3eQTL2000000T0fMWI00<000000=WIf@3IfMT0F@3IfMT005<0fMWI0P0000080=WIf@8000005`17
6DL00`000000]4]F0;A;EP0D0;A;EP030000002dBeH0]4]F01<0]4]F00<000000?F6A`3eQTL05@3e
QTL2000000P0fMWI0P00001I0=WIf@00D`3IfMT00`000000fMWI000000050=WIf@8000006@176DL0
0`000000]4]F0;A;EP0D0;A;EP030000002dBeH0]4]F01<0]4]F00<000000?F6A`3eQTL05`3eQTL2
000000H0fMWI0P00001I0=WIf@00DP3IfMT00`000000fMWI0=WIf@040=WIf@8000006`176DL00`00
0000]4]F0;A;EP0Z0;A;EP030000003eQTL0mHI701T0mHI70P0000060=WIf@030000003IfMT0fMWI
05H0fMWI001A0=WIf@030000003IfMT0fMWI00<0fMWI0P00000M04LIA`030000002dBeH0]4]F02X0
]4]F00<000000?F6A`3eQTL06`3eQTL2000000D0fMWI00<000000=WIf@3IfMT0E@3IfMT004l0fMWI
0P0000050=WIf@03000000176DL0AaU701d0AaU700<000000;A;EP2dBeH0502dBeH00`000000]4]F
0;A;EP0C0;A;EP030000003eQTL0mHI701d0mHI700<000000=WIf@3IfMT00`3IfMT2000005D0fMWI
001>0=WIf@<000001@3IfMT00`000000AaU704LIA`0M04LIA`030000002dBeH0]4]F01@0]4]F00<0
00000;A;EP2dBeH04`2dBeH00`000000mHI70?F6A`0M0?F6A`030000003IfMT0fMWI00<0fMWI0`00
001D0=WIf@00CP3IfMT00`000000fMWI0=WIf@040=WIf@8000007`176DL00`000000]4]F0;A;EP0D
0;A;EP030000002dBeH0]4]F01<0]4]F00<000000?F6A`3eQTL07@3eQTL2000000H0fMWI00<00000
0=WIf@3IfMT0DP3IfMT004`0fMWI0P0000070=WIf@8000007`176DL00`000000]4]F0;A;EP0D0;A;
EP030000002dBeH0]4]F01<0]4]F00<000000?F6A`3eQTL07@3eQTL2000000L0fMWI0P00001B0=WI
f@00B`3IfMT2000000L0fMWI0P00000P04LIA`030000002dBeH0]4]F02X0]4]F00<000000?F6A`3e
QTL07P3eQTL2000000L0fMWI0P00001A0=WIf@00BP3IfMT3000000L0fMWI0P00000O04LIA`030000
002dBeH0]4]F02`0]4]F00<000000?F6A`3eQTL07@3eQTL2000000P0fMWI0P00001@0=WIf@00BP3I
fMT00`000000fMWI0=WIf@060=WIf@030000000I6AT0000001l0AaU700<000000;A;EP2dBeH05@2d
BeH00`000000]4]F0;A;EP0D0;A;EP030000003eQTL0mHI701d0mHI700<000000>jJ6@000000203I
fMT00`000000fMWI0=WIf@1>0=WIf@00<03IfMT300000080fMWI0`00000A0=WIf@030000003IfMT0
fMWI00L0fMWI00<0000001TI6@0000007`176DL00`000000]4]F0;A;EP0E0;A;EP030000002dBeH0
]4]F01@0]4]F00<000000?F6A`3eQTL07@3eQTL00`000000kYXI000000090=WIf@800000603IfMT3
00000080fMWI0`00000^0=WIf@00<@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00d0fMWI00<000000=WIf@3IfMT01`3IfMT0100000006ATI01TI6@00000O04LIA`030000002d
BeH0]4]F01D0]4]F00<000000;A;EP2dBeH0502dBeH00`000000mHI70?F6A`0M0?F6A`040000003^
VQT0kYXI000000T0fMWI0P00000H0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3I
fMT0:`3IfMT00340fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0<0=WIf@80
00002@3IfMT00`0000006ATI0000000P04LIA`030000002dBeH0]4]F02`0]4]F00<000000?F6A`3e
QTL07P3eQTL00`000000kYXI0000000:0=WIf@8000005`3IfMT010000000fMWI0=WIf@0000030=WI
f@030000003IfMT0fMWI02/0fMWI000V0=WIf@L00000103IfMT010000000fMWI0=WIf@0000030=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0203IfMT0100000006ATI01TI6@00000P
04LIA`030000002dBeH0]4]F02`0]4]F00<000000?F6A`3eQTL07P3eQTL010000000kYXI0>jJ6@00
000:0=WIf@030000003IfMT0fMWI00X0fMWI1`0000040=WIf@040000003IfMT0fMWI000000<0fMWI
00<000000=WIf@3IfMT0:`3IfMT00340fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00@0000001TI6@0I6AT0000080176DL00`000000
]4]F0;A;EP0E0;A;EP030000002dBeH0]4]F01@0]4]F00<000000?F6A`3eQTL07P3eQTL010000000
kYXI0>jJ6@00000;0=WIf@8000005@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI02/0fMWI000a0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@090=WIf@050000000I6AT06ATI01TI6@00000080176DL00`000000]4]F0;A;
EP0E0;A;EP030000002dBeH0]4]F01@0]4]F00<000000?F6A`3eQTL07P3eQTL01@000000kYXI0>jJ
6@3^VQT0000000/0fMWI0P00000D0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3I
fMT0:`3IfMT00340fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@080=WIf@80
00002`3IfMT01@0000006ATI01TI6@0I6AT000000200AaU700<000000;A;EP2dBeH05@2dBeH00`00
0000]4]F0;A;EP0D0;A;EP030000003eQTL0mHI701h0mHI700D000000>jJ6@3^VQT0kYXI0000000;
0=WIf@<000004`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI02/0fMWI000`
0=WIf@8000000`3IfMT3000000X0fMWI00<000000=WIf@3IfMT02P3IfMT00`0000006ATI01TI6@02
01TI6@03000000176DL0AaU701h0AaU700<000000;A;EP2dBeH05@2dBeH00`000000]4]F0;A;EP0D
0;A;EP030000003eQTL0mHI701h0mHI700<000000>jJ6@3^VQT00P3^VQT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0100fMWI0P0000030=WIf@<00000;P3IfMT00440fMWI00<000000=WI
f@3IfMT02`3IfMT01@0000006ATI01TI6@0I6AT000000240AaU700<000000;A;EP2dBeH0;02dBeH0
0`000000mHI70?F6A`0O0?F6A`050000003^VQT0kYXI0>jJ6@0000003@3IfMT2000004H0fMWI000o
0=WIf@8000003@3IfMT00`0000006ATI01TI6@0201TI6@03000000176DL0AaU701l0AaU700<00000
0;A;EP2dBeH0;02dBeH00`000000mHI70?F6A`0O0?F6A`030000003^VQT0kYXI0080kYXI00<00000
0=WIf@3IfMT02`3IfMT2000004D0fMWI000o0=WIf@030000003IfMT0000000`0fMWI00<0000001TI
6@0I6AT00P0I6AT00`000000AaU704LIA`0O04LIA`030000002dBeH0]4]F01D0]4]F00<000000;A;
EP2dBeH0502dBeH00`000000mHI70?F6A`0O0?F6A`030000003^VQT0kYXI0080kYXI00<000000=WI
f@3IfMT02`3IfMT3000004@0fMWI000n0=WIf@030000003IfMT0fMWI00`0fMWI00<0000001TI6@0I
6AT00`0I6AT00`000000AaU704LIA`0O04LIA`030000002dBeH0]4]F01D0]4]F00<000000;A;EP2d
BeH0502dBeH00`000000mHI70?F6A`0O0?F6A`030000003^VQT0kYXI00<0kYXI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@120=WIf@00?@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000
000I6AT06ATI00<06ATI00<0000004LIA`176DL07P176DL00`000000]4]F0;A;EP0F0;A;EP030000
002dBeH0]4]F01D0]4]F00<000000?F6A`3eQTL07P3eQTL00`000000kYXI0>jJ6@030>jJ6@030000
003IfMT0fMWI00d0fMWI0P0000120=WIf@00?03IfMT00`000000fMWI0=WIf@0=0=WIf@030000000I
6AT06ATI00@06ATI00<0000004LIA`176DL07P176DL00`000000]4]F0;A;EP0^0;A;EP030000003e
QTL0mHI701h0mHI700<000000>jJ6@3^VQT0103^VQT00`000000fMWI0=WIf@0=0=WIf@800000@@3I
fMT003/0fMWI00<000000=WIf@0000003P3IfMT00`0000006ATI01TI6@0301TI6@03000000176DL0
AaU701l0AaU700<000000;A;EP2dBeH0;P2dBeH00`000000mHI70?F6A`0O0?F6A`030000003^VQT0
kYXI00<0kYXI00<000000=WIf@3IfMT03@3IfMT200000440fMWI000j0=WIf@030000003IfMT0fMWI
00h0fMWI00<0000001TI6@0I6AT0100I6AT00`000000AaU704LIA`0O04LIA`030000002dBeH0]4]F
01H0]4]F00<000000;A;EP2dBeH05@2dBeH00`000000mHI70?F6A`0O0?F6A`030000003^VQT0kYXI
00@0kYXI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0n0=WIf@00>@3IfMT00`000000
fMWI0=WIf@0?0=WIf@030000000I6AT06ATI00@06ATI00<0000004LIA`176DL07`176DL00`000000
]4]F0;A;EP0F0;A;EP030000002dBeH0]4]F01D0]4]F00<000000?F6A`3eQTL07`3eQTL00`000000
kYXI0>jJ6@040>jJ6@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0?@3IfMT003P0fMWI
0P00000@0=WIf@030000000I6AT06ATI00D06ATI00<0000004LIA`176DL07`176DL00`000000]4]F
0;A;EP0F0;A;EP030000002dBeH0]4]F01D0]4]F00<000000?F6A`3eQTL07`3eQTL00`000000kYXI
0>jJ6@050>jJ6@030000003IfMT0fMWI00h0fMWI0P00000n0=WIf@007@3IfMT4000000<0fMWI0`00
000@0=WIf@030000003IfMT0fMWI0100fMWI00<0000001TI6@0I6AT01@0I6AT00`000000AaU704LI
A`0O04LIA`030000002dBeH0]4]F01H0]4]F00<000000;A;EP2dBeH05@2dBeH00`000000mHI70?F6
A`0O0?F6A`030000003^VQT0kYXI00D0kYXI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WI
f@0D0=WIf@@000000`3IfMT3000001d0fMWI000M0=WIf@070000003IfMT0fMWI0=WIf@000000fMWI
000000030=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0403IfMT00`0000006ATI
01TI6@0501TI6@03000000176DL0AaU70200AaU700<000000;A;EP2dBeH0;P2dBeH00`000000mHI7
0?F6A`0P0?F6A`030000003^VQT0kYXI00D0kYXI00<000000=WIf@3IfMT0403IfMT00`000000fMWI
0=WIf@0C0=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000030=WIf@030000003IfMT0fMWI
01X0fMWI000N0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI0000000=0=WI
f@030000003IfMT0fMWI0140fMWI00<0000001TI6@0I6AT01@0I6AT00`000000AaU704LIA`0P04LI
A`030000002dBeH0]4]F02h0]4]F00<000000?F6A`3eQTL0803eQTL00`000000kYXI0>jJ6@050>jJ
6@030000003IfMT0fMWI0140fMWI0P00000D0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WI
f@3IfMT0fMWI0000000L0=WIf@005@3IfMT7000000<0fMWI00D000000=WIf@3IfMT0fMWI00000003
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@0000004P3IfMT00`0000006ATI01TI6@05
01TI6@03000000176DL0AaU70200AaU700<000000;A;EP2dBeH05P2dBeH00`000000]4]F0;A;EP0E
0;A;EP030000003eQTL0mHI70200mHI700<000000>jJ6@3^VQT01@3^VQT00`000000fMWI0=WIf@0A
0=WIf@8000002`3IfMT7000000<0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003I
fMT0fMWI01X0fMWI000P0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@0C0=WIf@030000000I6AT06ATI00D06ATI00<0000004LIA`176DL08017
6DL00`000000]4]F0;A;EP0F0;A;EP030000002dBeH0]4]F01D0]4]F00<000000?F6A`3eQTL0803e
QTL00`000000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT04`3I
fMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01X0fMWI000P0=WIf@040000003I
fMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0C0=WIf@030000
000I6AT06ATI00H06ATI00<0000004LIA`176DL080176DL00`000000]4]F0;A;EP0F0;A;EP030000
002dBeH0]4]F01D0]4]F00<000000?F6A`3eQTL0803eQTL00`000000kYXI0>jJ6@060>jJ6@030000
003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT02`3IfMT3000000@0fMWI00@000000=WIf@3IfMT0
00000`3IfMT00`000000fMWI0=WIf@0J0=WIf@007@3IfMT010000000fMWI0=WIf@0000020=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT2000001D0fMWI00<0000001TI6@0I6AT01P0I6AT00`00
0000AaU704LIA`0P04LIA`030000002dBeH0]4]F02h0]4]F00<000000?F6A`3eQTL0803eQTL00`00
0000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI01<0fMWI0P00000;0=WIf@040000003IfMT0fMWI
0=WIf@8000000P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01X0fMWI000N
0=WIf@800000103IfMT3000000T0fMWI00<000000=WIf@3IfMT05@3IfMT00`0000006ATI01TI6@05
01TI6@03000000176DL0AaU70240AaU700<000000;A;EP2dBeH0;P2dBeH00`000000mHI70?F6A`0Q
0?F6A`030000003^VQT0kYXI00D0kYXI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@08
0=WIf@060000003IfMT0fMWI0=WIf@000000fMWI0P0000040=WIf@<000007@3IfMT002l0fMWI00<0
00000=WIf@3IfMT05P3IfMT00`0000006ATI01TI6@0501TI6@03000000176DL0AaU70200AaU700<0
00000;A;EP2dBeH05`2dBeH00`000000]4]F0;A;EP0F0;A;EP030000003eQTL0mHI70200mHI700<0
00000>jJ6@3^VQT01@3^VQT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00L0fMWI00D0
00000=WIf@3IfMT0fMWI0000000W0=WIf@00;P3IfMT2000001P0fMWI00<0000001TI6@0I6AT01@0I
6AT00`000000AaU704LIA`0P04LIA`030000002dBeH0]4]F01L0]4]F00<000000;A;EP2dBeH05P2d
BeH00`000000mHI70?F6A`0P0?F6A`030000003^VQT0kYXI00H0kYXI00<000000=WIf@3IfMT05P3I
fMT00`000000fMWI0=WIf@060=WIf@050000003IfMT0fMWI0=WIf@0000009`3IfMT002d0fMWI00@0
00000=WIf@3IfMT000005P3IfMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU70200AaU7
00<000000;A;EP2dBeH05`2dBeH00`000000]4]F0;A;EP0F0;A;EP030000003eQTL0mHI70200mHI7
00<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0000000L0fMWI
00D000000=WIf@3IfMT0fMWI0000000W0=WIf@00;03IfMT00`000000fMWI0=WIf@0H0=WIf@030000
000I6AT06ATI00H06ATI00<0000004LIA`176DL080176DL00`000000]4]F0;A;EP0G0;A;EP030000
002dBeH0]4]F01H0]4]F00<000000?F6A`3eQTL0803eQTL00`000000kYXI0>jJ6@060>jJ6@030000
003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000002L0
fMWI000[0=WIf@<000006@3IfMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU70200AaU7
00<000000;A;EP2dBeH0<02dBeH00`000000mHI70?F6A`0P0?F6A`030000003^VQT0kYXI00H0kYXI
00<000000=WIf@3IfMT0603IfMT2000000H0fMWI0`00000X0=WIf@00:`3IfMT010000000fMWI0=WI
f@00000H0=WIf@030000000I6AT06ATI00D06ATI00<0000004LIA`176DL08@176DL00`000000]4]F
0;A;EP0`0;A;EP030000003eQTL0mHI70240mHI700<000000>jJ6@3^VQT01@3^VQT00`000000fMWI
0=WIf@0G0=WIf@040000003IfMT0000000000300fMWI000Z0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0503IfMT00`0000006ATI01TI6@0501TI6@03000000176DL0AaU70240AaU7
00<000000;A;EP2dBeH05`2dBeH00`000000]4]F0;A;EP0F0;A;EP030000003eQTL0mHI70240mHI7
00<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0C0=WIf@040000003IfMT0fMWI0=WIf@<0
0000<03IfMT00340fMWI00<000000=WIf@3IfMT04P3IfMT00`0000006ATI01TI6@0601TI6@030000
00176DL0AaU70240AaU700<000000;A;EP2dBeH05`2dBeH00`000000]4]F0;A;EP0F0;A;EP030000
003eQTL0mHI70240mHI700<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0B0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0;P3IfMT00380fMWI00<000000=WIf@3IfMT04@3I
fMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU70240AaU700<000000;A;EP2dBeH05`2d
BeH00`000000]4]F0;A;EP0F0;A;EP030000003eQTL0mHI70240mHI700<000000>jJ6@3^VQT01P3^
VQT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0;P3I
fMT002X0fMWI00<000000=WIf@3IfMT0203IfMT2000000l0fMWI00<0000001TI6@0I6AT01P0I6AT0
0`000000AaU704LIA`0Q04LIA`030000002dBeH0]4]F0300]4]F00<000000?F6A`3eQTL08@3eQTL0
0`000000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI00d0fMWI0P00000:0=WIf@800000;`3IfMT0
02X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000000I6AT06ATI
00D06ATI00<0000004LIA`176DL08P176DL00`000000]4]F0;A;EP0`0;A;EP030000003eQTL0mHI7
0280mHI700<000000>jJ6@3^VQT01@3^VQT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00/0fMWI00<000000=WIf@3IfMT0;@3IfMT002T0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000
6ATI01TI6@0501TI6@03000000176DL0AaU70280AaU700<000000;A;EP2dBeH05`2dBeH00`000000
]4]F0;A;EP0F0;A;EP030000003eQTL0mHI70280mHI700<000000>jJ6@3^VQT01P3^VQT00`000000
fMWI0=WIf@0H0=WIf@800000;`3IfMT003X0fMWI0P0000090=WIf@030000000I6AT06ATI00H06ATI
00<0000004LIA`176DL08P176DL00`000000]4]F0;A;EP0G0;A;EP030000002dBeH0]4]F01H0]4]F
00<000000?F6A`3eQTL08P3eQTL00`000000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI00P0fMWI
0P00000?0=WIf@030000003IfMT0fMWI02d0fMWI000l0=WIf@030000003IfMT0fMWI00H0fMWI00<0
000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0R04LIA`030000002dBeH0]4]F01H0]4]F0`00
000G0;A;EP030000003eQTL0mHI70280mHI700<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WI
f@060=WIf@8000004@3IfMT00`000000fMWI0=WIf@0]0=WIf@00:03IfMT00`000000fMWI0=WIf@0D
0=WIf@800000103IfMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU70240AaU700<00000
0;A;EP2dBeH05@2dBeH2000000<0]4]F00<000000;A;EP2dBeH05@2dBeH00`000000mHI70?F6A`0Q
0?F6A`030000003^VQT0kYXI00H0kYXI00<000000=WIf@3IfMT00`3IfMT2000001D0fMWI00<00000
0=WIf@3IfMT0;03IfMT002P0fMWI00<000000=WIf@3IfMT05P3IfMT01@000000fMWI0=WIf@3IfMT0
000000P06ATI00<0000004LIA`176DL08@176DL00`000000]4]F0;A;EP0b0;A;EP030000003eQTL0
mHI70240mHI700<000000>jJ6@3^VQT01P3^VQT010000000fMWI0=WIf@3IfMT2000001L0fMWI00<0
00000=WIf@3IfMT0;03IfMT002L0fMWI00<000000=WIf@3IfMT06`3IfMT00`0000006ATI01TI6@05
01TI6@03000000176DL0AaU70280AaU700<000000;A;EP2dBeH04P2dBeH2000000P0]4]F0`00000C
0;A;EP030000003eQTL0mHI70280mHI700<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0I
0=WIf@800000;@3IfMT002L0fMWI00<000000=WIf@3IfMT06@3IfMT2000000P06ATI00<0000004LI
A`176DL08P176DL00`000000]4]F0;A;EP0A0;A;EP030000002dBeH0]4]F00/0]4]F00<000000;A;
EP2dBeH0402dBeH00`000000mHI70?F6A`0R0?F6A`030000003^VQT0kYXI00H0kYXI0P00000K0=WI
f@030000003IfMT0fMWI02/0fMWI00140=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`17
6DL08P176DL00`000000]4]F0;A;EP0b0;A;EP030000003eQTL0mHI70280mHI700<000000>jJ6@3^
VQT01P3^VQT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI02/0fMWI000W0=WIf@030000
003IfMT0fMWI01X0fMWI00<0000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0R04LIA`030000
002dBeH0]4]F00h0]4]F0P00000A0;A;EP8000003`2dBeH00`000000mHI70?F6A`0R0?F6A`030000
003^VQT0kYXI00H0kYXI00<000000=WIf@3IfMT06P3IfMT2000002`0fMWI000W0=WIf@030000003I
fMT0fMWI01X0fMWI00<0000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0R04LIA`030000002d
BeH0]4]F00`0]4]F0P00000E0;A;EP030000002dBeH0]4]F00`0]4]F00<000000?F6A`3eQTL08P3e
QTL00`000000kYXI0>jJ6@070>jJ6@030000003IfMT0fMWI01T0fMWI0P00000/0=WIf@009P3IfMT0
0`000000fMWI0=WIf@0K0=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`176DL08P176DL0
0`000000]4]F0;A;EP0b0;A;EP030000003eQTL0mHI70280mHI700<000000>jJ6@3^VQT01`3^VQT0
0`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI02X0fMWI000V0=WIf@030000003IfMT0fMWI
01X0fMWI00<0000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0S04LIA`030000002dBeH0]4]F
00T0]4]F0P00000J0;A;EP<000002P2dBeH00`000000mHI70?F6A`0S0?F6A`030000003^VQT0kYXI
00H0kYXI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00@`3IfMT00`000000
6ATI01TI6@0601TI6@03000000176DL0AaU702<0AaU700<000000;A;EP2dBeH0202dBeH00`000000
]4]F0;A;EP0M0;A;EP030000002dBeH0]4]F00L0]4]F00<000000?F6A`3eQTL08`3eQTL00`000000
kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT01`3IfMT300000080
fMWI0`00000K0=WIf@00@`3IfMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU702<0AaU7
00<000000;A;EP2dBeH0<P2dBeH00`000000mHI70?F6A`0S0?F6A`030000003^VQT0kYXI00H0kYXI
00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@070=WIf@040000003IfMT0fMWI000000<0
fMWI00<000000=WIf@3IfMT0603IfMT002D0fMWI00<000000=WIf@3IfMT06`3IfMT00`0000006ATI
01TI6@0601TI6@03000000176DL0AaU702<0AaU700<000000;A;EP2dBeH0102dBeH2000002@0]4]F
0P0000060;A;EP030000003eQTL0mHI702<0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI
0=WIf@0J0=WIf@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000
fMWI0=WIf@0H0=WIf@009@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000000I6AT06ATI00H06ATI
00<0000004LIA`176DL08`176DL00`000000]4]F0;A;EP030;A;EP030000002dBeH0]4]F02H0]4]F
00<000000;A;EP2dBeH00`2dBeH00`000000mHI70?F6A`0S0?F6A`030000003^VQT0kYXI00L0kYXI
00<000000=WIf@3IfMT06@3IfMT2000000T0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000
fMWI0=WIf@0H0=WIf@00903IfMT00`000000fMWI0=WIf@0K0=WIf@030000000I6AT06ATI00H06ATI
00<0000004LIA`176DL090176DL00`000000]4]F0;A;EP0b0;A;EP030000003eQTL0mHI702@0mHI7
00<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI00H0fMWI
00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0H0=WIf@00@P3IfMT00`0000006ATI
01TI6@0601TI6@03000000176DL0AaU702<0AaU700@000000;A;EP2dBeH0]4]F0P00000]0;A;EP05
0000002dBeH0]4]F0;A;EP0000009@3eQTL00`000000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI
01/0fMWI00<000000=WIf@3IfMT01P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI01P0fMWI00120=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`176DL08`176DL01000
0000]4]F0;A;EP00000`0;A;EP040000002dBeH0]4]F000002D0mHI700<000000>jJ6@3^VQT01P3^
VQT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI00H0fMWI00@000000=WIf@3IfMT00000
0`3IfMT00`000000fMWI0=WIf@0H0=WIf@00903IfMT00`000000fMWI0=WIf@0K0=WIf@030000000I
6AT06ATI00H06ATI00<0000004LIA`176DL08`176DL00`000000]4]F0000000b0;A;EP030000002d
BeH0000002D0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI0=WIf@0J0=WIf@8000001P3I
fMT2000000<0fMWI0`00000:0=WIf@H000002`3IfMT002@0fMWI00<000000=WIf@3IfMT06`3IfMT0
0`0000006ATI01TI6@0601TI6@03000000176DL0AaU702<0AaU700<000000;A;EP2dBeH0=02dBeH0
0`000000mHI70?F6A`0S0?F6A`030000003^VQT0kYXI00L0kYXI00<000000=WIf@3IfMT06@3IfMT0
0`000000fMWI0000000I0=WIf@050000003IfMT0fMWI0=WIf@0000002`3IfMT002<0fMWI00<00000
0=WIf@3IfMT06`3IfMT00`0000006ATI01TI6@0701TI6@03000000176DL0AaU70280AaU70P00000f
0;A;EP800000903eQTL00`000000kYXI0>jJ6@070>jJ6@030000003IfMT0fMWI01/0fMWI0P00000H
0=WIf@030000003IfMT0fMWI00d0fMWI000S0=WIf@030000003IfMT0fMWI01/0fMWI00<0000001TI
6@0I6AT01P0I6AT00`000000AaU704LIA`0R04LIA`03000000176DL0000003H0]4]F00<000000?F6
A`000000903eQTL00`000000kYXI0>jJ6@060>jJ6@030000003IfMT0fMWI01/0fMWI0P00000I0=WI
f@030000003IfMT0fMWI00`0fMWI00110=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`17
6DL07`176DL2000000<0AaU700<000000;A;EP2dBeH0=02dBeH00`000000mHI70?F6A`020?F6A`03
0000003eQTL0mHI701l0mHI700<000000>jJ6@3^VQT01P3^VQT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT02`3IfMT00280fMWI00<000000=WIf@3IfMT0
703IfMT00`0000006ATI01TI6@0601TI6@03000000176DL0AaU701h0AaU700<0000004LIA`176DL0
0`176DL00`000000]4]F0;A;EP0d0;A;EP030000003eQTL0mHI700<0mHI700<000000?F6A`3eQTL0
7P3eQTL00`000000kYXI0>jJ6@070>jJ6@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0
6@3IfMT00`000000fMWI0=WIf@0:0=WIf@008P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000000I
6AT06ATI00H06ATI00<0000004LIA`176DL07@176DL00`000000AaU704LIA`0404LIA`030000002d
BeH0]4]F03@0]4]F00<000000?F6A`3eQTL0103eQTL00`000000mHI70?F6A`0M0?F6A`030000003^
VQT0kYXI00L0kYXI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0E0=WIf@050000003I
fMT0fMWI0=WIf@000000303IfMT00240fMWI00<000000=WIf@3IfMT0703IfMT00`0000006ATI01TI
6@0701TI6@03000000176DL0AaU701/0AaU700<0000004LIA`176DL01P176DL00`000000]4]F0;A;
EP0d0;A;EP030000003eQTL0mHI700H0mHI70P00000L0?F6A`030000003^VQT0kYXI00L0kYXI00<0
00000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0D0=WIf@H000002`3IfMT00240fMWI00<00000
0=WIf@3IfMT0703IfMT00`0000006ATI01TI6@0701TI6@03000000176DL0AaU701X0AaU700<00000
04LIA`176DL01`176DL00`000000]4]F0;A;EP0d0;A;EP030000003eQTL0mHI700P0mHI700<00000
0?F6A`3eQTL06@3eQTL00`000000kYXI0>jJ6@070>jJ6@030000003IfMT0fMWI01`0fMWI00<00000
0=WIf@3IfMT09@3IfMT00400fMWI00<0000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0J04LI
A`03000000176DL0AaU700P0AaU700<000000;A;EP2dBeH0=02dBeH00`000000mHI70?F6A`090?F6
A`030000003eQTL0mHI701T0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI0=WIf@0K0=WI
f@030000003IfMT0fMWI02D0fMWI00100=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`17
6DL05`176DL00`000000AaU704LIA`0;04LIA`030000002dBeH0]4]F03@0]4]F00<000000?F6A`3e
QTL02`3eQTL00`000000mHI70?F6A`0G0?F6A`030000003^VQT0kYXI00L0kYXI00<000000=WIf@3I
fMT06`3IfMT00`000000fMWI0=WIf@0U0=WIf@008@3IfMT00`000000fMWI0=WIf@0L0=WIf@030000
000I6AT06ATI00H06ATI00<0000004LIA`176DL05P176DL00`000000AaU704LIA`0<04LIA`030000
002dBeH0]4]F03@0]4]F00<000000?F6A`3eQTL0303eQTL00`000000mHI70?F6A`0F0?F6A`030000
003^VQT0kYXI00L0kYXI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0T0=WIf@008@3I
fMT00`000000fMWI0=WIf@0K0=WIf@030000000I6AT06ATI00L06ATI00<0000004LIA`176DL05@17
6DL00`000000AaU704LIA`0<04LIA`030000002dBeH0]4]F03H0]4]F00<000000?F6A`3eQTL0303e
QTL00`000000mHI70?F6A`0E0?F6A`030000003^VQT0kYXI00L0kYXI00<000000=WIf@3IfMT06`3I
fMT2000002H0fMWI000P0=WIf@030000003IfMT0fMWI01`0fMWI00<0000001TI6@0I6AT01`0I6AT0
0`000000AaU704LIA`0C04LIA`03000000176DL0AaU700h0AaU700<000000;A;EP2dBeH0=P2dBeH0
0`000000mHI70?F6A`0?0?F6A`030000003eQTL0mHI70180mHI700<000000>jJ6@3^VQT01`3^VQT0
0`000000fMWI0=WIf@0L0=WIf@8000009@3IfMT003l0fMWI00<0000001TI6@0I6AT01P0I6AT00`00
0000AaU704LIA`0C04LIA`03000000176DL0AaU700l0AaU700<000000;A;EP2dBeH0=P2dBeH00`00
0000mHI70?F6A`0@0?F6A`030000003eQTL0mHI70180mHI700<000000>jJ6@3^VQT01`3^VQT00`00
0000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI02<0fMWI000o0=WIf@030000000I6AT06ATI00H0
6ATI00<0000004LIA`176DL04P176DL00`000000AaU704LIA`0@04LIA`030000002dBeH0]4]F03H0
]4]F00<000000?F6A`3eQTL04@3eQTL00`000000mHI70?F6A`0A0?F6A`030000003^VQT0kYXI00L0
kYXI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0S0=WIf@007`3IfMT00`000000fMWI
0=WIf@0M0=WIf@030000000I6AT06ATI00H06ATI00<0000004LIA`176DL09@176DL00`000000]4]F
0;A;EP0f0;A;EP030000003eQTL0mHI702D0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI
0=WIf@0L0=WIf@030000003IfMT0fMWI02<0fMWI000O0=WIf@030000003IfMT0fMWI01`0fMWI00<0
000001TI6@0I6AT01`0I6AT00`000000AaU704LIA`0>04LIA`8000005@176DL00`000000]4]F0;A;
EP0f0;A;EP030000003eQTL0mHI701<0mHI70P00000@0?F6A`030000003^VQT0kYXI00L0kYXI00<0
00000=WIf@3IfMT0703IfMT2000002@0fMWI000N0=WIf@030000003IfMT0fMWI01d0fMWI00<00000
01TI6@0I6AT01`0I6AT00`000000AaU704LIA`0=04LIA`03000000176DL0AaU701@0AaU7?000000F
0?F6A`030000003eQTL0mHI700d0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI0=WIf@0L
0=WIf@800000903IfMT001h0fMWI00<000000=WIf@3IfMT07@3IfMT00`0000006ATI01TI6@0701TI
6@03000000176DL0AaU70240AaU70`0000000`2:jOl0000008[Yo`0g08[Yo`030000002:jOl00000
008000008`3eQTL00`000000kYXI0>jJ6@080>jJ6@030000003IfMT0fMWI01`0fMWI00<000000=WI
f@3IfMT08P3IfMT003h0fMWI00<0000001TI6@0I6AT01P0I6AT00`000000AaU704LIA`0;04LIA`80
00004P176DL3000000D0R^Wo00<0000008[Yo`2:jOl0=02:jOl00`000000R^Wo08[Yo`0308[Yo`<0
00004`3eQTL2000000`0mHI700<000000>jJ6@3^VQT01`3^VQT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI0280fMWI000M0=WIf@030000003IfMT0fMWI01h0fMWI00<0000001TI6@0I6AT0
1P0I6AT00`000000AaU704LIA`0904LIA`8000004@176DL3000000T0R^Wo00<0000008[Yo`2:jOl0
<P2:jOl00`000000R^Wo08[Yo`0708[Yo`<000004P3eQTL00`000000mHI70?F6A`090?F6A`030000
003^VQT0kYXI00L0kYXI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0Q0=WIf@007@3I
fMT00`000000fMWI0=WIf@0M0=WIf@030000000I6AT06ATI00L06ATI00<0000004LIA`176DL06@17
6DL3000000`0R^Wo00<0000008[Yo`2:jOl0<P2:jOl00`000000R^Wo08[Yo`0:08[Yo`<000006`3e
QTL00`000000kYXI0>jJ6@070>jJ6@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT01@3I
fMT4000000<0fMWI0`00000B0=WIf@007@3IfMT00`000000fMWI0=WIf@0M0=WIf@030000000I6AT0
6ATI00L06ATI00<0000004LIA`176DL01P176DL2000000h0AaU70`00000@08[Yo`030000002:jOl0
R^Wo0300R^Wo00<0000008[Yo`2:jOl03P2:jOl3000000h0mHI70`0000070?F6A`030000003^VQT0
kYXI00L0kYXI00<000000=WIf@3IfMT07@3IfMT2000000H0fMWI00L000000=WIf@3IfMT0fMWI0000
003IfMT0000000<0fMWI00<000000=WIf@3IfMT03`3IfMT001d0fMWI00<000000=WIf@3IfMT07@3I
fMT00`0000006ATI01TI6@0701TI6@03000000176DL0AaU700D0AaU700<0000004LIA`176DL02`17
6DL3000001<0R^Wo00<0000008[Yo`2:jOl0<02:jOl00`000000R^Wo08[Yo`0A08[Yo`<000003P3e
QTL00`000000mHI70?F6A`040?F6A`030000003^VQT0kYXI00P0kYXI00<000000=WIf@3IfMT0703I
fMT2000000L0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT000000140fMWI
000m0=WIf@030000000I6AT06ATI00L06ATI00<0000004LIA`176DL040176DL3000001L0R^Wo00<0
000008[Yo`2:jOl0;P2:jOl00`000000R^Wo08[Yo`0E08[Yo`<000004P3eQTL00`000000kYXI0>jJ
6@080>jJ6@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT01P3IfMT01@000000fMWI0=WI
f@3IfMT0000000<0fMWI00<000000=WIf@3IfMT03`3IfMT003d0fMWI00<0000001TI6@0I6AT01P0I
6AT00`000000AaU704LIA`0304LIA`8000002P176DL2000001/0R^Wo00<0000008[Yo`2:jOl0;02:
jOl00`000000R^Wo08[Yo`0I08[Yo`8000002`3eQTL2000000@0mHI700<000000>jJ6@3^VQT01`3^
VQT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT00000
0`3IfMT00`000000fMWI0=WIf@0?0=WIf@00703IfMT00`000000fMWI0=WIf@0M0=WIf@030000000I
6AT06ATI00L06ATI00@0000004LIA`176DL0AaU70P00000904LIA`<000007@2:jOl00`000000R^Wo
08[Yo`0/08[Yo`030000002:jOl0R^Wo01/0R^Wo0`00000:0?F6A`050000003eQTL0mHI70?F6A`00
00002@3^VQT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3I
fMT000000`3IfMT00`000000fMWI0=WIf@0?0=WIf@00703IfMT00`000000fMWI0=WIf@0M0=WIf@03
0000000I6AT06ATI00L06ATI00<0000004LIA`176DL02@176DL300000240R^Wo00<0000008[Yo`2:
jOl0:P2:jOl00`000000R^Wo08[Yo`0O08[Yo`<000002`3eQTL00`000000kYXI0>jJ6@070>jJ6@03
0000003IfMT0fMWI01d0fMWI0P0000050=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WI
f@3IfMT0fMWI0000000A0=WIf@006`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000000I6AT06ATI
00L06ATI0`00000604LIA`<00000902:jOl00`000000R^Wo08[Yo`0Z08[Yo`030000002:jOl0R^Wo
0280R^Wo0`0000060?F6A`<000002P3^VQT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI
00@0fMWI0P0000040=WIf@<000004P3IfMT003`0fMWI00<0000001TI6@0I6AT01`0I6AT00`000000
AaU704LIA`0304LIA`<00000:02:jOl00`000000R^Wo08[Yo`0X08[Yo`030000002:jOl0R^Wo02H0
R^Wo0`0000050?F6A`8000002@3^VQT00`000000fMWI0=WIf@0L0=WIf@8000008@3IfMT003`0fMWI
00<0000001TI6@0I6AT01P0I6AT010000000AaU704LIA`176DL3000002`0R^Wo00<0000008[Yo`2:
jOl09P2:jOl00`000000R^Wo08[Yo`0Z08[Yo`<000000`3eQTL00`000000kYXI0>jJ6@070>jJ6@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07P3IfMT001X0fMWI00<000000=WIf@3IfMT0
7P3IfMT00`0000006ATI01TI6@0501TI6@030000000I6AT0000000<00000;`2:jOl00`000000R^Wo
08[Yo`0V08[Yo`030000002:jOl0R^Wo02d0R^Wo100000000`3^VQT000000>jJ6@060>jJ6@030000
003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07P3IfMT001X0fMWI00<000000=WIf@3IfMT07P3I
fMT00`0000006ATI01TI6@0401TI6@030000000I6AT06ATI00800000<P2:jOl00`000000R^Wo08[Y
o`0T08[Yo`030000002:jOl0R^Wo0340R^Wo00@000000>jJ6@3^VQT000001`3^VQT00`000000fMWI
0=WIf@0M0=WIf@030000003IfMT0fMWI01h0fMWI000J0=WIf@030000003IfMT0fMWI01h0fMWI00<0
000001TI6@0I6AT00`0I6AT01P0000006ATI01TI6@0I6AT0000008[Yo`800000<@2:jOl00`000000
R^Wo08[Yo`0R08[Yo`030000002:jOl0R^Wo02l0R^Wo0P0000000`2:jOl000000>jJ6@020>jJ6@03
0000003^VQT0kYXI00@0kYXI00<000000=WIf@3IfMT07@3IfMT2000001l0fMWI000J0=WIf@030000
003IfMT0fMWI01h0fMWI00D0000001TI6@0I6AT06ATI0000000401TI6@030000002:jOl0R^Wo0080
R^Wo0`00000^08[Yo`030000002:jOl0R^Wo0280R^Wo00<0000008[Yo`2:jOl0;02:jOl3000000@0
R^Wo00<000000>jJ6@3^VQT00`3^VQT01@000000kYXI0>jJ6@3^VQT000000200fMWI00<000000=WI
f@3IfMT07@3IfMT003/0fMWI00@0000001TI6@0I6AT00000100I6AT00`000000R^Wo08[Yo`0608[Y
o`800000;@2:jOl00`000000R^Wo08[Yo`0P08[Yo`030000002:jOl0R^Wo02/0R^Wo0P00000808[Y
o`030000003^VQT0kYXI00<0kYXI00@000000>jJ6@3^VQT000007`3IfMT2000001l0fMWI000I0=WI
f@030000003IfMT0fMWI01h0fMWI00@0000001TI6@0I6AT000001@0I6AT00`000000R^Wo08[Yo`08
08[Yo`800000:`2:jOl00`000000R^Wo08[Yo`0P08[Yo`030000002:jOl0R^Wo02T0R^Wo0P00000;
08[Yo`030000003^VQT0kYXI00<0kYXI00<000000>jJ6@000000803IfMT00`000000fMWI0=WIf@0M
0=WIf@006@3IfMT00`000000fMWI0=WIf@0N0=WIf@030000000I6AT06ATI00D06ATI00<0000008[Y
o`2:jOl02`2:jOl3000002T0R^Wo00<0000008[Yo`2:jOl07P2:jOl00`000000R^Wo08[Yo`0W08[Y
o`<000003@2:jOl00`000000kYXI0>jJ6@050>jJ6@8000007`3IfMT2000001h0fMWI000H0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000601TI6@030000002:jOl0R^Wo00l0R^Wo0P00000X08[Yo`03
0000002:jOl0R^Wo01`0R^Wo00<0000008[Yo`2:jOl09P2:jOl200000140R^Wo00<000000>jJ6@3^
VQT01@3^VQT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI01`0fMWI000H0=WIf@030000
003IfMT0fMWI01d0fMWI00<000000=WIf@0000001P0I6AT00`000000R^Wo08[Yo`0A08[Yo`800000
9P2:jOl00`000000R^Wo08[Yo`0L08[Yo`030000002:jOl0R^Wo02@0R^Wo0P00000D08[Yo`030000
003^VQT0kYXI00@0kYXI0P00000O0=WIf@030000003IfMT0fMWI01`0fMWI000e0=WIf@8000000`3I
fMT00`0000006ATI01TI6@0301TI6@030000002:jOl0R^Wo01@0R^Wo0`00000T08[Yo`030000002:
jOl0R^Wo01X0R^Wo00<0000008[Yo`2:jOl08P2:jOl3000001H0R^Wo00<000000>jJ6@3^VQT0103^
VQT01@000000fMWI0=WIf@3IfMT0000001d0fMWI00<000000=WIf@3IfMT06`3IfMT001L0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@020=WIf@030000000I6AT06ATI00<06ATI00<0
000008[Yo`2:jOl0602:jOl200000280R^Wo00<0000008[Yo`2:jOl06P2:jOl00`000000R^Wo08[Y
o`0P08[Yo`8000006P2:jOl00`000000kYXI0>jJ6@030>jJ6@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0K0=WIf@005`3IfMT00`000000fMWI0=WIf@0I
0=WIf@030000003IfMT0fMWI00<0fMWI00<0000001TI6@0I6AT00`0I6AT00`000000R^Wo08[Yo`0J
08[Yo`8000008@2:jOl00`000000R^Wo08[Yo`0H08[Yo`030000002:jOl0R^Wo01l0R^Wo0P00000M
08[Yo`030000003^VQT0kYXI00<0kYXI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0H
0=WIf@8000007@3IfMT001L0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@050=WI
f@030000000I6AT06ATI00806ATI00<0000008[Yo`2:jOl07@2:jOl2000001h0R^Wo7000000P08[Y
o`800000802:jOl00`000000kYXI0>jJ6@020>jJ6@030000003IfMT0fMWI00@0fMWI0P00000H0=WI
f@800000703IfMT001L0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@060=WIf@05
0000000I6AT06ATI01TI6@0000008P2:jOl3000001P0R^Wo0`0000060?BNQ00300000034LhP0a7>8
00h0a7>800<0000008A3Q024@h@01024@h@3000001P0R^Wo0`00000R08[Yo`030000003^VQT0kYXI
0080kYXI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI
01X0fMWI000_0=WIf@030000003IfMT0fMWI00L0fMWI00D0000001TI6@0I6AT06ATI0000000U08[Y
o`8000004`2:jOl3000000T0m9j400<000000<AcR034LhP03P34LhP00`000000Q4>408A3Q00708A3
Q0<000004`2:jOl2000002H0R^Wo00D000000>jJ6@3^VQT0kYXI000000090=WIf@030000003IfMT0
fMWI01D0fMWI00<000000=WIf@3IfMT06P3IfMT002`0fMWI00<000000=WIf@3IfMT02@3IfMT01@00
00006ATI01TI6@0I6AT0000002P0R^Wo0P00000=08[Yo`@00000303dWX@00`000000a7>80<AcR00>
0<AcR00300000024@h@0Q4>400X0Q4>41000000=08[Yo`800000:@2:jOl010000000kYXI0>jJ6@00
000;0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT06P3IfMT001H0fMWI00<00000
0=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0:0=WIf@040000000I6AT06ATI000002/0R^Wo0`00
000708[Yo`@000003`3dWX@00`000000a7>80<AcR00>0<AcR00300000024@h@0Q4>400h0Q4>40`00
000708[Yo`<00000:`2:jOl01@000000kYXI0>jJ6@3^VQT0000000/0fMWI00<000000=WIf@3IfMT0
4`3IfMT00`000000fMWI0=WIf@0I0=WIf@005P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI00/0fMWI00@0000001TI6@0I6AT00000;P2:jOl200000080R^Wo0`0000030?o4L`030000
003dWX@0m9j400d0m9j400<000000<AcR034LhP03P34LhP00`000000Q4>408A3Q00>08A3Q0030000
000S6G<08aUc00<000000P2:jOl2000002l0R^Wo00@000000>jJ6@3^VQT00000303IfMT00`000000
fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI01T0fMWI000E0=WIf@030000003IfMT0fMWI0200fMWI
0P0I6AT00`000000R^Wo08[Yo`0_08[Yo`8000001@3oa7<00`000000m9j40?BNQ00>0?BNQ0030000
0034LhP0a7>800h0a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<IL`0302<IL`800000
<P2:jOl00`000000kYXI0000000P0=WIf@8000006`3IfMT002L0fMWI0P00000?0=WIf@0301TI6@00
0000R^Wo0300R^Wo00<000000?o4L`3oa7<01@3oa7<00`000000m9j40?BNQ00>0?BNQ00300000034
LhP0a7>800h0a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<IL`0502<IL`030000002:
jOl0R^Wo0300R^Wo0P00000>0=WIf@<00000403IfMT00`000000fMWI0=WIf@0I0=WIf@009P3IfMT0
0`000000fMWI0=WIf@0>0=WIf@030000000I6AT000000300R^Wo00<000000?o4L`3oa7<01P3oa7<0
0`000000m9j40?BNQ00>0?BNQ00300000034LhP0a7>800h0a7>800<0000008A3Q024@h@03P24@h@0
0`0000008aUc02<IL`0602<IL`030000002:jOl0R^Wo02l0R^Wo0P00000A0=WIf@030000003IfMT0
fMWI00h0fMWI00<000000=WIf@3IfMT0603IfMT001@0fMWI00<000000=WIf@3IfMT0803IfMT20000
0300R^Wo00<000000?o4L`3oa7<01`3oa7<00`000000m9j40?BNQ00>0?BNQ00300000034LhP0a7>8
00h0a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<IL`0702<IL`030000002:jOl0R^Wo
02l0R^Wo0P00000Q0=WIf@030000003IfMT0fMWI01P0fMWI000D0=WIf@030000003IfMT0fMWI00/0
fMWI0P00000C0=WIf@D00000;02:jOl00`000000olAc0?o4L`080?o4L`030000003dWX@0m9j400h0
m9j400<000000<AcR034LhP03P34LhP00`000000Q4>408A3Q00>08A3Q0030000000S6G<08aUc00P0
8aUc00<0000008[Yo`2:jOl0;`2:jOl00`000000fMWI0=WIf@0@0=WIf@8000003@3IfMT00`000000
fMWI0=WIf@0H0=WIf@00503IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01<0fMWI
00<0000008[Yo`2:jOl00P2:jOl900000280R^Wo00<000000?o4L`3oa7<02@3oa7<00`000000m9j4
0?BNQ00>0?BNQ00300000034LhP0a7>800h0a7>800<0000008A3Q024@h@03`24@h@00`0000008aUc
02<IL`0802<IL`030000002:jOl0R^Wo0240R^Wo2@00000408[Yo`030000003IfMT0fMWI0180fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0G0=WIf@00503IfMT00`000000fMWI0=WI
f@0Q0=WIf@030000002:jOl0R^Wo00X0R^Wo2@00000H08[Yo`8000002`3oa7<00`000000m9j40?BN
Q00>0?BNQ00300000034LhP0a7>800h0a7>800<0000008A3Q024@h@03`24@h@00`0000008aUc02<I
L`0902<IL`030000002:jOl0R^Wo01L0R^Wo2@00000<08[Yo`030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT05`3IfMT001h0fMWI0P00000H0=WIf@030000002:jOl0R^Wo01<0R^Wo2@00000>
08[Yo`030000003bbT80000000/0olAc00<000000?BNQ03dWX@03P3dWX@00`000000a7>80<AcR00>
0<AcR00300000024@h@0Q4>400l0Q4>400<0000002<IL`0S6G<02@0S6G<00`0I6D80000008[Yo`0>
08[Yo`T00000502:jOl00`000000fMWI0=WIf@0G0=WIf@800000203IfMT2000000H0fMWI10000003
0=WIf@<000002@3IfMT001<0fMWI00<000000=WIf@3IfMT01P3IfMT2000001/0fMWI00<0000008[Y
o`2:jOl06`2:jOl9000000@0R^Wo00@000000?;:@P3bbT8000002`3oa7<00`000000m9j40?BNQ00>
0?BNQ00300000034LhP0a7>800h0a7>800<0000008A3Q024@h@03`24@h@00`0000008aUc02<IL`09
02<IL`806AU200<0000008[Yo`2:jOl00`2:jOl9000001d0R^Wo00<000000=WIf@3IfMT06@3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@060=WIf@004`3IfMT00`000000fMWI0=WIf@0T0=WIf@030000002:jOl0R^Wo
02<0R^Wo100000030?;:@P030000003oa7<0olAc00T0olAc00<000000?BNQ03dWX@03@3dWX@00`00
0000a7>80<AcR00@0<AcR00300000024@h@0Q4>400h0Q4>400<0000002<IL`0S6G<02@0S6G<301TI
@PD000009@2:jOl00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@0000000`3IfMT00`000000fMWI0=WIf@060=WIf@004P3IfMT00`000000fMWI0=WIf@040=WIf@80
00007`3IfMT00`000000R^Wo08[Yo`0V08[Yo`050000003bbT80l/Y20?;:@P0000002`3oa7<00`00
0000m9j40?BNQ00=0?BNQ00300000034LhP0a7>80100a7>800<0000008A3Q024@h@03P24@h@00`00
00008aUc02<IL`0902<IL`<06AU200<0000008[Yo`2:jOl09`2:jOl00`000000fMWI0=WIf@0L0=WI
f@<000001@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0000000<0fMWI00<000000=WI
f@3IfMT01P3IfMT00180fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000002:jOl0R^Wo02H0R^Wo00@000000?;:@P3bbT8000002`3oa7<00`000000m9j40?BNQ00=0?BN
Q00300000034LhP0a7>80100a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<IL`0902<I
L`<06AU200<0000008[Yo`2:jOl09P2:jOl00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT300000080fMWI00D000000=WIf@3IfMT0fMWI00000008
0=WIf@00>`3IfMT00`000000R^Wo08[Yo`0V08[Yo`040000003bbT80l/Y2000000/0olAc00<00000
0?BNQ03dWX@03@3dWX@00`000000a7>80<AcR00@0<AcR00300000024@h@0Q4>400h0Q4>400<00000
02<IL`0S6G<02@0S6G<00`0000006AU20000000X08[Yo`030000003IfMT0fMWI02L0fMWI00<00000
0=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00H0fMWI000E
0=WIf@8000009@3IfMT00`000000R^Wo08[Yo`0U08[Yo`040000003bbT80l/Y2000000/0olAc00<0
00000?BNQ03dWX@03@3dWX@00`000000a7>80<AcR00@0<AcR00300000024@h@0Q4>400h0Q4>400<0
000002<IL`0S6G<02@0S6G<00`0000006AU20000000X08[Yo`030000003IfMT0fMWI02<0fMWI0P00
00020=WIf@030000003IfMT0fMWI0080fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000<0
fMWI00<000000=WIf@3IfMT01P3IfMT00140fMWI00@000000=WIf@00000000009`3IfMT00`000000
R^Wo08[Yo`0V08[Yo`800000303oa7<00`000000m9j40?BNQ00=0?BNQ00300000034LhP0a7>80100
a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<IL`0:02<IL`0301TI@P000000R^Wo02H0
R^Wo00<000000=WIf@3IfMT09P3IfMT3000000D0fMWI0`0000030=WIf@<000002@3IfMT00140fMWI
00<000000=WIf@3IfMT0:@3IfMT00`000000R^Wo08[Yo`0U08[Yo`800000303oa7<00`000000m9j4
0?BNQ00=0?BNQ00300000034LhP0a7>80100a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc
02<IL`0:02<IL`0301TI@P000000R^Wo02H0R^Wo00<000000=WIf@3IfMT0:03IfMT2000001H0fMWI
000@0=WIf@<00000:P3IfMT00`000000R^Wo08[Yo`0U08[Yo`800000303oa7<00`000000m9j40?BN
Q00=0?BNQ00300000034LhP0a7>80100a7>800<0000008A3Q024@h@03P24@h@00`0000008aUc02<I
L`0:02<IL`0301TI@P000000R^Wo02D0R^Wo00<000000=WIf@3IfMT0:@3IfMT2000001H0fMWI000C
0=WIf@030000003IfMT0fMWI02P0fMWI00<0000008[Yo`2:jOl09@2:jOl00`000000olAc0?o4L`09
0?o4L`030000003dWX@0m9j400h0m9j400<000000<AcR034LhP04034LhP00`000000Q4>408A3Q00>
08A3Q0030000000S6G<08aUc00X08aUc00<0000008[Yo`2:jOl0902:jOl00`000000fMWI0=WIf@0X
0=WIf@800000603IfMT001H0fMWI0P00000W0=WIf@030000002:jOl0R^Wo01l0R^Wo100000000`2:
jOl000000000000:0?o4L`030000003dWX@0m9j400h0m9j400<000000<AcR034LhP04034LhP00`00
0000Q4>408A3Q00>08A3Q0030000000S6G<08aUc00T08aUc1`00000Q08[Yo`030000003IfMT0fMWI
02D0fMWI0P00000K0=WIf@00603IfMT00`000000fMWI0=WIf@0T0=WIf@030000002:jOl0R^Wo01H0
R^Wo2@00000708[Yo`800000203oa7<00`000000m9j40?BNQ00>0?BNQ00300000034LhP0a7>80100
a7>800<0000008A3Q024@h@03`24@h@902<IL`8000001`2:jOl9000001L0R^Wo00<000000=WIf@3I
fMT0903IfMT2000001d0fMWI000K0=WIf@@000008@3IfMT00`000000R^Wo08[Yo`0<08[Yo`T00000
4P2:jOl00`000000olAc0?o4L`050?o4L`030000003dWX@0m9j400h0m9j400<000000<AcR034LhP0
4034LhP00`000000Q4>408A3Q00?08A3Q0P08aUc00<0000008[Yo`2:jOl0402:jOl9000000h0R^Wo
00<000000=WIf@3IfMT07`3IfMT300000240fMWI000P0=WIf@<000007@3IfMT00`000000R^Wo08[Y
o`0308[Yo`T00000702:jOl2000000D0olAc00<000000?BNQ03dWX@03P3dWX@00`000000a7>80<Ac
R00@0<AcR00300000024@h@0Q4>400l0Q4>41P0S6G<2000001`0R^Wo2@00000408[Yo`030000003I
fMT0fMWI01`0fMWI0P00000V0=WIf@008`3IfMT00`000000fMWI0=WIf@0K0=WIf@D000009`2:jOl2
000000<0olAc00<000000?BNQ03dWX@03P3dWX@00`000000a7>80<AcR00@0<AcR00300000024@h@0
Q4>400l0Q4>4100S6G<2000002L0R^Wo1000000M0=WIf@800000:03IfMT002H0fMWI0P00000K0=WI
f@800000:P2:jOl010000000olAc0?o4L`00000@0?BNQ00300000034LhP0a7>80100a7>800<00000
08A3Q024@h@03`24@h@302<IL`030000002:jOl0R^Wo02L0R^Wo0P00000L0=WIf@800000:`3IfMT0
02P0fMWI00<000000=WIf@3IfMT00`00000G0=WIf@800000:@2:jOl300000100m9j400<000000<Ac
R034LhP04034LhP00`000000Q4>408A3Q00?08A3Q00302<IL`000000000002P0R^Wo0P00000I0=WI
f@80000000<0fMWI000000000000;@3IfMT002h0fMWI00<000000=WIf@3IfMT05P3IfMT2000002T0
R^Wo0`00000>0?BNQ00300000034LhP0a7>80100a7>800<0000008A3Q024@h@03@24@h@4000002L0
R^Wo0P00000I0=WIf@800000<P3IfMT00300fMWI0`00000F0=WIf@800000902:jOl2000000@0R^Wo
1000000:0?BNQ00300000034LhP0a7>80100a7>800<0000008A3Q024@h@02024@h@5000000@0R^Wo
0P00000S08[Yo`8000005`3IfMT2000003H0fMWI000c0=WIf@030000003IfMT0fMWI01D0fMWI0P00
000O08[Yo`<000002P2:jOl5000000D0m9j400<000000<AcR034LhP04034LhP708A3Q0@000002`2:
jOl3000001h0R^Wo0P00000H0=WIf@030000003IfMT0fMWI03H0fMWI000e0=WIf@@00000503IfMT2
000001/0R^Wo0P00000B08[Yo`@0000000<0m9j400000034LhP04@34LhP208A3Q0D000004P2:jOl2
000001X0R^Wo0P00000D0=WIf@@00000>`3IfMT003/0fMWI0P00000B0=WIf@8000005`2:jOl20000
01P0R^Wo5P00000I08[Yo`8000005`2:jOl00`000000fMWI0=WIf@0A0=WIf@800000@03IfMT003d0
fMWI00<000000=WIf@3IfMT04@3IfMT200000180R^Wo0`00000K08[Yo`030000002:jOl0R^Wo0100
R^Wo00<0000008[Yo`2:jOl06P2:jOl300000180R^Wo0P00000B0=WIf@800000@P3IfMT00400fMWI
0`00000@0=WIf@8000003P2:jOl2000001d0R^Wo00<0000008[Yo`2:jOl04P2:jOl00`000000R^Wo
08[Yo`0L08[Yo`8000003P2:jOl200000100fMWI0P0000160=WIf@00@`3IfMT00`000000fMWI0000
0002000000d0fMWI0P00000:08[Yo`8000007P2:jOl00`000000R^Wo08[Yo`0D08[Yo`030000002:
jOl0R^Wo01d0R^Wo0P00000:08[Yo`8000003@3IfMT200000080fMWI00<000000=WIf@3IfMT0AP3I
fMT004P0fMWI00<000000=WIf@3IfMT0303IfMT2000000D0R^Wo0`00000P08[Yo`030000002:jOl0
R^Wo01@0R^Wo00<0000008[Yo`2:jOl07`2:jOl3000000D0R^Wo0P00000=0=WIf@800000C@3IfMT0
04/0fMWI0P00000<0=WIf@80000000<0R^Wo0000000000008P2:jOl00`000000R^Wo08[Yo`0F08[Y
o`030000002:jOl0R^Wo0240R^Wo00<0000008[Yo`2:jOl00P00000<0=WIf@800000D03IfMT004d0
fMWI00<000000=WIf@3IfMT02`3IfMT010000000R^Wo08[Yo`00000P08[Yo`030000002:jOl0R^Wo
01P0R^Wo00<0000008[Yo`2:jOl07`2:jOl4000000`0fMWI0P00001B0=WIf@00D03IfMT4000000/0
fMWI1@00000K08[Yo`030000002:jOl0R^Wo01P0R^Wo00<0000008[Yo`2:jOl06P2:jOl5000000/0
fMWI1000001E0=WIf@00E@3IfMT3000000`0fMWI1@00000E08[Yo`030000002:jOl0R^Wo01X0R^Wo
00<0000008[Yo`2:jOl04`2:jOl6000000`0fMWI0P00001K0=WIf@00F03IfMT00`000000fMWI0=WI
f@0>0=WIf@H000003P2:jOl00`000000R^Wo08[Yo`0L08[Yo`030000002:jOl0R^Wo00d0R^Wo1@00
000A0=WIf@030000003IfMT0fMWI05/0fMWI001J0=WIf@<000004P3IfMT5000000T0R^Wo00<00000
08[Yo`2:jOl0702:jOl00`000000R^Wo08[Yo`0708[Yo`H000004P3IfMT200000600fMWI001M0=WI
f@030000003IfMT0fMWI008000004P3IfMT5000000<0R^Wo00<0000008[Yo`2:jOl07P2:jOl01000
0000R^Wo08[Yo`2:jOl5000001<0fMWI0P0000000`3IfMT000000000001R0=WIf@00HP3IfMT00`00
0000fMWI0=WIf@0D0=WIfBP000005P3IfMT2000006L0fMWI001U0=WIf@<00000B`3IfMT2000006/0
fMWI001X0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI
0=WIf@1[0=WIf@00JP3IfMT4000001l0fMWI00<000000=WIf@3IfMT0703IfMT400000700fMWI001`
0=WIf@8000006`3IfMT00`000000fMWI0=WIf@0I0=WIf@800000M@3IfMT00780fMWI00<000000=WI
f@3IfMT0<P3IfMT2000007L0fMWI001e0=WIf@<00000:`3IfMT2000007/0fMWI001h0=WIf@030000
003IfMT0000000800000403IfMT00`000000fMWI0=WIf@0>0=WIf@8000000P3IfMT00`000000fMWI
0=WIf@1k0=WIf@00O@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00d0fMWI00<0
00000=WIf@3IfMT0P03IfMT007l0fMWI0`00000;0=WIf@030000003IfMT0fMWI00T0fMWI0P000025
0=WIf@00PP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI0P0000270=WI
f@00Q@3IfMT3000000X0fMWI1000002:0=WIf@00RP3IfMT3000000030=WIf@00000000000900fMWI
002=0=WIf@030000003IfMT0fMWI0900fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0110458, -0.0387461, 
  0.00361934, 0.00361934}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the field along cylinder axis", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = 
      Table[{z, radFld[cyl1, "\<Bz\>", {0, 0, z}]}, {z, \(-20\), Lz + 20, 
          1}]; \nMultipleListPlot[T1, PlotJoined \[Rule] True, \n\t\t
      PlotRange \[Rule] All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.295918 0.0136054 0.436784 1.50636 [
[.02381 .42428 -12.5 -14 ]
[.02381 .42428 12.5 0 ]
[.15986 .42428 -12.5 -14 ]
[.15986 .42428 12.5 0 ]
[.43197 .42428 -8 -14 ]
[.43197 .42428 8 0 ]
[.56803 .42428 -8 -14 ]
[.56803 .42428 8 0 ]
[.70408 .42428 -8 -14 ]
[.70408 .42428 8 0 ]
[.84014 .42428 -8 -14 ]
[.84014 .42428 8 0 ]
[.97619 .42428 -8 -14 ]
[.97619 .42428 8 0 ]
[.28342 .13551 -29 -7 ]
[.28342 .13551 0 7 ]
[.28342 .28615 -29 -7 ]
[.28342 .28615 0 7 ]
[.28342 .58742 -20 -7 ]
[.28342 .58742 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .43678 m
.02381 .44303 L
s
gsave
.02381 .42428 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.15986 .43678 m
.15986 .44303 L
s
gsave
.15986 .42428 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.43197 .43678 m
.43197 .44303 L
s
gsave
.43197 .42428 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.56803 .43678 m
.56803 .44303 L
s
gsave
.56803 .42428 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.70408 .43678 m
.70408 .44303 L
s
gsave
.70408 .42428 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84014 .43678 m
.84014 .44303 L
s
gsave
.84014 .42428 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .43678 m
.97619 .44303 L
s
gsave
.97619 .42428 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05102 .43678 m
.05102 .44053 L
s
.07823 .43678 m
.07823 .44053 L
s
.10544 .43678 m
.10544 .44053 L
s
.13265 .43678 m
.13265 .44053 L
s
.18707 .43678 m
.18707 .44053 L
s
.21429 .43678 m
.21429 .44053 L
s
.2415 .43678 m
.2415 .44053 L
s
.26871 .43678 m
.26871 .44053 L
s
.32313 .43678 m
.32313 .44053 L
s
.35034 .43678 m
.35034 .44053 L
s
.37755 .43678 m
.37755 .44053 L
s
.40476 .43678 m
.40476 .44053 L
s
.45918 .43678 m
.45918 .44053 L
s
.48639 .43678 m
.48639 .44053 L
s
.51361 .43678 m
.51361 .44053 L
s
.54082 .43678 m
.54082 .44053 L
s
.59524 .43678 m
.59524 .44053 L
s
.62245 .43678 m
.62245 .44053 L
s
.64966 .43678 m
.64966 .44053 L
s
.67687 .43678 m
.67687 .44053 L
s
.73129 .43678 m
.73129 .44053 L
s
.7585 .43678 m
.7585 .44053 L
s
.78571 .43678 m
.78571 .44053 L
s
.81293 .43678 m
.81293 .44053 L
s
.86735 .43678 m
.86735 .44053 L
s
.89456 .43678 m
.89456 .44053 L
s
.92177 .43678 m
.92177 .44053 L
s
.94898 .43678 m
.94898 .44053 L
s
.25 Mabswid
0 .43678 m
1 .43678 L
s
.29592 .13551 m
.30217 .13551 L
s
gsave
.28342 .13551 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.29592 .28615 m
.30217 .28615 L
s
gsave
.28342 .28615 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.29592 .58742 m
.30217 .58742 L
s
gsave
.28342 .58742 -81 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.29592 .16564 m
.29967 .16564 L
s
.29592 .19577 m
.29967 .19577 L
s
.29592 .22589 m
.29967 .22589 L
s
.29592 .25602 m
.29967 .25602 L
s
.29592 .31628 m
.29967 .31628 L
s
.29592 .3464 m
.29967 .3464 L
s
.29592 .37653 m
.29967 .37653 L
s
.29592 .40666 m
.29967 .40666 L
s
.29592 .46691 m
.29967 .46691 L
s
.29592 .49704 m
.29967 .49704 L
s
.29592 .52717 m
.29967 .52717 L
s
.29592 .55729 m
.29967 .55729 L
s
.29592 .10538 m
.29967 .10538 L
s
.29592 .07526 m
.29967 .07526 L
s
.29592 .04513 m
.29967 .04513 L
s
.29592 .015 m
.29967 .015 L
s
.29592 .61755 m
.29967 .61755 L
s
.25 Mabswid
.29592 0 m
.29592 .61803 L
s
.001 w
.02381 .55985 m
.03741 .56609 L
.05102 .57239 L
.06463 .57863 L
.07823 .58467 L
.09184 .59034 L
.10544 .59538 L
.11905 .5995 L
.13265 .6023 L
.14626 .60332 L
.15986 .60197 L
.17347 .5976 L
.18707 .58945 L
.20068 .57673 L
.21429 .55867 L
.22789 .53463 L
.2415 .50425 L
.2551 .4676 L
.26871 .42533 L
.28231 .37874 L
.29592 .32968 L
.30952 .28035 L
.32313 .23294 L
.33673 .1893 L
.35034 .15073 L
.36395 .11789 L
.37755 .09087 L
.39116 .06932 L
.40476 .05261 L
.41837 .04001 L
.43197 .03077 L
.44558 .02419 L
.45918 .0197 L
.47279 .01682 L
.48639 .01522 L
.5 .01472 L
.51361 .01522 L
.52721 .01682 L
.54082 .0197 L
.55442 .02419 L
.56803 .03077 L
.58163 .04001 L
.59524 .05261 L
.60884 .06932 L
.62245 .09087 L
.63605 .11789 L
.64966 .15073 L
.66327 .1893 L
.67687 .23294 L
.69048 .28035 L
Mistroke
.70408 .32968 L
.71769 .37874 L
.73129 .42533 L
.7449 .4676 L
.7585 .50425 L
.77211 .53463 L
.78571 .55867 L
.79932 .57673 L
.81293 .58945 L
.82653 .5976 L
.84014 .60197 L
.85374 .60332 L
.86735 .6023 L
.88095 .5995 L
.89456 .59538 L
.90816 .59034 L
.92177 .58467 L
.93537 .57863 L
.94898 .57239 L
.96259 .56609 L
.97619 .55985 L
Mfstroke
.0001 w
.02381 .55985 -1.875 0 Mabsadd m
.02381 .55985 0 2.5 Mabsadd L
.02381 .55985 1.875 0 Mabsadd L
.02381 .55985 0 -2.5 Mabsadd L
.02381 .55985 -1.875 0 Mabsadd L closepath F
.03741 .56609 -1.875 0 Mabsadd m
.03741 .56609 0 2.5 Mabsadd L
.03741 .56609 1.875 0 Mabsadd L
.03741 .56609 0 -2.5 Mabsadd L
.03741 .56609 -1.875 0 Mabsadd L closepath F
.05102 .57239 -1.875 0 Mabsadd m
.05102 .57239 0 2.5 Mabsadd L
.05102 .57239 1.875 0 Mabsadd L
.05102 .57239 0 -2.5 Mabsadd L
.05102 .57239 -1.875 0 Mabsadd L closepath F
.06463 .57863 -1.875 0 Mabsadd m
.06463 .57863 0 2.5 Mabsadd L
.06463 .57863 1.875 0 Mabsadd L
.06463 .57863 0 -2.5 Mabsadd L
.06463 .57863 -1.875 0 Mabsadd L closepath F
.07823 .58467 -1.875 0 Mabsadd m
.07823 .58467 0 2.5 Mabsadd L
.07823 .58467 1.875 0 Mabsadd L
.07823 .58467 0 -2.5 Mabsadd L
.07823 .58467 -1.875 0 Mabsadd L closepath F
.09184 .59034 -1.875 0 Mabsadd m
.09184 .59034 0 2.5 Mabsadd L
.09184 .59034 1.875 0 Mabsadd L
.09184 .59034 0 -2.5 Mabsadd L
.09184 .59034 -1.875 0 Mabsadd L closepath F
.10544 .59538 -1.875 0 Mabsadd m
.10544 .59538 0 2.5 Mabsadd L
.10544 .59538 1.875 0 Mabsadd L
.10544 .59538 0 -2.5 Mabsadd L
.10544 .59538 -1.875 0 Mabsadd L closepath F
.11905 .5995 -1.875 0 Mabsadd m
.11905 .5995 0 2.5 Mabsadd L
.11905 .5995 1.875 0 Mabsadd L
.11905 .5995 0 -2.5 Mabsadd L
.11905 .5995 -1.875 0 Mabsadd L closepath F
.13265 .6023 -1.875 0 Mabsadd m
.13265 .6023 0 2.5 Mabsadd L
.13265 .6023 1.875 0 Mabsadd L
.13265 .6023 0 -2.5 Mabsadd L
.13265 .6023 -1.875 0 Mabsadd L closepath F
.14626 .60332 -1.875 0 Mabsadd m
.14626 .60332 0 2.5 Mabsadd L
.14626 .60332 1.875 0 Mabsadd L
.14626 .60332 0 -2.5 Mabsadd L
.14626 .60332 -1.875 0 Mabsadd L closepath F
.15986 .60197 -1.875 0 Mabsadd m
.15986 .60197 0 2.5 Mabsadd L
.15986 .60197 1.875 0 Mabsadd L
.15986 .60197 0 -2.5 Mabsadd L
.15986 .60197 -1.875 0 Mabsadd L closepath F
.17347 .5976 -1.875 0 Mabsadd m
.17347 .5976 0 2.5 Mabsadd L
.17347 .5976 1.875 0 Mabsadd L
.17347 .5976 0 -2.5 Mabsadd L
.17347 .5976 -1.875 0 Mabsadd L closepath F
.18707 .58945 -1.875 0 Mabsadd m
.18707 .58945 0 2.5 Mabsadd L
.18707 .58945 1.875 0 Mabsadd L
.18707 .58945 0 -2.5 Mabsadd L
.18707 .58945 -1.875 0 Mabsadd L closepath F
.20068 .57673 -1.875 0 Mabsadd m
.20068 .57673 0 2.5 Mabsadd L
.20068 .57673 1.875 0 Mabsadd L
.20068 .57673 0 -2.5 Mabsadd L
.20068 .57673 -1.875 0 Mabsadd L closepath F
.21429 .55867 -1.875 0 Mabsadd m
.21429 .55867 0 2.5 Mabsadd L
.21429 .55867 1.875 0 Mabsadd L
.21429 .55867 0 -2.5 Mabsadd L
.21429 .55867 -1.875 0 Mabsadd L closepath F
.22789 .53463 -1.875 0 Mabsadd m
.22789 .53463 0 2.5 Mabsadd L
.22789 .53463 1.875 0 Mabsadd L
.22789 .53463 0 -2.5 Mabsadd L
.22789 .53463 -1.875 0 Mabsadd L closepath F
.2415 .50425 -1.875 0 Mabsadd m
.2415 .50425 0 2.5 Mabsadd L
.2415 .50425 1.875 0 Mabsadd L
.2415 .50425 0 -2.5 Mabsadd L
.2415 .50425 -1.875 0 Mabsadd L closepath F
.2551 .4676 -1.875 0 Mabsadd m
.2551 .4676 0 2.5 Mabsadd L
.2551 .4676 1.875 0 Mabsadd L
.2551 .4676 0 -2.5 Mabsadd L
.2551 .4676 -1.875 0 Mabsadd L closepath F
.26871 .42533 -1.875 0 Mabsadd m
.26871 .42533 0 2.5 Mabsadd L
.26871 .42533 1.875 0 Mabsadd L
.26871 .42533 0 -2.5 Mabsadd L
.26871 .42533 -1.875 0 Mabsadd L closepath F
.28231 .37874 -1.875 0 Mabsadd m
.28231 .37874 0 2.5 Mabsadd L
.28231 .37874 1.875 0 Mabsadd L
.28231 .37874 0 -2.5 Mabsadd L
.28231 .37874 -1.875 0 Mabsadd L closepath F
.29592 .32968 -1.875 0 Mabsadd m
.29592 .32968 0 2.5 Mabsadd L
.29592 .32968 1.875 0 Mabsadd L
.29592 .32968 0 -2.5 Mabsadd L
.29592 .32968 -1.875 0 Mabsadd L closepath F
.30952 .28035 -1.875 0 Mabsadd m
.30952 .28035 0 2.5 Mabsadd L
.30952 .28035 1.875 0 Mabsadd L
.30952 .28035 0 -2.5 Mabsadd L
.30952 .28035 -1.875 0 Mabsadd L closepath F
.32313 .23294 -1.875 0 Mabsadd m
.32313 .23294 0 2.5 Mabsadd L
.32313 .23294 1.875 0 Mabsadd L
.32313 .23294 0 -2.5 Mabsadd L
.32313 .23294 -1.875 0 Mabsadd L closepath F
.33673 .1893 -1.875 0 Mabsadd m
.33673 .1893 0 2.5 Mabsadd L
.33673 .1893 1.875 0 Mabsadd L
.33673 .1893 0 -2.5 Mabsadd L
.33673 .1893 -1.875 0 Mabsadd L closepath F
.35034 .15073 -1.875 0 Mabsadd m
.35034 .15073 0 2.5 Mabsadd L
.35034 .15073 1.875 0 Mabsadd L
.35034 .15073 0 -2.5 Mabsadd L
.35034 .15073 -1.875 0 Mabsadd L closepath F
.36395 .11789 -1.875 0 Mabsadd m
.36395 .11789 0 2.5 Mabsadd L
.36395 .11789 1.875 0 Mabsadd L
.36395 .11789 0 -2.5 Mabsadd L
.36395 .11789 -1.875 0 Mabsadd L closepath F
.37755 .09087 -1.875 0 Mabsadd m
.37755 .09087 0 2.5 Mabsadd L
.37755 .09087 1.875 0 Mabsadd L
.37755 .09087 0 -2.5 Mabsadd L
.37755 .09087 -1.875 0 Mabsadd L closepath F
.39116 .06932 -1.875 0 Mabsadd m
.39116 .06932 0 2.5 Mabsadd L
.39116 .06932 1.875 0 Mabsadd L
.39116 .06932 0 -2.5 Mabsadd L
.39116 .06932 -1.875 0 Mabsadd L closepath F
.40476 .05261 -1.875 0 Mabsadd m
.40476 .05261 0 2.5 Mabsadd L
.40476 .05261 1.875 0 Mabsadd L
.40476 .05261 0 -2.5 Mabsadd L
.40476 .05261 -1.875 0 Mabsadd L closepath F
.41837 .04001 -1.875 0 Mabsadd m
.41837 .04001 0 2.5 Mabsadd L
.41837 .04001 1.875 0 Mabsadd L
.41837 .04001 0 -2.5 Mabsadd L
.41837 .04001 -1.875 0 Mabsadd L closepath F
.43197 .03077 -1.875 0 Mabsadd m
.43197 .03077 0 2.5 Mabsadd L
.43197 .03077 1.875 0 Mabsadd L
.43197 .03077 0 -2.5 Mabsadd L
.43197 .03077 -1.875 0 Mabsadd L closepath F
.44558 .02419 -1.875 0 Mabsadd m
.44558 .02419 0 2.5 Mabsadd L
.44558 .02419 1.875 0 Mabsadd L
.44558 .02419 0 -2.5 Mabsadd L
.44558 .02419 -1.875 0 Mabsadd L closepath F
.45918 .0197 -1.875 0 Mabsadd m
.45918 .0197 0 2.5 Mabsadd L
.45918 .0197 1.875 0 Mabsadd L
.45918 .0197 0 -2.5 Mabsadd L
.45918 .0197 -1.875 0 Mabsadd L closepath F
.47279 .01682 -1.875 0 Mabsadd m
.47279 .01682 0 2.5 Mabsadd L
.47279 .01682 1.875 0 Mabsadd L
.47279 .01682 0 -2.5 Mabsadd L
.47279 .01682 -1.875 0 Mabsadd L closepath F
.48639 .01522 -1.875 0 Mabsadd m
.48639 .01522 0 2.5 Mabsadd L
.48639 .01522 1.875 0 Mabsadd L
.48639 .01522 0 -2.5 Mabsadd L
.48639 .01522 -1.875 0 Mabsadd L closepath F
.5 .01472 -1.875 0 Mabsadd m
.5 .01472 0 2.5 Mabsadd L
.5 .01472 1.875 0 Mabsadd L
.5 .01472 0 -2.5 Mabsadd L
.5 .01472 -1.875 0 Mabsadd L closepath F
.51361 .01522 -1.875 0 Mabsadd m
.51361 .01522 0 2.5 Mabsadd L
.51361 .01522 1.875 0 Mabsadd L
.51361 .01522 0 -2.5 Mabsadd L
.51361 .01522 -1.875 0 Mabsadd L closepath F
.52721 .01682 -1.875 0 Mabsadd m
.52721 .01682 0 2.5 Mabsadd L
.52721 .01682 1.875 0 Mabsadd L
.52721 .01682 0 -2.5 Mabsadd L
.52721 .01682 -1.875 0 Mabsadd L closepath F
.54082 .0197 -1.875 0 Mabsadd m
.54082 .0197 0 2.5 Mabsadd L
.54082 .0197 1.875 0 Mabsadd L
.54082 .0197 0 -2.5 Mabsadd L
.54082 .0197 -1.875 0 Mabsadd L closepath F
.55442 .02419 -1.875 0 Mabsadd m
.55442 .02419 0 2.5 Mabsadd L
.55442 .02419 1.875 0 Mabsadd L
.55442 .02419 0 -2.5 Mabsadd L
.55442 .02419 -1.875 0 Mabsadd L closepath F
.56803 .03077 -1.875 0 Mabsadd m
.56803 .03077 0 2.5 Mabsadd L
.56803 .03077 1.875 0 Mabsadd L
.56803 .03077 0 -2.5 Mabsadd L
.56803 .03077 -1.875 0 Mabsadd L closepath F
.58163 .04001 -1.875 0 Mabsadd m
.58163 .04001 0 2.5 Mabsadd L
.58163 .04001 1.875 0 Mabsadd L
.58163 .04001 0 -2.5 Mabsadd L
.58163 .04001 -1.875 0 Mabsadd L closepath F
.59524 .05261 -1.875 0 Mabsadd m
.59524 .05261 0 2.5 Mabsadd L
.59524 .05261 1.875 0 Mabsadd L
.59524 .05261 0 -2.5 Mabsadd L
.59524 .05261 -1.875 0 Mabsadd L closepath F
.60884 .06932 -1.875 0 Mabsadd m
.60884 .06932 0 2.5 Mabsadd L
.60884 .06932 1.875 0 Mabsadd L
.60884 .06932 0 -2.5 Mabsadd L
.60884 .06932 -1.875 0 Mabsadd L closepath F
.62245 .09087 -1.875 0 Mabsadd m
.62245 .09087 0 2.5 Mabsadd L
.62245 .09087 1.875 0 Mabsadd L
.62245 .09087 0 -2.5 Mabsadd L
.62245 .09087 -1.875 0 Mabsadd L closepath F
.63605 .11789 -1.875 0 Mabsadd m
.63605 .11789 0 2.5 Mabsadd L
.63605 .11789 1.875 0 Mabsadd L
.63605 .11789 0 -2.5 Mabsadd L
.63605 .11789 -1.875 0 Mabsadd L closepath F
.64966 .15073 -1.875 0 Mabsadd m
.64966 .15073 0 2.5 Mabsadd L
.64966 .15073 1.875 0 Mabsadd L
.64966 .15073 0 -2.5 Mabsadd L
.64966 .15073 -1.875 0 Mabsadd L closepath F
.66327 .1893 -1.875 0 Mabsadd m
.66327 .1893 0 2.5 Mabsadd L
.66327 .1893 1.875 0 Mabsadd L
.66327 .1893 0 -2.5 Mabsadd L
.66327 .1893 -1.875 0 Mabsadd L closepath F
.67687 .23294 -1.875 0 Mabsadd m
.67687 .23294 0 2.5 Mabsadd L
.67687 .23294 1.875 0 Mabsadd L
.67687 .23294 0 -2.5 Mabsadd L
.67687 .23294 -1.875 0 Mabsadd L closepath F
.69048 .28035 -1.875 0 Mabsadd m
.69048 .28035 0 2.5 Mabsadd L
.69048 .28035 1.875 0 Mabsadd L
.69048 .28035 0 -2.5 Mabsadd L
.69048 .28035 -1.875 0 Mabsadd L closepath F
.70408 .32968 -1.875 0 Mabsadd m
.70408 .32968 0 2.5 Mabsadd L
.70408 .32968 1.875 0 Mabsadd L
.70408 .32968 0 -2.5 Mabsadd L
.70408 .32968 -1.875 0 Mabsadd L closepath F
.71769 .37874 -1.875 0 Mabsadd m
.71769 .37874 0 2.5 Mabsadd L
.71769 .37874 1.875 0 Mabsadd L
.71769 .37874 0 -2.5 Mabsadd L
.71769 .37874 -1.875 0 Mabsadd L closepath F
.73129 .42533 -1.875 0 Mabsadd m
.73129 .42533 0 2.5 Mabsadd L
.73129 .42533 1.875 0 Mabsadd L
.73129 .42533 0 -2.5 Mabsadd L
.73129 .42533 -1.875 0 Mabsadd L closepath F
.7449 .4676 -1.875 0 Mabsadd m
.7449 .4676 0 2.5 Mabsadd L
.7449 .4676 1.875 0 Mabsadd L
.7449 .4676 0 -2.5 Mabsadd L
.7449 .4676 -1.875 0 Mabsadd L closepath F
.7585 .50425 -1.875 0 Mabsadd m
.7585 .50425 0 2.5 Mabsadd L
.7585 .50425 1.875 0 Mabsadd L
.7585 .50425 0 -2.5 Mabsadd L
.7585 .50425 -1.875 0 Mabsadd L closepath F
.77211 .53463 -1.875 0 Mabsadd m
.77211 .53463 0 2.5 Mabsadd L
.77211 .53463 1.875 0 Mabsadd L
.77211 .53463 0 -2.5 Mabsadd L
.77211 .53463 -1.875 0 Mabsadd L closepath F
.78571 .55867 -1.875 0 Mabsadd m
.78571 .55867 0 2.5 Mabsadd L
.78571 .55867 1.875 0 Mabsadd L
.78571 .55867 0 -2.5 Mabsadd L
.78571 .55867 -1.875 0 Mabsadd L closepath F
.79932 .57673 -1.875 0 Mabsadd m
.79932 .57673 0 2.5 Mabsadd L
.79932 .57673 1.875 0 Mabsadd L
.79932 .57673 0 -2.5 Mabsadd L
.79932 .57673 -1.875 0 Mabsadd L closepath F
.81293 .58945 -1.875 0 Mabsadd m
.81293 .58945 0 2.5 Mabsadd L
.81293 .58945 1.875 0 Mabsadd L
.81293 .58945 0 -2.5 Mabsadd L
.81293 .58945 -1.875 0 Mabsadd L closepath F
.82653 .5976 -1.875 0 Mabsadd m
.82653 .5976 0 2.5 Mabsadd L
.82653 .5976 1.875 0 Mabsadd L
.82653 .5976 0 -2.5 Mabsadd L
.82653 .5976 -1.875 0 Mabsadd L closepath F
.84014 .60197 -1.875 0 Mabsadd m
.84014 .60197 0 2.5 Mabsadd L
.84014 .60197 1.875 0 Mabsadd L
.84014 .60197 0 -2.5 Mabsadd L
.84014 .60197 -1.875 0 Mabsadd L closepath F
.85374 .60332 -1.875 0 Mabsadd m
.85374 .60332 0 2.5 Mabsadd L
.85374 .60332 1.875 0 Mabsadd L
.85374 .60332 0 -2.5 Mabsadd L
.85374 .60332 -1.875 0 Mabsadd L closepath F
.86735 .6023 -1.875 0 Mabsadd m
.86735 .6023 0 2.5 Mabsadd L
.86735 .6023 1.875 0 Mabsadd L
.86735 .6023 0 -2.5 Mabsadd L
.86735 .6023 -1.875 0 Mabsadd L closepath F
.88095 .5995 -1.875 0 Mabsadd m
.88095 .5995 0 2.5 Mabsadd L
.88095 .5995 1.875 0 Mabsadd L
.88095 .5995 0 -2.5 Mabsadd L
.88095 .5995 -1.875 0 Mabsadd L closepath F
.89456 .59538 -1.875 0 Mabsadd m
.89456 .59538 0 2.5 Mabsadd L
.89456 .59538 1.875 0 Mabsadd L
.89456 .59538 0 -2.5 Mabsadd L
.89456 .59538 -1.875 0 Mabsadd L closepath F
.90816 .59034 -1.875 0 Mabsadd m
.90816 .59034 0 2.5 Mabsadd L
.90816 .59034 1.875 0 Mabsadd L
.90816 .59034 0 -2.5 Mabsadd L
.90816 .59034 -1.875 0 Mabsadd L closepath F
.92177 .58467 -1.875 0 Mabsadd m
.92177 .58467 0 2.5 Mabsadd L
.92177 .58467 1.875 0 Mabsadd L
.92177 .58467 0 -2.5 Mabsadd L
.92177 .58467 -1.875 0 Mabsadd L closepath F
.93537 .57863 -1.875 0 Mabsadd m
.93537 .57863 0 2.5 Mabsadd L
.93537 .57863 1.875 0 Mabsadd L
.93537 .57863 0 -2.5 Mabsadd L
.93537 .57863 -1.875 0 Mabsadd L closepath F
.94898 .57239 -1.875 0 Mabsadd m
.94898 .57239 0 2.5 Mabsadd L
.94898 .57239 1.875 0 Mabsadd L
.94898 .57239 0 -2.5 Mabsadd L
.94898 .57239 -1.875 0 Mabsadd L closepath F
.96259 .56609 -1.875 0 Mabsadd m
.96259 .56609 0 2.5 Mabsadd L
.96259 .56609 1.875 0 Mabsadd L
.96259 .56609 0 -2.5 Mabsadd L
.96259 .56609 -1.875 0 Mabsadd L closepath F
.97619 .55985 -1.875 0 Mabsadd m
.97619 .55985 0 2.5 Mabsadd L
.97619 .55985 1.875 0 Mabsadd L
.97619 .55985 0 -2.5 Mabsadd L
.97619 .55985 -1.875 0 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{363, 224.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005[0000h2000`400?l00000o`00003oo`3IfMU/
0=WIf@00K@3IfMT00`000000fMWI0=WIf@3k0=WIf@00K@3IfMT00`000000fMWI0=WIf@3k0=WIf@00
K@3IfMT00`000000fMWI0=WIf@3k0=WIf@00K@3IfMT00`000000fMWI0=WIf@3k0=WIf@00K@3IfMT0
0`000000fMWI0=WIf@3k0=WIf@00K@3IfMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI
0080fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0Z03IfMT006d0fMWI0`00000h0=WIf@030000003IfMT0fMWI01T0000000<0fMWI0000
003IfMT0Y03IfMT006d0fMWI00<000000=WIf@3IfMT0=`3IfMT800000080fMWI0P0000020=WIf@<0
00000P3IfMT3000000030=WIf@0000000000008000000P3IfMT300000:@0fMWI001]0=WIf@030000
003IfMT0fMWI03<0fMWI1`0000020=WIf@<000000`3IfMT01@000000fMWI0=WIf@3IfMT0000000@0
fMWI00@000000=WIf@3IfMT0fMWI0`0000000`3IfMT000000000000600000:00fMWI001]0=WIf@03
0000003IfMT0fMWI0380fMWI0`0000020=WIf@<000000`3IfMT00`000000fMWI0=WIf@0@0=WIf@04
0000003IfMT0fMWI0=WIf@<000000P3IfMT3000009l0fMWI001]0=WIf@030000003IfMT0fMWI02h0
fMWI1`0000030=WIf@030000003IfMT0fMWI01X0fMWI00@000000=WIf@3IfMT0fMWI1`00002K0=WI
f@00K@3IfMT00`000000fMWI0=WIf@0]0=WIf@<000000`3IfMT00`000000fMWI0=WIf@0T0=WIf@04
0000003IfMT0fMWI0=WIf@<00000VP3IfMT006d0fMWI00<000000=WIf@3IfMT0;03IfMT4000002d0
fMWI1@00002I0=WIf@00K@3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0000000800000
;P3IfMT3000000030=WIf@000000fMWI09L0fMWI001]0=WIf@030000003IfMT0fMWI02T0fMWI0P00
00030=WIf@030000003IfMT0fMWI02h0fMWI00@000000=WIf@3IfMT0fMWI0P00002F0=WIf@00K@3I
fMT00`000000fMWI0=WIf@0X0=WIf@<00000>03IfMT3000009D0fMWI001]0=WIf@<000009`3IfMT4
000003P0fMWI1000002D0=WIf@00K@3IfMT00`000000fMWI0=WIf@0V0=WIf@040000003IfMT0fMWI
000003X0fMWI00@000000=WIf@3IfMT00000T`3IfMT006d0fMWI00<000000=WIf@3IfMT0903IfMT2
00000480fMWI00<000000=WIf@3IfMT0T03IfMT006d0fMWI00<000000=WIf@3IfMT0903IfMT20000
0480fMWI0P00002A0=WIf@00K@3IfMT00`000000fMWI0=WIf@0S0=WIf@<00000@@3IfMT300000940
fMWI001]0=WIf@030000003IfMT0fMWI02<0fMWI0`0000120=WIf@<00000T03IfMT006d0fMWI00<0
00000=WIf@3IfMT08P3IfMT00`000000fMWI000000160=WIf@030000003IfMT0fMWI08d0fMWI001]
0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT0AP3IfMT00`000000fMWI0=WIf@2=
0=WIf@00K@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI04P0fMWI0P00002=0=WI
f@00K@3IfMT00`000000fMWI0=WIf@0O0=WIf@800000C03IfMT2000008`0fMWI001]0=WIf@030000
003IfMT0fMWI01h0fMWI0`00001;0=WIf@<00000S03IfMT006d0fMWI0`00000O0=WIf@800000C03I
fMT2000008`0fMWI001]0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0C03IfMT0
0`000000fMWI0000002;0=WIf@00K@3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI
04h0fMWI00<000000=WIf@3IfMT0R@3IfMT006d0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000
fMWI0=WIf@1@0=WIf@030000003IfMT0fMWI08P0fMWI001]0=WIf@030000003IfMT0fMWI01d0fMWI
00<000000=WIf@3IfMT0D03IfMT00`000000fMWI0=WIf@280=WIf@00K@3IfMT00`000000fMWI0=WI
f@0K0=WIf@800000E03IfMT2000008P0fMWI001]0=WIf@030000003IfMT0fMWI01X0fMWI0`00001D
0=WIf@<00000Q`3IfMT006d0fMWI00<000000=WIf@3IfMT06P3IfMT3000005@0fMWI0`0000270=WI
f@00K@3IfMT00`000000fMWI0=WIf@0J0=WIf@800000EP3IfMT2000008L0fMWI001]0=WIf@030000
003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0EP3IfMT00`000000fMWI0=WIf@250=WIf@00K@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI05P0fMWI00<000000=WIf@3IfMT0Q03I
fMT006d0fMWI0`00000H0=WIf@030000003IfMT0fMWI05X0fMWI00<000000=WIf@3IfMT0P`3IfMT0
06d0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@1J0=WIf@030000003IfMT0fMWI
08<0fMWI001]0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0G03IfMT00`000000
fMWI0=WIf@220=WIf@00K@3IfMT00`000000fMWI0=WIf@0F0=WIf@800000GP3IfMT2000008<0fMWI
001]0=WIf@030000003IfMT0fMWI01D0fMWI0`00001N0=WIf@<00000PP3IfMT006d0fMWI00<00000
0=WIf@3IfMT0503IfMT4000005d0fMWI100000220=WIf@00K@3IfMT00`000000fMWI0=WIf@0E0=WI
f@<00000GP3IfMT300000880fMWI001]0=WIf@030000003IfMT0fMWI01D0fMWI0P00001P0=WIf@80
0000PP3IfMT005P0fMWI0`0000030=WIf@030000003IfMT0000000<000002@3IfMT00`000000fMWI
0=WIf@0E0=WIf@030000003IfMT0fMWI0600fMWI00<000000=WIf@3IfMT0P03IfMT005L0fMWI00D0
00000=WIf@3IfMT0fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@000000203IfMT00`000000
fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT0O`3IfMT005L0fMWI
00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT0503IfMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI07l0fMWI001?0=WIf@L00000
00<0fMWI0000003IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI
1000000B0=WIf@030000003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT0OP3IfMT005L0fMWI00D0
00000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
4`3IfMT00`000000fMWI0=WIf@1T0=WIf@030000003IfMT0fMWI07h0fMWI001G0=WIf@050000003I
fMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0180fMWI
00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI0=WIf@1m0=WIf@00E`3IfMT01@000000fMWI0=WI
f@3IfMT0000000@0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0B0=WIf@03
0000003IfMT0fMWI06H0fMWI00<000000=WIf@3IfMT0O@3IfMT005P0fMWI0`0000060=WIf@800000
2P3IfMT00`000000fMWI0=WIf@0A0=WIf@800000J03IfMT2000007h0fMWI001]0=WIf@030000003I
fMT0fMWI0100fMWI0`00001X0=WIf@<00000O@3IfMT006d0fMWI00<000000=WIf@3IfMT03`3IfMT4
000006L0fMWI1000001m0=WIf@00K@3IfMT00`000000fMWI0=WIf@0@0=WIf@<00000J03IfMT30000
07d0fMWI001]0=WIf@030000003IfMT0fMWI0100fMWI0P00001Z0=WIf@800000O@3IfMT006d0fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@1Z0=WIf@030000003IfMT0fMWI07/0fMWI
001]0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0K03IfMT00`000000fMWI0=WI
f@1j0=WIf@00K@3IfMT3000000l0fMWI00<000000=WIf@3IfMT0K03IfMT00`000000fMWI0=WIf@1j
0=WIf@00K@3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WI
f@3IfMT0NP3IfMT006d0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@1^0=WIf@03
0000003IfMT0fMWI07T0fMWI001]0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0
KP3IfMT00`000000fMWI0=WIf@1i0=WIf@00K@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003I
fMT0fMWI06h0fMWI00<000000=WIf@3IfMT0N@3IfMT006d0fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000fMWI0=WIf@1`0=WIf@030000003IfMT0fMWI07P0fMWI001]0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT0L03IfMT00`000000fMWI0=WIf@1h0=WIf@00K@3IfMT00`000000
fMWI0=WIf@0<0=WIf@800000LP3IfMT2000007T0fMWI001]0=WIf@030000003IfMT0fMWI00/0fMWI
0`00001b0=WIf@<00000N03IfMT006d0fMWI00<000000=WIf@3IfMT02P3IfMT400000740fMWI1000
001h0=WIf@00K@3IfMT3000000/0fMWI0`00001b0=WIf@<00000N03IfMT006d0fMWI00<000000=WI
f@3IfMT02`3IfMT2000007@0fMWI0P00001h0=WIf@00K@3IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI07@0fMWI00<000000=WIf@3IfMT0MP3IfMT006d0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@1d0=WIf@030000003IfMT0fMWI07H0fMWI001]0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0MP3IfMT00`000000fMWI0=WIf@1e0=WIf@00K@3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI07H0fMWI00<000000=WIf@3IfMT0M@3IfMT0
06d0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI
07D0fMWI001]0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0N03IfMT00`000000
fMWI0=WIf@1d0=WIf@00K@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI07P0fMWI
00<000000=WIf@3IfMT0M03IfMT006d0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@1h0=WIf@030000003IfMT0fMWI07@0fMWI001]0=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@1c0=WIf@00K@3IfMT3000000P0fMWI00<000000=WI
f@3IfMT0NP3IfMT00`000000fMWI0=WIf@1c0=WIf@00K@3IfMT00`000000fMWI0=WIf@080=WIf@03
0000003IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0L`3IfMT006d0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@1l0=WIf@030000003IfMT0fMWI0780fMWI001]0=WIf@030000003I
fMT0fMWI00H0fMWI0`00001l0=WIf@<00000L`3IfMT006d0fMWI00<000000=WIf@3IfMT01P3IfMT3
000007`0fMWI0`00001c0=WIf@00K@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
07`0fMWI00<000000=WIf@3IfMT0LP3IfMT006d0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000
fMWI0=WIf@1n0=WIf@030000003IfMT0fMWI0740fMWI001]0=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0OP3IfMT00`000000fMWI0=WIf@1a0=WIf@00K@3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@3IfMT0L@3IfMT006d0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@200=WIf@030000003IfMT0fMWI0700fMWI001]0=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@1`0=WI
f@00K@3IfMT3000000D0fMWI00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@1`0=WIf@00
K@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0880fMWI00<000000=WIf@3IfMT0
K`3IfMT006d0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@220=WIf@030000003I
fMT0fMWI06l0fMWI001]0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0PP3IfMT0
0`000000fMWI0=WIf@1_0=WIf@00K@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
0880fMWI00<000000=WIf@3IfMT0K`3IfMT006d0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@240=WIf@030000003IfMT0fMWI06h0fMWI001]0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0Q03IfMT00`000000fMWI0=WIf@1^0=WIf@00K@3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI08@0fMWI00<000000=WIf@3IfMT0KP3IfMT005P0fMWI0`000003
0=WIf@040000003IfMT0fMWI0=WIf@<00000203IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI08H0fMWI00<000000=WIf@3IfMT0K@3IfMT005L0fMWI00D000000=WIf@3IfMT0fMWI0000
00070=WIf@030000003IfMT0fMWI00L0fMWI00@000000=WIf@3IfMT0fMWI0`0000260=WIf@<00000
KP3IfMT005L0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00L0fMWI
00@000000=WIf@3IfMT0fMWI0`0000260=WIf@<00000KP3IfMT004l0fMWI1`0000000`3IfMT00000
0=WIf@020=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01`3IfMT4000000030=WI
f@000000fMWI08L0fMWI00<000000=WIf@3IfMT0K@3IfMT005L0fMWI00D000000=WIf@3IfMT0fMWI
000000070=WIf@030000003IfMT0fMWI00L0fMWI00D000000=WIf@3IfMT0fMWI0000002:0=WIf@03
0000003IfMT0fMWI06`0fMWI001G0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000
fMWI0=WIf@070=WIf@050000003IfMT0fMWI0=WIf@000000RP3IfMT00`000000fMWI0=WIf@1/0=WI
f@00E`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@3IfMT01`3IfMT01@00
0000fMWI0=WIf@3IfMT0000008X0fMWI00<000000=WIf@3IfMT0K03IfMT005P0fMWI0`0000070=WI
f@8000002@3IfMT010000000fMWI0=WIf@00002<0=WIf@030000003IfMT0fMWI06/0fMWI001]0=WI
f@040000003IfMT0fMWI000008`0fMWI00<000000=WIf@3IfMT0J`3IfMT006d0fMWI00@000000=WI
f@3IfMT00000S03IfMT00`000000fMWI0=WIf@1[0=WIf@00K@3IfMT00`000000fMWI0000002>0=WI
f@030000003IfMT0fMWI06X0fMWI001]0=WIf@030000003IfMT0000008h0fMWI00<000000=WIf@3I
fMT0JP3IfMT006d0fMWI00<000000=WIf@000000SP3IfMT00`000000fMWI0=WIf@1Z0=WIf@00K@3I
fMT3000008h0fMWI00<000000=WIf@3IfMT0JP3IfMT006d0fMWI0P00002@0=WIf@030000003IfMT0
fMWI06T0fMWI001]0=WIf@800000T03IfMT00`000000fMWI0=WIf@1Y0=WIf@00K@3IfMT200000900
fMWI00<000000=WIf@3IfMT0J@3IfMT006d0fMWI00<000000=WIf@3IfMT0T03IfMT00`000000fMWI
0=WIf@1X0=WIf@00K@3IfMT200000900fMWI0P00001Z0=WIf@00K03IfMT3000008l0fMWI0`00001Z
0=WIf@00K@3IfMT200000900fMWI0P00001Z0=WIf@00K03IfMT2000009<0fMWI00<000000=WIf@3I
fMT0I`3IfMT006`0fMWI0P00002C0=WIf@030000003IfMT0fMWI06L0fMWI001/0=WIf@800000T`3I
fMT00`000000fMWI0=WIf@1W0=WIf@00K03IfMT400000940fMWI00<000000=WIf@3IfMT0I`3IfMT0
06`0fMWI0P00002C0=WIf@030000003IfMT0fMWI06L0fMWI001[0=WIf@030000003IfMT0000009@0
fMWI00<000000=WIf@3IfMT0IP3IfMT006/0fMWI00<000000=WIf@000000U03IfMT00`000000fMWI
0=WIf@1V0=WIf@00J`3IfMT00`000000fMWI0000002D0=WIf@030000003IfMT0fMWI06H0fMWI001[
0=WIf@030000003IfMT0000009@0fMWI00<000000=WIf@3IfMT0IP3IfMT006X0fMWI00@000000=WI
f@3IfMT00000U@3IfMT00`000000fMWI0=WIf@1U0=WIf@00JP3IfMT010000000fMWI0=WIf@00002E
0=WIf@030000003IfMT0fMWI06D0fMWI001Z0=WIf@040000003IfMT0fMWI000009D0fMWI00<00000
0=WIf@3IfMT0I@3IfMT006X0fMWI00@000000=WIf@3IfMT00000U@3IfMT00`000000fMWI0=WIf@1U
0=WIf@00JP3IfMT010000000fMWI0=WIf@00002E0=WIf@030000003IfMT0fMWI06D0fMWI001Y0=WI
f@040000003IfMT0fMWI0=WIf@<00000U03IfMT00`000000fMWI0=WIf@1T0=WIf@00J03IfMT20000
00<0fMWI00<000000=WIf@3IfMT0T`3IfMT3000006D0fMWI001X0=WIf@8000000`3IfMT00`000000
fMWI0=WIf@2C0=WIf@<00000I@3IfMT006T0fMWI00D000000=WIf@3IfMT0fMWI0000002F0=WIf@03
0000003IfMT0fMWI06@0fMWI001X0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
U@3IfMT00`000000fMWI0=WIf@1S0=WIf@00J03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI09D0fMWI00<000000=WIf@3IfMT0H`3IfMT006P0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@2E0=WIf@030000003IfMT0fMWI06<0fMWI000:0=WIf@@000000`3IfMT30000
02T0fMWI0`0000020=WIf@<000008P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
02X0fMWI0`0000020=WIf@<000009`3IfMT4000000<0fMWI0`00000W0=WIf@@000000`3IfMT30000
0080fMWI00<000000=WIf@3IfMT0903IfMT010000000fMWI0=WIf@3IfMT3000002L0fMWI10000003
0=WIf@<000001P3IfMT000X0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000<0fMWI00<0
00000=WIf@3IfMT09`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01l0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0[0=WIf@040000003IfMT0fMWI000000<0
fMWI00<000000=WIf@3IfMT0903IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@0X0=WIf@030000003IfMT0000000<0fMWI00<000000=WIf@0000009P3IfMT0
10000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@0000000`3I
fMT00`000000fMWI0=WIf@030=WIf@002`3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0
fMWI0=WIf@000000:@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01l0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0[0=WIf@040000003IfMT0fMWI000000<0
fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WI
f@000000:P3IfMT00`000000fMWI000000030=WIf@030000003IfMT0000002<0fMWI1`0000030=WI
f@030000003IfMT0fMWI02P0fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@030=WI
f@000`3IfMT700000080fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI
01`0fMWI1`0000040=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT07P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02/0fMWI00@000000=WIf@3IfMT000000`3I
fMT00`000000fMWI0=WIf@0V0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT00`000000fMWI
0=WIf@0X0=WIf@030000003IfMT0000000<0fMWI00@000000=WIf@3IfMT000008P3IfMT010000000
fMWI0=WIf@0000020=WIf@050000003IfMT0fMWI0=WIf@000000:P3IfMT00`000000fMWI00000003
0=WIf@030000003IfMT0fMWI00<0fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI00<00000
0=WIf@3IfMT09`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01h0fMWI00<0
00000=WIf@3IfMT0103IfMT3000002/0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI
0=WIf@0W0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT09@3IfMT300000080
fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@0000000P3IfMT01@000000fMWI0=WIf@3IfMT0000002X0fMWI00<000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@030=WIf@003@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI02L0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@0000030=WIf@030000
003IfMT0fMWI02L0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0W0=WIf@04
0000003IfMT0fMWI000000<0fMWI00@000000=WIf@3IfMT00000903IfMT200000080fMWI00D00000
0=WIf@3IfMT0fMWI0000000V0=WIf@@000000P3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI
000:0=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI0000000Y0=WIf@04
0000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI02/0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0T
0=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI0000000V0=WIf@070000
003IfMT0fMWI0=WIf@000000fMWI000000030=WIf@040000003IfMT0fMWI000002@0fMWI0P000002
0=WIf@050000003IfMT0fMWI0=WIf@0000009`3IfMT00`000000fMWI0=WIf@020=WIf@050000003I
fMT0fMWI0=WIf@0000001@3IfMT000/0fMWI0P0000040=WIf@<00000:@3IfMT2000000<0fMWI0`00
000P0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI0`00
000X0=WIf@800000103IfMT3000002P0fMWI0`0000030=WIf@<00000103IfMT00`000000fMWI0=WI
f@0R0=WIf@040000003IfMT0fMWI0=WIf@<00000:03IfMT400000080fMWI0`0000060=WIf@00I@3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI09P0fMWI00<000000=WIf@3IfMT0H03I
fMT006D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@2H0=WIf@030000003IfMT0
fMWI0600fMWI001T0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0V@3IfMT00`00
0000fMWI0=WIf@1O0=WIf@00H`3IfMT3000000L0fMWI00<000000=WIf@3IfMT0V03IfMT300000600
fMWI001S0=WIf@<000001`3IfMT00`000000fMWI0=WIf@2H0=WIf@<00000H03IfMT006<0fMWI0P00
00080=WIf@030000003IfMT0fMWI09T0fMWI0P00001P0=WIf@00H`3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI09X0fMWI00<000000=WIf@3IfMT0GP3IfMT000<0fMWIo`00001Y0000
0000303IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI000000080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@00
00001`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT000`0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0R0=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0^0=WIf@030000
003IfMT0fMWI02h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0R0=WIf@030000
003IfMT0fMWI02h0fMWI00<000000=WIf@3IfMT01`3IfMT00680fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@2K0=WIf@030000003IfMT0fMWI05d0fMWI001Q0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@1L0=WIf@00H@3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI09`0fMWI00<000000=WIf@3IfMT0G03IfMT00640
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@2L0=WIf@030000003IfMT0fMWI05`0
fMWI001P0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0W@3IfMT00`000000fMWI
0=WIf@1K0=WIf@00H03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI09d0fMWI00<0
00000=WIf@3IfMT0F`3IfMT00600fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2M
0=WIf@030000003IfMT0fMWI05/0fMWI001O0=WIf@030000003IfMT0fMWI00/0fMWI0`00002N0=WI
f@030000003IfMT0fMWI05X0fMWI001N0=WIf@<00000303IfMT00`000000fMWI0=WIf@2M0=WIf@<0
0000F`3IfMT005h0fMWI0`00000<0=WIf@030000003IfMT0fMWI09d0fMWI0`00001K0=WIf@00GP3I
fMT2000000d0fMWI00<000000=WIf@3IfMT0WP3IfMT2000005/0fMWI001N0=WIf@030000003IfMT0
fMWI00`0fMWI00<000000=WIf@3IfMT0W`3IfMT00`000000fMWI0=WIf@1I0=WIf@00GP3IfMT00`00
0000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI09l0fMWI00<000000=WIf@3IfMT0F@3IfMT005d0
fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@2P0=WIf@030000003IfMT0fMWI05P0
fMWI001M0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0X03IfMT00`000000fMWI
0=WIf@1H0=WIf@00G03IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0:40fMWI00<0
00000=WIf@3IfMT0E`3IfMT005`0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@2Q
0=WIf@030000003IfMT0fMWI05L0fMWI001L0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT0X@3IfMT00`000000fMWI0=WIf@1G0=WIf@00F`3IfMT00`000000fMWI0=WIf@0?0=WIf@<0
0000XP3IfMT00`000000fMWI0=WIf@1F0=WIf@00F`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000
003IfMT0fMWI0:80fMWI00<000000=WIf@3IfMT0EP3IfMT005X0fMWI0P00000A0=WIf@030000003I
fMT0fMWI0:80fMWI0P00001G0=WIf@00F@3IfMT300000140fMWI00<000000=WIf@3IfMT0XP3IfMT3
000005H0fMWI001I0=WIf@<000004@3IfMT00`000000fMWI0=WIf@2R0=WIf@<00000EP3IfMT005T0
fMWI0P00000B0=WIf@030000003IfMT0fMWI0:<0fMWI0P00001F0=WIf@00F@3IfMT00`000000fMWI
0=WIf@0A0=WIf@030000003IfMT0fMWI0:@0fMWI00<000000=WIf@3IfMT0E03IfMT005P0fMWI00<0
00000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@2U0=WIf@030000003IfMT0fMWI05<0fMWI001H
0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0Y@3IfMT00`000000fMWI0=WIf@1C
0=WIf@00E`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI0:H0fMWI00<000000=WI
f@3IfMT0DP3IfMT005L0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@2V0=WIf@03
0000003IfMT0fMWI0580fMWI001G0=WIf@030000003IfMT0fMWI01<0fMWI0`00002V0=WIf@030000
003IfMT0fMWI0580fMWI001F0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0Y`3I
fMT00`000000fMWI0=WIf@1A0=WIf@00E@3IfMT2000001H0fMWI00<000000=WIf@3IfMT0Y`3IfMT2
00000580fMWI001D0=WIf@<000005P3IfMT00`000000fMWI0=WIf@2W0=WIf@<00000D@3IfMT005@0
fMWI0`00000F0=WIf@030000003IfMT0fMWI0:L0fMWI0`00001A0=WIf@00E03IfMT2000001L0fMWI
00<000000=WIf@3IfMT0Z03IfMT200000540fMWI001C0=WIf@030000003IfMT0fMWI01L0fMWI00<0
00000=WIf@3IfMT0ZP3IfMT00`000000fMWI0=WIf@1>0=WIf@00D`3IfMT00`000000fMWI0=WIf@0G
0=WIf@030000003IfMT0fMWI0:X0fMWI00<000000=WIf@3IfMT0CP3IfMT00580fMWI00<000000=WI
f@3IfMT0603IfMT00`000000fMWI0=WIf@2[0=WIf@030000003IfMT0fMWI04d0fMWI001B0=WIf@03
0000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`000000fMWI0=WIf@1=0=WIf@00
D03IfMT2000001/0fMWI00<000000=WIf@3IfMT0[03IfMT2000004d0fMWI000<0=WIf@030000003I
fMT0fMWI0400fMWI0`00000K0=WIf@<00000[03IfMT300000480fMWI00<000000=WIf@3IfMT01`3I
fMT000/0fMWI0`0000100=WIf@@000006`3IfMT00`000000fMWI0=WIf@2[0=WIf@@00000@@3IfMT3
000000P0fMWI000;0=WIf@L00000?@3IfMT3000001/0fMWI00<000000=WIf@3IfMT0[03IfMT30000
03d0fMWI1`0000080=WIf@00303IfMT010000000fMWI0=WIf@3IfMT3000003/0fMWI00<000000=WI
f@000000703IfMT00`000000fMWI0=WIf@2]0=WIf@030000003IfMT0000003/0fMWI0`0000030=WI
f@030000003IfMT0fMWI00L0fMWI000@0=WIf@L00000=P3IfMT00`000000fMWI0=WIf@0M0=WIf@03
0000003IfMT0fMWI0;00fMWI00<000000=WIf@3IfMT0=03IfMT7000000d0fMWI000A0=WIf@040000
003IfMT0fMWI0=WIf@<00000=@3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0;00
fMWI00<000000=WIf@3IfMT0<`3IfMT3000000<0fMWI00<000000=WIf@3IfMT0303IfMT001@0fMWI
1`00000`0=WIf@800000803IfMT00`000000fMWI0=WIf@2a0=WIf@800000;`3IfMT700000180fMWI
000E0=WIf@<000000P3IfMT3000002d0fMWI0`00000P0=WIf@030000003IfMT0fMWI0;40fMWI0`00
000]0=WIf@<000000P3IfMT300000180fMWI000F0=WIf@030000003IfMT0fMWI00<0000000<0fMWI
0000003IfMT0:P3IfMT4000000/0fMWI0`0000030=WIf@040000003IfMT0fMWI0=WIf@<00000203I
fMT00`000000fMWI0=WIf@2a0=WIf@@00000:P3IfMT5000000<0fMWI00<000000=WIf@3IfMT04@3I
fMT001X0fMWI0P0000020=WIf@800000:03IfMT010000000fMWI0=WIf@00000;0=WIf@050000003I
fMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0;80fMWI
00@000000=WIf@3IfMT000009`3IfMT200000080fMWI0`00000G0=WIf@007P3IfMT3000002D0fMWI
0P00000?0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI0;H0fMWI00<000000=WIf@3IfMT08`3IfMT3000000<0fMWI00<000000=WIf@3I
fMT05P3IfMT001h0fMWI1`00000P0=WIf@<000003`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0
fMWI00<000000=WIf@3IfMT01`3IfMT400000;D0fMWI0`00000P0=WIf@H00000703IfMT001l0fMWI
00@000000=WIf@3IfMT0fMWI1@0000000`3IfMT000000=WIf@0I0=WIf@@000003`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@2e0=WI
f@<0000000<0fMWI0000003IfMT06@3IfMT00`000000fMWI0=WIf@03000000<0fMWI00<000000=WI
f@3IfMT06`3IfMT002<0fMWI0`0000020=WIf@<00000603IfMT00`000000fMWI0=WIf@02000000l0
fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0]P3IfMT200000080fMWI0P00000G0=WIf@@0000000<0fMWI0000000000008@3IfMT002@0
fMWI00<000000=WIf@3IfMT02000000B0=WIf@8000000`3IfMT00`000000fMWI0=WIf@0>0=WIf@05
0000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0;/0fMWI0P00000B0=WIf@L000000`3IfMT00`000000fMWI0=WIf@0O0=WIf@00:03IfMT300000080
fMWI1@0000000`3IfMT000000=WIf@030=WIf@030000003IfMT0fMWI0080fMWI1P00000E0=WIf@<0
00001`3IfMT2000000T0fMWI00<000000=WIf@3IfMT0^P3IfMT7000000@0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0400000080fMWI0`00000U0=WIf@00:@3IfMT010000000fMWI
0=WIf@3IfMT300000080fMWI3@0000020=WIf@800000:P3IfMT00`000000fMWI0=WIf@2k0=WIf@80
00000P3IfMT>000000040=WIf@0000000000000000<0fMWI00<000000=WIf@3IfMT0903IfMT002h0
fMWI00@000000=WIf@3IfMT0fMWI0`0000000`3IfMT000000000000200000080fMWI0`00000^0=WI
f@030000003IfMT0fMWI0;/0fMWI00@000000=WIf@3IfMT0fMWI0`0000000`3IfMT0000000000002
00000080fMWI0`0000030=WIf@030000003IfMT0fMWI02T0fMWI000c0=WIf@040000003IfMT0fMWI
0=WIf@<000000`3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI0<00fMWI00@00000
0=WIf@3IfMT0fMWI0`0000030=WIf@030000003IfMT0fMWI02h0fMWI000h0=WIf@030000003IfMT0
fMWI0380fMWI00<000000=WIf@3IfMT0a@3IfMT00`000000fMWI0=WIf@0c0=WIf@00K@3IfMT00`00
0000fMWI0=WIf@3k0=WIf@00K@3IfMT300000?/0fMWI001]0=WIf@030000003IfMT0fMWI0?/0fMWI
0000\
\>"],
  ImageRangeCache->{{{0, 362}, {223.25, 0}} -> {-22.5666, -0.291798, 0.205296,
   0.00185423}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A Quarupole structure with 8 azimutal segments", "Subsection"],

Cell[BoxData[
    \(radUtiDelAll[]; \nnseg = 8; \nrint = 10; \nrext = 20; \nLz = 30; \n
    phi1 = \(-Pi\)/nseg; \nphi2 = phi1 + 2\ Pi; \nnz = 1; \nnr = {1, 1}; \n
    pt = {0, 0, 0}; \ndphi = \((phi2 - phi1)\)/nseg; \nbr = 1.2; \n
    mag = {0, br, 0, 3}; \n
    cyl2 = RadCylinder[pt, rint, rext, phi1, phi2, Lz, nr, nseg, nz, mag]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      RowBox[{"d2", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "cyl2", "]"}]}], ";", "\n", 
      \(Show[Graphics3D[d2]\n, ViewPoint -> {0, 0, 10000}]\), ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.20252 .17514 -12.5 -14 ]
[.20252 .17514 12.5 0 ]
[.35126 .17514 -12.5 -14 ]
[.35126 .17514 12.5 0 ]
[.5 .17514 -5 -14 ]
[.5 .17514 5 0 ]
[.64874 .17514 -8 -14 ]
[.64874 .17514 8 0 ]
[.79748 .17514 -8 -14 ]
[.79748 .17514 8 0 ]
[.5 .11264 -8 -14 ]
[.5 .11264 8 0 ]
[.17514 .20252 -25 -7 ]
[.17514 .20252 0 7 ]
[.17514 .35126 -25 -7 ]
[.17514 .35126 0 7 ]
[.17514 .5 -10 -7 ]
[.17514 .5 0 7 ]
[.17514 .64874 -16 -7 ]
[.17514 .64874 0 7 ]
[.17514 .79748 -16 -7 ]
[.17514 .79748 0 7 ]
[.11264 .5 -15 -7 ]
[.11264 .5 0 7 ]
[.82484 .18766 0 -7 ]
[.82484 .18766 10 7 ]
[.82484 .18766 0 -7 ]
[.82484 .18766 16 7 ]
[.82485 .18765 0 -7 ]
[.82485 .18765 16 7 ]
[.82486 .18764 0 -7 ]
[.82486 .18764 16 7 ]
[.88735 .18765 0 -7 ]
[.88735 .18765 14 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.18764 .18764 m
.81236 .18764 L
s
.25 Mabswid
.20252 .18764 m
.20252 .19389 L
s
gsave
.20252 .17514 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.35126 .18764 m
.35126 .19389 L
s
gsave
.35126 .17514 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .18764 m
.5 .19389 L
s
gsave
.5 .17514 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.64874 .18764 m
.64874 .19389 L
s
gsave
.64874 .17514 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.79748 .18764 m
.79748 .19389 L
s
gsave
.79748 .17514 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.23226 .18764 m
.23226 .19139 L
s
.26201 .18764 m
.26201 .19139 L
s
.29176 .18764 m
.29176 .19139 L
s
.32151 .18764 m
.32151 .19139 L
s
.38101 .18764 m
.38101 .19139 L
s
.41075 .18764 m
.41075 .19139 L
s
.4405 .18764 m
.4405 .19139 L
s
.47025 .18764 m
.47025 .19139 L
s
.52975 .18764 m
.52975 .19139 L
s
.5595 .18764 m
.5595 .19139 L
s
.58925 .18764 m
.58925 .19139 L
s
.61899 .18764 m
.61899 .19139 L
s
.67849 .18764 m
.67849 .19139 L
s
.70824 .18764 m
.70824 .19139 L
s
.73799 .18764 m
.73799 .19139 L
s
.76774 .18764 m
.76774 .19139 L
s
gsave
.5 .11264 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
75.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.18764 .18764 m
.18764 .81236 L
s
.25 Mabswid
.18764 .20252 m
.19389 .20252 L
s
gsave
.17514 .20252 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18764 .35126 m
.19389 .35126 L
s
gsave
.17514 .35126 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18764 .5 m
.19389 .5 L
s
gsave
.17514 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18764 .64874 m
.19389 .64874 L
s
gsave
.17514 .64874 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18764 .79748 m
.19389 .79748 L
s
gsave
.17514 .79748 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.18764 .23226 m
.19139 .23226 L
s
.18764 .26201 m
.19139 .26201 L
s
.18764 .29176 m
.19139 .29176 L
s
.18764 .32151 m
.19139 .32151 L
s
.18764 .38101 m
.19139 .38101 L
s
.18764 .41075 m
.19139 .41075 L
s
.18764 .4405 m
.19139 .4405 L
s
.18764 .47025 m
.19139 .47025 L
s
.18764 .52975 m
.19139 .52975 L
s
.18764 .5595 m
.19139 .5595 L
s
.18764 .58925 m
.19139 .58925 L
s
.18764 .61899 m
.19139 .61899 L
s
.18764 .67849 m
.19139 .67849 L
s
.18764 .70824 m
.19139 .70824 L
s
.18764 .73799 m
.19139 .73799 L
s
.18764 .76774 m
.19139 .76774 L
s
gsave
.11264 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.81234 .18766 m
.81236 .18764 L
s
.25 Mabswid
.81234 .18766 m
.80609 .18766 L
s
gsave
.82484 .18766 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81234 .18766 m
.80609 .18766 L
s
gsave
.82484 .18766 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81235 .18765 m
.8061 .18765 L
s
gsave
.82485 .18765 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81236 .18764 m
.80611 .18764 L
s
gsave
.82486 .18764 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.81234 .18766 m
.80859 .18766 L
s
.81234 .18766 m
.80859 .18766 L
s
.81234 .18766 m
.80859 .18766 L
s
.81234 .18766 m
.80859 .18766 L
s
.81235 .18765 m
.8086 .18765 L
s
.81235 .18765 m
.8086 .18765 L
s
.81235 .18765 m
.8086 .18765 L
s
.81235 .18765 m
.8086 .18765 L
s
.81235 .18765 m
.8086 .18765 L
s
.81235 .18765 m
.8086 .18765 L
s
.81236 .18764 m
.80861 .18764 L
s
.81236 .18764 m
.80861 .18764 L
s
gsave
.88735 .18765 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.18766 .18766 m
.18764 .18764 L
s
.18764 .18764 m
.18764 .81236 L
s
.18764 .81236 m
.18766 .81234 L
s
.18766 .81234 m
.18766 .18766 L
s
.81234 .18766 m
.81234 .81234 L
s
.81234 .81234 m
.81236 .81236 L
s
.81236 .81236 m
.81236 .18764 L
s
.81236 .18764 m
.81234 .18766 L
s
.18766 .18766 m
.18764 .18764 L
s
.18764 .18764 m
.81236 .18764 L
s
.81236 .18764 m
.81234 .18766 L
s
.81234 .18766 m
.18766 .18766 L
s
.18766 .81234 m
.81234 .81234 L
s
.81234 .81234 m
.81236 .81236 L
s
.81236 .81236 m
.18764 .81236 L
s
.18764 .81236 m
.18766 .81234 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.79748 .37678 m .79746 .37679 L .64873 .43839 L p .1 .1 .1 r
F P
0 g
s
.62321 .79746 m .62322 .79748 L .56161 .64874 L p .1 .1 .371 r
F P
0 g
s
.56161 .64874 m .56161 .64873 L .62321 .79746 L p .1 .1 .371 r
F P
0 g
s
.62321 .20254 m .56161 .35127 L .64873 .43839 L p .807 .677 .807 r
F P
0 g
s
.64873 .43839 m .79746 .37679 L .62321 .20254 L p .807 .677 .807 r
F P
0 g
s
.56161 .35127 m .56161 .35126 L .64874 .43839 L p .1 .234 .75 r
F P
0 g
s
.64874 .43839 m .64873 .43839 L .56161 .35127 L p .1 .234 .75 r
F P
0 g
s
.79748 .37678 m .64874 .43839 L .64873 .43839 L p .1 .1 .1 r
F P
0 g
s
.62322 .20252 m .62321 .20254 L .79746 .37679 L p .1 .348 .855 r
F P
0 g
s
.62321 .20254 m .62322 .20252 L .56161 .35126 L p .753 .854 .371 r
F P
0 g
s
.56161 .35126 m .56161 .35127 L .62321 .20254 L p .753 .854 .371 r
F P
0 g
s
.37679 .20254 m .43839 .35127 L .56161 .35127 L p .807 .677 .807 r
F P
0 g
s
.56161 .35127 m .62321 .20254 L .37679 .20254 L p .807 .677 .807 r
F P
0 g
s
.43839 .35127 m .43839 .35126 L .56161 .35126 L p .264 .795 .952 r
F P
0 g
s
.56161 .35126 m .56161 .35127 L .43839 .35127 L p .264 .795 .952 r
F P
0 g
s
.56161 .35127 m .56161 .35126 L .62322 .20252 L p .753 .854 .371 r
F P
0 g
s
.62322 .20252 m .62321 .20254 L .56161 .35127 L p .753 .854 .371 r
F P
0 g
s
.62321 .20254 m .62322 .20252 L .37678 .20252 L p .404 .869 1 r
F P
0 g
s
.37678 .20252 m .37679 .20254 L .62321 .20254 L p .404 .869 1 r
F P
0 g
s
.37679 .20254 m .37678 .20252 L .43839 .35126 L p .753 .412 .1 r
F P
0 g
s
.43839 .35126 m .43839 .35127 L .37679 .20254 L p .753 .412 .1 r
F P
0 g
s
.20254 .37679 m .35127 .43839 L .43839 .35127 L p .807 .677 .807 r
F P
0 g
s
.43839 .35127 m .37679 .20254 L .20254 .37679 L p .807 .677 .807 r
F P
0 g
s
.35127 .43839 m .35126 .43839 L .43839 .35126 L p .75 1 .75 r
F P
0 g
s
.43839 .35126 m .43839 .35127 L .35127 .43839 L p .75 1 .75 r
F P
0 g
s
.43839 .35127 m .43839 .35126 L .37678 .20252 L p .753 .412 .1 r
F P
0 g
s
.37678 .20252 m .37679 .20254 L .43839 .35127 L p .753 .412 .1 r
F P
0 g
s
.20252 .37678 m .20254 .37679 L .37679 .20254 L p .855 1 .855 r
F P
0 g
s
.20254 .37679 m .20252 .37678 L .35126 .43839 L p .371 .1 .1 r
F P
0 g
s
.35126 .43839 m .35127 .43839 L .20254 .37679 L p .371 .1 .1 r
F P
0 g
s
.20254 .62321 m .35127 .56161 L .35127 .43839 L p .807 .677 .807 r
F P
0 g
s
.35127 .43839 m .20254 .37679 L .20254 .62321 L p .807 .677 .807 r
F P
0 g
s
.35127 .56161 m .35126 .56161 L .35126 .43839 L p .952 .795 .264 r
F P
0 g
s
.35126 .43839 m .35127 .43839 L .35127 .56161 L p .952 .795 .264 r
F P
0 g
s
.35127 .43839 m .35126 .43839 L .20252 .37678 L p .1 .412 .753 r
F P
0 g
s
.20252 .37678 m .20254 .37679 L .35127 .43839 L p .1 .412 .753 r
F P
0 g
s
.20254 .37679 m .20252 .37678 L .20252 .62322 L p 1 .869 .404 r
F P
0 g
s
.20252 .62322 m .20254 .62321 L .20254 .37679 L p 1 .869 .404 r
F P
0 g
s
.20254 .62321 m .20252 .62322 L .35126 .56161 L p .1 .1 .1 r
F P
0 g
s
.35126 .56161 m .35127 .56161 L .20254 .62321 L p .1 .1 .1 r
F P
0 g
s
.37679 .79746 m .43839 .64873 L .35127 .56161 L p .807 .677 .807 r
F P
0 g
s
.35127 .56161 m .20254 .62321 L .37679 .79746 L p .807 .677 .807 r
F P
0 g
s
.43839 .64873 m .43839 .64874 L .35126 .56161 L p .75 .234 .1 r
F P
0 g
s
.35126 .56161 m .35127 .56161 L .43839 .64873 L p .75 .234 .1 r
F P
0 g
s
.35127 .56161 m .35126 .56161 L .20252 .62322 L p .1 .1 .1 r
F P
0 g
s
.20252 .62322 m .20254 .62321 L .35127 .56161 L p .1 .1 .1 r
F P
0 g
s
.20254 .62321 m .20252 .62322 L .37678 .79748 L p .855 .348 .1 r
F P
0 g
s
.37678 .79748 m .37679 .79746 L .20254 .62321 L p .855 .348 .1 r
F P
0 g
s
.37679 .79746 m .37678 .79748 L .43839 .64874 L p .1 .1 .1 r
F P
0 g
s
.43839 .64874 m .43839 .64873 L .37679 .79746 L p .1 .1 .1 r
F P
0 g
s
.62321 .79746 m .56161 .64873 L .43839 .64873 L p .807 .677 .807 r
F P
0 g
s
.43839 .64873 m .37679 .79746 L .62321 .79746 L p .807 .677 .807 r
F P
0 g
s
.56161 .64873 m .56161 .64874 L .43839 .64874 L p .264 .1 .1 r
F P
0 g
s
.43839 .64874 m .43839 .64873 L .56161 .64873 L p .264 .1 .1 r
F P
0 g
s
.43839 .64873 m .43839 .64874 L .37678 .79748 L p .1 .1 .1 r
F P
0 g
s
.37678 .79748 m .37679 .79746 L .43839 .64873 L p .1 .1 .1 r
F P
0 g
s
.37679 .79746 m .37678 .79748 L .62322 .79748 L p .404 .1 .1 r
F P
0 g
s
.62322 .79748 m .62321 .79746 L .37679 .79746 L p .404 .1 .1 r
F P
0 g
s
.79746 .62321 m .64873 .56161 L .56161 .64873 L p .807 .677 .807 r
F P
0 g
s
.56161 .64873 m .62321 .79746 L .79746 .62321 L p .807 .677 .807 r
F P
0 g
s
.64873 .56161 m .64874 .56161 L .56161 .64874 L p .1 .1 .1 r
F P
0 g
s
.56161 .64874 m .56161 .64873 L .64873 .56161 L p .1 .1 .1 r
F P
0 g
s
.56161 .64873 m .56161 .64874 L .62322 .79748 L p .1 .1 .371 r
F P
0 g
s
.62322 .79748 m .62321 .79746 L .56161 .64873 L p .1 .1 .371 r
F P
0 g
s
.62321 .79746 m .62322 .79748 L .79748 .62322 L p .1 .1 .1 r
F P
0 g
s
.79748 .62322 m .79746 .62321 L .62321 .79746 L p .1 .1 .1 r
F P
0 g
s
.79746 .62321 m .79748 .62322 L .64874 .56161 L p .1 .412 .753 r
F P
0 g
s
.64874 .56161 m .64873 .56161 L .79746 .62321 L p .1 .412 .753 r
F P
0 g
s
.79746 .37679 m .64873 .43839 L .64873 .56161 L p .807 .677 .807 r
F P
0 g
s
.64873 .56161 m .79746 .62321 L .79746 .37679 L p .807 .677 .807 r
F P
0 g
s
.64873 .43839 m .64874 .43839 L .64874 .56161 L p .1 .1 .264 r
F P
0 g
s
.64874 .56161 m .64873 .56161 L .64873 .43839 L p .1 .1 .264 r
F P
0 g
s
.64873 .56161 m .64874 .56161 L .79748 .62322 L p .371 .1 .1 r
F P
0 g
s
.79748 .62322 m .79746 .62321 L .64873 .56161 L p .371 .1 .1 r
F P
0 g
s
.79746 .62321 m .79748 .62322 L .79748 .37678 L p .1 .1 .404 r
F P
0 g
s
.79748 .37678 m .79746 .37679 L .79746 .62321 L p .1 .1 .404 r
F P
0 g
s
.79746 .37679 m .79748 .37678 L .64874 .43839 L p .1 .1 .1 r
F P
0 g
s
.64874 .43839 m .64873 .43839 L .79746 .37679 L p .1 .1 .1 r
F P
0 g
s
.79746 .37679 m .79748 .37678 L .62322 .20252 L p .1 .348 .855 r
F P
0 g
s
.37679 .20254 m .37678 .20252 L .20252 .37678 L p .855 1 .855 r
F P
0 g
s
.79748 .37678 m .64874 .43839 L .56161 .35126 L p .807 .677 .807 r
F P
0 g
s
.56161 .35126 m .62322 .20252 L .79748 .37678 L p .807 .677 .807 r
F P
0 g
s
.62322 .20252 m .56161 .35126 L .43839 .35126 L p .807 .677 .807 r
F P
0 g
s
.43839 .35126 m .37678 .20252 L .62322 .20252 L p .807 .677 .807 r
F P
0 g
s
.20252 .37678 m .35126 .43839 L .35126 .56161 L p .807 .677 .807 r
F P
0 g
s
.35126 .56161 m .20252 .62322 L .20252 .37678 L p .807 .677 .807 r
F P
0 g
s
.20252 .62322 m .35126 .56161 L .43839 .64874 L p .807 .677 .807 r
F P
0 g
s
.43839 .64874 m .37678 .79748 L .20252 .62322 L p .807 .677 .807 r
F P
0 g
s
.37678 .79748 m .43839 .64874 L .56161 .64874 L p .807 .677 .807 r
F P
0 g
s
.56161 .64874 m .62322 .79748 L .37678 .79748 L p .807 .677 .807 r
F P
0 g
s
.62322 .79748 m .56161 .64874 L .64874 .56161 L p .807 .677 .807 r
F P
0 g
s
.64874 .56161 m .79748 .62322 L .62322 .79748 L p .807 .677 .807 r
F P
0 g
s
.79748 .62322 m .64874 .56161 L .64874 .43839 L p .807 .677 .807 r
F P
0 g
s
.64874 .43839 m .79748 .37678 L .79748 .62322 L p .807 .677 .807 r
F P
0 g
s
.37678 .20252 m .43839 .35126 L .35126 .43839 L p .807 .677 .807 r
F P
0 g
s
.35126 .43839 m .20252 .37678 L .37678 .20252 L p .807 .677 .807 r
F P
0 g
s
.003 w
.18764 .18764 m
.18764 .81236 L
s
.25 Mabswid
.18764 .20252 m
.19389 .20252 L
s
gsave
.17514 .20252 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18764 .35126 m
.19389 .35126 L
s
gsave
.17514 .35126 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18764 .5 m
.19389 .5 L
s
gsave
.17514 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18764 .64874 m
.19389 .64874 L
s
gsave
.17514 .64874 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.18764 .79748 m
.19389 .79748 L
s
gsave
.17514 .79748 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.18764 .23226 m
.19139 .23226 L
s
.18764 .26201 m
.19139 .26201 L
s
.18764 .29176 m
.19139 .29176 L
s
.18764 .32151 m
.19139 .32151 L
s
.18764 .38101 m
.19139 .38101 L
s
.18764 .41075 m
.19139 .41075 L
s
.18764 .4405 m
.19139 .4405 L
s
.18764 .47025 m
.19139 .47025 L
s
.18764 .52975 m
.19139 .52975 L
s
.18764 .5595 m
.19139 .5595 L
s
.18764 .58925 m
.19139 .58925 L
s
.18764 .61899 m
.19139 .61899 L
s
.18764 .67849 m
.19139 .67849 L
s
.18764 .70824 m
.19139 .70824 L
s
.18764 .73799 m
.19139 .73799 L
s
.18764 .76774 m
.19139 .76774 L
s
gsave
.11264 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00R@3IfMT300000080fMWI0`00002?0=WIf@00R`3I
fMT010000000fMWI0=WIf@00002A0=WIf@00R`3IfMT010000000fMWI0=WIf@00002A0=WIf@00S03I
fMT200000980fMWI002<0=WIf@800000TP3IfMT008/0fMWI00@000000=WIf@3IfMT00000T@3IfMT0
08/0fMWI00@000000=WIf@3IfMT00000T@3IfMT008T0fMWI0`0000020=WIf@<00000S`3IfMT00?l0
fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0
fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT003P0
fMWI100000030=WIf@<000008P3IfMT300000080fMWI0`00000Q0=WIf@<000009P3IfMT300000080
fMWI0`00000P0=WIf@@000000`3IfMT3000003P0fMWI000h0=WIf@070000003IfMT0fMWI0=WIf@00
0000fMWI000000030=WIf@030000003IfMT0fMWI0200fMWI00@000000=WIf@3IfMT000000`3IfMT0
0`000000fMWI0=WIf@0M0=WIf@050000003IfMT0fMWI0=WIf@0000009P3IfMT010000000fMWI0=WI
f@0000030=WIf@030000003IfMT0fMWI01d0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT00000
00<0fMWI00<000000=WIf@3IfMT0=@3IfMT003T0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000
fMWI0=WIf@3IfMT000000280fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0M
0=WIf@050000003IfMT0fMWI0=WIf@0000009P3IfMT010000000fMWI0=WIf@0000030=WIf@030000
003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0000003L0
fMWI000`0=WIf@L000000`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3I
fMT05P3IfMT7000000<0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0M0=WI
f@050000003IfMT0fMWI0=WIf@0000009P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003I
fMT0fMWI01l0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI03D0fMWI
000k0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0803IfMT010000000fMWI
0=WIf@0000030=WIf@030000003IfMT0fMWI01d0fMWI00D000000=WIf@3IfMT0fMWI0000000V0=WI
f@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0803IfMT010000000fMWI0=WIf@00
00030=WIf@030000003IfMT0fMWI03D0fMWI000k0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT0803IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI01d0fMWI
00D000000=WIf@3IfMT0fMWI0000000V0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WI
f@3IfMT0803IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI03D0fMWI000h0=WI
f@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI0000000R0=WIf@040000003I
fMT0fMWI000000<0fMWI00<000000=WIf@3IfMT07@3IfMT01@000000fMWI0=WIf@3IfMT0000002H0
fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0M0=WIf@040000003IfMT0fMWI
00000080fMWI00D000000=WIf@3IfMT0fMWI0000000g0=WIf@00>@3IfMT2000000@0fMWI0`00000R
0=WIf@8000000`3IfMT300000240fMWI0`00000V0=WIf@8000000`3IfMT300000240fMWI0P000004
0=WIf@<00000>03IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00>h0fMWI1@0000020=WIf@<00000
203IfMT6000001X0fMWI003^0=WIf@030000003IfMT0fMWI0080000000<0fMWI0000003IfMT00P3I
fMT00`000000fMWI0=WIf@060=WIf@050000003IfMT0fMWI0=WIf@0000006P3IfMT00>h0fMWI0P00
00001@3IfMT000000000003IfMT0000000<0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@0L0=WIf@00=@3IfMVe000000@0fMWI00<000000=WIf@0000000P0000000`3IfMT000000=WI
f@020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT06`3IfMT003D0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@D0000000<0fMWI0000003IfMT00P3IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI01X0fMWI000S0=WIf@@000000`3IfMT30000
00P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI
02P0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@02000000030=WIf@000000fMWI
0080fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0I0=WIf@008`3IfMT01`000000
fMWI0=WIf@3IfMT000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0;40fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@02000000030=WIf@000000
fMWI0080fMWI00<000000=WIf@3IfMT01@3IfMT01@000000fMWI0=WIf@3IfMT0000001/0fMWI000T
0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003I
fMT0fMWI0;L0fMWI0`0000030=WIf@<00000203IfMT6000001X0fMWI000L0=WIf@L000000P3IfMT0
1@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT01@3IfMT3000003@0fMWIA`00
000f0=WIf@030000003IfMT0fMWI03@0fMWI000V0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0c0=WIf@800000A@3>[Lh2000003D0fMWI00<0
00000=WIf@3IfMT0=03IfMT002H0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI0380fMWI00@000000<j]cP3>[Lh00000@`3>[Lh010000000cZg>
0<j]cP00000d0=WIf@030000003IfMT0fMWI03@0fMWI000S0=WIf@040000003IfMT0fMWI00000080
fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI0340fMWI00D000000<j]
cP3>[Lh0cZg>000000130<j]cP050000003>[Lh0cZg>0<j]cP000000<`3IfMT00`000000fMWI0=WI
f@0d0=WIf@00903IfMT2000000@0fMWI0`0000080=WIf@030000003IfMT0fMWI0300fMWI00<00000
0<j]cP3>[Lh00P3>[Lh00`000000cZg>0<j]cP110<j]cP030000003>[Lh0cZg>0080cZg>00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0_0=WI
f@030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh0?`3>[Lh00`000000cZg>0<j]cP040<j]
cP030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3I
fMT0;P3IfMT00`000000cZg>0<j]cP050<j]cP030000003>[Lh0cZg>03l0cZg>00<000000<j]cP3>
[Lh01@3>[Lh00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000<j]cP3>[Lh01`3>[Lh00`000000cZg>0<j]cP0m0<j]cP030000
003>[Lh0cZg>00L0cZg>00<000000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3I
fMT2000002d0fMWI00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP0m0<j]cP030000003>
[Lh0cZg>00P0cZg>00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT0
0`000000fMWI0=WIf@0[0=WIf@030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh0?@3>[Lh0
0`000000cZg>0<j]cP090<j]cP030000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0=03IfMT0
03D0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000cZg>0<j]cP0;0<j]cP030000003>[Lh0cZg>
03/0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI
03@0fMWI000e0=WIf@030000003IfMT0fMWI02T0fMWI00<000000<j]cP3>[Lh0303>[Lh00`000000
cZg>0<j]cP0k0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000=WIf@3IfMT0:@3IfMT00`000000
fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003>[Lh0cZg>00h0cZg>
00<000000<j]cP3>[Lh0>@3>[Lh00`000000cZg>0<j]cP0>0<j]cP030000003IfMT0fMWI02P0fMWI
00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000cZg>0<j]
cP0?0<j]cP030000003>[Lh0cZg>03T0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WI
f@0W0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI02H0fMWI00<00000
0<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0i0<j]cP030000003>[Lh0cZg>0100cZg>00<00000
0=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0U0=WI
f@030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh0=`3>[Lh00`000000cZg>0<j]cP0B0<j]
cP030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3I
fMT0903IfMT00`000000cZg>0<j]cP0C0<j]cP030000003>[Lh0cZg>03L0cZg>00<000000<j]cP3>
[Lh04`3>[Lh00`000000fMWI0=WIf@1K0=WIf@00=@3IfMT2000002@0fMWI00<000000<j]cP3>[Lh0
5@3>[Lh00`000000cZg>0<j]cP0e0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000=WIf@3IfMT0
8`3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003>
[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh0=@3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003I
fMT0fMWI0280fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>03D0cZg>00<000000<j]cP3>[Lh05`3>[Lh0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI
0200fMWI00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0c0<j]cP030000003>[Lh0cZg>
01T0cZg>00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000
fMWI0=WIf@0O0=WIf@030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh0<`3>[Lh00`000000
cZg>0<j]cP0J0<j]cP030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI
00<000000=WIf@3IfMT07P3IfMT00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0cZg>0340cZg>
00<000000<j]cP3>[Lh0703>[Lh00`000000fMWI0=WIf@1E0=WIf@00=@3IfMT00`000000fMWI0=WI
f@0M0=WIf@030000003>[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh0<@3>[Lh00`000000cZg>0<j]
cP0M0<j]cP030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<00000
0=WIf@3IfMT0703IfMT00`000000cZg>0<j]cP0O0<j]cP030000003>[Lh0cZg>02l0cZg>00<00000
0<j]cP3>[Lh07`3>[Lh00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WI
f@800000703IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>02l0cZg>00<000000<j]
cP3>[Lh0803>[Lh00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@03
0000003IfMT0fMWI01X0fMWI00<000000<j]cP3>[Lh08@3>[Lh00`000000cZg>0<j]cP0_0<j]cP03
0000003>[Lh0cZg>0240cZg>00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003>[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh0
;@3>[Lh00`000000cZg>0<j]cP0S0<j]cP030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0
=03IfMT003D0fMWI00<000000=WIf@3IfMT0603IfMT00`000000cZg>0<j]cP0T0<j]cP030000003>
[Lh0cZg>02d0cZg>00<000000<j]cP3>[Lh0903>[Lh00`000000fMWI0=WIf@0H0=WIf@030000003I
fMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI01L0fMWI00<000000<j]cP3>[Lh09P3>[Lh0
0`000000cZg>0<j]cP0[0<j]cP030000003>[Lh0cZg>02H0cZg>00<000000=WIf@3IfMT05`3IfMT0
0`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003>[Lh0cZg>
02L0cZg>00<000000<j]cP3>[Lh0:`3>[Lh00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI
01H0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000
cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>02/0cZg>00<000000<j]cP3>[Lh0:03>[Lh00`000000
fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI01@0fMWI
00<000000<j]cP3>[Lh0:P3>[Lh00`000000cZg>0<j]cP0Y0<j]cP030000003>[Lh0cZg>02X0cZg>
00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WI
f@0C0=WIf@030000003>[Lh0cZg>02/0cZg>00<000000<j]cP3>[Lh0:@3>[Lh00`000000cZg>0<j]
cP0[0<j]cP030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI0P00000C
0=WIf@030000003>[Lh0cZg>02d0cZg>00<000000<j]cP3>[Lh09`3>[Lh00`000000cZg>0<j]cP0]
0<j]cP030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WI
f@3IfMT04@3IfMT00`000000cZg>0<j]cP0^0<j]cP030000003>[Lh0cZg>02L0cZg>00<000000<j]
cP3>[Lh0;P3>[Lh00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@03
0000003IfMT0fMWI0100fMWI00<000000<j]cP3>[Lh0;`3>[Lh00`000000cZg>0<j]cP0W0<j]cP03
0000003>[Lh0cZg>02l0cZg>00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003>[Lh0cZg>0340cZg>00<000000<j]cP3>[Lh0
9@3>[Lh00`000000cZg>0<j]cP0a0<j]cP030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0
=03IfMT003D0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000cZg>0<j]cP0b0<j]cP030000003>
[Lh0cZg>02D0cZg>00<000000<j]cP3>[Lh0<P3>[Lh00`000000fMWI0=WIf@0>0=WIf@030000003I
fMT0fMWI03@0fMWI000U0=WIf@<000000P3IfMT3000000P0fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000cZg>0<j]cP0d0<j]cP030000003>[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh0=03>[Lh0
0`000000fMWI0=WIf@140=WIf@009P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT0303IfMT00`000000cZg>0<j]cP0e0<j]cP030000003>[Lh0
cZg>02<0cZg>00<000000<j]cP3>[Lh0=@3>[Lh00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0
fMWI03@0fMWI000V0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003>[Lh0cZg>03H0cZg>00<000000<j]cP3>[Lh08`3>[Lh0
0`000000cZg>0<j]cP0f0<j]cP030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0=03IfMT0
01`0fMWI1`0000030=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01@3IfMT3
000000X0fMWI00<000000<j]cP3>[Lh0>03>[LhU000003X0cZg>00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@0d0=WIf@009P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000cZg>0<j]cP0h0<j]cP030000003IfMT0
fMWI02<0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI03@0fMWI000V0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@080=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT09@3IfMT0
0`000000cZg>0<j]cP0h0<j]cP030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0=03IfMT0
02H0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI00L0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@0W0=WIf@030000003>[Lh0
cZg>03P0cZg>00<000000=WIf@3IfMT0?P3IfMT002D0fMWI0P0000030=WIf@<00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT0:@3IfMT00`00
0000cZg>0<j]cP0h0<j]cP030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0=03IfMT003D0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000cZg>0<j]cP0h0<j]cP030000003IfMT0fMWI02/0
fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI03@0
fMWI000e0=WIf@030000003IfMT0fMWI00@0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI
0=WIf@0]0=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@800000>P3>[Lh00`000000fMWI0=WI
f@0_0=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@800000>@3>[Lh00`000000fMWI0=WIf@0a
0=WIf@030000003>[Lh0cZg>03L0cZg>0P0000040=WIf@030000003IfMT0fMWI03@0fMWI000e0=WI
f@8000000`3IfMT00`000000cZg>00000002000003D0cZg>00<000000=WIf@3IfMT0<`3IfMT00`00
0000cZg>0<j]cP0c0<j]cP<0000000<0cZg>0000003IfMT00`3IfMT00`000000fMWI0=WIf@0d0=WI
f@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>0080cZg>0P00000b0<j]cP03
0000003IfMT0fMWI03D0fMWI00<000000<j]cP3>[Lh0<03>[Lh2000000@0cZg>00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003>[Lh0cZg>00@0cZg>0`00000^0<j]cP030000003IfMT0fMWI03L0fMWI00<000000<j]cP3>[Lh0
;03>[Lh3000000H0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>00L0cZg>0P00000[0<j]cP030000003I
fMT0fMWI03T0fMWI00<000000<j]cP3>[Lh0:@3>[Lh2000000T0cZg>00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0
cZg>00T0cZg>0`00000W0<j]cP030000003IfMT0fMWI03/0fMWI00<000000<j]cP3>[Lh09@3>[Lh3
000000/0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>00`0cZg>0P00000T0<j]cP030000003IfMT0fMWI
03d0fMWI00<000000<j]cP3>[Lh08P3>[Lh2000000h0cZg>00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>00h0
cZg>0`00000P0<j]cP030000003IfMT0fMWI03l0fMWI00<000000<j]cP3>[Lh07P3>[Lh300000100
cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003>[Lh0cZg>0140cZg>0P00000M0<j]cP030000003IfMT0fMWI0440fMWI
00<000000<j]cP3>[Lh06`3>[Lh2000001<0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0d0=WIf@00=@3IfMT2000000<0fMWI00<000000<j]cP3>[Lh04`3>[Lh2000001X0cZg>00<0
00000=WIf@3IfMT0@`3IfMT00`000000cZg>0<j]cP0H0<j]cP8000005@3>[Lh00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0<j]cP3>[Lh05@3>[Lh3000001H0cZg>00<000000=WIf@3IfMT0A@3IfMT00`000000cZg>0<j]cP0D
0<j]cP<000005`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WI
f@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0603>[Lh2000001<0cZg>00<000000=WI
f@3IfMT0A`3IfMT00`000000cZg>0<j]cP0A0<j]cP8000006P3>[Lh00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>
[Lh06P3>[Lh3000000l0cZg>00<000000=WIf@3IfMT0B@3IfMT00`000000cZg>0<j]cP0=0<j]cP<0
0000703>[Lh00`000000fMWI0=WIf@0i0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003>[Lh0cZg>01d0cZg>0P00000<0<j]cP030000003IfMT0fMWI04/0fMWI00<000000<j]cP3>[Lh0
2P3>[Lh2000001l0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>01l0cZg>0`0000080<j]cP030000003I
fMT0fMWI04d0fMWI00<000000<j]cP3>[Lh01P3>[Lh300000240cZg>00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0
cZg>0280cZg>0P0000050<j]cP030000003IfMT0fMWI04l0fMWI00<000000<j]cP3>[Lh00`3>[Lh2
000002@0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02@0cZg>0`0000000`3>[Lh000000=WIf@1B0=WI
f@030000003>[Lh00000008000009P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh2000005@0
fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0
fMWI000e0=WIf@8000000`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI
:P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003I
fMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>
[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT0
0`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT0
03D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI
05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000
fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02L0cZg>
00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]
cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT2000000<0fMWI00<000000<j]
cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]cP3>[Lh0
9`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003I
fMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>
[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT0
0`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT0
03D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI
05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
03@0fMWI000E0=WIf@<000004`3IfMT3000000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000F0=WIf@030000003IfMT0fMWI0140fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>
[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@005P3IfMT00`000000fMWI0=WIf@0A0=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02L0
cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0=03IfMT001H0fMWI00<000000=WIf@3IfMT04@3IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI0`0000020=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3I
fMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI03T0fMWI000E0=WIf@030000
003IfMT000000180fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080
fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0
cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@005@3IfMT00`000000fMWI
0000000B0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT001@0fMWI00D000000=WIf@3IfMT0
fMWI0000000A0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]
cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT001<0fMWI0`000000103IfMT0
000000000000000A0=WIf@<000001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>
02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI
00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]
cP0W0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<00000
0<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WI
f@8000000`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]
cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@03
0000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0
D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003I
fMT0fMWI05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh09`3>[Lh0
0`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>
02L0cZg>00<000000=WIf@3IfMT0D`3IfMT00`000000cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
cZg>0<j]cP0W0<j]cP030000003IfMT0fMWI05<0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI
00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@1C0=WIf@030000003>[Lh0cZg>02L0cZg>
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT2000000<0fMWI00<0
00000<j]cP3>[Lh09`3>[Lh2000005@0fMWI00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0<j]cP3>[Lh09P3>[Lh2000005D0fMWI0P00000X0<j]cP030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0S0<j]
cP<000000P3>[Lh00`000000fMWI0=WIf@1A0=WIf@030000003>[Lh0cZg>00<000009@3>[Lh00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080
fMWI00<000000<j]cP3>[Lh08@3>[Lh2000000H0cZg>00<000000=WIf@3IfMT0C`3IfMT00`000000
cZg>0<j]cP040<j]cP8000008`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0
fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh07P3>[Lh3000000T0cZg>
00<000000=WIf@3IfMT0C@3IfMT00`000000cZg>0<j]cP070<j]cP<00000803>[Lh00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000<j]cP3>[Lh0703>[Lh2000000d0cZg>00<000000=WIf@3IfMT0B`3IfMT00`000000cZg>0<j]
cP0;0<j]cP8000007P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e
0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh06@3>[Lh300000100cZg>00<00000
0=WIf@3IfMT0B@3IfMT00`000000cZg>0<j]cP0>0<j]cP<000006`3>[Lh00`000000fMWI0=WIf@0i
0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>01L0cZg>0P00000D0<j]
cP030000003IfMT0fMWI04L0fMWI00<000000<j]cP3>[Lh04P3>[Lh2000001T0cZg>00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003>[Lh0cZg>01@0cZg>0`00000G0<j]cP030000003IfMT0fMWI04D0fMWI00<000000<j]cP3>
[Lh05@3>[Lh3000001H0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT2000000<0fMWI00<000000<j]cP3>[Lh04P3>[Lh2000001/0cZg>00<000000=WIf@3IfMT0
@`3IfMT00`000000cZg>0<j]cP0I0<j]cP800000503>[Lh00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0403>
[Lh2000001h0cZg>00<000000=WIf@3IfMT0@@3IfMT00`000000cZg>0<j]cP0L0<j]cP8000004P3>
[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0
fMWI0080fMWI00<000000<j]cP3>[Lh03@3>[Lh300000240cZg>00<000000=WIf@3IfMT0?`3IfMT0
0`000000cZg>0<j]cP0O0<j]cP<000003`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh02`3>[Lh20000
02D0cZg>00<000000=WIf@3IfMT0?@3IfMT00`000000cZg>0<j]cP0S0<j]cP8000003@3>[Lh00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080
fMWI00<000000<j]cP3>[Lh0203>[Lh3000002P0cZg>00<000000=WIf@3IfMT0>`3IfMT00`000000
cZg>0<j]cP0V0<j]cP<000002P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0
fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh01P3>[Lh2000002`0cZg>
00<000000=WIf@3IfMT0>@3IfMT00`000000cZg>0<j]cP0Z0<j]cP800000203>[Lh00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000<j]cP3>[Lh00`3>[Lh3000002l0cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>0<j]
cP0]0<j]cP<000001@3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI000e
0=WIf@030000003IfMT0fMWI0080fMWI00@000000<j]cP3>[Lh0cZg>0P00000c0<j]cP030000003I
fMT0fMWI03D0fMWI00<000000<j]cP3>[Lh0<@3>[Lh2000000<0cZg>00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT2000000<0fMWI1000000f0<j]cP030000003IfMT0
fMWI03<0fMWI00<000000<j]cP3>[Lh0=03>[Lh2000000030<j]cP000000fMWI00<0fMWI00<00000
0=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0h0<j]
cP030000003IfMT0fMWI0340fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>
[Lh0>03>[Lh00`000000fMWI0=WIf@0_0=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT0;@3IfMT00`000000cZg>0<j]cP0h0<j]cP030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000cZg>0<j]cP0h0<j]cP030000003IfMT0fMWI02/0fMWI00<000000<j]cP3>[Lh0>03>
[Lh00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0
fMWI00H0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@0Y0=WIf@030000003>[Lh0
cZg>03P0cZg>00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0d0=WIf@009P3IfMT30000
0080fMWI0`0000070=WIf@030000003IfMT0fMWI00L0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`00
0000fMWI0=WIf@0W0=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@0d0=WIf@009`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000cZg>0<j]cP0h0<j]cP030000003IfMT0fMWI
02D0fMWI00<000000<j]cP3>[Lh0>03>[Lh00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
03@0fMWI000W0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@090=WIf@030000003>[Lh0cZg>03P0cZg>00<000000=WIf@0000008P3IfMT20000
03X0cZg>00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0d0=WIf@009`3IfMT010000000
fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI0`00000:0=WIf@030000003>[Lh0cZg>
03P0cZg>9@00000j0<j]cP030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0=03IfMT002L0
fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00/0fMWI00<000000<j]cP3>[Lh0=`3>[Lh00`000000cZg>0<j]cP0Q0<j]cP030000003>[Lh0cZg>
03L0cZg>00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0d0=WIf@009`3IfMT010000000
fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0303IfMT00`00
0000cZg>0<j]cP0e0<j]cP030000003>[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh0=@3>[Lh00`00
0000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI03@0fMWI000W0=WIf@040000003IfMT0fMWI0000
00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0=0=WIf@030000003>[Lh0cZg>
03@0cZg>00<000000<j]cP3>[Lh08`3>[Lh00`000000cZg>0<j]cP0d0<j]cP030000003IfMT0fMWI
04@0fMWI000V0=WIf@8000000`3IfMT3000000L0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
cZg>0<j]cP0c0<j]cP030000003>[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh0<`3>[Lh00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI00l0fMWI
00<000000<j]cP3>[Lh0<@3>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003>[Lh0cZg>0340cZg>
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WI
f@0@0=WIf@030000003>[Lh0cZg>0300cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000cZg>0<j]
cP0`0<j]cP030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<00000
0=WIf@3IfMT04@3IfMT00`000000cZg>0<j]cP0^0<j]cP030000003>[Lh0cZg>02L0cZg>00<00000
0<j]cP3>[Lh0;P3>[Lh00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WI
f@8000004`3IfMT00`000000cZg>0<j]cP0]0<j]cP030000003>[Lh0cZg>02L0cZg>00<000000<j]
cP3>[Lh0;@3>[Lh00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@03
0000003IfMT0fMWI01<0fMWI00<000000<j]cP3>[Lh0;03>[Lh00`000000cZg>0<j]cP0W0<j]cP03
0000003>[Lh0cZg>02`0cZg>00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003>[Lh0cZg>02X0cZg>00<000000<j]cP3>[Lh0
:@3>[Lh00`000000cZg>0<j]cP0Z0<j]cP030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0
=03IfMT003D0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000cZg>0<j]cP0Y0<j]cP030000003>
[Lh0cZg>02T0cZg>00<000000<j]cP3>[Lh0:@3>[Lh00`000000fMWI0=WIf@0E0=WIf@030000003I
fMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI01H0fMWI00<000000<j]cP3>[Lh09`3>[Lh0
0`000000cZg>0<j]cP0[0<j]cP030000003>[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT05P3IfMT0
0`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003>[Lh0cZg>
02H0cZg>00<000000<j]cP3>[Lh0:`3>[Lh00`000000cZg>0<j]cP0V0<j]cP030000003IfMT0fMWI
01L0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT0603IfMT00`000000
cZg>0<j]cP0U0<j]cP030000003>[Lh0cZg>02/0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000
fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI01T0fMWI
00<000000<j]cP3>[Lh08`3>[Lh00`000000cZg>0<j]cP0]0<j]cP030000003>[Lh0cZg>02<0cZg>
00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WI
f@0J0=WIf@030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0;@3>[Lh00`000000cZg>0<j]
cP0R0<j]cP030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI0P00000L
0=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh0;`3>[Lh00`000000cZg>0<j]cP0P
0<j]cP030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WI
f@3IfMT0703IfMT00`000000cZg>0<j]cP0O0<j]cP030000003>[Lh0cZg>02l0cZg>00<000000<j]
cP3>[Lh07`3>[Lh00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0_0<j]cP03
0000003>[Lh0cZg>01h0cZg>00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003>[Lh0cZg>01`0cZg>00<000000<j]cP3>[Lh0
<@3>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003IfMT0fMWI05D0fMWI000e0=WIf@030000003I
fMT0fMWI01l0fMWI00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0a0<j]cP030000003>
[Lh0cZg>01/0cZg>00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT0
0`000000fMWI0=WIf@0P0=WIf@030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh0<`3>[Lh0
0`000000cZg>0<j]cP0I0<j]cP030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT0=03IfMT0
03D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>
03<0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
03@0fMWI000e0=WIf@030000003IfMT0fMWI0280fMWI00<000000<j]cP3>[Lh05P3>[Lh00`000000
cZg>0<j]cP0e0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000=WIf@3IfMT08P3IfMT00`000000
fMWI0=WIf@0d0=WIf@00=@3IfMT2000002@0fMWI00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>
0<j]cP0e0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000=WIf@3IfMT08`3IfMT00`000000fMWI
0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0T0=WIf@030000003>[Lh0cZg>01@0cZg>00<0
00000<j]cP3>[Lh0=@3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003IfMT0fMWI05/0fMWI000e
0=WIf@030000003IfMT0fMWI02D0fMWI00<000000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]cP0g
0<j]cP030000003>[Lh0cZg>0180cZg>00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0d
0=WIf@00=@3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003>[Lh0cZg>0140cZg>00<000000<j]
cP3>[Lh0=`3>[Lh00`000000cZg>0<j]cP0A0<j]cP030000003IfMT0fMWI02H0fMWI00<000000=WI
f@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000cZg>0<j]cP0?0<j]cP03
0000003>[Lh0cZg>03T0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@0W0=WIf@03
0000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI02P0fMWI00<000000<j]cP3>[Lh0
3P3>[Lh00`000000cZg>0<j]cP0i0<j]cP030000003>[Lh0cZg>00h0cZg>00<000000=WIf@3IfMT0
:03IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003>
[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh0>@3>[Lh00`000000cZg>0<j]cP0=0<j]cP030000003I
fMT0fMWI02T0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<000000=WIf@3IfMT0:P3IfMT0
0`000000cZg>0<j]cP0;0<j]cP030000003>[Lh0cZg>03/0cZg>00<000000<j]cP3>[Lh02`3>[Lh0
0`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI03@0fMWI000e0=WIf@030000003IfMT0fMWI
02/0fMWI00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0k0<j]cP030000003>[Lh0cZg>
00X0cZg>00<000000=WIf@3IfMT0:`3IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT2000002d0
fMWI00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP0m0<j]cP030000003>[Lh0cZg>00P0
cZg>00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@0d0=WIf@00=@3IfMT00`000000fMWI
0=WIf@0]0=WIf@030000003>[Lh0cZg>00L0cZg>00<000000<j]cP3>[Lh0?@3>[Lh00`000000cZg>
0<j]cP070<j]cP030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0=03IfMT003D0fMWI00<0
00000=WIf@3IfMT0;P3IfMT00`000000cZg>0<j]cP060<j]cP030000003>[Lh0cZg>03d0cZg>00<0
00000<j]cP3>[Lh01P3>[Lh00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI03@0fMWI000e
0=WIf@030000003IfMT0fMWI02l0fMWI00<000000<j]cP3>[Lh0103>[Lh00`000000cZg>0<j]cP0o
0<j]cP030000003>[Lh0cZg>00@0cZg>00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0d
0=WIf@00=@3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003>[Lh0cZg>00<0cZg>00<000000<j]
cP3>[Lh0?`3>[Lh00`000000cZg>0<j]cP030<j]cP030000003IfMT0fMWI0300fMWI00<000000=WI
f@3IfMT0=03IfMT002@0fMWI100000030=WIf@<000001`3IfMT00`000000fMWI0=WIf@0a0=WIf@05
0000003>[Lh0cZg>0<j]cP000000@`3>[Lh01@000000cZg>0<j]cP3>[Lh0000003<0fMWI00<00000
0=WIf@3IfMT0=03IfMT002@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000<0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0b0=WIf@040000003>[Lh0cZg>000004<0cZg>
00@000000<j]cP3>[Lh00000=03IfMT00`000000fMWI0=WIf@0d0=WIf@009@3IfMT00`000000fMWI
0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@0c0=WIf@03
0000003>[Lh0000004<0cZg>00<000000<j]cP000000=@3IfMT00`000000fMWI0=WIf@0d0=WIf@00
9P3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT0103IfMT3000003@0
fMWIB000000e0=WIf@030000003IfMT0fMWI03@0fMWI000W0=WIf@040000003IfMT0fMWI000000<0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3X0=WIf@009`3IfMT010000000fMWI
0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0/@3IfMT00`000000
fMWI0=WIf@0d0=WIf@00903IfMT010000000fMWI0=WIf@0000020=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@2a0=WIf@030000003IfMT0fMWI03@0fMWI000U0=WIf@80
0000103IfMT3000000L0fMWI00<000000=WIf@3IfMT0/@3IfMT00`000000fMWI0=WIf@0d0=WIf@00
=@3IfMT4000000030=WIf@000000000000h0000000<0fMWI0000000000000`0000000`3IfMT00000
0000000>000000030=WIf@000000000001@0000000<0fMWI000000000000500000000`3IfMT00000
0000000D000000030=WIf@000000000000h0000000<0fMWI0000000000000`0000000`3IfMT00000
0000000>000000030=WIf@000000000000<0000000<0fMWI0000000000003P0000000`3IfMT00000
00000002000003H0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, 
  0.00348436, 0.00348436}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the field along x axis", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2 = 
      Table[{x, radFld[cyl2, "\<By\>", {x, 0, Lz/2.}]}, {x, \(-rint\)*0.9, 
          rint*0.9, 1}]; \n
    MultipleListPlot[T2, PlotJoined \[Rule] {True, True}, \n\t\t
      PlotRange \[Rule] All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0529101 0.309017 0.384713 [
[.10317 .29652 -14.5 -14 ]
[.10317 .29652 14.5 0 ]
[.23545 .29652 -9.5 -14 ]
[.23545 .29652 9.5 0 ]
[.36772 .29652 -14.5 -14 ]
[.36772 .29652 14.5 0 ]
[.63228 .29652 -10 -14 ]
[.63228 .29652 10 0 ]
[.76455 .29652 -5 -14 ]
[.76455 .29652 5 0 ]
[.89683 .29652 -10 -14 ]
[.89683 .29652 10 0 ]
[.4875 .02048 -35 -7 ]
[.4875 .02048 0 7 ]
[.4875 .11666 -29 -7 ]
[.4875 .11666 0 7 ]
[.4875 .21284 -35 -7 ]
[.4875 .21284 0 7 ]
[.4875 .4052 -26 -7 ]
[.4875 .4052 0 7 ]
[.4875 .50137 -20 -7 ]
[.4875 .50137 0 7 ]
[.4875 .59755 -26 -7 ]
[.4875 .59755 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .30902 m
.10317 .31527 L
s
gsave
.10317 .29652 -75.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.23545 .30902 m
.23545 .31527 L
s
gsave
.23545 .29652 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.36772 .30902 m
.36772 .31527 L
s
gsave
.36772 .29652 -75.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.63228 .30902 m
.63228 .31527 L
s
gsave
.63228 .29652 -71 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76455 .30902 m
.76455 .31527 L
s
gsave
.76455 .29652 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.89683 .30902 m
.89683 .31527 L
s
gsave
.89683 .29652 -71 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.12963 .30902 m
.12963 .31277 L
s
.15608 .30902 m
.15608 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.20899 .30902 m
.20899 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.28836 .30902 m
.28836 .31277 L
s
.31481 .30902 m
.31481 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.39418 .30902 m
.39418 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.44709 .30902 m
.44709 .31277 L
s
.47354 .30902 m
.47354 .31277 L
s
.52646 .30902 m
.52646 .31277 L
s
.55291 .30902 m
.55291 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.60582 .30902 m
.60582 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.68519 .30902 m
.68519 .31277 L
s
.71164 .30902 m
.71164 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.79101 .30902 m
.79101 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.84392 .30902 m
.84392 .31277 L
s
.87037 .30902 m
.87037 .31277 L
s
.07672 .30902 m
.07672 .31277 L
s
.05026 .30902 m
.05026 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92328 .30902 m
.92328 .31277 L
s
.94974 .30902 m
.94974 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .02048 m
.50625 .02048 L
s
gsave
.4875 .02048 -96 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .11666 m
.50625 .11666 L
s
gsave
.4875 .11666 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .21284 m
.50625 .21284 L
s
gsave
.4875 .21284 -96 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .4052 m
.50625 .4052 L
s
gsave
.4875 .4052 -87 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .50137 m
.50625 .50137 L
s
gsave
.4875 .50137 -81 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .59755 m
.50625 .59755 L
s
gsave
.4875 .59755 -87 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .03972 m
.50375 .03972 L
s
.5 .05895 m
.50375 .05895 L
s
.5 .07819 m
.50375 .07819 L
s
.5 .09742 m
.50375 .09742 L
s
.5 .1359 m
.50375 .1359 L
s
.5 .15513 m
.50375 .15513 L
s
.5 .17437 m
.50375 .17437 L
s
.5 .1936 m
.50375 .1936 L
s
.5 .23207 m
.50375 .23207 L
s
.5 .25131 m
.50375 .25131 L
s
.5 .27055 m
.50375 .27055 L
s
.5 .28978 m
.50375 .28978 L
s
.5 .32825 m
.50375 .32825 L
s
.5 .34749 m
.50375 .34749 L
s
.5 .36672 m
.50375 .36672 L
s
.5 .38596 m
.50375 .38596 L
s
.5 .42443 m
.50375 .42443 L
s
.5 .44367 m
.50375 .44367 L
s
.5 .4629 m
.50375 .4629 L
s
.5 .48214 m
.50375 .48214 L
s
.5 .52061 m
.50375 .52061 L
s
.5 .53984 m
.50375 .53984 L
s
.5 .55908 m
.50375 .55908 L
s
.5 .57832 m
.50375 .57832 L
s
.5 .00125 m
.50375 .00125 L
s
.5 .61679 m
.50375 .61679 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.001 w
.02381 .60332 m
.07672 .57749 L
.12963 .54642 L
.18254 .51308 L
.23545 .47903 L
.28836 .44487 L
.34127 .41078 L
.39418 .3768 L
.44709 .34289 L
.5 .30902 L
.55291 .27515 L
.60582 .24124 L
.65873 .20725 L
.71164 .17317 L
.76455 .13901 L
.81746 .10495 L
.87037 .07161 L
.92328 .04055 L
.97619 .01472 L
s
.0001 w
.02381 .60332 -1.875 0 Mabsadd m
.02381 .60332 0 2.5 Mabsadd L
.02381 .60332 1.875 0 Mabsadd L
.02381 .60332 0 -2.5 Mabsadd L
.02381 .60332 -1.875 0 Mabsadd L closepath F
.07672 .57749 -1.875 0 Mabsadd m
.07672 .57749 0 2.5 Mabsadd L
.07672 .57749 1.875 0 Mabsadd L
.07672 .57749 0 -2.5 Mabsadd L
.07672 .57749 -1.875 0 Mabsadd L closepath F
.12963 .54642 -1.875 0 Mabsadd m
.12963 .54642 0 2.5 Mabsadd L
.12963 .54642 1.875 0 Mabsadd L
.12963 .54642 0 -2.5 Mabsadd L
.12963 .54642 -1.875 0 Mabsadd L closepath F
.18254 .51308 -1.875 0 Mabsadd m
.18254 .51308 0 2.5 Mabsadd L
.18254 .51308 1.875 0 Mabsadd L
.18254 .51308 0 -2.5 Mabsadd L
.18254 .51308 -1.875 0 Mabsadd L closepath F
.23545 .47903 -1.875 0 Mabsadd m
.23545 .47903 0 2.5 Mabsadd L
.23545 .47903 1.875 0 Mabsadd L
.23545 .47903 0 -2.5 Mabsadd L
.23545 .47903 -1.875 0 Mabsadd L closepath F
.28836 .44487 -1.875 0 Mabsadd m
.28836 .44487 0 2.5 Mabsadd L
.28836 .44487 1.875 0 Mabsadd L
.28836 .44487 0 -2.5 Mabsadd L
.28836 .44487 -1.875 0 Mabsadd L closepath F
.34127 .41078 -1.875 0 Mabsadd m
.34127 .41078 0 2.5 Mabsadd L
.34127 .41078 1.875 0 Mabsadd L
.34127 .41078 0 -2.5 Mabsadd L
.34127 .41078 -1.875 0 Mabsadd L closepath F
.39418 .3768 -1.875 0 Mabsadd m
.39418 .3768 0 2.5 Mabsadd L
.39418 .3768 1.875 0 Mabsadd L
.39418 .3768 0 -2.5 Mabsadd L
.39418 .3768 -1.875 0 Mabsadd L closepath F
.44709 .34289 -1.875 0 Mabsadd m
.44709 .34289 0 2.5 Mabsadd L
.44709 .34289 1.875 0 Mabsadd L
.44709 .34289 0 -2.5 Mabsadd L
.44709 .34289 -1.875 0 Mabsadd L closepath F
.5 .30902 -1.875 0 Mabsadd m
.5 .30902 0 2.5 Mabsadd L
.5 .30902 1.875 0 Mabsadd L
.5 .30902 0 -2.5 Mabsadd L
.5 .30902 -1.875 0 Mabsadd L closepath F
.55291 .27515 -1.875 0 Mabsadd m
.55291 .27515 0 2.5 Mabsadd L
.55291 .27515 1.875 0 Mabsadd L
.55291 .27515 0 -2.5 Mabsadd L
.55291 .27515 -1.875 0 Mabsadd L closepath F
.60582 .24124 -1.875 0 Mabsadd m
.60582 .24124 0 2.5 Mabsadd L
.60582 .24124 1.875 0 Mabsadd L
.60582 .24124 0 -2.5 Mabsadd L
.60582 .24124 -1.875 0 Mabsadd L closepath F
.65873 .20725 -1.875 0 Mabsadd m
.65873 .20725 0 2.5 Mabsadd L
.65873 .20725 1.875 0 Mabsadd L
.65873 .20725 0 -2.5 Mabsadd L
.65873 .20725 -1.875 0 Mabsadd L closepath F
.71164 .17317 -1.875 0 Mabsadd m
.71164 .17317 0 2.5 Mabsadd L
.71164 .17317 1.875 0 Mabsadd L
.71164 .17317 0 -2.5 Mabsadd L
.71164 .17317 -1.875 0 Mabsadd L closepath F
.76455 .13901 -1.875 0 Mabsadd m
.76455 .13901 0 2.5 Mabsadd L
.76455 .13901 1.875 0 Mabsadd L
.76455 .13901 0 -2.5 Mabsadd L
.76455 .13901 -1.875 0 Mabsadd L closepath F
.81746 .10495 -1.875 0 Mabsadd m
.81746 .10495 0 2.5 Mabsadd L
.81746 .10495 1.875 0 Mabsadd L
.81746 .10495 0 -2.5 Mabsadd L
.81746 .10495 -1.875 0 Mabsadd L closepath F
.87037 .07161 -1.875 0 Mabsadd m
.87037 .07161 0 2.5 Mabsadd L
.87037 .07161 1.875 0 Mabsadd L
.87037 .07161 0 -2.5 Mabsadd L
.87037 .07161 -1.875 0 Mabsadd L closepath F
.92328 .04055 -1.875 0 Mabsadd m
.92328 .04055 0 2.5 Mabsadd L
.92328 .04055 1.875 0 Mabsadd L
.92328 .04055 0 -2.5 Mabsadd L
.92328 .04055 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{372, 229.812},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005d0000iB000`400?l00000o`00003o^@3IfMT2
00000;T0fMWI002i0=WIf@030000003IfMT0fMWI0;P0fMWI002i0=WIf@030000003IfMT0fMWI0;P0
fMWI002i0=WIf@030000003IfMT0fMWI0;P0fMWI002M0=WIf@<000000`3IfMT01@000000fMWI0=WI
f@3IfMT0000000<0fMWI1000000:0=WIf@030000003IfMT0fMWI0:d0fMWI00<000000=WIf@3IfMT0
203IfMT009`0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@2/0=WIf@<000002@3IfMT009`0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@2Z0=WIf@D000002@3IfMT009@0fMWI1`0000000`3IfMT000000=WI
f@020=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@070=WIf@<00000Z03IfMT200000080fMWI0`0000090=WIf@00W03IfMT01@000000fMWI0=WIf@3I
fMT0000000L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI0:H0fMWI0P0000050=WIf@030000003IfMT0fMWI00P0fMWI002L0=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@04000000X0fMWI00<000000=WIf@3IfMT0Y03I
fMT200000180fMWI002L0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2S0=WIf@030000
003IfMT0fMWI0180fMWI002M0=WIf@<000001P3IfMT400000080fMWI100000090=WIf@030000003I
fMT0fMWI0:40fMWI0P00000E0=WIf@00^@3IfMT00`000000fMWI0=WIf@2O0=WIf@8000005`3IfMT0
0;T0fMWI00<000000=WIf@3IfMT0W@3IfMT2000001T0fMWI002i0=WIf@800000V`3IfMT3000001/0
fMWI002i0=WIf@030000003IfMT0fMWI09T0fMWI0`00000L0=WIf@00^@3IfMT00`000000fMWI0=WI
f@2G0=WIf@D00000703IfMT00;T0fMWI00<000000=WIf@3IfMT0U@3IfMT2000000<0fMWI00<00000
0=WIf@3IfMT06`3IfMT00;T0fMWI00<000000=WIf@3IfMT0U03IfMT00`000000fMWI0=WIf@0Q0=WI
f@00^@3IfMT00`000000fMWI0=WIf@2B0=WIf@800000903IfMT00;T0fMWI00<000000=WIf@3IfMT0
T03IfMT2000002H0fMWI002i0=WIf@030000003IfMT0fMWI08h0fMWI0P00000X0=WIf@00^@3IfMT2
000008d0fMWI0P00000Z0=WIf@00^@3IfMT00`000000fMWI0=WIf@2;0=WIf@030000003IfMT0fMWI
02X0fMWI002i0=WIf@030000003IfMT0fMWI08T0fMWI0P00000]0=WIf@00^@3IfMT00`000000fMWI
0=WIf@260=WIf@<00000;`3IfMT00;T0fMWI00<000000=WIf@3IfMT0Q@3IfMT300000300fMWI002i
0=WIf@030000003IfMT0fMWI08@0fMWI1000000`0=WIf@00^@3IfMT00`000000fMWI0=WIf@220=WI
f@80000000@0fMWI0000000000000000<03IfMT00;T0fMWI0P0000220=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0;`3IfMT00;T0fMWI00<000000=WIf@3IfMT0O`3IfMT2000003L0
fMWI002i0=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@3IfMT0=`3IfMT00;T0fMWI00<0
00000=WIf@3IfMT0O03IfMT2000003X0fMWI002i0=WIf@030000003IfMT0fMWI07/0fMWI00<00000
0=WIf@3IfMT0>P3IfMT00;T0fMWI00<000000=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@0k0=WI
f@00^@3IfMT00`000000fMWI0=WIf@1h0=WIf@800000?P3IfMT00;T0fMWI0P00001h0=WIf@030000
003IfMT0fMWI03h0fMWI002i0=WIf@030000003IfMT0fMWI07D0fMWI0P0000110=WIf@00^@3IfMT0
0`000000fMWI0=WIf@1c0=WIf@800000@`3IfMT00;T0fMWI00<000000=WIf@3IfMT0LP3IfMT20000
04@0fMWI002S0=WIf@<000000`3IfMT00`000000fMWI00000003000000X0fMWI00<000000=WIf@3I
fMT0L03IfMT4000004@0fMWI002R0=WIf@050000003IfMT0fMWI0=WIf@000000203IfMT00`000000
fMWI0=WIf@070=WIf@030000003IfMT0fMWI06l0fMWI00D000000=WIf@3IfMT0fMWI000000140=WI
f@00XP3IfMT01@000000fMWI0=WIf@3IfMT0000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@1]0=WIf@800000B@3IfMT009X0fMWI1`0000000`3IfMT000000=WIf@020=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT3000006/0fMWI0P00001;0=WIf@00
XP3IfMT01@000000fMWI0=WIf@3IfMT0000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000
fMWI0=WIf@1Z0=WIf@030000003IfMT0fMWI04/0fMWI002R0=WIf@050000003IfMT0fMWI0=WIf@00
0000103IfMT4000000X0fMWI00<000000=WIf@3IfMT0J03IfMT2000004h0fMWI002R0=WIf@050000
003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI06H0
fMWI0P00001@0=WIf@00X`3IfMT3000000H0fMWI100000090=WIf@030000003IfMT0fMWI06D0fMWI
00<000000=WIf@3IfMT0D03IfMT00;T0fMWI00<000000=WIf@3IfMT0H`3IfMT2000005<0fMWI002i
0=WIf@030000003IfMT0fMWI0640fMWI0P00001E0=WIf@00^@3IfMT200000600fMWI0P00001G0=WI
f@00^@3IfMT00`000000fMWI0=WIf@1N0=WIf@<00000E`3IfMT00;T0fMWI00<000000=WIf@3IfMT0
G@3IfMT4000005L0fMWI002i0=WIf@030000003IfMT0fMWI05/0fMWI0P000000103IfMT000000000
0000001G0=WIf@00^@3IfMT00`000000fMWI0=WIf@1J0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0EP3IfMT00;T0fMWI00<000000=WIf@3IfMT0F03IfMT2000005h0fMWI002i0=WI
f@030000003IfMT0fMWI05L0fMWI00<000000=WIf@3IfMT0GP3IfMT00;T0fMWI0P00001F0=WIf@80
0000H@3IfMT00;T0fMWI00<000000=WIf@3IfMT0D`3IfMT2000006<0fMWI002i0=WIf@030000003I
fMT0fMWI0580fMWI00<000000=WIf@3IfMT0H`3IfMT00;T0fMWI00<000000=WIf@3IfMT0D03IfMT2
000006H0fMWI002i0=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3IfMT0IP3IfMT00;T0
fMWI00<000000=WIf@3IfMT0C@3IfMT2000006T0fMWI002i0=WIf@030000003IfMT0fMWI04/0fMWI
0P00001[0=WIf@00^@3IfMT2000004/0fMWI0`00001[0=WIf@00^@3IfMT00`000000fMWI0=WIf@19
0=WIf@@00000J`3IfMT00;T0fMWI00<000000=WIf@3IfMT0A`3IfMT200000080fMWI00<000000=WI
f@3IfMT0JP3IfMT00;T0fMWI00<000000=WIf@3IfMT0A@3IfMT200000740fMWI002i0=WIf@030000
003IfMT0fMWI04@0fMWI00<000000=WIf@3IfMT0L@3IfMT00;T0fMWI00<000000=WIf@3IfMT0@P3I
fMT2000007@0fMWI002i0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0M03IfMT0
0;T0fMWI0P0000100=WIf@800000M`3IfMT00;T0fMWI00<000000=WIf@3IfMT0?P3IfMT00`000000
fMWI0=WIf@1g0=WIf@00^@3IfMT00`000000fMWI0=WIf@0l0=WIf@800000NP3IfMT00;T0fMWI00<0
00000=WIf@3IfMT0>P3IfMT2000007`0fMWI002M0=WIf@<000000`3IfMT00`000000fMWI00000003
00000080fMWI1000000:0=WIf@030000003IfMT0fMWI03P0fMWI0P00001n0=WIf@00W03IfMT01@00
0000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0=`3IfMT3000007h0fMWI002L0=WIf@050000003IfMT0
fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0=P3IfMT4000007h0fMWI002D0=WIf@L0000000<0fMWI0000003IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01`3IfMT3
000003@0fMWI0P000000103IfMT0000000000000001n0=WIf@00W03IfMT01@000000fMWI0=WIf@3I
fMT0000000L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI03<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1m0=WIf@00W03IfMT0
1@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@3IfMT01000000:0=WIf@030000003I
fMT0fMWI0340fMWI0P0000250=WIf@00W03IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0300fMWI
00<000000=WIf@3IfMT0Q@3IfMT009d0fMWI0`0000060=WIf@800000103IfMT4000000T0fMWI00<0
00000=WIf@3IfMT0;P3IfMT2000008P0fMWI002i0=WIf@030000003IfMT0fMWI02`0fMWI0P00002:
0=WIf@00^@3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI08X0fMWI002i0=WIf@03
0000003IfMT0fMWI02T0fMWI0P00002=0=WIf@00^@3IfMT2000002T0fMWI00<000000=WIf@3IfMT0
S@3IfMT00;T0fMWI00<000000=WIf@3IfMT09P3IfMT200000900fMWI002i0=WIf@030000003IfMT0
fMWI02@0fMWI0P00002B0=WIf@00^@3IfMT00`000000fMWI0=WIf@0S0=WIf@<00000TP3IfMT00;T0
fMWI00<000000=WIf@3IfMT08P3IfMT400000980fMWI002i0=WIf@030000003IfMT0fMWI0200fMWI
0P0000020=WIf@030000003IfMT0fMWI0940fMWI002i0=WIf@030000003IfMT0fMWI01l0fMWI00<0
00000=WIf@3IfMT0UP3IfMT00;T0fMWI0P00000N0=WIf@800000V@3IfMT00;T0fMWI00<000000=WI
f@3IfMT0703IfMT00`000000fMWI0=WIf@2I0=WIf@00^@3IfMT00`000000fMWI0=WIf@0J0=WIf@80
0000W03IfMT00;T0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@2L0=WIf@00^@3I
fMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI09d0fMWI002i0=WIf@030000003IfMT0
fMWI01H0fMWI0P00002P0=WIf@00903IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT00000
00<00000:@3IfMT4000002P0fMWI100000030=WIf@030000003IfMT0000000<00000:03IfMT00`00
0000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00h0fMWI100000030=WIf@030000003IfMT00000
00<00000:@3IfMT4000002X0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI000000030000
02<0fMWI000T0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000
fMWI0=WIf@0U0=WIf@050000003IfMT0fMWI0=WIf@000000203IfMT00`000000fMWI0=WIf@0U0=WI
f@800000503IfMT200000140fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@030000003IfMT0
fMWI02X0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI0200fMWI000T0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0:P3IfMT00`00
0000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT09@3IfMT00`00
0000fMWI0=WIf@0A0=WIf@800000503IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
02X0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
0200fMWI000K0=WIf@L000000`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01l0
fMWI1`0000040=WIf@030000003IfMT0fMWI01h0fMWI1`0000020=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0@0=WIf@8000005P3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000
fMWI0=WIf@070=WIf@030000003IfMT0fMWI0200fMWI000U0=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0>0=WIf@@000005`3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI0200fMWI000U0=WIf@030000003IfMT0fMWI00<0fMWI1000
000Y0=WIf@@00000:`3IfMT00`000000fMWI0=WIf@030=WIf@@00000:03IfMT00`000000fMWI0=WI
f@0=0=WIf@050000003IfMT0fMWI0=WIf@0000005`3IfMT00`000000fMWI0=WIf@030=WIf@@00000
:@3IfMT4000002/0fMWI00<000000=WIf@3IfMT00`3IfMT4000002<0fMWI000R0=WIf@050000003I
fMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI02P0fMWI
00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI00/0
fMWI0P00000I0=WIf@040000003IfMT0fMWI000000H0fMWI00<000000=WIf@3IfMT0:P3IfMT00`00
0000fMWI0=WIf@0X0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@0S
0=WIf@008`3IfMT4000000D0fMWI1000000Y0=WIf@@00000:03IfMT2000000L0fMWI1000000W0=WI
f@030000003IfMT0fMWI00T0fMWI0P00000L0=WIf@8000001`3IfMT4000002T0fMWI1000000X0=WI
f@@000001@3IfMT400000280fMWI002i0=WIf@8000002@3IfMT00`000000fMWI0=WIf@2]0=WIf@00
^@3IfMT00`000000fMWI0=WIf@060=WIf@800000/03IfMT00;T0fMWI00<000000=WIf@3IfMT0103I
fMT200000;80fMWI002i0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0/P3IfMT0
0;T0fMWI00@000000=WIf@3IfMT0fMWI0P00002e0=WIf@00^@3IfMT010000000fMWI00000000002g
0=WIf@00^@3IfMT200000;T0fMWI003o000007@000000@3IfMT000T0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00D0fMWI100000080=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@080=WIf@009P3I
fMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI02h0fMWI00<000000=WIf@3IfMT0:P3I
fMT2000000040=WIf@0000000000000002l0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI
0=WIf@0^0=WIf@030000003IfMT0fMWI02D0fMWI002d0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0^03IfMT00;80fMWI0P0000050=WIf@030000003IfMT0fMWI0;P0fMWI002a0=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0^03IfMT00:l0fMWI0P0000080=WIf@03
0000003IfMT0fMWI0;P0fMWI002]0=WIf@8000002P3IfMT200000;T0fMWI002/0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0^03IfMT00:X0fMWI0P00000=0=WIf@030000003IfMT0
fMWI0;P0fMWI002Y0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0^03IfMT00:L0
fMWI0P00000@0=WIf@030000003IfMT0fMWI0;P0fMWI002U0=WIf@8000004P3IfMT00`000000fMWI
0=WIf@2h0=WIf@00Y03IfMT300000180fMWI00<000000=WIf@3IfMT0^03IfMT00:<0fMWI1000000B
0=WIf@800000^@3IfMT00:40fMWI0P0000020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WI
f@3IfMT0^03IfMT009l0fMWI0P00000H0=WIf@030000003IfMT0fMWI0;P0fMWI002N0=WIf@030000
003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0^03IfMT009`0fMWI0P00000K0=WIf@030000003I
fMT0fMWI0;P0fMWI002K0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0^03IfMT0
09T0fMWI0P00000N0=WIf@030000003IfMT0fMWI0;P0fMWI002H0=WIf@030000003IfMT0fMWI01h0
fMWI0P00002i0=WIf@00UP3IfMT200000240fMWI00<000000=WIf@3IfMT0^03IfMT009@0fMWI0P00
000S0=WIf@030000003IfMT0fMWI0;P0fMWI002B0=WIf@8000009@3IfMT00`000000fMWI0=WIf@2h
0=WIf@00T@3IfMT3000002D0fMWI00<000000=WIf@3IfMT0^03IfMT00900fMWI1000000U0=WIf@03
0000003IfMT0fMWI0;P0fMWI002>0=WIf@80000000@0fMWI00000000000000009@3IfMT00`000000
fMWI0=WIf@2h0=WIf@00S@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02@0fMWI
00<000000=WIf@3IfMT0^03IfMT008/0fMWI0P00000/0=WIf@800000^@3IfMT008X0fMWI00<00000
0=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@2h0=WIf@00R03IfMT2000002l0fMWI00<000000=WI
f@3IfMT0^03IfMT008H0fMWI0P00000a0=WIf@030000003IfMT0fMWI0;P0fMWI00250=WIf@030000
003IfMT0fMWI01D0fMWI0`0000030=WIf@030000003IfMT0000000<000000P3IfMT4000000X0fMWI
00<000000=WIf@3IfMT0^03IfMT008<0fMWI0P00000G0=WIf@050000003IfMT0fMWI0=WIf@000000
103IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000
fMWI0=WIf@2h0=WIf@00PP3IfMT00`000000fMWI0=WIf@0G0=WIf@050000003IfMT0fMWI0=WIf@00
00001@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0^03IfMT00800fMWI0P00000J0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI00L0fMWI0`00002h0=WIf@00OP3IfMT2000001`0fMWI
00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@2h0=WIf@00O@3IfMT3000001`0fMWI00D000000=WIf@3IfMT0
fMWI000000070=WIf@030000003IfMT0fMWI00@000002P3IfMT00`000000fMWI0=WIf@2h0=WIf@00
O03IfMT4000001`0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@040000003IfMT0fMWI0000
00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2h0=WIf@00NP3IfMT200000080
fMWI00<000000=WIf@3IfMT0703IfMT3000000H0fMWI0P0000040=WIf@@000002@3IfMT00`000000
fMWI0=WIf@2h0=WIf@00N03IfMT2000003l0fMWI00<000000=WIf@3IfMT0^03IfMT007L0fMWI00<0
00000=WIf@3IfMT0?`3IfMT00`000000fMWI0=WIf@2h0=WIf@00M@3IfMT200000480fMWI0P00002i
0=WIf@00M03IfMT00`000000fMWI0=WIf@120=WIf@030000003IfMT0fMWI0;P0fMWI001b0=WIf@80
0000A@3IfMT00`000000fMWI0=WIf@2h0=WIf@00L@3IfMT00`000000fMWI0=WIf@150=WIf@030000
003IfMT0fMWI0;P0fMWI001_0=WIf@800000B03IfMT00`000000fMWI0=WIf@2h0=WIf@00K@3IfMT2
000004X0fMWI00<000000=WIf@3IfMT0^03IfMT006/0fMWI0P00001<0=WIf@030000003IfMT0fMWI
0;P0fMWI001Z0=WIf@<00000C03IfMT200000;T0fMWI001Y0=WIf@@00000C03IfMT00`000000fMWI
0=WIf@2h0=WIf@00I`3IfMT2000000040=WIf@0000000000000004`0fMWI00<000000=WIf@3IfMT0
^03IfMT006H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1;0=WIf@030000003I
fMT0fMWI0;P0fMWI001T0=WIf@800000D`3IfMT00`000000fMWI0=WIf@2h0=WIf@00H`3IfMT00`00
0000fMWI0=WIf@1C0=WIf@030000003IfMT0fMWI0;P0fMWI001Q0=WIf@800000EP3IfMT00`000000
fMWI0=WIf@2h0=WIf@00G`3IfMT2000005P0fMWI0P00002i0=WIf@00GP3IfMT00`000000fMWI0=WI
f@1H0=WIf@030000003IfMT0fMWI0;P0fMWI001L0=WIf@800000F`3IfMT00`000000fMWI0=WIf@2h
0=WIf@00F`3IfMT00`000000fMWI0=WIf@1K0=WIf@030000003IfMT0fMWI0;P0fMWI001I0=WIf@80
0000GP3IfMT00`000000fMWI0=WIf@2h0=WIf@00E`3IfMT200000600fMWI00<000000=WIf@3IfMT0
^03IfMT005H0fMWI0`00001P0=WIf@030000003IfMT0fMWI0;P0fMWI001E0=WIf@@00000H03IfMT2
00000;T0fMWI001C0=WIf@80000000@0fMWI0000000000000000H03IfMT00`000000fMWI0=WIf@2h
0=WIf@00DP3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI05l0fMWI00<000000=WI
f@3IfMT0^03IfMT00500fMWI0P00001W0=WIf@030000003IfMT0fMWI0;P0fMWI001?0=WIf@030000
003IfMT0fMWI0540fMWI0`0000030=WIf@030000003IfMT0000000<000002P3IfMT00`000000fMWI
0=WIf@2h0=WIf@00C@3IfMT2000005<0fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0^03IfMT004/0fMWI0P00001E0=WIf@050000003I
fMT0fMWI0=WIf@000000203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0;P0fMWI
001:0=WIf@030000003IfMT0fMWI05D0fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@030000
003IfMT0fMWI00L0fMWI0`00002h0=WIf@00B03IfMT2000005P0fMWI00D000000=WIf@3IfMT0fMWI
000000080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0^03IfMT004L0fMWI00<0
00000=WIf@3IfMT0F03IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI1000000:0=WIf@030000
003IfMT0fMWI0;P0fMWI00150=WIf@800000F`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2h0=WIf@00@`3IfMT2000005h0fMWI0`00
00060=WIf@@000002@3IfMT00`000000fMWI0=WIf@2h0=WIf@00@P3IfMT3000007@0fMWI00<00000
0=WIf@3IfMT0^03IfMT00440fMWI1000001d0=WIf@030000003IfMT0fMWI0;P0fMWI000o0=WIf@80
00000P3IfMT00`000000fMWI0=WIf@1c0=WIf@800000^@3IfMT003d0fMWI0P00001j0=WIf@030000
003IfMT0fMWI0;P0fMWI000l0=WIf@030000003IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0^03I
fMT003X0fMWI0P00001m0=WIf@030000003IfMT0fMWI0;P0fMWI000i0=WIf@030000003IfMT0fMWI
07d0fMWI00<000000=WIf@3IfMT0^03IfMT003L0fMWI0P0000200=WIf@030000003IfMT0fMWI0;P0
fMWI000f0=WIf@030000003IfMT0fMWI0800fMWI00<000000=WIf@3IfMT0^03IfMT003@0fMWI0P00
00230=WIf@030000003IfMT0fMWI0;P0fMWI000b0=WIf@800000Q@3IfMT200000;T0fMWI000`0=WI
f@800000Q`3IfMT00`000000fMWI0=WIf@2h0=WIf@00;`3IfMT3000008L0fMWI00<000000=WIf@3I
fMT0^03IfMT002d0fMWI1@0000270=WIf@030000003IfMT0fMWI0;P0fMWI000[0=WIf@8000000`3I
fMT00`000000fMWI0=WIf@260=WIf@030000003IfMT0fMWI0;P0fMWI000Z0=WIf@030000003IfMT0
fMWI08`0fMWI00<000000=WIf@3IfMT0^03IfMT002P0fMWI0P00002?0=WIf@030000003IfMT0fMWI
0;P0fMWI000V0=WIf@800000T@3IfMT200000;T0fMWI000T0=WIf@800000T`3IfMT00`000000fMWI
0=WIf@2h0=WIf@008P3IfMT2000009D0fMWI00<000000=WIf@3IfMT0^03IfMT00240fMWI00<00000
0=WIf@3IfMT0U@3IfMT00`000000fMWI0=WIf@2h0=WIf@007`3IfMT2000009P0fMWI00<000000=WI
f@3IfMT0^03IfMT001`0fMWI0`00002J0=WIf@030000003IfMT0fMWI0;P0fMWI000K0=WIf@<00000
V`3IfMT00`000000fMWI0=WIf@2h0=WIf@006@3IfMT5000009/0fMWI0P00002i0=WIf@005`3IfMT2
00000080fMWI0`00002K0=WIf@030000003IfMT0fMWI0;P0fMWI000E0=WIf@8000001@3IfMT00`00
0000fMWI0=WIf@2J0=WIf@030000003IfMT0fMWI0;P0fMWI000C0=WIf@800000Y03IfMT00`000000
fMWI0=WIf@2h0=WIf@004P3IfMT00`000000fMWI0=WIf@280=WIf@<000000`3IfMT01@000000fMWI
0=WIf@3IfMT0000000<0fMWI1000000:0=WIf@030000003IfMT0fMWI0;P0fMWI000@0=WIf@800000
RP3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@070=WIf@030000003IfMT0fMWI0;P0fMWI000>0=WIf@800000S03IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI0;P0fMWI000<0=WIf@800000SP3IfMT01@000000fMWI0=WIf@3IfMT0000000L0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@070=WIf@<00000^03IfMT000T0fMWI
0`00002@0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0^03IfMT000P0fMWI0`00002A0=WIf@050000
003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@04000000X0fMWI00<000000=WIf@3I
fMT0^03IfMT000L0fMWI1000002A0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@000000
fMWI0=WIf@3IfMT000000080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@2h0=WI
f@00203IfMT300000980fMWI0`0000060=WIf@@000000P3IfMT4000000T0fMWI00<000000=WIf@3I
fMT0^03IfMT000T0fMWI00<000000=WIf@3IfMT0[@3IfMT00`000000fMWI0=WIf@2h0=WIf@00^@3I
fMT00`000000fMWI0=WIf@2h0=WIf@00^@3IfMT200000;T0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 371}, {228.812, 0}} -> {-9.46977, -0.803248, 0.05105,
   0.00702097}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the flux lines in the cental plane ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g1 = 
      ContourPlot[
        radFld[cyl2, "\<Az\>", {x, y, Lz/2.}], {x, \(-rint\), rint}, {y, 
          \(-rint\), rint}, ColorFunction -> Hue]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0480769 0.5 0.0480769 [
[.01923 -0.0125 -12.5 -14 ]
[.01923 -0.0125 12.5 0 ]
[.25962 -0.0125 -9.5 -14 ]
[.25962 -0.0125 9.5 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.74038 -0.0125 -5 -14 ]
[.74038 -0.0125 5 0 ]
[.98077 -0.0125 -8 -14 ]
[.98077 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -25 -7 ]
[-0.0125 .01923 0 7 ]
[-0.0125 .25962 -19 -7 ]
[-0.0125 .25962 0 7 ]
[-0.0125 .5 -10 -7 ]
[-0.0125 .5 0 7 ]
[-0.0125 .74038 -10 -7 ]
[-0.0125 .74038 0 7 ]
[-0.0125 .98077 -16 -7 ]
[-0.0125 .98077 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 1 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 .4 1 r
.01923 .94144 m
.05094 .91209 L
.08791 .87702 L
.12197 .84341 L
.15659 .8079 L
.18686 .77473 L
.22527 .7319 L
.24583 .70604 L
.29396 .64408 L
.29776 .63736 L
.33517 .56868 L
.35113 .5 L
.33517 .43132 L
.29776 .36264 L
.29396 .35592 L
.24583 .29396 L
.22527 .2681 L
.18686 .22527 L
.15659 .1921 L
.12197 .15659 L
.08791 .12298 L
.05094 .08791 L
.01923 .05856 L
F
0 g
.01923 .94144 m
.05094 .91209 L
.08791 .87702 L
.12197 .84341 L
.15659 .8079 L
.18686 .77473 L
.22527 .7319 L
.24583 .70604 L
.29396 .64408 L
.29776 .63736 L
.33517 .56868 L
.35113 .5 L
.33517 .43132 L
.29776 .36264 L
.29396 .35592 L
.24583 .29396 L
.22527 .2681 L
.18686 .22527 L
.15659 .1921 L
.12197 .15659 L
.08791 .12298 L
.05094 .08791 L
.01923 .05856 L
s
.2 0 1 r
.01923 .87203 m
.05269 .84341 L
.08791 .80999 L
.11988 .77473 L
.15659 .72818 L
.17101 .70604 L
.2097 .63736 L
.22527 .60051 L
.23483 .56868 L
.24355 .5 L
.23483 .43132 L
.22527 .39949 L
.2097 .36264 L
.17101 .29396 L
.15659 .27182 L
.11988 .22527 L
.08791 .19001 L
.05269 .15659 L
.01923 .12797 L
F
0 g
.01923 .87203 m
.05269 .84341 L
.08791 .80999 L
.11988 .77473 L
.15659 .72818 L
.17101 .70604 L
.2097 .63736 L
.22527 .60051 L
.23483 .56868 L
.24355 .5 L
.23483 .43132 L
.22527 .39949 L
.2097 .36264 L
.17101 .29396 L
.15659 .27182 L
.11988 .22527 L
.08791 .19001 L
.05269 .15659 L
.01923 .12797 L
s
.8 0 1 r
.01923 .8115 m
.05928 .77473 L
.08791 .7429 L
.1109 .70604 L
.14365 .63736 L
.15659 .5975 L
.16318 .56868 L
.16976 .5 L
.16318 .43132 L
.15659 .4025 L
.14365 .36264 L
.1109 .29396 L
.08791 .2571 L
.05928 .22527 L
.01923 .1885 L
F
0 g
.01923 .8115 m
.05928 .77473 L
.08791 .7429 L
.1109 .70604 L
.14365 .63736 L
.15659 .5975 L
.16318 .56868 L
.16976 .5 L
.16318 .43132 L
.15659 .4025 L
.14365 .36264 L
.1109 .29396 L
.08791 .2571 L
.05928 .22527 L
.01923 .1885 L
s
1 0 .6 r
.01923 .76748 m
.06221 .70604 L
.08791 .64412 L
.08966 .63736 L
.10439 .56868 L
.10927 .5 L
.10439 .43132 L
.08966 .36264 L
.08791 .35588 L
.06221 .29396 L
.01923 .23252 L
F
0 g
.01923 .76748 m
.06221 .70604 L
.08791 .64412 L
.08966 .63736 L
.10439 .56868 L
.10927 .5 L
.10439 .43132 L
.08966 .36264 L
.08791 .35588 L
.06221 .29396 L
.01923 .23252 L
s
1 0 0 r
.01923 .7179 m
.02328 .70604 L
.04407 .63736 L
.05328 .56868 L
.05627 .5 L
.05328 .43132 L
.04407 .36264 L
.02328 .29396 L
.01923 .2821 L
F
0 g
.01923 .7179 m
.02328 .70604 L
.04407 .63736 L
.05328 .56868 L
.05627 .5 L
.05328 .43132 L
.04407 .36264 L
.02328 .29396 L
.01923 .2821 L
s
0 1 .4 r
.94144 .01923 m
.91209 .05094 L
.87702 .08791 L
.84341 .12197 L
.8079 .15659 L
.77473 .18686 L
.7319 .22527 L
.70604 .24583 L
.64408 .29396 L
.63736 .29776 L
.56868 .33517 L
.5 .35113 L
.43132 .33517 L
.36264 .29776 L
.35592 .29396 L
.29396 .24583 L
.2681 .22527 L
.22527 .18686 L
.1921 .15659 L
.15659 .12197 L
.12298 .08791 L
.08791 .05094 L
.05856 .01923 L
F
0 g
.94144 .01923 m
.91209 .05094 L
.87702 .08791 L
.84341 .12197 L
.8079 .15659 L
.77473 .18686 L
.7319 .22527 L
.70604 .24583 L
.64408 .29396 L
.63736 .29776 L
.56868 .33517 L
.5 .35113 L
.43132 .33517 L
.36264 .29776 L
.35592 .29396 L
.29396 .24583 L
.2681 .22527 L
.22527 .18686 L
.1921 .15659 L
.15659 .12197 L
.12298 .08791 L
.08791 .05094 L
.05856 .01923 L
s
0 1 .4 r
.94144 .98077 m
.91209 .94906 L
.87702 .91209 L
.84341 .87803 L
.8079 .84341 L
.77473 .81314 L
.7319 .77473 L
.70604 .75417 L
.64408 .70604 L
.63736 .70224 L
.56868 .66483 L
.5 .64887 L
.43132 .66483 L
.36264 .70224 L
.35592 .70604 L
.29396 .75417 L
.2681 .77473 L
.22527 .81314 L
.1921 .84341 L
.15659 .87803 L
.12298 .91209 L
.08791 .94906 L
.05856 .98077 L
F
0 g
.94144 .98077 m
.91209 .94906 L
.87702 .91209 L
.84341 .87803 L
.8079 .84341 L
.77473 .81314 L
.7319 .77473 L
.70604 .75417 L
.64408 .70604 L
.63736 .70224 L
.56868 .66483 L
.5 .64887 L
.43132 .66483 L
.36264 .70224 L
.35592 .70604 L
.29396 .75417 L
.2681 .77473 L
.22527 .81314 L
.1921 .84341 L
.15659 .87803 L
.12298 .91209 L
.08791 .94906 L
.05856 .98077 L
s
.2 1 0 r
.87203 .01923 m
.84341 .05269 L
.80999 .08791 L
.77473 .11988 L
.72818 .15659 L
.70604 .17101 L
.63736 .2097 L
.60051 .22527 L
.56868 .23483 L
.5 .24355 L
.43132 .23483 L
.39949 .22527 L
.36264 .2097 L
.29396 .17101 L
.27182 .15659 L
.22527 .11988 L
.19001 .08791 L
.15659 .05269 L
.12797 .01923 L
F
0 g
.87203 .01923 m
.84341 .05269 L
.80999 .08791 L
.77473 .11988 L
.72818 .15659 L
.70604 .17101 L
.63736 .2097 L
.60051 .22527 L
.56868 .23483 L
.5 .24355 L
.43132 .23483 L
.39949 .22527 L
.36264 .2097 L
.29396 .17101 L
.27182 .15659 L
.22527 .11988 L
.19001 .08791 L
.15659 .05269 L
.12797 .01923 L
s
.2 1 0 r
.87203 .98077 m
.84341 .94731 L
.80999 .91209 L
.77473 .88012 L
.72818 .84341 L
.70604 .82899 L
.63736 .7903 L
.60051 .77473 L
.56868 .76517 L
.5 .75645 L
.43132 .76517 L
.39949 .77473 L
.36264 .7903 L
.29396 .82899 L
.27182 .84341 L
.22527 .88012 L
.19001 .91209 L
.15659 .94731 L
.12797 .98077 L
F
0 g
.87203 .98077 m
.84341 .94731 L
.80999 .91209 L
.77473 .88012 L
.72818 .84341 L
.70604 .82899 L
.63736 .7903 L
.60051 .77473 L
.56868 .76517 L
.5 .75645 L
.43132 .76517 L
.39949 .77473 L
.36264 .7903 L
.29396 .82899 L
.27182 .84341 L
.22527 .88012 L
.19001 .91209 L
.15659 .94731 L
.12797 .98077 L
s
.8 1 0 r
.8115 .98077 m
.77473 .94072 L
.7429 .91209 L
.70604 .8891 L
.63736 .85635 L
.5975 .84341 L
.56868 .83682 L
.5 .83024 L
.43132 .83682 L
.4025 .84341 L
.36264 .85635 L
.29396 .8891 L
.2571 .91209 L
.22527 .94072 L
.1885 .98077 L
F
0 g
.8115 .98077 m
.77473 .94072 L
.7429 .91209 L
.70604 .8891 L
.63736 .85635 L
.5975 .84341 L
.56868 .83682 L
.5 .83024 L
.43132 .83682 L
.4025 .84341 L
.36264 .85635 L
.29396 .8891 L
.2571 .91209 L
.22527 .94072 L
.1885 .98077 L
s
.8 1 0 r
.8115 .01923 m
.77473 .05928 L
.7429 .08791 L
.70604 .1109 L
.63736 .14365 L
.5975 .15659 L
.56868 .16318 L
.5 .16976 L
.43132 .16318 L
.4025 .15659 L
.36264 .14365 L
.29396 .1109 L
.2571 .08791 L
.22527 .05928 L
.1885 .01923 L
F
0 g
.8115 .01923 m
.77473 .05928 L
.7429 .08791 L
.70604 .1109 L
.63736 .14365 L
.5975 .15659 L
.56868 .16318 L
.5 .16976 L
.43132 .16318 L
.4025 .15659 L
.36264 .14365 L
.29396 .1109 L
.2571 .08791 L
.22527 .05928 L
.1885 .01923 L
s
1 .6 0 r
.76748 .98077 m
.70604 .93779 L
.64412 .91209 L
.63736 .91034 L
.56868 .89561 L
.5 .89073 L
.43132 .89561 L
.36264 .91034 L
.35588 .91209 L
.29396 .93779 L
.23252 .98077 L
F
0 g
.76748 .98077 m
.70604 .93779 L
.64412 .91209 L
.63736 .91034 L
.56868 .89561 L
.5 .89073 L
.43132 .89561 L
.36264 .91034 L
.35588 .91209 L
.29396 .93779 L
.23252 .98077 L
s
1 .6 0 r
.76748 .01923 m
.70604 .06221 L
.64412 .08791 L
.63736 .08966 L
.56868 .10439 L
.5 .10927 L
.43132 .10439 L
.36264 .08966 L
.35588 .08791 L
.29396 .06221 L
.23252 .01923 L
F
0 g
.76748 .01923 m
.70604 .06221 L
.64412 .08791 L
.63736 .08966 L
.56868 .10439 L
.5 .10927 L
.43132 .10439 L
.36264 .08966 L
.35588 .08791 L
.29396 .06221 L
.23252 .01923 L
s
1 0 0 r
.7179 .98077 m
.70604 .97672 L
.63736 .95593 L
.56868 .94672 L
.5 .94373 L
.43132 .94672 L
.36264 .95593 L
.29396 .97672 L
.2821 .98077 L
F
0 g
.7179 .98077 m
.70604 .97672 L
.63736 .95593 L
.56868 .94672 L
.5 .94373 L
.43132 .94672 L
.36264 .95593 L
.29396 .97672 L
.2821 .98077 L
s
1 0 0 r
.7179 .01923 m
.70604 .02328 L
.63736 .04407 L
.56868 .05328 L
.5 .05627 L
.43132 .05328 L
.36264 .04407 L
.29396 .02328 L
.2821 .01923 L
F
0 g
.7179 .01923 m
.70604 .02328 L
.63736 .04407 L
.56868 .05328 L
.5 .05627 L
.43132 .05328 L
.36264 .04407 L
.29396 .02328 L
.2821 .01923 L
s
0 .4 1 r
.98077 .94144 m
.94906 .91209 L
.91209 .87702 L
.87803 .84341 L
.84341 .8079 L
.81314 .77473 L
.77473 .7319 L
.75417 .70604 L
.70604 .64408 L
.70224 .63736 L
.66483 .56868 L
.64887 .5 L
.66483 .43132 L
.70224 .36264 L
.70604 .35592 L
.75417 .29396 L
.77473 .2681 L
.81314 .22527 L
.84341 .1921 L
.87803 .15659 L
.91209 .12298 L
.94906 .08791 L
.98077 .05856 L
F
0 g
.98077 .94144 m
.94906 .91209 L
.91209 .87702 L
.87803 .84341 L
.84341 .8079 L
.81314 .77473 L
.77473 .7319 L
.75417 .70604 L
.70604 .64408 L
.70224 .63736 L
.66483 .56868 L
.64887 .5 L
.66483 .43132 L
.70224 .36264 L
.70604 .35592 L
.75417 .29396 L
.77473 .2681 L
.81314 .22527 L
.84341 .1921 L
.87803 .15659 L
.91209 .12298 L
.94906 .08791 L
.98077 .05856 L
s
.2 0 1 r
.98077 .87203 m
.94731 .84341 L
.91209 .80999 L
.88012 .77473 L
.84341 .72818 L
.82899 .70604 L
.7903 .63736 L
.77473 .60051 L
.76517 .56868 L
.75645 .5 L
.76517 .43132 L
.77473 .39949 L
.7903 .36264 L
.82899 .29396 L
.84341 .27182 L
.88012 .22527 L
.91209 .19001 L
.94731 .15659 L
.98077 .12797 L
F
0 g
.98077 .87203 m
.94731 .84341 L
.91209 .80999 L
.88012 .77473 L
.84341 .72818 L
.82899 .70604 L
.7903 .63736 L
.77473 .60051 L
.76517 .56868 L
.75645 .5 L
.76517 .43132 L
.77473 .39949 L
.7903 .36264 L
.82899 .29396 L
.84341 .27182 L
.88012 .22527 L
.91209 .19001 L
.94731 .15659 L
.98077 .12797 L
s
.8 0 1 r
.98077 .8115 m
.94072 .77473 L
.91209 .7429 L
.8891 .70604 L
.85635 .63736 L
.84341 .5975 L
.83682 .56868 L
.83024 .5 L
.83682 .43132 L
.84341 .4025 L
.85635 .36264 L
.8891 .29396 L
.91209 .2571 L
.94072 .22527 L
.98077 .1885 L
F
0 g
.98077 .8115 m
.94072 .77473 L
.91209 .7429 L
.8891 .70604 L
.85635 .63736 L
.84341 .5975 L
.83682 .56868 L
.83024 .5 L
.83682 .43132 L
.84341 .4025 L
.85635 .36264 L
.8891 .29396 L
.91209 .2571 L
.94072 .22527 L
.98077 .1885 L
s
1 0 .6 r
.98077 .76748 m
.93779 .70604 L
.91209 .64412 L
.91034 .63736 L
.89561 .56868 L
.89073 .5 L
.89561 .43132 L
.91034 .36264 L
.91209 .35588 L
.93779 .29396 L
.98077 .23252 L
F
0 g
.98077 .76748 m
.93779 .70604 L
.91209 .64412 L
.91034 .63736 L
.89561 .56868 L
.89073 .5 L
.89561 .43132 L
.91034 .36264 L
.91209 .35588 L
.93779 .29396 L
.98077 .23252 L
s
1 0 0 r
.98077 .7179 m
.97672 .70604 L
.95593 .63736 L
.94672 .56868 L
.94373 .5 L
.94672 .43132 L
.95593 .36264 L
.97672 .29396 L
.98077 .2821 L
F
0 g
.98077 .7179 m
.97672 .70604 L
.95593 .63736 L
.94672 .56868 L
.94373 .5 L
.94672 .43132 L
.95593 .36264 L
.97672 .29396 L
.98077 .2821 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{311, 311},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004g0001=b000`400?l00000o`00003oo`3IfMTh
0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh
0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@008@3IfMT3
00000080fMWI0`00000l0=WIf@@00000?03IfMT3000003l0fMWI1000000o0=WIf@<000000P3IfMT3
000000D0fMWI000R0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0?@3IfMT0
0`000000fMWI0=WIf@0h0=WIf@050000003IfMT0fMWI0=WIf@000000@P3IfMT00`000000fMWI0=WI
f@0m0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00280fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI03P0fMWI
00D000000=WIf@3IfMT0fMWI000000120=WIf@030000003IfMT0fMWI03d0fMWI00@000000=WIf@3I
fMT000000`3IfMT00`000000fMWI0=WIf@020=WIf@00603IfMT7000000<0fMWI00@000000=WIf@3I
fMT000000`3IfMT00`000000fMWI0=WIf@0b0=WIf@L00000103IfMT00`000000fMWI0=WIf@0h0=WI
f@050000003IfMT0fMWI0=WIf@000000@P3IfMT00`000000fMWI0=WIf@0m0=WIf@040000003IfMT0
fMWI000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00280fMWI00@000000=WIf@3IfMT000000`3I
fMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI03P0fMWI00D000000=WIf@3IfMT0fMWI
000000120=WIf@030000003IfMT0fMWI03d0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000
fMWI0=WIf@020=WIf@008P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI03T0
fMWI1000000k0=WIf@050000003IfMT0fMWI0=WIf@000000?P3IfMT400000400fMWI00@000000=WI
f@3IfMT000000`3IfMT00`000000fMWI0=WIf@020=WIf@008P3IfMT010000000fMWI0=WIf@000003
0=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>`3IfMT01@000000fMWI0=WIf@3I
fMT0000003l0fMWI00<000000=WIf@3IfMT0@03IfMT010000000fMWI0=WIf@0000030=WIf@030000
003IfMT0fMWI0080fMWI000Q0=WIf@8000000`3IfMT3000003d0fMWI1000000k0=WIf@<00000@03I
fMT4000003h0fMWI0P0000030=WIf@<000001@3IfMT00?l0fMWI>03IfMT00?l0fMWI>03IfMT00?l0
fMWI>03IfMT00?l0fMWI>03IfMT00?l0fMWI>03IfMT00?l0fMWI>03IfMT001`0fMWIo`00000I0000
00<0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00@3IfMT000`0fMWI
0`0000020=WIf@<00000203IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0400fMWI
00<000000=WIf@3IfMT0@03IfMT00`000000fMWI0=WIf@100=WIf@030000003IfMT0fMWI0440fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@010=WIf@003@3IfMT010000000fMWI0=WI
f@0000030=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMTE0=WIf@030000
003IfMT0fMWI0040fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@3o0=WIfAD0fMWI00<000000=WIf@3IfMT00@3IfMT000<0fMWI1`00
00030=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01@3IfMT3000000d0fMWI
00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00T0fMWI
0P00000<0=WIf@<00000M@3IfMT2000000`0fMWI0P00000;0=WIf@030000003IfMT0fMWI00h0fMWI
00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0;0=WIf@<000000`3IfMT000d0fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0080fMWI
3000ool00`0000000?mV003oIP0@003oIP030000000co`00<ol000h0<ol000<000000<co003<o`00
2`3<o`000`000000oiT00?nI000<0?nI00<00000KP3o0004000000d0oiT000<000000<co003<o`00
2`3<o`000`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<00000003oo`00ool0
2@00ool50=WIf@030000003IfMT0fMWI0040fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@020=WIf@d00?oo00<00000003oIP00ofH0
4000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l000/0c?l00P00000?0?nI00<00000
J03o0003000000l0oiT00P00000=0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH0
4000ofH00`0000000?oo003oo`0:003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT000d0fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0080fMWI
3P00ool00`0000000?mV003oIP0@003oIP030000000co`00<ol000h0<ol000<000000<co003<o`00
303<o`000`000000oiT00?nI000?0?nI00<00000HP3o000300000140oiT000<000000<co003<o`00
303<o`000`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<00000003oo`00ool0
2`00ool50=WIf@030000003IfMT0fMWI0040fMWI000<0=WIf@8000000`3IfMT3000000P0fMWI00<0
00000=WIf@3IfMT00P3IfMT?003oo`0300000000ofH00?mV01000?mV00<0000003?o000co`003P0c
o`000`000000c?l00<co000<0<co00030000003oV@00oiT00140oiT00`00001L0?l000<000004`3o
V@000`000000c?l00<co000<0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH04000
ofH00`0000000?oo003oo`0<003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT@003oo`0300000000ofH00?mV01000?mV00<0000003?o000co`003P0co`00
0`000000c?l00<co000<0<co00800000503oV@03000005H0o`000`00000D0?nI008000003P3<o`00
0`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<00000003oo`00ool03@00ool5
0=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI4@00ool00`00
00000?mV003oIP0?003oIP030000000co`00<ol000l0<ol000<000000<co003<o`003@3<o`000`00
0000oiT00?nI000D0?nI00<00000D03o0003000001H0oiT000<000000<co003<o`003@3<o`000`00
0000<ol003?o000?03?o000300000000ofH00?mV00l00?mV00<00000003oo`00ool03P00ool50=WI
f@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI4P00ool00`000000
0?mV003oIP0?003oIP030000000co`00<ol000h0<ol000<000000<co003<o`003P3<o`02000001L0
oiT01@0000160?l000D000005`3oV@0200000100c?l000<0000003?o000co`003P0co`000`000000
0?mV003oIP0?003oIP0300000000ool00?oo00l00?oo1@3IfMT00`000000fMWI0=WIf@010=WIf@00
703IfMT00`000000fMWI0=WIf@020=WIfA<00?oo00<00000003oIP00ofH03`00ofH00`000000<ol0
03?o000>03?o00030000003<o`00c?l000l0c?l000<000000?nI003oV@006@3oV@07000003P0o`00
1`00000K0?nI00030000003<o`00c?l000l0c?l000<0000003?o000co`003P0co`000`0000000?mV
003oIP0?003oIP0300000000ool00?oo01000?oo1@3IfMT00`000000fMWI0=WIf@010=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIfA@00?oo00<00000003oIP00ofH03`00ofH00`000000<ol003?o
000>03?o00030000003<o`00c?l000l0c?l000<000000?nI003oV@007`3oV@06000002`0o`001P00
000Q0?nI00030000003<o`00c?l000l0c?l000<0000003?o000co`003P0co`000`0000000?mV003o
IP0?003oIP0300000000ool00?oo01400?oo1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIfA@00?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000>
03?o00030000003<o`00c?l000l0c?l00P00000U0?nI00d000004P3o000=000002D0oiT00P00000A
0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH04000ofH00`0000000?oo003oo`0A
003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
00000?oo003oo`0B003oo`0300000000ofH00?mV00l00?mV00<0000003?o000co`003`0co`000`00
0000c?l00<co000@0<co00030000003oV@00oiT002l0oiT04P00000a0?nI00030000003<o`00c?l0
0100c?l000<0000003?o000co`003`0co`000`0000000?mV003oIP0?003oIP0300000000ool00?oo
01800?oo00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@03001Vo`0000000?oo01<00?oo00<00000003oIP00ofH03`00ofH00`000000
<ol003?o000?03?o008000004@3<o`0200000700oiT00P00000A0<co008000004@0co`000`000000
0?mV003oIP0?003oIP0300000000ool00?oo01800?oo00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@8006Ko00<00000003oo`00ool0
4P00ool00`0000000?mV003oIP0?003oIP030000000co`00<ol00100<ol000<000000<co003<o`00
403<o`02000006`0oiT00P00000B0<co00030000000co`00<ol00100<ol000<00000003oIP00ofH0
3`00ofH00`0000000?oo003oo`0B003oo`0300000000I_l0fMWI00@0fMWI00<000000=WIf@3IfMT0
0@3IfMT001`0fMWI0P0000030=WIf@<006Ko00<00000003oo`00ool04P00ool00`0000000?mV003o
IP0?003oIP030000000co`00<ol00100<ol000<000000<co003<o`004@3<o`02000006P0oiT00P00
000C0<co00030000000co`00<ol00100<ol000<00000003oIP00ofH03`00ofH00`0000000?oo003o
o`0B003oo`0300000000I_l006Ko00@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@@006Ko00<00000003oo`00ool04P00ool00`0000000?mV003oIP0?003oIP030000000co`00
<ol00100<ol000<000000<co003<o`004P3<o`02000006@0oiT00P00000D0<co00030000000co`00
<ol00100<ol000<00000003oIP00ofH03`00ofH00`0000000?oo003oo`0B003oo`0400000000I_l0
06Ko001Vo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT5
001Vo`0300000000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000@
03?o00030000003<o`00c?l001<0c?l00`00001N0?nI00<000005@3<o`000`000000<ol003?o000@
03?o000300000000ofH00?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`02
001Vo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT6001V
o`0300000000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000@03?o
00030000003<o`00c?l001D0c?l00P00001J0?nI008000005`3<o`000`000000<ol003?o000@03?o
000300000000ofH00?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`03001V
o`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT7001Vo`03
00000000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000@03?o0003
0000003<o`00c?l001H0c?l00P00001F0?nI00800000603<o`000`000000<ol003?o000@03?o0003
00000000ofH00?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`04001Vo`D0
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT8001Vo`030000
0000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000@03?o00030000
003<o`00c?l001L0c?l00P00001B0?nI008000006@3<o`000`000000<ol003?o000@03?o00030000
0000ofH00?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`05001Vo`D0fMWI
00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT9001Vo`8000004P00
ool2000001400?mV0P00000A03?o008000006@3<o`05000004P0oiT01@00000I0<co008000004@0c
o`02000001400?mV0P00000B003oo`8000002000I_l50=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI2`00I_l00`0000000?oo003oo`0A003oo`0300000000ofH0
0?mV01000?mV00<0000003?o000co`00400co`02000001`0c?l01@00000n0?nI00D00000703<o`02
00000180<ol000<00000003oIP00ofH04000ofH00`0000000?oo003oo`0A003oo`0300000000I_l0
06Ko00P006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WI
f@`006Ko00<00000003oo`00ool04@00ool00`0000000?mV003oIP0@003oIP030000000co`00<ol0
0140<ol000<000000<co003<o`007P3<o`05000003@0oiT01@00000P0<co00030000000co`00<ol0
0140<ol000<00000003oIP00ofH04000ofH00`0000000?oo003oo`0A003oo`0300000000I_l006Ko
00T006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@d0
06Ko00<00000003oo`00ool04@00ool00`0000000?mV003oIP0@003oIP030000000co`00<ol00140
<ol00P00000S0<co00D00000:P3oV@05000002<0c?l00P00000C03?o000300000000ofH00?mV0100
0?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`0:001Vo`D0fMWI00<000000=WIf@3I
fMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT>001Vo`8000004P00ool00`0000000?mV
003oIP0@003oIP8000004`0co`02000002H0c?l03000000B0?nI00`000009P3<o`02000001<0<ol0
0P00000B003oIP0300000000ool00?oo01000?oo0P00000=001Vo`D0fMWI00<000000=WIf@3IfMT0
0@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT@001Vo`0300000000ool00?oo01000?oo00<0
0000003oIP00ofH04@00ofH00`000000<ol003?o000B03?o00030000003<o`00c?l002l0c?l04P00
000a0<co00030000000co`00<ol00180<ol000<00000003oIP00ofH04@00ofH00`0000000?oo003o
o`0@003oo`0300000000I_l006Ko00d006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIfA4006Ko00<00000003oo`00ool04000ool00`0000000?mV003oIP0A
003oIP030000000co`00<ol00180<ol00P00001`0<co00800000500co`000`0000000?mV003oIP0A
003oIP0300000000ool00?oo01000?oo00<00000001Vo`00I_l03P00I_l50=WIf@030000003IfMT0
fMWI0040fMWI000L0=WIf@8000000`3IfMTB001Vo`0300000000ool00?oo01000?oo00<00000003o
IP00ofH04@00ofH00`000000<ol003?o000C03?o00800000K03<o`02000001D0<ol000<00000003o
IP00ofH04@00ofH00`0000000?oo003oo`0@003oo`0300000000I_l006Ko00l006Ko103IfMT20000
00<0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI4`00I_l00`0000000?oo003oo`0@003oo`03
00000000ofH00?mV01400?mV0P00000E03?o00800000J03<o`02000001D0<ol00P00000C003oIP03
00000000ool00?oo01000?oo00<00000001Vo`00I_l04000I_l50=WIf@030000003IfMT0fMWI0040
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI5000I_l00`0000000?oo003oo`0@003oo`030000
0000ofH00?mV01800?mV00<0000003?o000co`00500co`02000006@0c?l00P00000F03?o00030000
0000ofH00?mV01800?mV00<00000003oo`00ool04000ool00`00000006Ko001Vo`0A001Vo`D0fMWI
00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTD001Vo`0300000000
ool00?oo01400?oo00<00000003oIP00ofH04P00ofH00`000000<ol003?o000E03?o00<00000GP3<
o`03000001L0<ol000<00000003oIP00ofH04P00ofH00`0000000?oo003oo`0A003oo`0300000000
I_l006Ko014006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@8000004`00I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01800?mV00<00000
03?o000co`005`0co`02000005X0c?l00P00000I03?o000300000000ofH00?mV01800?mV00<00000
003oo`00ool04@00ool00`00000006Ko001Vo`0A001Vo`800000103IfMT00`000000fMWI0=WIf@01
0=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@80<`3o00<00000001Vo`00I_l04@00I_l00`00
00000?oo003oo`0A003oo`0300000000ofH00?mV01800?mV00<0000003?o000co`00600co`020000
05H0c?l00P00000J03?o000300000000ofH00?mV01800?mV00<00000003oo`00ool04@00ool00`00
000006Ko001Vo`0A001Vo`030000000c0?l0fMWI00@0fMWI00<000000=WIf@3IfMT00@3IfMT001`0
fMWI00<000000=WIf@3IfMT00P3IfMT303<0o`0300000000I_l006Ko014006Ko00<00000003oo`00
ool04@00ool00`0000000?mV003oIP0B003oIP8000006P0co`0200000580c?l00P00000J03?o0080
00005000ofH00`0000000?oo003oo`0A003oo`0300000000I_l006Ko014006Ko00<0000003<0o`0c
0?l01@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@@0<`3o
00<00000001Vo`00I_l04@00I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01<00?mV
00<0000003?o000co`006@0co`02000004h0c?l00P00000K03?o000300000000ofH00?mV01<00?mV
00<00000003oo`00ool04@00ool00`00000006Ko001Vo`0A001Vo`040000000c0?l0<`3o03<0o`D0
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT503<0o`800000
4P00I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01<00?mV00<0000003?o000co`00
6P0co`02000004X0c?l00P00000L03?o000300000000ofH00?mV01<00?mV00<00000003oo`00ool0
4@00ool00`00000006Ko001Vo`0@001Vo`800000100c0?l50=WIf@030000003IfMT0fMWI0040fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI1`0c0?l00`00000006Ko001Vo`0@001Vo`0300000000
ool00?oo01400?oo00<00000003oIP00ofH04`00ofH00`000000<ol003?o000K03?o00<00000A03<
o`03000001d0<ol000<00000003oIP00ofH04`00ofH00`0000000?oo003oo`0A003oo`0300000000
I_l006Ko010006Ko00<0000003<0o`0c0?l0100c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI200c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool0
0?oo01400?oo00<00000003oIP00ofH04`00ofH00`000000<ol003?o000M03?o00<00000?P3<o`03
000001l0<ol000<00000003oIP00ofH04`00ofH00`0000000?oo003oo`0A003oo`0300000000I_l0
06Ko010006Ko00<0000003<0o`0c0?l01@0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI2@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo
01400?oo00<00000003oIP00ofH04`00ofH00`000000<ol003?o000O03?o00<00000>03<o`030000
0240<ol000<00000003oIP00ofH04`00ofH00`0000000?oo003oo`0A003oo`0300000000I_l006Ko
010006Ko00<0000003<0o`0c0?l01P0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI2P0c0?l20000014006Ko00<00000003oo`00ool04@00ool2000001@0
0?mV0P00000R03?o00D00000;P3<o`0500000280<ol00P00000D003oIP8000004`00ool00`000000
06Ko001Vo`0?001Vo`8000002@0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI300c0?l00`00000006Ko001Vo`0?001Vo`0300000000ool00?oo01800?oo
00<00000003oIP00ofH04`00ofH00`000000<ol003?o000T03?o00T00000703<o`09000002H0<ol0
00<00000003oIP00ofH04`00ofH00`0000000?oo003oo`0B003oo`0300000000I_l006Ko00l006Ko
00<0000003<0o`0c0?l02@0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@8000000`3I
fMT=03<0o`0300000000I_l006Ko00l006Ko00<00000003oo`00ool04P00ool00`0000000?mV003o
IP0C003oIP800000;@0co`09000000T0c?l02P00000]03?o008000005@00ofH00`0000000?oo003o
o`0B003oo`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l02P0c0?l40=WIf@8000000`3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT>03<0o`0300000000I_l006Ko00l006Ko00<00000
003oo`00ool04P00ool00`0000000?mV003oIP0D003oIP030000000co`00<ol003<0<ol02@00000f
03?o000300000000ofH00?mV01@00?mV00<00000003oo`00ool04P00ool00`00000006Ko001Vo`0?
001Vo`030000000c0?l0<`3o00/0<`3o1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`00
0000fMWI0=WIf@020=WIf@l0<`3o00<00000001Vo`00I_l03`00I_l00`0000000?oo003oo`0B003o
o`0300000000ofH00?mV01@00?mV0P00001`03?o008000005P00ofH00`0000000?oo003oo`0B003o
o`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l0300c0?l50=WIf@030000003IfMT0fMWI
0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI400c0?l00`00000006Ko001Vo`0?001Vo`03
00000000ool00?oo01800?oo00<00000003oIP00ofH05@00ofH2000006`0<ol00P00000G003oIP03
00000000ool00?oo01800?oo00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0=03<0o`D0
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTA03<0o`030000
0000I_l006Ko00l006Ko00<00000003oo`00ool04P00ool00`0000000?mV003oIP0F003oIP800000
J00co`02000001P00?mV00<00000003oo`00ool04P00ool00`00000006Ko001Vo`0?001Vo`030000
000c0?l0<`3o00h0<`3o1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WI
f@020=WIfA80<`3o00<00000001Vo`00I_l03`00I_l00`0000000?oo003oo`0B003oo`0300000000
ofH00?mV01L00?mV0P00001T03?o008000006@00ofH00`0000000?oo003oo`0B003oo`0300000000
I_l006Ko00l006Ko00<0000003<0o`0c0?l03`0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI4`0c0?l00`00000006Ko001Vo`0?001Vo`0300000000ool0
0?oo01800?oo0P00000I003oIP800000H00co`02000001T00?mV0P00000D003oo`0300000000I_l0
06Ko00l006Ko00<0000003<0o`0c0?l0400c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI0P00000B03<0o`0300000000I_l006Ko00l006Ko00<00000003o
o`00ool04`00ool00`0000000?mV003oIP0H003oIP030000000co`00<ol005`0<ol000<00000003o
IP00ofH06000ofH00`0000000?oo003oo`0C003oo`0300000000I_l006Ko00l006Ko00<0000003<0
o`0c0?l0400c0?l2000000@0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3I
fMT00P3IfMT20<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l04000I_l00`000000
0?oo003oo`0C003oo`0300000000ofH00?mV01P00?mV0P00001J03?o008000006P00ofH00`000000
0?oo003oo`0C003oo`0300000000I_l006Ko010006Ko00<0000003<0o`0c0?l03`0c0?l00`000000
c03o0=WIf@040=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI
0`3<0?l00`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko00l006Ko00<00000003oo`00ool0
5000ool00`0000000?mV003oIP0I003oIP800000EP0co`02000001/00?mV00<00000003oo`00ool0
5000ool00`00000006Ko001Vo`0?001Vo`030000000c0?l0<`3o00l0<`3o00<000000<`0o`3<0?l0
1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@@0c03o00<0
000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0?001Vo`0300000000ool00?oo01@00?oo00<0
0000003oIP00ofH06P00ofH200000580<ol00P00000L003oIP0300000000ool00?oo01@00?oo00<0
0000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0?03<0o`040000003<0?l0c03o0<`0o`D0fMWI
00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT50<`0o`030000000c
0?l0<`3o00l0<`3o00<00000001Vo`00I_l03`00I_l00`0000000?oo003oo`0D003oo`0300000000
ofH00?mV01/00?mV0P00001>03?o008000007@00ofH00`0000000?oo003oo`0D003oo`0300000000
I_l006Ko00l006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`020<`0o`D0fMWI00<0
00000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT60<`0o`800000400c0?l0
0`00000006Ko001Vo`0?001Vo`0300000000ool00?oo01@00?oo00<00000003oIP00ofH07000ofH2
000004X0<ol00P00000N003oIP0300000000ool00?oo01@00?oo00<00000001Vo`00I_l03`00I_l0
0`000000<`3o03<0o`0>03<0o`8000001@3<0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@8000000`3IfMT80<`0o`030000000c0?l0<`3o00d0<`3o00<00000001Vo`00I_l04000I_l00`00
00000?oo003oo`0D003oo`0300000000ofH00?mV01d00?mV0P00001603?o008000007`00ofH00`00
00000?oo003oo`0D003oo`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l03P0c0?l00`00
0000c03o0<`0o`050<`0o`@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@T0
c03o00<0000003<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@0
0?oo00<00000003oIP00ofH07P00ofH200000440<ol00`00000P003oIP0300000000ool00?oo01@0
0?oo00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00H0
c03o1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@X0c03o
00<0000003<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo
00<00000003oIP00ofH07`00ofH2000003d0<ol00P00000R003oIP0300000000ool00?oo01@00?oo
00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00L0c03o
1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0c03o00<0
000003<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo00<0
0000003oIP00ofH08000ofH2000003T0<ol00P00000S003oIP0300000000ool00?oo01@00?oo00<0
0000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00P0c03o1@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@`0c03o00<00000
03<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo0P00000R
003oIP<00000<`0co`03000002<00?mV0P00000F003oo`0300000000I_l006Ko00l006Ko00<00000
03<0o`0c0?l03P0c0?l00`000000c03o0<`0o`090<`0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT<0<`0o`030000000c0?l0<`3o00d0<`3o00<00000001V
o`00I_l04000I_l00`0000000?oo003oo`0F003oo`0300000000ofH00?mV02800?mV1@00000Z03?o
00@000009@00ofH00`0000000?oo003oo`0F003oo`0300000000I_l006Ko00l006Ko00<0000003<0
o`0c0?l03P0c0?l00`000000c03o0<`0o`090<`0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000c03o0<`0o`0:0<`0o`030000000c0?l0<`3o00d0
<`3o00<00000001Vo`00I_l04000I_l00`0000000?oo003oo`0F003oo`0300000000ofH00?mV02H0
0?mV1@00000P03?o00D00000:000ofH00`0000000?oo003oo`0F003oo`0300000000I_l006Ko00l0
06Ko00<0000003<0o`0c0?l03P0c0?l00`000000c03o0<`0o`0:0<`0o`030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000c03o
0<`0o`0;0<`0o`030000000c0?l0<`3o00d0<`3o00<00000001Vo`00I_l04000I_l00`0000000?oo
003oo`0F003oo`0300000000ofH00?mV02X00?mV1`00000B03?o00L00000;000ofH00`0000000?oo
003oo`0F003oo`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l03P0c0?l00`000000c03o
0<`0o`0;0<`0o`030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`3o09T000000<`0o`0<0<`0o`030000000c0?l0<`3o00d0<`3o00<0
0000001Vo`00I_l04000I_l00`0000000?oo003oo`0F003oo`0300000000ofH00?mV03000?mV1P00
000503?o00L00000<P00ofH00`0000000?oo003oo`0F003oo`0300000000I_l006Ko00l006Ko00<0
000003<0o`0c0?l03P0c0?l00`000000c03o0<`0o`0;0<`0o`030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT20?l0V@030000003<0?l0
c03o00/0c03o00<0000003<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool0
0?oo01H00?oo00<00000003oIP00ofH0=@00ofH5000003P00?mV00<00000003oo`00ool05P00ool0
0`00000006Ko001Vo`0@001Vo`030000000c0?l0<`3o00d0<`3o00<000000<`0o`3<0?l02`3<0?l0
0`000000o`2I0=WIf@040=WIf@030000003IfMT0fMWI0040fMWI000@0=WIf@@00000203IfMT00`00
0000fMWI0=WIf@020=WIf@80o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0=03<0
o`0300000000I_l006Ko010006Ko00<00000003oo`00ool05P00ool2000007000?mV0P00000H003o
o`0300000000I_l006Ko010006Ko00<0000003<0o`0c0?l03@0c0?l00`000000c03o0<`0o`0<0<`0
o`030000003o09T0fMWI00@0fMWI00<000000=WIf@3IfMT00@3IfMT001@0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@020=WIf@<0o`2I00<000000<`0o`3<0?l0303<0?l00`000000
<`3o03<0o`0=03<0o`0300000000I_l006Ko010006Ko00<00000003oo`00ool05`00ool00`000000
0?mV003oIP1/003oIP0300000000ool00?oo01L00?oo00<00000001Vo`00I_l04000I_l00`000000
<`3o03<0o`0=03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o09T01@3IfMT00`000000
fMWI0=WIf@010=WIf@00503IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0080fMWI
103o09T00`000000c03o0<`0o`0<0<`0o`030000000c0?l0<`3o00`0<`3o00<00000001Vo`00I_l0
4@00I_l00`0000000?oo003oo`0G003oo`0300000000ofH00?mV06X00?mV00<00000003oo`00ool0
5`00ool00`00000006Ko001Vo`0@001Vo`030000000c0?l0<`3o00d0<`3o00<000000<`0o`3<0?l0
303<0?l010000000o`2I0?l0V@3o09T50=WIf@030000003IfMT0fMWI0040fMWI00090=WIf@L00000
103IfMT00`000000fMWI0=WIf@050=WIf@<000000P3IfMT50?l0V@030000003<0?l0c03o00`0c03o
00<0000003<0o`0c0?l0300c0?l00`00000006Ko001Vo`0A001Vo`0300000000ool00?oo01L00?oo
0P00001X003oIP8000006@00ool00`00000006Ko001Vo`0@001Vo`030000000c0?l0<`3o00d0<`3o
00<000000<`0o`3<0?l0303<0?l00`000000o`2I0?l0V@020?l0V@<0fMWI0`0000030=WIf@00503I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0080fMWI1@3o09T00`000000c03o0<`0
o`0<0<`0o`030000000c0?l0<`3o00d0<`3o00<00000001Vo`00I_l04@00I_l00`0000000?oo003o
o`0H003oo`0300000000ofH00?mV06@00?mV00<00000003oo`00ool06000ool00`00000006Ko001V
o`0A001Vo`030000000c0?l0<`3o00d0<`3o00<000000<`0o`3<0?l0303<0?l00`000000o`2I0?l0
V@020?l0V@D0fMWI00<000000=WIf@3IfMT00@3IfMT00100fMWI100000080=WIf@030000003IfMT0
fMWI0080fMWI1P3o09T00`000000c03o0<`0o`0<0<`0o`030000000c0?l0<`3o00d0<`3o00<00000
001Vo`00I_l04@00I_l00`0000000?oo003oo`0H003oo`0300000000ofH00?mV06800?mV00<00000
003oo`00ool06000ool00`00000006Ko001Vo`0A001Vo`030000000c0?l0<`3o00d0<`3o00<00000
0<`0o`3<0?l0303<0?l00`000000o`2I0?l0V@030?l0V@D0fMWI00<000000=WIf@3IfMT00@3IfMT0
0140fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIf@L0o`2I00<000000<`0
o`3<0?l0303<0?l00`000000<`3o03<0o`0=03<0o`0300000000I_l006Ko014006Ko00<00000003o
o`00ool06000ool2000006000?mV0P00000J003oo`0300000000I_l006Ko014006Ko00<0000003<0
o`0c0?l03@0c0?l00`000000c03o0<`0o`0<0<`0o`030000003o09T0o`2I00@0o`2I1@3IfMT00`00
0000fMWI0=WIf@010=WIf@004@3IfMT4000000L0fMWI00<000000=WIf@3IfMT00P3IfMT70?l0V@03
0000003<0?l0c03o00`0c03o00<0000003<0o`0c0?l03P0c0?l00`00000006Ko001Vo`0@001Vo`03
00000000ool00?oo01X00?oo00<00000003oIP00ofH0G000ofH00`0000000?oo003oo`0J003oo`03
00000000I_l006Ko010006Ko00<0000003<0o`0c0?l03P0c0?l00`000000c03o0<`0o`0<0<`0o`03
0000003o09T0o`2I00@0o`2I1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@P0o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0=03<0o`030000
0000I_l006Ko014006Ko00<00000003oo`00ool06P00ool00`0000000?mV003oIP1J003oIP030000
0000ool00?oo01X00?oo00<00000001Vo`00I_l04@00I_l00`000000<`3o03<0o`0=03<0o`030000
003<0?l0c03o00`0c03o00<000000?l0V@3o09T01@3o09T50=WIf@030000003IfMT0fMWI0040fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI2@3o09T00`000000c03o0<`0o`0;0<`0o`030000000c
0?l0<`3o00h0<`3o00<00000001Vo`00I_l04@00I_l00`0000000?oo003oo`0J003oo`0300000000
ofH00?mV05P00?mV00<00000003oo`00ool06P00ool00`00000006Ko001Vo`0A001Vo`030000000c
0?l0<`3o00h0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@060?l0V@D0fMWI00<0
00000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000o`2I0?l0V@07
0?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03P0c0?l00`00000006Ko001Vo`0A
001Vo`0300000000ool00?oo01X00?oo0P00001F003oIP8000007000ool00`00000006Ko001Vo`0A
001Vo`030000000c0?l0<`3o00h0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@07
0?l0V@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000o`2I0?l0V@070?l0V@030000003<0?l0c03o00`0c03o00<0000003<0
o`0c0?l03@0c0?l00`00000006Ko001Vo`0B001Vo`0300000000ool00?oo01/00?oo00<00000003o
IP00ofH0DP00ofH00`0000000?oo003oo`0K003oo`0300000000I_l006Ko018006Ko00<0000003<0
o`0c0?l03@0c0?l00`000000c03o0<`0o`0<0<`0o`030000003o09T0o`2I00L0o`2I00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@03
0?l000000000o`2I00P0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0>03<0o`03
00000000I_l006Ko018006Ko00<00000003oo`00ool06`00ool00`0000000?mV003oIP1@003oIP03
00000000ool00?oo01/00?oo00<00000001Vo`00I_l04P00I_l00`000000<`3o03<0o`0>03<0o`03
0000003<0?l0c03o00/0c03o00<000000?l0V@3o09T01`3o09T00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0o`000000003o09T0
2@3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l0
4P00I_l00`0000000?oo003oo`0K003oo`800000CP00ofH2000001d00?oo00<00000001Vo`00I_l0
4P00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T0
1`3o09T00`000000o`000=WIf@040=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI00<0o`000000003o09T02@3o09T00`000000c03o0<`0o`0;0<`0o`030000000c
0?l0<`3o00h0<`3o00<00000001Vo`00I_l04P00I_l00`0000000?oo003oo`0M003oo`800000BP00
ofH2000001l00?oo00<00000001Vo`00I_l04P00I_l00`000000<`3o03<0o`0>03<0o`030000003<
0?l0c03o00/0c03o00<000000?l0V@3o09T01`3o09T00`000000o`000=WIf@040=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0o`000000003o09T02P3o09T0
0`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04P00I_l0
0`0000000?oo003oo`0N003oo`800000AP00ofH2000002000?oo00<00000001Vo`00I_l04P00I_l0
0`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T0203o09T0
0`000000o`000=WIf@040=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI0P3o00000`000000o`2I0?l0V@080?l0V@030000003<0?l0c03o00/0c03o00<0000003<0
o`0c0?l03P0c0?l00`00000006Ko001Vo`0C001Vo`0300000000ool00?oo01l00?oo0P000012003o
IP8000008@00ool00`00000006Ko001Vo`0C001Vo`030000000c0?l0<`3o00h0<`3o00<000000<`0
o`3<0?l02`3<0?l00`000000o`2I0?l0V@070?l0V@030000003o0000o`0000D0fMWI00<000000=WI
f@3IfMT00@3IfMT001`0fMWI0P0000030=WIf@80o`0000<000000?l0V@3o09T02@3o09T00`000000
c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04`00I_l00`000000
0?oo003oo`0P003oo`800000?P00ofH2000002800?oo00<00000001Vo`00I_l04`00I_l00`000000
<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T0203o09T00`000000
o`000?l000040=WIf@8000000`3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT20?l000030000
003o09T0o`2I00T0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0>03<0o`030000
0000I_l006Ko01<006Ko00<00000003oo`00ool08P00ool2000003X00?mV0P00000T003oo`030000
0000I_l006Ko018006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`0;0<`0o`030000
003o09T0o`2I00P0o`2I00<000000?l0003o00001@3IfMT00`000000fMWI0=WIf@010=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@<0o`0000<000000?l0V@3o09T02@3o09T00`000000c03o0<`0
o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04`00I_l00`0000000?oo003o
o`0S003oo`0300000000ofH00?mV03H00?mV00<00000003oo`00ool08`00ool00`00000006Ko001V
o`0C001Vo`030000000c0?l0<`3o00h0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0
V@090?l0V@030000003o0000o`0000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT30?l000030000003o09T0o`2I00T0o`2I00<000000<`0o`3<0?l02`3<0?l0
0`000000<`3o03<0o`0>03<0o`0300000000I_l006Ko01@006Ko00<00000003oo`00ool08`00ool2
000003@00?mV0P00000U003oo`0300000000I_l006Ko01<006Ko00<0000003<0o`0c0?l03`0c0?l0
0`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00P0o`2I00@000000?l0003o0000o`001@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<0o`0000<00000
0?l0V@3o09T02P3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000
001Vo`00I_l05000I_l00`0000000?oo003oo`0T003oo`800000<000ofH2000002H00?oo00<00000
001Vo`00I_l05000I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<00000
0?l0V@3o09T02@3o09T010000000o`000?l0003o00050=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI103o00000`000000o`2I0?l0V@090?l0V@030000003<0?l0
c03o00/0c03o00<0000003<0o`0c0?l03P0c0?l00`00000006Ko001Vo`0E001Vo`0300000000ool0
0?oo02D00?oo0P00000/003oIP8000009`00ool00`00000006Ko001Vo`0D001Vo`030000000c0?l0
<`3o00l0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@090?l0V@040000003o0000
o`000?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT4
0?l000030000003o09T0o`2I00T0o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0>
03<0o`0300000000I_l006Ko01@006Ko00<00000003oo`00ool09`00ool2000002P00?mV0P00000Y
003oo`0300000000I_l006Ko01<006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`0<
0<`0o`030000003o09T0o`2I00P0o`2I00<000000?l0003o00000P3o00050=WIf@030000003IfMT0
fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI103o00000`000000o`2I0?l0V@0:0?l0
V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0D001V
o`0300000000ool00?oo02P00?oo0`00000R003oIP<00000:P00ool00`00000006Ko001Vo`0D001V
o`030000000c0?l0<`3o00l0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@090?l0
V@030000003o0000o`000080o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@D0o`0000<000000?l0V@3o09T02@3o09T00`000000c03o0<`0o`0;0<`0o`03
0000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05@00I_l00`0000000?oo003oo`0Z003oo`@0
00006P00ofH4000002`00?oo00<00000001Vo`00I_l05000I_l00`000000<`3o03<0o`0@03<0o`03
0000003<0?l0c03o00/0c03o00<000000?l0V@3o09T02@3o09T00`000000o`000?l000020?l000D0
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT50?l000030000
003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0?03<0o`030000
0000I_l006Ko01D006Ko00<00000003oo`00ool0;@00ool4000001800?mV1000000_003oo`030000
0000I_l006Ko01D006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`0;0<`0o`030000
003o09T0o`2I00X0o`2I00<000000?l0003o00000P3o00050=WIf@030000003IfMT0fMWI0040fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI1@3o00000`000000o`2I0?l0V@0:0?l0V@030000003<
0?l0c03o00/0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0E001Vo`0300000000
ool00?oo03400?oo0`00000;003oIP@00000<`00ool00`00000006Ko001Vo`0D001Vo`030000000c
0?l0<`3o0100<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@090?l0V@030000003o
0000o`0000<0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@H0o`0000<000000?l0V@3o09T02P3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0
<`3o00l0<`3o00<00000001Vo`00I_l05@00I_l00`0000000?oo003oo`0c003oo`@000000`00ofH4
000003H00?oo00<00000001Vo`00I_l05@00I_l00`000000<`3o03<0o`0?03<0o`030000003<0?l0
c03o00/0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l000030?l000D0fMWI00<00000
0=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT60?l000030000003o09T0o`2I
00X0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko
01H006Ko00<00000003oo`00ool0=P00ool3000003T00?oo00<00000001Vo`00I_l05@00I_l00`00
0000<`3o03<0o`0@03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T02P3o09T00`00
0000o`000?l000030?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI0P0000030=WIf@H0
o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00l0
<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003oo`1`003oo`0300000000I_l006Ko01D0
06Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00/0
o`2I00<000000?l0003o00000`3o00040=WIf@8000000`3IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMT70?l000030000003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o
03<0o`0?03<0o`0300000000I_l006Ko01H006Ko00<00000003oo`00ool0L000ool00`00000006Ko
001Vo`0E001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I
0?l0V@0:0?l0V@030000003o0000o`0000@0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@L0o`0000<000000?l0V@3o09T02P3o09T00`000000c03o0<`0
o`0<0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003o
o`1^003oo`0300000000I_l006Ko01D006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0
o`0<0<`0o`030000003o09T0o`2I00X0o`2I00<000000?l0003o0000103o00050=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1`3o00000`000000o`2I0?l0V@0:
0?l0V@030000003<0?l0c03o00`0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0F
001Vo`0300000000ool00?oo06h00?oo00<00000001Vo`00I_l05@00I_l00`000000<`3o03<0o`0@
03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l00004
0?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT70?l0
00030000003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0?03<0
o`0300000000I_l006Ko01H006Ko00<00000003oo`00ool0K000ool00`00000006Ko001Vo`0E001V
o`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0:0?l0
V@030000003o0000o`0000@0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@L0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0<0<`0o`03
0000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003oo`1/003oo`03
00000000I_l006Ko01D006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0<0<`0o`03
0000003o09T0o`2I00/0o`2I00<000000?l0003o0000103o00050=WIf@030000003IfMT0fMWI0040
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI203o00000`000000o`2I0?l0V@0:0?l0V@030000
003<0?l0c03o00`0c03o00<0000003<0o`0c0?l0400c0?l00`00000006Ko001Vo`0F001Vo`030000
0000ool00?oo06X00?oo00<00000001Vo`00I_l05P00I_l00`000000<`3o03<0o`0@03<0o`030000
003<0?l0c03o00`0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l000050?l000D0fMWI
00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT80?l000030000003o
09T0o`2I00X0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0?03<0o`0300000000
I_l006Ko01H006Ko00<00000003oo`00ool0J@00ool00`00000006Ko001Vo`0F001Vo`030000000c
0?l0<`3o0100<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0:0?l0V@030000003o
0000o`0000D0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@P0o`0000<000000?l0V@3o09T02P3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0
<`3o0100<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003oo`1X003oo`0300000000I_l0
06Ko01H006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0
o`2I00X0o`2I00<000000?l0003o00001@3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI203o00000`000000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o
00d0c03o00<0000003<0o`0c0?l0400c0?l00`00000006Ko001Vo`0F001Vo`0300000000ool00?oo
06L00?oo00<00000001Vo`00I_l05P00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o
00d0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l000050?l000D0fMWI00<000000=WI
f@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT80?l000030000003o09T0o`2I00/0
o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0@03<0o`0300000000I_l006Ko01H0
06Ko00<00000003oo`00ool0IP00ool00`00000006Ko001Vo`0F001Vo`030000000c0?l0<`3o0100
<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000D0
o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@P0o`00
00<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0100<`3o
00<00000001Vo`00I_l05P00I_l00`0000000?oo003oo`1U003oo`0300000000I_l006Ko01L006Ko
00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00/0o`2I
00<000000?l0003o00001@3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI2@3o00000`000000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00d0c03o00<0
000003<0o`0c0?l04@0c0?l00`00000006Ko001Vo`0F001Vo`0300000000ool00?oo06<00?oo00<0
0000001Vo`00I_l05`00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o00d0c03o00<0
00000?l0V@3o09T02P3o09T00`000000o`000?l000060?l000D0fMWI00<000000=WIf@3IfMT00@3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT90?l000030000003o09T0o`2I00X0o`2I00<00000
0<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0@03<0o`0300000000I_l006Ko01L006Ko00<00000
003oo`00ool0HP00ool00`00000006Ko001Vo`0G001Vo`030000000c0?l0<`3o0100<`3o00<00000
0<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0:0?l0V@030000003o0000o`0000H0o`001@3IfMT0
0`000000fMWI0=WIf@010=WIf@00703IfMT2000000<0fMWI2@3o00000`000000o`2I0?l0V@0:0?l0
V@030000003<0?l0c03o00h0c03o00<0000003<0o`0c0?l0400c0?l00`00000006Ko001Vo`0G001V
o`0300000000ool00?oo06400?oo00<00000001Vo`00I_l05`00I_l00`000000<`3o03<0o`0A03<0
o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l000060?l0
00@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@T0o`0000<000000?l0V@3o
09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00
I_l05`00I_l00`0000000?oo003oo`1P003oo`0300000000I_l006Ko01L006Ko00<0000003<0o`0c
0?l04@0c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o
00001P3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI
2@3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l0
4@0c0?l00`00000006Ko001Vo`0G001Vo`0300000000ool00?oo05l00?oo00<00000001Vo`00I_l0
6000I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T0
2`3o09T00`000000o`000?l000060?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<0
00000=WIf@3IfMT00P3IfMT90?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<
0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko01P006Ko00<00000003oo`00ool0GP00
ool00`00000006Ko001Vo`0G001Vo`030000000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<
0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000H0o`001@3IfMT00`000000fMWI0=WI
f@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@T0o`0000<000000?l0V@3o09T02`3o09T0
0`000000c03o0<`0o`0>0<`0o`030000000c0?l0<`3o0100<`3o00<00000001Vo`00I_l06000I_l0
0`0000000?oo003oo`1M003oo`0300000000I_l006Ko01P006Ko00<0000003<0o`0c0?l04@0c0?l0
0`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001P3o0005
0=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`00
0000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00h0c03o00<0000003<0o`0c0?l0400c0?l00`00
000006Ko001Vo`0I001Vo`0300000000ool00?oo05/00?oo00<00000001Vo`00I_l06@00I_l00`00
0000<`3o03<0o`0A03<0o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02P3o09T00`00
0000o`000?l000070?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3I
fMT00P3IfMT:0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000
<`3o03<0o`0A03<0o`0300000000I_l006Ko01P006Ko00<00000003oo`00ool0F`00ool00`000000
06Ko001Vo`0H001Vo`030000000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000
o`2I0?l0V@0;0?l0V@030000003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00
703IfMT00`000000fMWI0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o
0<`0o`0=0<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l06@00I_l00`0000000?oo
003oo`1I003oo`0300000000I_l006Ko01T006Ko00<0000003<0o`0c0?l04@0c0?l00`000000c03o
0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001`3o00050=WIf@030000
003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I0?l0
V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l04@0c0?l00`00000006Ko001V
o`0I001Vo`0300000000ool00?oo05T00?oo00<00000001Vo`00I_l06@00I_l00`000000<`3o03<0
o`0A03<0o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02`3o09T00`000000o`000?l0
00070?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT:
0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0A
03<0o`0300000000I_l006Ko01T006Ko00<00000003oo`00ool0F@00ool00`00000006Ko001Vo`0I
001Vo`030000000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;
0?l0V@030000003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`00
0000fMWI0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0
o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l06P00I_l00`0000000?oo003oo`1G003o
o`0300000000I_l006Ko01X006Ko00<0000003<0o`0c0?l04@0c0?l00`000000c03o0<`0o`0>0<`0
o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001`3o00050=WIf@030000003IfMT0fMWI
0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I0?l0V@0;0?l0V@03
0000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l04P0c0?l00`00000006Ko001Vo`0I001Vo`03
00000000ool00?oo05L00?oo00<00000001Vo`00I_l06P00I_l00`000000<`3o03<0o`0A03<0o`03
0000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02`3o09T00`000000o`000?l000070?l000D0
fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT:0?l000030000
003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0B03<0o`030000
0000I_l006Ko01T006Ko00<00000003oo`00ool0E`00ool00`00000006Ko001Vo`0J001Vo`030000
000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;0?l0V@030000
003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT2000000<0fMWI2P3o
00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00h0c03o00<0000003<0o`0c0?l04@0c
0?l00`00000006Ko001Vo`0I001Vo`0300000000ool00?oo05L00?oo00<00000001Vo`00I_l06@00
I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0c03o00d0c03o00<000000?l0V@3o09T0303o
09T00`000000o`000?l000070?l000@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0>0<`0o`030000000c0?l0
<`3o0140<`3o00<00000001Vo`00I_l06P00I_l00`0000000?oo003oo`1F003oo`0300000000I_l0
06Ko01T006Ko00<0000003<0o`0c0?l04P0c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0
o`2I00`0o`2I00<000000?l0003o00001`3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o
00h0c03o00<0000003<0o`0c0?l04@0c0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo
05D00?oo00<00000001Vo`00I_l06P00I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0c03o
00d0c03o00<000000?l0V@3o09T0303o09T00`000000o`000?l000070?l000D0fMWI00<000000=WI
f@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT:0?l000030000003o09T0o`2I00/0
o`2I00<000000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko01X0
06Ko00<00000003oo`00ool0E@00ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0180
<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`0000L0
o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0o`00
00<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0180<`3o
00<00000001Vo`00I_l06P00I_l00`0000000?oo003oo`1D003oo`0300000000I_l006Ko01X006Ko
00<0000003<0o`0c0?l04@0c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I
00<000000?l0003o0000203o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0
000003<0o`0c0?l04P0c0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo05@00?oo00<0
0000001Vo`00I_l06P00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o00h0c03o00<0
00000?l0V@3o09T02`3o09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT00@3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I00/0o`2I00<00000
0<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0B03<0o`0300000000I_l006Ko01X006Ko00<00000
003oo`00ool0E000ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0140<`3o00<00000
0<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000P0o`001@3IfMT0
0`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0o`0000<000000?l0
V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0180<`3o00<00000001V
o`00I_l06P00I_l00`0000000?oo003oo`1C003oo`0300000000I_l006Ko01/006Ko00<0000003<0
o`0c0?l04@0c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0
003o0000203o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c
0?l04P0c0?l00`00000006Ko001Vo`0K001Vo`0300000000ool00?oo05800?oo00<00000001Vo`00
I_l06`00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o
09T02`3o09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI
00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l0
3P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko01/006Ko00<00000003oo`00ool0
DP00ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0180<`3o00<000000<`0o`3<0?l0
3@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`0000P0o`001@3IfMT00`000000fMWI
0=WIf@010=WIf@004P3IfMT3000000L0fMWI00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o
09T0o`2I00/0o`2I00<000000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000
I_l006Ko01/006Ko00<00000003oo`00ool0DP00ool00`00000006Ko001Vo`0J001Vo`030000000c
0?l0<`3o0180<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o
0000o`0000P0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@004@3IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I00/0o`2I00<0
00000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0B03<0o`0300000000I_l006Ko01X006Ko00<0
0000003oo`00ool0DP00ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0180<`3o00<0
00000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`0000P0o`001@3I
fMT00`000000fMWI0=WIf@010=WIf@004@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<0
00000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03P3<
0?l00`000000<`3o03<0o`0B03<0o`0300000000I_l006Ko01/006Ko00<00000003oo`00ool0D000
ool00`00000006Ko001Vo`0K001Vo`030000000c0?l0<`3o0180<`3o00<000000<`0o`3<0?l03@3<
0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`0000P0o`001@3IfMT00`000000fMWI0=WI
f@010=WIf@004@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI0`0000020=WIf@/0o`0000<0
00000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0>0<`0o`030000000c0?l0<`3o0180<`3o00<0
0000001Vo`00I_l06`00I_l00`0000000?oo003oo`1@003oo`0300000000I_l006Ko01/006Ko00<0
000003<0o`0c0?l04P0c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00`0o`2I00<0
00000?l0003o0000203o00030=WIf@<000000`3IfMT00140fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@030000003IfMT0fMWI0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<
0?l0c03o00h0c03o00<0000003<0o`0c0?l04P0c0?l00`00000006Ko001Vo`0K001Vo`0300000000
ool00?oo05000?oo00<00000001Vo`00I_l06`00I_l00`000000<`3o03<0o`0B03<0o`030000003<
0?l0c03o00d0c03o00<000000?l0V@3o09T0303o09T00`000000o`000?l000080?l000D0fMWI00<0
00000=WIf@3IfMT00@3IfMT00140fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00h0c03o00<0
000003<0o`0c0?l04P0c0?l00`00000006Ko001Vo`0K001Vo`0300000000ool00?oo05000?oo00<0
0000001Vo`00I_l06`00I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0c03o00d0c03o00<0
00000?l0V@3o09T0303o09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT00@3I
fMT00140fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI2`3o
00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00h0c03o00<0000003<0o`0c0?l04P0c
0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo05800?oo00<00000001Vo`00I_l06P00
I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0c03o00d0c03o00<000000?l0V@3o09T0303o
09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT00180fMWI0`000007
0=WIf@030000003IfMT0fMWI0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0
c03o00h0c03o00<0000003<0o`0c0?l04@0c0?l00`00000006Ko001Vo`0K001Vo`0300000000ool0
0?oo05800?oo00<00000001Vo`00I_l06P00I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0
c03o00d0c03o00<000000?l0V@3o09T0303o09T00`000000o`000?l000080?l000D0fMWI00<00000
0=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I
00/0o`2I00<000000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko
01/006Ko00<00000003oo`00ool0DP00ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o
0180<`3o00<000000<`0o`3<0?l03@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`00
00P0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0
o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0180
<`3o00<00000001Vo`00I_l06`00I_l00`0000000?oo003oo`1B003oo`0300000000I_l006Ko01/0
06Ko00<0000003<0o`0c0?l04@0c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0
o`2I00<000000?l0003o0000203o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o
00<0000003<0o`0c0?l04P0c0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo05<00?oo
00<00000001Vo`00I_l06`00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o00h0c03o
00<000000?l0V@3o09T02`3o09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT0
0@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT;0?l000030000003o09T0o`2I00/0o`2I00<0
00000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0B03<0o`0300000000I_l006Ko01X006Ko00<0
0000003oo`00ool0E000ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0140<`3o00<0
00000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000P0o`001@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0o`0000<00000
0?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0180<`3o00<00000
001Vo`00I_l06P00I_l00`0000000?oo003oo`1D003oo`0300000000I_l006Ko01X006Ko00<00000
03<0o`0c0?l04@0c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I00<00000
0?l0003o0000203o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI2`3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0
o`0c0?l04P0c0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo05@00?oo00<00000001V
o`00I_l06P00I_l00`000000<`3o03<0o`0A03<0o`030000003<0?l0c03o00h0c03o00<000000?l0
V@3o09T02`3o09T00`000000o`000?l000080?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0
fMWI00<000000=WIf@3IfMT00P3IfMT:0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<
0?l03P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko01X006Ko00<00000003oo`00
ool0E@00ool00`00000006Ko001Vo`0J001Vo`030000000c0?l0<`3o0180<`3o00<000000<`0o`3<
0?l03@3<0?l00`000000o`2I0?l0V@0<0?l0V@030000003o0000o`0000L0o`001@3IfMT00`000000
fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T0
2`3o09T00`000000c03o0<`0o`0>0<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l0
6P00I_l00`0000000?oo003oo`1E003oo`0300000000I_l006Ko01X006Ko00<0000003<0o`0c0?l0
4P0c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00`0o`2I00<000000?l0003o0000
1`3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o
00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00h0c03o00<0000003<0o`0c0?l04@0c
0?l00`00000006Ko001Vo`0J001Vo`0300000000ool00?oo05H00?oo00<00000001Vo`00I_l06@00
I_l00`000000<`3o03<0o`0B03<0o`030000003<0?l0c03o00d0c03o00<000000?l0V@3o09T0303o
09T00`000000o`000?l000070?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI0P000003
0=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0>0<`0o`030000000c0?l0
<`3o0140<`3o00<00000001Vo`00I_l06P00I_l00`0000000?oo003oo`1F003oo`0300000000I_l0
06Ko01T006Ko00<0000003<0o`0c0?l04P0c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0
o`2I00`0o`2I00<000000?l0003o00001`3o00040=WIf@8000000`3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT:0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03P3<0?l00`00
0000<`3o03<0o`0A03<0o`0300000000I_l006Ko01T006Ko00<00000003oo`00ool0E`00ool00`00
000006Ko001Vo`0I001Vo`030000000c0?l0<`3o0180<`3o00<000000<`0o`3<0?l03@3<0?l00`00
0000o`2I0?l0V@0<0?l0V@030000003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000
c03o0<`0o`0=0<`0o`030000000c0?l0<`3o0180<`3o00<00000001Vo`00I_l06@00I_l00`000000
0?oo003oo`1G003oo`0300000000I_l006Ko01X006Ko00<0000003<0o`0c0?l04@0c0?l00`000000
c03o0<`0o`0>0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001`3o00050=WIf@03
0000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I
0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l04P0c0?l00`00000006Ko
001Vo`0I001Vo`0300000000ool00?oo05L00?oo00<00000001Vo`00I_l06P00I_l00`000000<`3o
03<0o`0A03<0o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02`3o09T00`000000o`00
0?l000070?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT:0?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0
o`0A03<0o`0300000000I_l006Ko01X006Ko00<00000003oo`00ool0F000ool00`00000006Ko001V
o`0I001Vo`030000000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0
V@0;0?l0V@030000003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=
0<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l06@00I_l00`0000000?oo003oo`1I
003oo`0300000000I_l006Ko01T006Ko00<0000003<0o`0c0?l04@0c0?l00`000000c03o0<`0o`0>
0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001`3o00050=WIf@030000003IfMT0
fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I0?l0V@0;0?l0
V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l04@0c0?l00`00000006Ko001Vo`0I001V
o`0300000000ool00?oo05T00?oo00<00000001Vo`00I_l06@00I_l00`000000<`3o03<0o`0A03<0
o`030000003<0?l0c03o00h0c03o00<000000?l0V@3o09T02`3o09T00`000000o`000?l000070?l0
00D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT:0?l00003
0000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l03@3<0?l00`000000<`3o03<0o`0A03<0o`03
00000000I_l006Ko01T006Ko00<00000003oo`00ool0F@00ool00`00000006Ko001Vo`0I001Vo`03
0000000c0?l0<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;0?l0V@03
0000003o0000o`0000L0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@X0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000
000c0?l0<`3o0140<`3o00<00000001Vo`00I_l06000I_l00`0000000?oo003oo`1K003oo`030000
0000I_l006Ko01T006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0>0<`0o`030000
003o09T0o`2I00/0o`2I00<000000?l0003o00001`3o00050=WIf@030000003IfMT0fMWI0040fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI2P3o00000`000000o`2I0?l0V@0:0?l0V@030000003<
0?l0c03o00h0c03o00<0000003<0o`0c0?l0400c0?l00`00000006Ko001Vo`0I001Vo`0300000000
ool00?oo05/00?oo00<00000001Vo`00I_l06@00I_l00`000000<`3o03<0o`0A03<0o`030000003<
0?l0c03o00h0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l000070?l000D0fMWI00<0
00000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT90?l000030000003o09T0
o`2I00/0o`2I00<000000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0@03<0o`0300000000I_l0
06Ko01P006Ko00<00000003oo`00ool0G@00ool00`00000006Ko001Vo`0H001Vo`030000000c0?l0
<`3o0140<`3o00<000000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000
o`0000H0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WI
f@T0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o
0140<`3o00<00000001Vo`00I_l06000I_l00`0000000?oo003oo`1N003oo`0300000000I_l006Ko
01P006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I
00/0o`2I00<000000?l0003o00001P3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI2@3o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0
c03o00<0000003<0o`0c0?l04@0c0?l00`00000006Ko001Vo`0G001Vo`0300000000ool00?oo05l0
0?oo00<00000001Vo`00I_l06000I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00h0
c03o00<000000?l0V@3o09T02`3o09T00`000000o`000?l000060?l000D0fMWI00<000000=WIf@3I
fMT00@3IfMT001`0fMWI0P0000030=WIf@T0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o
0<`0o`0=0<`0o`030000000c0?l0<`3o0100<`3o00<00000001Vo`00I_l06000I_l00`0000000?oo
003oo`1P003oo`0300000000I_l006Ko01L006Ko00<0000003<0o`0c0?l04@0c0?l00`000000c03o
0<`0o`0=0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o00001P3o00040=WIf@800000
0`3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT90?l000030000003o09T0o`2I00X0o`2I00<0
00000<`0o`3<0?l03P3<0?l00`000000<`3o03<0o`0@03<0o`0300000000I_l006Ko01L006Ko00<0
0000003oo`00ool0H@00ool00`00000006Ko001Vo`0H001Vo`030000000c0?l0<`3o0100<`3o00<0
00000<`0o`3<0?l03P3<0?l00`000000o`2I0?l0V@0:0?l0V@030000003o0000o`0000H0o`001@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@T0o`0000<00000
0?l0V@3o09T02P3o09T00`000000c03o0<`0o`0>0<`0o`030000000c0?l0<`3o0100<`3o00<00000
001Vo`00I_l05`00I_l00`0000000?oo003oo`1R003oo`0300000000I_l006Ko01L006Ko00<00000
03<0o`0c0?l0400c0?l00`000000c03o0<`0o`0>0<`0o`030000003o09T0o`2I00X0o`2I00<00000
0?l0003o00001P3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI203o00000`000000o`2I0?l0V@0;0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0
o`0c0?l0400c0?l00`00000006Ko001Vo`0G001Vo`0300000000ool00?oo06@00?oo00<00000001V
o`00I_l05`00I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00d0c03o00<000000?l0
V@3o09T02`3o09T00`000000o`000?l000050?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0
fMWI00<000000=WIf@3IfMT00P3IfMT80?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<
0?l03@3<0?l00`000000<`3o03<0o`0@03<0o`0300000000I_l006Ko01H006Ko00<00000003oo`00
ool0I@00ool00`00000006Ko001Vo`0G001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<
0?l03@3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000D0o`001@3IfMT00`000000
fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@P0o`0000<000000?l0V@3o09T0
2`3o09T00`000000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l0
5`00I_l00`0000000?oo003oo`1V003oo`0300000000I_l006Ko01H006Ko00<0000003<0o`0c0?l0
400c0?l00`000000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00/0o`2I00<000000?l0003o0000
1@3o00050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI203o
00000`000000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00d0c03o00<0000003<0o`0c0?l0400c
0?l00`00000006Ko001Vo`0F001Vo`0300000000ool00?oo06L00?oo00<00000001Vo`00I_l05`00
I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00d0c03o00<000000?l0V@3o09T02P3o
09T00`000000o`000?l000050?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT80?l000030000003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l03@3<0?l0
0`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko01L006Ko00<00000003oo`00ool0J000ool0
0`00000006Ko001Vo`0F001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l03@3<0?l0
0`000000o`2I0?l0V@0:0?l0V@030000003o0000o`0000D0o`001@3IfMT00`000000fMWI0=WIf@01
0=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@P0o`0000<000000?l0V@3o09T02P3o09T00`00
0000c03o0<`0o`0=0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00I_l00`00
00000?oo003oo`1Y003oo`0300000000I_l006Ko01H006Ko00<0000003<0o`0c0?l0400c0?l00`00
0000c03o0<`0o`0=0<`0o`030000003o09T0o`2I00X0o`2I00<000000?l0003o00001@3o00050=WI
f@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI203o00000`000000
o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00`0c03o00<0000003<0o`0c0?l0400c0?l00`000000
06Ko001Vo`0F001Vo`0300000000ool00?oo06X00?oo00<00000001Vo`00I_l05P00I_l00`000000
<`3o03<0o`0@03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o09T02P3o09T00`000000
o`000?l000050?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMT70?l000030000003o09T0o`2I00/0o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o
03<0o`0?03<0o`0300000000I_l006Ko01H006Ko00<00000003oo`00ool0K000ool00`00000006Ko
001Vo`0E001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l0303<0?l00`000000o`2I
0?l0V@0;0?l0V@030000003o0000o`0000@0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@L0o`0000<000000?l0V@3o09T02P3o09T00`000000c03o0<`0
o`0=0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003o
o`1/003oo`0300000000I_l006Ko01D006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0
o`0=0<`0o`030000003o09T0o`2I00X0o`2I00<000000?l0003o0000103o00050=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1`3o00000`000000o`2I0?l0V@0:
0?l0V@030000003<0?l0c03o00`0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0F
001Vo`0300000000ool00?oo06h00?oo00<00000001Vo`00I_l05@00I_l00`000000<`3o03<0o`0@
03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o09T02P3o09T00`000000o`000?l00004
0?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT70?l0
00030000003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0?03<0
o`0300000000I_l006Ko01H006Ko00<00000003oo`00ool0KP00ool00`00000006Ko001Vo`0E001V
o`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l0303<0?l00`000000o`2I0?l0V@0:0?l0
V@030000003o0000o`0000@0o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT2000000<0
fMWI1`3o00000`000000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c
0?l03`0c0?l00`00000006Ko001Vo`0F001Vo`0300000000ool00?oo07000?oo00<00000001Vo`00
I_l05@00I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o
09T02P3o09T00`000000o`000?l000040?l000@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@H0o`0000<000000?l0V@3o09T02`3o09T00`000000c03o0<`0o`0;0<`0o`030000
000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00I_l00`0000000?oo003oo`0d003oo`H00000
=P00ool00`00000006Ko001Vo`0E001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l0
2`3<0?l00`000000o`2I0?l0V@0;0?l0V@030000003o0000o`0000<0o`001@3IfMT00`000000fMWI
0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@H0o`0000<000000?l0V@3o09T02P3o
09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05P00
I_l00`0000000?oo003oo`0`003oo`D000001P00ofH5000003800?oo00<00000001Vo`00I_l05@00
I_l00`000000<`3o03<0o`0@03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T02P3o
09T00`000000o`000?l000030?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT60?l000030000003o09T0o`2I00X0o`2I00<000000<`0o`3<0?l02`3<0?l0
0`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko01D006Ko00<00000003oo`00ool0;000ool5
000001000?mV1@00000^003oo`0300000000I_l006Ko01D006Ko00<0000003<0o`0c0?l03`0c0?l0
0`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00X0o`2I00<000000?l0003o00000`3o0005
0=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1@3o00000`00
0000o`2I0?l0V@0:0?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03`0c0?l00`00
000006Ko001Vo`0E001Vo`0300000000ool00?oo02P00?oo1@00000J003oIPD00000:P00ool00`00
000006Ko001Vo`0D001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l02`3<0?l00`00
0000o`2I0?l0V@090?l0V@030000003o0000o`0000<0o`001@3IfMT00`000000fMWI0=WIf@010=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIf@D0o`0000<000000?l0V@3o09T02P3o09T00`000000
c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00l0<`3o00<00000001Vo`00I_l05@00I_l00`000000
0?oo003oo`0U003oo`<000009000ofH3000002L00?oo00<00000001Vo`00I_l05@00I_l00`000000
<`3o03<0o`0?03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T02P3o09T00`000000
o`000?l000020?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMT50?l000030000003o09T0o`2I00T0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o
03<0o`0?03<0o`0300000000I_l006Ko01D006Ko00<00000003oo`00ool09000ool2000002X00?mV
0P00000V003oo`0300000000I_l006Ko01@006Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o
0<`0o`0;0<`0o`030000003o09T0o`2I00T0o`2I00<000000?l0003o00000P3o00050=WIf@030000
003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI103o00000`000000o`2I0?l0
V@0:0?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001V
o`0D001Vo`0300000000ool00?oo02@00?oo00<00000003oIP00ofH0;000ofH00`0000000?oo003o
o`0T003oo`0300000000I_l006Ko01@006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0
o`0;0<`0o`030000003o09T0o`2I00T0o`2I00<000000?l0003o00000P3o00050=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI103o00000`000000o`2I0?l0V@09
0?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03`0c0?l00`00000006Ko001Vo`0D
001Vo`0300000000ool00?oo02<00?oo0P00000`003oIP8000009@00ool00`00000006Ko001Vo`0D
001Vo`030000000c0?l0<`3o00l0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@09
0?l0V@040000003o0000o`000?l000D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT40?l000030000003o09T0o`2I00T0o`2I00<000000<`0o`3<0?l02`3<0?l0
0`000000<`3o03<0o`0>03<0o`0300000000I_l006Ko01@006Ko00<00000003oo`00ool08P00ool2
000003@00?mV0P00000T003oo`0300000000I_l006Ko01<006Ko00<0000003<0o`0c0?l03`0c0?l0
0`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00T0o`2I00@000000?l0003o0000o`001@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<0o`0000<00000
0?l0V@3o09T02P3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000
001Vo`00I_l05000I_l00`0000000?oo003oo`0P003oo`800000>000ofH2000002800?oo00<00000
001Vo`00I_l05000I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<00000
0?l0V@3o09T02@3o09T010000000o`000?l0003o00050=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI0`3o00000`000000o`2I0?l0V@090?l0V@030000003<0?l0
c03o00/0c03o00<0000003<0o`0c0?l03P0c0?l00`00000006Ko001Vo`0D001Vo`0300000000ool0
0?oo02000?oo00<00000003oIP00ofH0>P00ofH00`0000000?oo003oo`0P003oo`0300000000I_l0
06Ko01<006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`0;0<`0o`030000003o09T0
o`2I00P0o`2I00@000000?l0003o0000o`001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIf@<0o`0000<000000?l0V@3o09T02@3o09T00`000000c03o0<`0o`0;
0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04`00I_l00`0000000?oo003oo`0O
003oo`800000?P00ofH2000002400?oo00<00000001Vo`00I_l04`00I_l00`000000<`3o03<0o`0>
03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T02@3o09T00`000000o`000?l00005
0=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@8000000`3IfMT20?l000030000003o09T0o`2I
00T0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0>03<0o`0300000000I_l006Ko
01<006Ko00<00000003oo`00ool07P00ool2000004800?mV0P00000P003oo`0300000000I_l006Ko
018006Ko00<0000003<0o`0c0?l03`0c0?l00`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I
00P0o`2I00<000000?l0003o0000103IfMT2000000<0fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI0P3o00000`000000o`2I0?l0V@090?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c
0?l03P0c0?l00`00000006Ko001Vo`0C001Vo`0300000000ool00?oo01d00?oo00<00000003oIP00
ofH0A000ofH00`0000000?oo003oo`0M003oo`0300000000I_l006Ko01<006Ko00<0000003<0o`0c
0?l03P0c0?l00`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00P0o`2I00<000000?l0003o
00001@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@80o`00
00<000000?l0V@3o09T0203o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o
00<00000001Vo`00I_l04`00I_l00`0000000?oo003oo`0L003oo`800000B000ofH2000001h00?oo
00<00000001Vo`00I_l04`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o
00<000000?l0V@3o09T01`3o09T00`000000o`000?l000050=WIf@030000003IfMT0fMWI0040fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI00<0o`000000003o09T02P3o09T00`000000c03o0<`0
o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04P00I_l00`0000000?oo003o
o`0K003oo`800000C000ofH2000001d00?oo00<00000001Vo`00I_l04P00I_l00`000000<`3o03<0
o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T0203o09T00`000000o`000=WI
f@040=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0o`00
0000003o09T02@3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000
001Vo`00I_l04P00I_l00`0000000?oo003oo`0J003oo`800000D000ofH2000001`00?oo00<00000
001Vo`00I_l04P00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<00000
0?l0V@3o09T01`3o09T00`000000o`000=WIf@040=WIf@030000003IfMT0fMWI0040fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI00<0o`000000003o09T02@3o09T00`000000c03o0<`0o`0;0<`0
o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04P00I_l00`0000000?oo003oo`0I003o
o`0300000000ofH00?mV05800?mV00<00000003oo`00ool06@00ool00`00000006Ko001Vo`0B001V
o`030000000c0?l0<`3o00h0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@070?l0
V@030000003o0000fMWI00@0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000o`2I0?l0V@080?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c
0?l03P0c0?l00`00000006Ko001Vo`0B001Vo`0300000000ool00?oo01T00?oo00<00000003oIP00
ofH0E000ofH00`0000000?oo003oo`0I003oo`0300000000I_l006Ko018006Ko00<0000003<0o`0c
0?l03P0c0?l00`000000c03o0<`0o`0;0<`0o`030000003o09T0o`2I00L0o`2I00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030000
003o09T0o`2I00L0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0o`0>03<0o`030000
0000I_l006Ko018006Ko00<00000003oo`00ool06000ool2000005P00?mV0P00000J003oo`030000
0000I_l006Ko018006Ko00<0000003<0o`0c0?l03P0c0?l00`000000c03o0<`0o`0;0<`0o`030000
003o09T0o`2I00L0o`2I00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@010=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@X0o`2I00<000000<`0o`3<0?l02`3<0?l00`000000<`3o03<0
o`0>03<0o`0300000000I_l006Ko014006Ko00<00000003oo`00ool06000ool00`0000000?mV003o
IP1J003oIP0300000000ool00?oo01P00?oo00<00000001Vo`00I_l04@00I_l00`000000<`3o03<0
o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3o09T01`3o09T50=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2@3o09T00`000000c03o0<`0o`0;
0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l04@00I_l00`0000000?oo003oo`0H
003oo`0300000000ofH00?mV05`00?mV00<00000003oo`00ool06000ool00`00000006Ko001Vo`0A
001Vo`030000000c0?l0<`3o00h0<`3o00<000000<`0o`3<0?l02`3<0?l00`000000o`2I0?l0V@06
0?l0V@D0fMWI00<000000=WIf@3IfMT00@3IfMT00140fMWI100000070=WIf@030000003IfMT0fMWI
0080fMWI203o09T00`000000c03o0<`0o`0<0<`0o`030000000c0?l0<`3o00d0<`3o00<00000001V
o`00I_l04@00I_l00`0000000?oo003oo`0G003oo`800000H000ofH2000001T00?oo00<00000001V
o`00I_l04@00I_l00`000000<`3o03<0o`0=03<0o`030000003<0?l0c03o00`0c03o00<000000?l0
V@3o09T01@3o09T50=WIf@030000003IfMT0fMWI0040fMWI000E0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00P3IfMT70?l0V@030000003<0?l0c03o00`0c03o00<0000003<0o`0c
0?l03P0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01L00?oo00<00000003oIP00
ofH0HP00ofH00`0000000?oo003oo`0G003oo`0300000000I_l006Ko010006Ko00<0000003<0o`0c
0?l03P0c0?l00`000000c03o0<`0o`0<0<`0o`030000003o09T0o`2I00@0o`2I1@3IfMT00`000000
fMWI0=WIf@010=WIf@005@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI
1`3o09T00`000000c03o0<`0o`0;0<`0o`030000000c0?l0<`3o00h0<`3o00<00000001Vo`00I_l0
4@00I_l00`0000000?oo003oo`0F003oo`0300000000ofH00?mV06@00?mV00<00000003oo`00ool0
5P00ool00`00000006Ko001Vo`0A001Vo`030000000c0?l0<`3o00h0<`3o00<000000<`0o`3<0?l0
2`3<0?l00`000000o`2I0?l0V@040?l0V@D0fMWI00<000000=WIf@3IfMT00@3IfMT001D0fMWI00<0
00000=WIf@3IfMT0103IfMT300000080fMWI1P3o09T00`000000c03o0<`0o`0<0<`0o`030000000c
0?l0<`3o00d0<`3o00<00000001Vo`00I_l04@00I_l00`0000000?oo003oo`0F003oo`0300000000
ofH00?mV06H00?mV00<00000003oo`00ool05P00ool00`00000006Ko001Vo`0A001Vo`030000000c
0?l0<`3o00d0<`3o00<000000<`0o`3<0?l0303<0?l00`000000o`2I0?l0V@030?l0V@<0fMWI0`00
00030=WIf@005@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI1@3o09T0
0`000000c03o0<`0o`0<0<`0o`030000000c0?l0<`3o00d0<`3o00<00000001Vo`00I_l04@00I_l0
0`0000000?oo003oo`0E003oo`800000JP00ofH2000001L00?oo00<00000001Vo`00I_l04@00I_l0
0`000000<`3o03<0o`0=03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o09T00P3o09T5
0=WIf@030000003IfMT0fMWI0040fMWI000A0=WIf@@000001`3IfMT00`000000fMWI0=WIf@020=WI
f@D0o`2I00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0<03<0o`0300000000I_l006Ko
014006Ko00<00000003oo`00ool05@00ool00`0000000?mV003oIP1/003oIP0300000000ool00?oo
01D00?oo00<00000001Vo`00I_l04000I_l00`000000<`3o03<0o`0=03<0o`030000003<0?l0c03o
00`0c03o00<000000?l0V@3o09T00P3o09T50=WIf@030000003IfMT0fMWI0040fMWI000B0=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3IfMT40?l0V@030000003<0?l0c03o00`0
c03o00<0000003<0o`0c0?l0300c0?l00`00000006Ko001Vo`0A001Vo`0300000000ool00?oo01D0
0?oo00<00000003oIP00ofH0KP00ofH00`0000000?oo003oo`0E003oo`0300000000I_l006Ko0100
06Ko00<0000003<0o`0c0?l03@0c0?l00`000000c03o0<`0o`0<0<`0o`040000003o09T0o`2I0?l0
V@D0fMWI00<000000=WIf@3IfMT00@3IfMT00180fMWI100000060=WIf@030000003IfMT0fMWI0080
fMWI0`3o09T00`000000c03o0<`0o`0<0<`0o`030000000c0?l0<`3o00`0<`3o00<00000001Vo`00
I_l04@00I_l00`0000000?oo003oo`0D003oo`800000LP00ofH2000001H00?oo00<00000001Vo`00
I_l04000I_l00`000000<`3o03<0o`0=03<0o`030000003<0?l0c03o00`0c03o00<000000?l0V@3o
09T01@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@80o`2I
00<000000<`0o`3<0?l0303<0?l00`000000<`3o03<0o`0=03<0o`0300000000I_l006Ko010006Ko
00<00000003oo`00ool05000ool00`0000000?mV003oIP0c003oIP/00000=P00ofH00`0000000?oo
003oo`0D003oo`0300000000I_l006Ko010006Ko00<0000003<0o`0c0?l03@0c0?l00`000000c03o
0<`0o`0<0<`0o`030000003o09T0fMWI00@0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<0
00000=WIf@3IfMT00P3IfMT20?l0V@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03@0c
0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo00<00000003oIP00ofH0:`00
ofH9000000/0<ol02P00000]003oIP0300000000ool00?oo01@00?oo00<00000001Vo`00I_l04000
I_l00`000000<`3o03<0o`0=03<0o`030000003<0?l0c03o00/0c03o00<000000?l0V@3IfMT0103I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030?l0V@000000
c03o00`0c03o00<0000003<0o`0c0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool0
0?oo01@00?oo00<00000003oIP00ofH09P00ofH6000001h0<ol01P00000X003oIP0300000000ool0
0?oo01@00?oo00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0
c03o00/0c03o00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`00
0000fMWI0=WIf@020=WIf@030000003<0?l0c03o00/0c03o00<0000003<0o`0c0?l03@0c0?l00`00
000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo00<00000003oIP00ofH09000ofH30000
02X0<ol00`00000V003oIP0300000000ool00?oo01@00?oo00<00000001Vo`00I_l03`00I_l00`00
0000<`3o03<0o`0>03<0o`030000003<0?l0c03o00/0c03o00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@d0c03o00<0000003<0o`0c
0?l03@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01@00?oo00<00000003oIP00
ofH08P00ofH300000300<ol00`00000T003oIP0300000000ool00?oo01@00?oo00<00000001Vo`00
I_l03`00I_l00`000000<`3o03<0o`0>03<0o`030000003<0?l0c03o00X0c03o1@3IfMT00`000000
fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@/0c03o0P00000?03<0o`030000
0000I_l006Ko010006Ko00<00000003oo`00ool04`00ool2000002800?mV0`00000f03?o00800000
8`00ofH2000001D00?oo00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0o`0>03<0o`800000
2P3<0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2P3<
0?l00`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko010006Ko00<00000003oo`00ool04P00
ool00`0000000?mV003oIP0O003oIP<00000>`0co`03000002800?mV00<00000003oo`00ool04P00
ool00`00000006Ko001Vo`0?001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l01`3<
0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2@3<0?l0
0`000000<`3o03<0o`0?03<0o`0300000000I_l006Ko010006Ko00<00000003oo`00ool04P00ool0
0`0000000?mV003oIP0N003oIP800000@@0co`03000002000?mV00<00000003oo`00ool04P00ool0
0`00000006Ko001Vo`0?001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l01P3<0?l5
0=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI203<0?l00`00
0000<`3o03<0o`0?03<0o`0300000000I_l006Ko010006Ko00<00000003oo`00ool04P00ool00`00
00000?mV003oIP0L003oIP<00000AP0co`03000001h00?mV00<00000003oo`00ool04P00ool00`00
000006Ko001Vo`0?001Vo`030000000c0?l0<`3o0100<`3o00<000000<`0o`3<0?l01@3<0?l50=WI
f@030000003IfMT0fMWI0040fMWI000L0=WIf@8000000`3IfMT70<`0o`030000000c0?l0<`3o00l0
<`3o00<00000001Vo`00I_l04000I_l00`0000000?oo003oo`0B003oo`0300000000ofH00?mV01/0
0?mV0P00001<03?o008000007@00ofH00`0000000?oo003oo`0B003oo`0300000000I_l006Ko00l0
06Ko00<0000003<0o`0c0?l0400c0?l00`000000c03o0<`0o`040<`0o`@0fMWI0P0000030=WIf@00
703IfMT00`000000fMWI0=WIf@020=WIf@D0c03o0P00000A03<0o`0300000000I_l006Ko010006Ko
00<00000003oo`00ool04P00ool00`0000000?mV003oIP0J003oIP800000D00co`02000001`00?mV
00<00000003oo`00ool04P00ool00`00000006Ko001Vo`0?001Vo`030000000c0?l0<`3o0100<`3o
0P0000040<`0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT40<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l03`00I_l00`0000000?oo003o
o`0B003oo`0300000000ofH00?mV01X00?mV00<0000003?o000co`00DP0co`000`0000000?mV003o
IP0J003oIP0300000000ool00?oo01800?oo00<00000001Vo`00I_l03`00I_l00`000000<`3o03<0
o`0A03<0o`040000003<0?l0c03o0<`0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<0
00000=WIf@3IfMT00P3IfMT30<`0o`030000000c0?l0<`3o0140<`3o00<00000001Vo`00I_l03`00
I_l00`0000000?oo003oo`0B003oo`0300000000ofH00?mV01T00?mV0P00001F03?o008000006`00
ofH00`0000000?oo003oo`0B003oo`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l04@0c
0?l00`000000c03o0<`0o`050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0
fMWI0080fMWI0P3<0?l00`000000<`3o03<0o`0A03<0o`0300000000I_l006Ko00l006Ko00<00000
003oo`00ool04P00ool00`0000000?mV003oIP0H003oIP800000FP0co`02000001X00?mV00<00000
003oo`00ool04P00ool00`00000006Ko001Vo`0?001Vo`030000000c0?l0<`3o0140<`3o00<00000
0<`0o`3IfMT0103IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WI
f@030<`0o`000000<`3o0180<`3o00<00000001Vo`00I_l03`00I_l00`0000000?oo003oo`0B003o
o`0300000000ofH00?mV01L00?mV0P00001N03?o008000006@00ofH00`0000000?oo003oo`0B003o
o`0300000000I_l006Ko00l006Ko00<0000003<0o`0c0?l04@0c0?l00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0000003<0o`0c
0?l0400c0?l20000014006Ko00<00000003oo`00ool04P00ool00`0000000?mV003oIP0G003oIP03
0000000co`00<ol00600<ol000<00000003oIP00ofH05`00ofH00`0000000?oo003oo`0B003oo`03
00000000I_l006Ko00l006Ko0P00000B03<0o`030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTB03<0o`0300000000I_l006Ko010006Ko
00<00000003oo`00ool04@00ool2000001P00?mV0P00001T03?o008000006000ofH2000001<00?oo
00<00000001Vo`00I_l04000I_l00`000000<`3o03<0o`0?03<0o`D0fMWI00<000000=WIf@3IfMT0
0@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTA03<0o`0300000000I_l006Ko010006Ko00<0
0000003oo`00ool04@00ool00`0000000?mV003oIP0F003oIP800000J00co`02000001P00?mV00<0
0000003oo`00ool04@00ool00`00000006Ko001Vo`0@001Vo`030000000c0?l0<`3o00h0<`3o1@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA00<`3o00<00000
001Vo`00I_l04000I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01H00?mV00<00000
03?o000co`00JP0co`000`0000000?mV003oIP0F003oIP0300000000ool00?oo01400?oo00<00000
001Vo`00I_l04000I_l00`000000<`3o03<0o`0=03<0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT?03<0o`0300000000I_l006Ko010006Ko00<00000003o
o`00ool04@00ool00`0000000?mV003oIP0E003oIP800000KP0co`02000001L00?mV00<00000003o
o`00ool04@00ool00`00000006Ko001Vo`0@001Vo`030000000c0?l0<`3o00`0<`3o1@3IfMT00`00
0000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@h0<`3o00<00000001Vo`00
I_l04000I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01@00?mV0P00001b03?o0080
00005P00ofH00`0000000?oo003oo`0A003oo`0300000000I_l006Ko010006Ko00<0000003<0o`0c
0?l02`0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI
3@0c0?l00`00000006Ko001Vo`0@001Vo`0300000000ool00?oo01400?oo00<00000003oIP00ofH0
5000ofH00`000000<ol003?o000_03?o01@00000<@0co`000`0000000?mV003oIP0D003oIP030000
0000ool00?oo01400?oo00<00000001Vo`00I_l04000I_l00`000000<`3o03<0o`0:03<0o`D0fMWI
00<000000=WIf@3IfMT00@3IfMT001`0fMWI0P0000030=WIf@`0<`3o00<00000001Vo`00I_l04000
I_l00`0000000?oo003oo`0A003oo`0300000000ofH00?mV01<00?mV0P00000V03?o00`00000503<
o`0<000002H0<ol00P00000E003oIP0300000000ool00?oo01400?oo00<00000001Vo`00I_l04000
I_l00`000000<`3o03<0o`0903<0o`@0fMWI0P0000030=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@/0<`3o00<00000001Vo`00I_l04000I_l00`0000000?oo003oo`0A003oo`0300000000ofH0
0?mV01<00?mV00<0000003?o000co`008P0co`04000002`0c?l01000000T03?o000300000000ofH0
0?mV01<00?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`0@001Vo`030000000c0?l0
<`3o00P0<`3o1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WI
f@T0<`3o0P00000B001Vo`0300000000ool00?oo01400?oo00<00000003oIP00ofH04P00ofH20000
0280<ol00`00000d0<co00<000008P0co`02000001@00?mV00<00000003oo`00ool04@00ool00`00
000006Ko001Vo`0@001Vo`800000200c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI200c0?l00`00000006Ko001Vo`0B001Vo`0300000000ool00?oo0100
0?oo00<00000003oIP00ofH04P00ofH00`000000<ol003?o000O03?o00<00000>P3<o`0300000240
<ol000<00000003oIP00ofH04P00ofH00`0000000?oo003oo`0@003oo`0300000000I_l006Ko0180
06Ko00<0000003<0o`0c0?l01@0c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI1`0c0?l00`00000006Ko001Vo`0B001Vo`0300000000ool00?oo01000?oo
00<00000003oIP00ofH04P00ofH00`000000<ol003?o000M03?o00<00000@03<o`03000001l0<ol0
00<00000003oIP00ofH04P00ofH00`0000000?oo003oo`0@003oo`0300000000I_l006Ko018006Ko
00<0000003<0o`0c0?l0100c0?l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI1P0c0?l00`00000006Ko001Vo`0B001Vo`0300000000ool00?oo01000?oo00<0
0000003oIP00ofH04@00ofH2000001d0<ol00`0000160<co00<000007@0co`02000001<00?mV00<0
0000003oo`00ool04000ool00`00000006Ko001Vo`0B001Vo`030000000c0?l0<`3o00<0<`3o1@3I
fMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@@0<`3o0P00000D
001Vo`0300000000ool00?oo01000?oo00<00000003oIP00ofH04@00ofH00`000000<ol003?o000K
03?o00800000C03<o`02000001d0<ol000<00000003oIP00ofH04@00ofH00`0000000?oo003oo`0@
003oo`0300000000I_l006Ko018006Ko0P00000303<0o`D0fMWI00<000000=WIf@3IfMT00@3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT303<0o`0300000000I_l006Ko01<006Ko00<00000003o
o`00ool04000ool00`0000000?mV003oIP0A003oIP030000000co`00<ol001X0<ol00P00001@0<co
00800000700co`000`0000000?mV003oIP0A003oIP0300000000ool00?oo01000?oo00<00000001V
o`00I_l04`00I_l00`000000<`3o03<0o`050=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI0P0c0?l00`00000006Ko001Vo`0C001Vo`0300000000ool00?oo0100
0?oo00<00000003oIP00ofH04@00ofH00`000000<ol003?o000I03?o00800000E03<o`02000001/0
<ol000<00000003oIP00ofH04@00ofH00`0000000?oo003oo`0@003oo`0300000000I_l006Ko01<0
06Ko00<0000003<0o`3IfMT0103IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@0303<0o`00000006Ko01@006Ko00<00000003oo`00ool04000ool00`0000000?mV
003oIP0@003oIP8000006P0co`02000005P0c?l00P00000J03?o008000004P00ofH00`0000000?oo
003oo`0@003oo`0300000000I_l006Ko01<006Ko00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@0300000000I_l006Ko01<006Ko00<0
0000003oo`00ool04000ool00`0000000?mV003oIP0@003oIP030000000co`00<ol001L0<ol00`00
001L0<co00<000006@0co`000`0000000?mV003oIP0@003oIP0300000000ool00?oo01000?oo00<0
0000001Vo`00I_l04`00I_l00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI5@00I_l00`0000000?oo003oo`0@003oo`0300000000ofH0
0?mV01000?mV00<0000003?o000co`005P0co`0200000680c?l00P00000H03?o000300000000ofH0
0?mV01000?mV00<00000003oo`00ool04000ool00`00000006Ko001Vo`0B001Vo`D0fMWI00<00000
0=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTC001Vo`8000004@00ool20000
01400?mV0P00000G03?o00800000IP3<o`02000001L0<ol00P00000A003oIP8000004@00ool20000
018006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA80
06Ko00<00000003oo`00ool04000ool00`0000000?mV003oIP0@003oIP030000000co`00<ol001D0
<ol00P00001Z0<co008000005`0co`000`0000000?mV003oIP0@003oIP0300000000ool00?oo0100
0?oo00<00000001Vo`00I_l03`00I_l50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@800000
0`3IfMTA001Vo`0300000000ool00?oo01000?oo00<00000003oIP00ofH04000ofH00`000000<ol0
03?o000D03?o00800000KP3<o`02000001H0<ol000<00000003oIP00ofH04000ofH00`0000000?oo
003oo`0@003oo`0300000000I_l006Ko00h006Ko103IfMT2000000<0fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI4000I_l00`0000000?oo003oo`0@003oo`0300000000ofH00?mV01000?mV00<0
000003?o000co`004`0co`02000003<0c?l02`00000d0<co008000005@0co`000`0000000?mV003o
IP0@003oIP0300000000ool00?oo01000?oo00<00000001Vo`00I_l03@00I_l50=WIf@030000003I
fMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI3P00I_l2000001800?oo00<00000
003oIP00ofH04000ofH00`000000<ol003?o000B03?o00800000;03<o`09000000/0oiT02P00000/
0<co00800000500co`000`0000000?mV003oIP0@003oIP0300000000ool00?oo01000?oo0P00000=
001Vo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT=001V
o`0300000000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000B03?o
00030000003<o`00c?l002D0c?l01`00000N0?nI00L000009`3<o`000`000000<ol003?o000B03?o
000300000000ofH00?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`0:001V
o`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT<001Vo`03
00000000ool00?oo01400?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000A03?o0080
00008`3<o`05000002`0oiT01@00000S0<co008000004`0co`000`0000000?mV003oIP0@003oIP03
00000000ool00?oo01400?oo00<00000001Vo`00I_l02@00I_l50=WIf@030000003IfMT0fMWI0040
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI2`00I_l00`0000000?oo003oo`0A003oo`030000
0000ofH00?mV01000?mV00<0000003?o000co`00400co`0200000200c?l01@00000f0?nI00D00000
803<o`0200000180<ol000<00000003oIP00ofH04000ofH00`0000000?oo003oo`0A003oo`030000
0000I_l006Ko00P006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WI
f@020=WIf@X006Ko00<00000003oo`00ool04@00ool00`0000000?mV003oIP0@003oIP030000000c
o`00<ol00100<ol000<000000<co003<o`006`3<o`0500000400oiT01@00000M0<co00030000000c
o`00<ol00100<ol000<00000003oIP00ofH04000ofH00`0000000?oo003oo`0A003oo`0300000000
I_l006Ko00L006Ko1@3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@T006Ko00<00000003oo`00ool04@00ool00`0000000?mV003oIP0@003oIP030000000co`00
<ol000l0<ol00P00000I0<co00D00000BP3oV@05000001T0c?l00P00000A03?o000300000000ofH0
0?mV01000?mV00<00000003oo`00ool04@00ool00`00000006Ko001Vo`06001Vo`D0fMWI00<00000
0=WIf@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT8001Vo`0300000000ool00?oo
01800?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l0
01L0c?l00P00001D0?nI008000006@3<o`000`000000<ol003?o000>03?o000300000000ofH00?mV
01000?mV00<00000003oo`00ool04P00ool00`00000006Ko001Vo`05001Vo`D0fMWI00<000000=WI
f@3IfMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT7001Vo`0300000000ool00?oo0180
0?oo00<00000003oIP00ofH04000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l001H0
c?l00P00001H0?nI00800000603<o`000`000000<ol003?o000>03?o000300000000ofH00?mV0100
0?mV00<00000003oo`00ool04P00ool00`00000006Ko001Vo`04001Vo`D0fMWI00<000000=WIf@3I
fMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT6001Vo`0300000000ool00?oo01800?oo
00<00000003oIP00ofH04000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l001D0c?l0
0P00001L0?nI008000005`3<o`000`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV
00<00000003oo`00ool04P00ool00`00000006Ko001Vo`03001Vo`D0fMWI00<000000=WIf@3IfMT0
0@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT5001Vo`0300000000ool00?oo01800?oo00<0
0000003oIP00ofH04000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l001<0c?l00`00
001P0?nI00<000005@3<o`000`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<0
0000003oo`00ool04P00ool00`00000006Ko001Vo`02001Vo`D0fMWI00<000000=WIf@3IfMT00@3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT4001Vo`0300000000ool00?oo01800?oo00<00000
003oIP00ofH04000ofH00`000000<ol003?o000>03?o00030000003<o`00c?l00180c?l00P00001V
0?nI00800000503<o`000`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<00000
003oo`00ool04P00ool01000000006Ko001Vo`00I_l50=WIf@030000003IfMT0fMWI0040fMWI000L
0=WIf@8000000`3IfMT3001Vo`0300000000ool00?oo01800?oo00<00000003oIP00ofH04000ofH0
0`000000<ol003?o000>03?o00030000003<o`00c?l00140c?l00P00001Z0?nI008000004`3<o`00
0`000000<ol003?o000>03?o000300000000ofH00?mV01000?mV00<00000003oo`00ool04P00ool0
0`00000006Ko001Vo`040=WIf@8000000`3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT2001V
o`0300000000ool00?oo01<00?oo00<00000003oIP00ofH03`00ofH00`000000<ol003?o000>03?o
00030000003<o`00c?l00100c?l00P00001^0?nI008000004P3<o`000`000000<ol003?o000>03?o
000300000000ofH00?mV00l00?mV00<00000003oo`00ool04`00ool00`00000006Ko0=WIf@040=WI
f@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<006Ko00000000
ool05000ool00`0000000?mV003oIP0?003oIP030000000co`00<ol000h0<ol000<000000<co003<
o`003`3<o`0200000780oiT00P00000A0<co00030000000co`00<ol000h0<ol000<00000003oIP00
ofH03`00ofH00`0000000?oo003oo`0C003oo`030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00@3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`0000000?oo003oo`0C003oo`030000
0000ofH00?mV00l00?mV00<0000003?o000co`003`0co`000`000000c?l00<co000>0<co00030000
003oV@00oiT002l0oiT05000000a0?nI00030000003<o`00c?l000h0c?l000<0000003?o000co`00
3`0co`000`0000000?mV003oIP0?003oIP0300000000ool00?oo01<00?oo00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAD00?oo00<0
0000003oIP00ofH03`00ofH00`000000<ol003?o000?03?o00030000003<o`00c?l000d0c?l00P00
000U0?nI00d00000503o000=000002D0oiT00P00000?0<co00030000000co`00<ol000l0<ol000<0
0000003oIP00ofH03`00ofH00`0000000?oo003oo`0B003oo`D0fMWI00<000000=WIf@3IfMT00@3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTC003oo`8000004P00ofH00`000000<ol003?o000>
03?o00030000003<o`00c?l000d0c?l000<000000?nI003oV@007P3oV@07000002h0o`001`00000P
0?nI00030000003<o`00c?l000d0c?l000<0000003?o000co`003P0co`000`0000000?mV003oIP0@
003oIP8000004P00ool50=WIf@030000003IfMT0fMWI0040fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI4P00ool00`0000000?mV003oIP0A003oIP030000000co`00<ol000h0<ol000<000000<co
003<o`00303<o`02000001/0oiT01P00000l0?l000H000006`3oV@02000000h0c?l000<0000003?o
000co`003P0co`000`0000000?mV003oIP0A003oIP0300000000ool00?oo00l00?oo1@3IfMT00`00
0000fMWI0=WIf@010=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA400?oo00<00000003oIP00
ofH04@00ofH00`000000<ol003?o000>03?o00030000003<o`00c?l000/0c?l00P00000H0?nI00D0
0000B03o0005000001P0oiT00P00000=0<co00030000000co`00<ol000h0<ol000<00000003oIP00
ofH04@00ofH00`0000000?oo003oo`0>003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI
00<000000=WIf@3IfMT00P3IfMT@003oo`0300000000ofH00?mV01400?mV00<0000003?o000co`00
3P0co`000`000000c?l00<co000;0<co00030000003oV@00oiT001@0oiT01000001B0?l000@00000
5P3oV@000`000000c?l00<co000;0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH0
4@00ofH00`0000000?oo003oo`0=003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT001`0fMWI00<0
00000=WIf@3IfMT00P3IfMT?003oo`0300000000ofH00?mV01400?mV00<0000003?o000co`003P0c
o`000`000000c?l00<co000:0<co008000004`3oV@04000005X0o`001000000C0?nI00800000303<
o`000`000000<ol003?o000>03?o000300000000ofH00?mV01400?mV00<00000003oo`00ool03000
ool50=WIf@030000003IfMT0fMWI0040fMWI000=0=WIf@<000000P3IfMT3000000L0fMWI00<00000
0=WIf@3IfMT00P3IfMT>003oo`0300000000ofH00?mV01400?mV00<0000003?o000co`003P0co`00
0`000000c?l00<co000:0<co00030000003oV@00oiT00100oiT00`00001R0?l000<000004P3oV@00
0`000000c?l00<co000:0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH04@00ofH0
0`0000000?oo003oo`0;003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT000h0fMWI00@000000=WI
f@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI3@00ool0
0`0000000?mV003oIP0A003oIP030000000co`00<ol000h0<ol000<000000<co003<o`002@3<o`02
000000l0oiT01000001X0?l000@000003`3oV@02000000/0c?l000<0000003?o000co`003P0co`00
0`0000000?mV003oIP0A003oIP0300000000ool00?oo00X00?oo1@3IfMT00`000000fMWI0=WIf@01
0=WIf@003P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<003oo`0300000000ofH00?mV01400?mV00<0000003?o000co`003P0co`00
0`000000c?l00<co00090<co00030000003oV@00oiT000`0oiT00`00001`0?l000@000003@3oV@00
0`000000c?l00<co00090<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH04@00ofH0
0`0000000?oo003oo`09003oo`D0fMWI00<000000=WIf@3IfMT00@3IfMT000h0fMWI00@000000=WI
f@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@<000000P3IfMT;003oo`0300000000ofH0
0?mV01400?mV00<0000003?o000co`003P0co`000`000000c?l00<co00090<co00030000003oV@00
oiT000/0oiT00P00001g0?l000030000003oV@00oiT000/0oiT000<000000<co003<o`002@3<o`00
0`000000<ol003?o000>03?o000300000000ofH00?mV01400?mV00<00000003oo`00ool02000ool3
0=WIf@<000000`3IfMT000h0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI0?l0fMWI5@3IfMT00`000000fMWI0=WIf@010=WIf@003P3IfMT01000
0000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMTE
0=WIf@030000003IfMT0fMWI0040fMWI000>0=WIf@040000003IfMT0fMWI000000<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3o0=WIfAD0fMWI00<000000=WIf@3IfMT00@3IfMT0
00d0fMWI0P0000030=WIf@<000001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0400fMWI00<000000=WIf@3IfMT0@03IfMT00`000000fMWI0=WIf@100=WIf@030000003IfMT0fMWI
0440fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@010=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0040fMWI000L0=WIfOl000006@0000030=WIf@00o`3I
fMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3IfMTh0=WIf@00o`3I
fMTh0=WIf@00o`3IfMTh0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 310}, {310, 0}} -> {-12.5247, -12.1518, 0.0745857, 
  0.0745857}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A Sextupole with 12 azimutal segments", "Subsection"],

Cell[BoxData[
    \(radUtiDelAll[]; \nnseg = 12; \nrint = 20; \nrext = 60; \nLz = 30; \n
    phi1 = \(-Pi\)/nseg; \nphi2 = phi1 + 2\ Pi; \nnz = 1; \nnr = {1, 1}; \n
    pt = {0, 0, 0}; \ndphi = \((phi2 - phi1)\)/nseg; \nbr = 1.2; \n
    mag = {0, br, 0, 4}; \n
    cyl3 = RadCylinder[pt, rint, rext, phi1, phi2, Lz, nr, nseg, nz, mag]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      RowBox[{"d3", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "cyl3", "]"}]}], ";", "\n", 
      \(Show[Graphics3D[d3]\n, ViewPoint -> {0, 0, 10000}]\), ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.22368 .13934 -12.5 -14 ]
[.22368 .13934 12.5 0 ]
[.5 .13934 -5 -14 ]
[.5 .13934 5 0 ]
[.77632 .13934 -8 -14 ]
[.77632 .13934 8 0 ]
[.5 .07684 -8 -14 ]
[.5 .07684 8 0 ]
[.13934 .22368 -25 -7 ]
[.13934 .22368 0 7 ]
[.13934 .5 -10 -7 ]
[.13934 .5 0 7 ]
[.13934 .77632 -16 -7 ]
[.13934 .77632 0 7 ]
[.07684 .5 -15 -7 ]
[.07684 .5 0 7 ]
[.86065 .84815 0 -7 ]
[.86065 .84815 10 7 ]
[.86065 .84815 0 -7 ]
[.86065 .84815 16 7 ]
[.86066 .84816 0 -7 ]
[.86066 .84816 16 7 ]
[.86066 .84816 0 -7 ]
[.86066 .84816 16 7 ]
[.92316 .84816 0 -7 ]
[.92316 .84816 14 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.15184 .15184 m
.84816 .15184 L
s
.25 Mabswid
.22368 .15184 m
.22368 .15809 L
s
gsave
.22368 .13934 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .15184 m
.5 .15809 L
s
gsave
.5 .13934 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77632 .15184 m
.77632 .15809 L
s
gsave
.77632 .13934 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.27895 .15184 m
.27895 .15559 L
s
.33421 .15184 m
.33421 .15559 L
s
.38947 .15184 m
.38947 .15559 L
s
.44474 .15184 m
.44474 .15559 L
s
.55526 .15184 m
.55526 .15559 L
s
.61053 .15184 m
.61053 .15559 L
s
.66579 .15184 m
.66579 .15559 L
s
.72105 .15184 m
.72105 .15559 L
s
.16842 .15184 m
.16842 .15559 L
s
.83158 .15184 m
.83158 .15559 L
s
gsave
.5 .07684 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
75.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.15184 .15184 m
.15184 .84816 L
s
.25 Mabswid
.15184 .22368 m
.15809 .22368 L
s
gsave
.13934 .22368 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.15184 .5 m
.15809 .5 L
s
gsave
.13934 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15184 .77632 m
.15809 .77632 L
s
gsave
.13934 .77632 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15184 .27895 m
.15559 .27895 L
s
.15184 .33421 m
.15559 .33421 L
s
.15184 .38947 m
.15559 .38947 L
s
.15184 .44474 m
.15559 .44474 L
s
.15184 .55526 m
.15559 .55526 L
s
.15184 .61053 m
.15559 .61053 L
s
.15184 .66579 m
.15559 .66579 L
s
.15184 .72105 m
.15559 .72105 L
s
.15184 .16842 m
.15559 .16842 L
s
.15184 .83158 m
.15559 .83158 L
s
gsave
.07684 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.84815 .84815 m
.84816 .84816 L
s
.25 Mabswid
.84815 .84815 m
.8419 .84815 L
s
gsave
.86065 .84815 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84815 .84815 m
.8419 .84815 L
s
gsave
.86065 .84815 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84816 .84816 m
.84191 .84816 L
s
gsave
.86066 .84816 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84816 .84816 m
.84191 .84816 L
s
gsave
.86066 .84816 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.84815 .84815 m
.8444 .84815 L
s
.84815 .84815 m
.8444 .84815 L
s
.84815 .84815 m
.8444 .84815 L
s
.84815 .84815 m
.8444 .84815 L
s
.84815 .84815 m
.8444 .84815 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
.84816 .84816 m
.84441 .84816 L
s
gsave
.92316 .84816 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.15185 .15185 m
.15184 .15184 L
s
.15184 .15184 m
.15184 .84816 L
s
.15184 .84816 m
.15185 .84815 L
s
.15185 .84815 m
.15185 .15185 L
s
.84815 .15185 m
.84815 .84815 L
s
.84815 .84815 m
.84816 .84816 L
s
.84816 .84816 m
.84816 .15184 L
s
.84816 .15184 m
.84815 .15185 L
s
.15185 .15185 m
.15184 .15184 L
s
.15184 .15184 m
.84816 .15184 L
s
.84816 .15184 m
.84815 .15185 L
s
.84815 .15185 m
.15185 .15185 L
s
.15185 .84815 m
.84815 .84815 L
s
.84815 .84815 m
.84816 .84816 L
s
.84816 .84816 m
.15184 .84816 L
s
.15184 .84816 m
.15185 .84815 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.74273 .25727 m .74273 .25727 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.41909 .41909 m .25727 .25727 L .25727 .25727 L p .1 .1 .6 r
F P
0 g
s
.25727 .25727 m .41909 .41909 L .41909 .41909 L p .1 .1 .6 r
F P
0 g
s
.16842 .41115 m .16843 .41116 L .38948 .47039 L p .283 .1 .1 r
F P
0 g
s
.38947 .52962 m .16842 .58885 L .16843 .58884 L p .1 .1 .1 r
F P
0 g
s
.38947 .52962 m .38948 .52961 L .16843 .58884 L p .1 .1 .1 r
F P
0 g
s
.25727 .74273 m .25727 .74273 L .41909 .58091 L p .6 .916 .6 r
F P
0 g
s
.58091 .58091 m .74273 .74273 L .74273 .74273 L p .6 .1 .1 r
F P
0 g
s
.74273 .74273 m .58091 .58091 L .58091 .58091 L p .6 .1 .1 r
F P
0 g
s
.83158 .58885 m .83157 .58884 L .61052 .52961 L p .283 .1 .1 r
F P
0 g
s
.83157 .41116 m .83158 .41115 L .61053 .47038 L p .1 .1 .1 r
F P
0 g
s
.61053 .47038 m .61052 .47039 L .83157 .41116 L p .1 .1 .1 r
F P
0 g
s
.74273 .25727 m .58091 .41909 L .61052 .47039 L p .807 .677 .807 r
F P
0 g
s
.61052 .47039 m .83157 .41116 L .74273 .25727 L p .807 .677 .807 r
F P
0 g
s
.58091 .41909 m .58091 .41909 L .61053 .47038 L p .1 .1 .56 r
F P
0 g
s
.61053 .47038 m .61052 .47039 L .58091 .41909 L p .1 .1 .56 r
F P
0 g
s
.61052 .47039 m .61053 .47038 L .83158 .41115 L p .283 .807 .783 r
F P
0 g
s
.83158 .41115 m .83157 .41116 L .61052 .47039 L p .283 .807 .783 r
F P
0 g
s
.83157 .41116 m .83158 .41115 L .74273 .25727 L p .1 .157 .723 r
F P
0 g
s
.74273 .25727 m .74273 .25727 L .83157 .41116 L p .1 .157 .723 r
F P
0 g
s
.74273 .25727 m .74273 .25727 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.58091 .41909 m .58091 .41909 L .74273 .25727 L p .6 .916 .6 r
F P
0 g
s
.58884 .16843 m .52961 .38948 L .58091 .41909 L p .807 .677 .807 r
F P
0 g
s
.58091 .41909 m .74273 .25727 L .58884 .16843 L p .807 .677 .807 r
F P
0 g
s
.52961 .38948 m .52962 .38947 L .58091 .41909 L p .1 .399 .816 r
F P
0 g
s
.58091 .41909 m .58091 .41909 L .52961 .38948 L p .1 .399 .816 r
F P
0 g
s
.74273 .25727 m .58091 .41909 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.74273 .25727 m .74273 .25727 L .58885 .16842 L p .1 .539 .957 r
F P
0 g
s
.58885 .16842 m .58884 .16843 L .74273 .25727 L p .1 .539 .957 r
F P
0 g
s
.58884 .16843 m .58885 .16842 L .52962 .38947 L p .1 .1 .1 r
F P
0 g
s
.52962 .38947 m .52961 .38948 L .58884 .16843 L p .1 .1 .1 r
F P
0 g
s
.41116 .16843 m .47039 .38948 L .52961 .38948 L p .807 .677 .807 r
F P
0 g
s
.52961 .38948 m .58884 .16843 L .41116 .16843 L p .807 .677 .807 r
F P
0 g
s
.47039 .38948 m .47038 .38947 L .52962 .38947 L p .211 .761 .909 r
F P
0 g
s
.52962 .38947 m .52961 .38948 L .47039 .38948 L p .211 .761 .909 r
F P
0 g
s
.52961 .38948 m .52962 .38947 L .58885 .16842 L p .1 .1 .1 r
F P
0 g
s
.58885 .16842 m .58884 .16843 L .52961 .38948 L p .1 .1 .1 r
F P
0 g
s
.58884 .16843 m .58885 .16842 L .41115 .16842 L p .404 .869 1 r
F P
0 g
s
.41115 .16842 m .41116 .16843 L .58884 .16843 L p .404 .869 1 r
F P
0 g
s
.41116 .16843 m .41115 .16842 L .47038 .38947 L p .783 .508 .1 r
F P
0 g
s
.47038 .38947 m .47039 .38948 L .41116 .16843 L p .783 .508 .1 r
F P
0 g
s
.25727 .25727 m .41909 .41909 L .47039 .38948 L p .807 .677 .807 r
F P
0 g
s
.47039 .38948 m .41116 .16843 L .25727 .25727 L p .807 .677 .807 r
F P
0 g
s
.41909 .41909 m .41909 .41909 L .47038 .38947 L p .56 .969 .816 r
F P
0 g
s
.47038 .38947 m .47039 .38948 L .41909 .41909 L p .56 .969 .816 r
F P
0 g
s
.47039 .38948 m .47038 .38947 L .41115 .16842 L p .783 .508 .1 r
F P
0 g
s
.41115 .16842 m .41116 .16843 L .47039 .38948 L p .783 .508 .1 r
F P
0 g
s
.41116 .16843 m .41115 .16842 L .25727 .25727 L p .723 1 .957 r
F P
0 g
s
.25727 .25727 m .25727 .25727 L .41116 .16843 L p .723 1 .957 r
F P
0 g
s
.16843 .41116 m .38948 .47039 L .41909 .41909 L p .807 .677 .807 r
F P
0 g
s
.41909 .41909 m .25727 .25727 L .16843 .41116 L p .807 .677 .807 r
F P
0 g
s
.38948 .47039 m .38947 .47038 L .41909 .41909 L p .816 .969 .56 r
F P
0 g
s
.41909 .41909 m .41909 .41909 L .38948 .47039 L p .816 .969 .56 r
F P
0 g
s
.25727 .25727 m .41909 .41909 L .41909 .41909 L p .6 .1 .1 r
F P
0 g
s
.41909 .41909 m .25727 .25727 L .25727 .25727 L p .6 .1 .1 r
F P
0 g
s
.25727 .25727 m .25727 .25727 L .16842 .41115 L p .957 1 .723 r
F P
0 g
s
.16842 .41115 m .16843 .41116 L .25727 .25727 L p .957 1 .723 r
F P
0 g
s
.16843 .41116 m .16842 .41115 L .38947 .47038 L p .1 .508 .783 r
F P
0 g
s
.38947 .47038 m .38948 .47039 L .16843 .41116 L p .1 .508 .783 r
F P
0 g
s
.16843 .58884 m .38948 .52961 L .38948 .47039 L p .807 .677 .807 r
F P
0 g
s
.38948 .47039 m .16843 .41116 L .16843 .58884 L p .807 .677 .807 r
F P
0 g
s
.38948 .52961 m .38947 .52962 L .38947 .47038 L p .909 .761 .211 r
F P
0 g
s
.38947 .47038 m .38948 .47039 L .38948 .52961 L p .909 .761 .211 r
F P
0 g
s
.38948 .47039 m .38947 .47038 L .16842 .41115 L p .283 .1 .1 r
F P
0 g
s
.16843 .41116 m .16842 .41115 L .16842 .58885 L p 1 .869 .404 r
F P
0 g
s
.16842 .58885 m .16843 .58884 L .16843 .41116 L p 1 .869 .404 r
F P
0 g
s
.25727 .74273 m .41909 .58091 L .38948 .52961 L p .807 .677 .807 r
F P
0 g
s
.38948 .52961 m .16843 .58884 L .25727 .74273 L p .807 .677 .807 r
F P
0 g
s
.41909 .58091 m .41909 .58091 L .38947 .52962 L p .816 .399 .1 r
F P
0 g
s
.38947 .52962 m .38948 .52961 L .41909 .58091 L p .816 .399 .1 r
F P
0 g
s
.38948 .52961 m .38947 .52962 L .16842 .58885 L p .1 .1 .1 r
F P
0 g
s
.16842 .58885 m .16843 .58884 L .38948 .52961 L p .1 .1 .1 r
F P
0 g
s
.16843 .58884 m .16842 .58885 L .25727 .74273 L p .957 .539 .1 r
F P
0 g
s
.25727 .74273 m .25727 .74273 L .16843 .58884 L p .957 .539 .1 r
F P
0 g
s
.25727 .74273 m .25727 .74273 L .41909 .58091 L p .6 .916 .6 r
F P
0 g
s
.41909 .58091 m .41909 .58091 L .25727 .74273 L p .6 .916 .6 r
F P
0 g
s
.41116 .83157 m .47039 .61052 L .41909 .58091 L p .807 .677 .807 r
F P
0 g
s
.41909 .58091 m .25727 .74273 L .41116 .83157 L p .807 .677 .807 r
F P
0 g
s
.47039 .61052 m .47038 .61053 L .41909 .58091 L p .56 .1 .1 r
F P
0 g
s
.41909 .58091 m .41909 .58091 L .47039 .61052 L p .56 .1 .1 r
F P
0 g
s
.25727 .74273 m .41909 .58091 L .41909 .58091 L p .6 .916 .6 r
F P
0 g
s
.25727 .74273 m .25727 .74273 L .41115 .83158 L p .723 .157 .1 r
F P
0 g
s
.41115 .83158 m .41116 .83157 L .25727 .74273 L p .723 .157 .1 r
F P
0 g
s
.41116 .83157 m .41115 .83158 L .47038 .61053 L p .1 .1 .1 r
F P
0 g
s
.47038 .61053 m .47039 .61052 L .41116 .83157 L p .1 .1 .1 r
F P
0 g
s
.58884 .83157 m .52961 .61052 L .47039 .61052 L p .807 .677 .807 r
F P
0 g
s
.47039 .61052 m .41116 .83157 L .58884 .83157 L p .807 .677 .807 r
F P
0 g
s
.52961 .61052 m .52962 .61053 L .47038 .61053 L p .211 .1 .1 r
F P
0 g
s
.47038 .61053 m .47039 .61052 L .52961 .61052 L p .211 .1 .1 r
F P
0 g
s
.47039 .61052 m .47038 .61053 L .41115 .83158 L p .783 .807 .283 r
F P
0 g
s
.41115 .83158 m .41116 .83157 L .47039 .61052 L p .783 .807 .283 r
F P
0 g
s
.41116 .83157 m .41115 .83158 L .58885 .83158 L p .404 .1 .1 r
F P
0 g
s
.58885 .83158 m .58884 .83157 L .41116 .83157 L p .404 .1 .1 r
F P
0 g
s
.58884 .83157 m .58885 .83158 L .52962 .61053 L p .783 .508 .1 r
F P
0 g
s
.52962 .61053 m .52961 .61052 L .58884 .83157 L p .783 .508 .1 r
F P
0 g
s
.74273 .74273 m .58091 .58091 L .52961 .61052 L p .807 .677 .807 r
F P
0 g
s
.52961 .61052 m .58884 .83157 L .74273 .74273 L p .807 .677 .807 r
F P
0 g
s
.58091 .58091 m .58091 .58091 L .52962 .61053 L p .1 .1 .1 r
F P
0 g
s
.52962 .61053 m .52961 .61052 L .58091 .58091 L p .1 .1 .1 r
F P
0 g
s
.52961 .61052 m .52962 .61053 L .58885 .83158 L p .1 .1 .283 r
F P
0 g
s
.58885 .83158 m .58884 .83157 L .52961 .61052 L p .1 .1 .283 r
F P
0 g
s
.58884 .83157 m .58885 .83158 L .74273 .74273 L p .1 .1 .1 r
F P
0 g
s
.74273 .74273 m .74273 .74273 L .58884 .83157 L p .1 .1 .1 r
F P
0 g
s
.83157 .58884 m .61052 .52961 L .58091 .58091 L p .807 .677 .807 r
F P
0 g
s
.58091 .58091 m .74273 .74273 L .83157 .58884 L p .807 .677 .807 r
F P
0 g
s
.61052 .52961 m .61053 .52962 L .58091 .58091 L p .1 .1 .1 r
F P
0 g
s
.58091 .58091 m .58091 .58091 L .61052 .52961 L p .1 .1 .1 r
F P
0 g
s
.74273 .74273 m .58091 .58091 L .58091 .58091 L p .1 .1 .6 r
F P
0 g
s
.58091 .58091 m .74273 .74273 L .74273 .74273 L p .1 .1 .6 r
F P
0 g
s
.74273 .74273 m .74273 .74273 L .83158 .58885 L p .1 .1 .1 r
F P
0 g
s
.83158 .58885 m .83157 .58884 L .74273 .74273 L p .1 .1 .1 r
F P
0 g
s
.83157 .58884 m .83158 .58885 L .61053 .52962 L p .1 .508 .783 r
F P
0 g
s
.61053 .52962 m .61052 .52961 L .83157 .58884 L p .1 .508 .783 r
F P
0 g
s
.83157 .41116 m .61052 .47039 L .61052 .52961 L p .807 .677 .807 r
F P
0 g
s
.61052 .52961 m .83157 .58884 L .83157 .41116 L p .807 .677 .807 r
F P
0 g
s
.61052 .47039 m .61053 .47038 L .61053 .52962 L p .1 .1 .211 r
F P
0 g
s
.61053 .52962 m .61052 .52961 L .61052 .47039 L p .1 .1 .211 r
F P
0 g
s
.61052 .52961 m .61053 .52962 L .83158 .58885 L p .283 .1 .1 r
F P
0 g
s
.83157 .58884 m .83158 .58885 L .83158 .41115 L p .1 .1 .404 r
F P
0 g
s
.83158 .41115 m .83157 .41116 L .83157 .58884 L p .1 .1 .404 r
F P
0 g
s
.83158 .41115 m .61053 .47038 L .58091 .41909 L p .807 .677 .807 r
F P
0 g
s
.58091 .41909 m .74273 .25727 L .83158 .41115 L p .807 .677 .807 r
F P
0 g
s
.74273 .25727 m .58091 .41909 L .52962 .38947 L p .807 .677 .807 r
F P
0 g
s
.52962 .38947 m .58885 .16842 L .74273 .25727 L p .807 .677 .807 r
F P
0 g
s
.58885 .16842 m .52962 .38947 L .47038 .38947 L p .807 .677 .807 r
F P
0 g
s
.47038 .38947 m .41115 .16842 L .58885 .16842 L p .807 .677 .807 r
F P
0 g
s
.41115 .16842 m .47038 .38947 L .41909 .41909 L p .807 .677 .807 r
F P
0 g
s
.41909 .41909 m .25727 .25727 L .41115 .16842 L p .807 .677 .807 r
F P
0 g
s
.25727 .25727 m .41909 .41909 L .38947 .47038 L p .807 .677 .807 r
F P
0 g
s
.38947 .47038 m .16842 .41115 L .25727 .25727 L p .807 .677 .807 r
F P
0 g
s
.16842 .41115 m .38947 .47038 L .38947 .52962 L p .807 .677 .807 r
F P
0 g
s
.38947 .52962 m .16842 .58885 L .16842 .41115 L p .807 .677 .807 r
F P
0 g
s
.16842 .58885 m .38947 .52962 L .41909 .58091 L p .807 .677 .807 r
F P
0 g
s
.41909 .58091 m .25727 .74273 L .16842 .58885 L p .807 .677 .807 r
F P
0 g
s
.25727 .74273 m .41909 .58091 L .47038 .61053 L p .807 .677 .807 r
F P
0 g
s
.47038 .61053 m .41115 .83158 L .25727 .74273 L p .807 .677 .807 r
F P
0 g
s
.41115 .83158 m .47038 .61053 L .52962 .61053 L p .807 .677 .807 r
F P
0 g
s
.52962 .61053 m .58885 .83158 L .41115 .83158 L p .807 .677 .807 r
F P
0 g
s
.58885 .83158 m .52962 .61053 L .58091 .58091 L p .807 .677 .807 r
F P
0 g
s
.58091 .58091 m .74273 .74273 L .58885 .83158 L p .807 .677 .807 r
F P
0 g
s
.74273 .74273 m .58091 .58091 L .61053 .52962 L p .807 .677 .807 r
F P
0 g
s
.61053 .52962 m .83158 .58885 L .74273 .74273 L p .807 .677 .807 r
F P
0 g
s
.83158 .58885 m .61053 .52962 L .61053 .47038 L p .807 .677 .807 r
F P
0 g
s
.61053 .47038 m .83158 .41115 L .83158 .58885 L p .807 .677 .807 r
F P
0 g
s
.003 w
.15184 .15184 m
.15184 .84816 L
s
.25 Mabswid
.15184 .22368 m
.15809 .22368 L
s
gsave
.13934 .22368 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.15184 .5 m
.15809 .5 L
s
gsave
.13934 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15184 .77632 m
.15809 .77632 L
s
gsave
.13934 .77632 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15184 .27895 m
.15559 .27895 L
s
.15184 .33421 m
.15559 .33421 L
s
.15184 .38947 m
.15559 .38947 L
s
.15184 .44474 m
.15559 .44474 L
s
.15184 .55526 m
.15559 .55526 L
s
.15184 .61053 m
.15559 .61053 L
s
.15184 .66579 m
.15559 .66579 L
s
.15184 .72105 m
.15559 .72105 L
s
.15184 .16842 m
.15559 .16842 L
s
.15184 .83158 m
.15559 .83158 L
s
gsave
.07684 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00R@3IfMT300000080fMWI0`00002?0=WIf@00R`3I
fMT010000000fMWI0=WIf@00002A0=WIf@00R`3IfMT010000000fMWI0=WIf@00002A0=WIf@00S03I
fMT200000980fMWI002<0=WIf@800000TP3IfMT008/0fMWI00@000000=WIf@3IfMT00000T@3IfMT0
08/0fMWI00@000000=WIf@3IfMT00000T@3IfMT008T0fMWI0`0000020=WIf@<00000S`3IfMT00?l0
fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0
fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT003h0fMWI100000030=WI
f@<00000A@3IfMT3000004P0fMWI100000030=WIf@<00000?P3IfMT00480fMWI00<000000=WIf@00
00000`3IfMT00`000000fMWI0=WIf@110=WIf@050000003IfMT0fMWI0=WIf@000000B`3IfMT00`00
0000fMWI000000030=WIf@030000003IfMT0fMWI03/0fMWI00120=WIf@030000003IfMT0000000<0
fMWI00<000000=WIf@3IfMT0@@3IfMT01@000000fMWI0=WIf@3IfMT0000004/0fMWI00<000000=WI
f@0000000`3IfMT00`000000fMWI0=WIf@0k0=WIf@00=P3IfMT7000000D0fMWI00<000000=WIf@00
00000`3IfMT00`000000fMWI0=WIf@110=WIf@050000003IfMT0fMWI0=WIf@000000B`3IfMT00`00
0000fMWI000000030=WIf@030000003IfMT0fMWI03/0fMWI00120=WIf@030000003IfMT0000000<0
fMWI00<000000=WIf@3IfMT0@@3IfMT01@000000fMWI0=WIf@3IfMT0000004/0fMWI00<000000=WI
f@0000000`3IfMT00`000000fMWI0=WIf@0k0=WIf@00?P3IfMT400000080fMWI00D000000=WIf@3I
fMT0fMWI000000130=WIf@050000003IfMT0fMWI0=WIf@000000A`3IfMT400000080fMWI00D00000
0=WIf@3IfMT0fMWI0000000m0=WIf@00?`3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0
fMWI0=WIf@000000@`3IfMT01@000000fMWI0=WIf@3IfMT0000004P0fMWI00<000000=WIf@3IfMT0
0P3IfMT01@000000fMWI0=WIf@3IfMT0000003d0fMWI000o0=WIf@@000000P3IfMT3000004D0fMWI
0`0000190=WIf@@000000P3IfMT3000003h0fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WI
fB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI003o0=WIfB40fMWI000[0=WIfLT00000;03IfMT0
02/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
02X0fMWI000[0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0C03IfMT00`000000
fMWI0=WIf@1<0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI
00<000000=WIf@3IfMT0a@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WI
f@350=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@800000B03IfMTf000004P0fMWI00<00000
0=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0A@3IfMT2000000030<j]cP000000cZg>
0340cZg>00@000000<j]cP0000000000AP3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`00
0000fMWI0=WIf@130=WIf@8000000`3>[Lh00`000000cZg>0<j]cP0`0<j]cP050000003>[Lh0cZg>
0<j]cP000000A@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@120=WI
f@030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh0;P3>[Lh00`000000cZg>0<j]cP030<j]
cP800000@`3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@100=WIf@80
00001`3>[Lh00`000000cZg>0<j]cP0^0<j]cP030000003>[Lh0cZg>00D0cZg>0P0000110=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI03h0fMWI0P0000090<j]cP030000
003>[Lh0cZg>02h0cZg>00<000000<j]cP3>[Lh01`3>[Lh2000003l0fMWI00<000000=WIf@3IfMT0
:P3IfMT002/0fMWI00<000000=WIf@3IfMT0?03IfMT2000000/0cZg>00<000000<j]cP3>[Lh0;P3>
[Lh00`000000cZg>0<j]cP090<j]cP030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT0:P3I
fMT002/0fMWI00<000000=WIf@3IfMT0>P3IfMT2000000h0cZg>00<000000<j]cP3>[Lh0;03>[Lh0
0`000000cZg>0<j]cP0;0<j]cP800000?03IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`00
0000fMWI0=WIf@0i0=WIf@030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh0;03>[Lh00`00
0000cZg>0<j]cP0=0<j]cP800000>P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000
fMWI0=WIf@0g0=WIf@8000004@3>[Lh00`000000cZg>0<j]cP0/0<j]cP030000003>[Lh0cZg>00l0
cZg>0P00000h0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI03D0fMWI
0P00000D0<j]cP030000003>[Lh0cZg>02X0cZg>00<000000<j]cP3>[Lh04P3>[Lh00`000000fMWI
0=WIf@0e0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI03<0fMWI0P00
000F0<j]cP030000003>[Lh0cZg>02X0cZg>00<000000<j]cP3>[Lh04`3>[Lh2000003D0fMWI00<0
00000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0<@3IfMT2000001P0cZg>00<00000
0<j]cP3>[Lh0:P3>[Lh00`000000cZg>0<j]cP0E0<j]cP800000<`3IfMT00`000000fMWI0=WIf@0Z
0=WIf@006@3IfMT4000000<0fMWI0`0000080=WIf@030000003IfMT0fMWI0300fMWI00<000000<j]
cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0Z0<j]cP030000003>[Lh0cZg>01L0cZg>0P00000a0=WI
f@030000003IfMT0fMWI02X0fMWI000M0=WIf@030000003IfMT0000000<0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@0^0=WIf@800000703>[Lh00`000000cZg>0<j]cP0X0<j]cP03
0000003>[Lh0cZg>01X0cZg>0P00000_0=WIf@030000003IfMT0fMWI02X0fMWI000M0=WIf@030000
003IfMT0000000<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0/0=WIf@800000
7P3>[Lh00`000000cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>01`0cZg>00<000000=WIf@3IfMT0
;03IfMT00`000000fMWI0=WIf@0Z0=WIf@004P3IfMT7000000@0fMWI00<000000=WIf@0000000`3I
fMT00`000000fMWI0=WIf@050=WIf@<00000:P3IfMT200000200cZg>00<000000<j]cP3>[Lh0:03>
[Lh00`000000cZg>0<j]cP0M0<j]cP800000;03IfMT00`000000fMWI0=WIf@0Z0=WIf@007@3IfMT0
0`000000fMWI000000030=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0:03IfMT2
00000280cZg>00<000000<j]cP3>[Lh0:03>[Lh00`000000cZg>0<j]cP0O0<j]cP800000:P3IfMT0
0`000000fMWI0=WIf@0Z0=WIf@006@3IfMT400000080fMWI00D000000=WIf@3IfMT0fMWI00000007
0=WIf@030000003IfMT0fMWI02L0fMWI00<000000<j]cP3>[Lh08`3>[Lh00`000000cZg>0<j]cP0V
0<j]cP030000003>[Lh0cZg>0280cZg>0P00000X0=WIf@030000003IfMT0fMWI02X0fMWI000J0=WI
f@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0
fMWI02D0fMWI0P00000V0<j]cP030000003>[Lh0cZg>02H0cZg>00<000000<j]cP3>[Lh0903>[Lh0
0`000000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI02X0fMWI000J0=WIf@@000000P3IfMT30000
00P0fMWI00<000000=WIf@3IfMT08`3IfMT2000002P0cZg>00<000000<j]cP3>[Lh09P3>[Lh00`00
0000cZg>0<j]cP0U0<j]cP8000009@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000
fMWI0=WIf@0Q0=WIf@800000:`3>[Lh00`000000cZg>0<j]cP0T0<j]cP030000003>[Lh0cZg>02P0
cZg>0P00000S0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01l0fMWI
0P00000]0<j]cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh0:P3>[Lh200000240fMWI
00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000cZg>0<j]
cP0]0<j]cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh0;03>[Lh00`000000fMWI0=WI
f@0N0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01`0fMWI0P00000`
0<j]cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh0;@3>[Lh2000001h0fMWI00<00000
0=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000cZg>0<j]cP0a0<j]
cP030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0<03>[Lh00`000000fMWI0=WIf@0K0=WI
f@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01/0fMWI0P00000b0<j]cP03
0000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0;`3>[Lh2000001d0fMWI00<000000=WIf@3I
fMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT06P3IfMT010000000cZg>0<j]cP00000a0<j]cP03
0000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0;P3>[Lh010000000cZg>0<j]cP00000L0=WI
f@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01X0fMWI00D000000<j]cP3>
[Lh0cZg>0000000`0<j]cP030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0;@3>[Lh01@00
0000cZg>0<j]cP3>[Lh0000001`0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WI
f@3IfMT06@3IfMT00`000000cZg>0<j]cP030<j]cP030000003>[Lh0cZg>02h0cZg>00<000000<j]
cP3>[Lh0803>[Lh00`000000cZg>0<j]cP0]0<j]cP030000003>[Lh0cZg>00<0cZg>00<000000=WI
f@3IfMT0AP3IfMT002/0fMWI00<000000=WIf@3IfMT0603IfMT00`000000cZg>0<j]cP050<j]cP03
0000003>[Lh0cZg>02d0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000cZg>0<j]cP0/0<j]cP03
0000003>[Lh0cZg>00D0cZg>00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0Z0=WIf@00
:`3IfMT00`000000fMWI0=WIf@0H0=WIf@030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>[Lh0
;03>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>02/0cZg>00<000000<j]cP3>[Lh0
1P3>[Lh00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@800000603I
fMT00`000000cZg>0<j]cP080<j]cP030000003>[Lh0cZg>02`0cZg>00<000000<j]cP3>[Lh07P3>
[Lh00`000000cZg>0<j]cP0[0<j]cP030000003>[Lh0cZg>00P0cZg>00<000000=WIf@3IfMT05`3I
fMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003>[Lh0
cZg>00T0cZg>00<000000<j]cP3>[Lh0:`3>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003>[Lh0
cZg>02X0cZg>00<000000<j]cP3>[Lh02@3>[Lh00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0
fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01H0fMWI00<000000<j]cP3>[Lh02`3>[Lh00`00
0000cZg>0<j]cP0Z0<j]cP030000003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh0:@3>[Lh00`00
0000cZg>0<j]cP0;0<j]cP030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0
fMWI00<000000=WIf@3IfMT05P3IfMT00`000000cZg>0<j]cP0<0<j]cP030000003>[Lh0cZg>02T0
cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>00`0
cZg>00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI
0=WIf@0E0=WIf@030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh0:@3>[Lh00`000000cZg>
0<j]cP0L0<j]cP030000003>[Lh0cZg>02P0cZg>00<000000<j]cP3>[Lh03P3>[Lh00`000000fMWI
0=WIf@0E0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01@0fMWI00<0
00000<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>01`0cZg>00<0
00000<j]cP3>[Lh09`3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003IfMT0fMWI01@0fMWI00<0
00000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0503IfMT00`000000cZg>0<j]cP0A
0<j]cP030000003>[Lh0cZg>02L0cZg>00<000000<j]cP3>[Lh0703>[Lh00`000000cZg>0<j]cP0V
0<j]cP030000003>[Lh0cZg>0140cZg>00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0Z
0=WIf@00:`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003>[Lh0cZg>01<0cZg>00<000000<j]
cP3>[Lh09P3>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0cZg>02D0cZg>00<000000<j]
cP3>[Lh04`3>[Lh00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI01<0fMWI00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0V0<j]cP03
0000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000cZg>0<j]cP0D0<j]cP03
0000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0
4P3IfMT00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>02D0cZg>00<000000<j]cP3>[Lh0
6P3>[Lh00`000000cZg>0<j]cP0T0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000=WIf@3IfMT0
4P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003>
[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh0903>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>
[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000fMWI0=WIf@0B0=WIf@030000003I
fMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0140fMWI00<000000<j]cP3>[Lh06@3>[Lh0
0`000000cZg>0<j]cP0S0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh08P3>[Lh0
0`000000cZg>0<j]cP0I0<j]cP030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0:P3IfMT0
02/0fMWI00<000000=WIf@3IfMT0403IfMT00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>
02<0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>
01/0cZg>00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003>[Lh0cZg>01`0cZg>00<000000<j]cP3>[Lh08P3>[Lh00`000000
cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>0240cZg>00<000000<j]cP3>[Lh0703>[Lh00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00l0fMWI
00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0Q0<j]cP030000003>[Lh0cZg>01P0cZg>
00<000000<j]cP3>[Lh0803>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003IfMT0fMWI00l0fMWI
00<000000=WIf@3IfMT0:P3IfMT002/0fMWI0P00000@0=WIf@030000003>[Lh0cZg>01l0cZg>00<0
00000<j]cP3>[Lh08@3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>0200cZg>00<0
00000<j]cP3>[Lh07`3>[Lh00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI02X0fMWI000[
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000<j]cP3>[Lh08@3>[Lh00`000000cZg>0<j]cP0P
0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh07`3>[Lh00`000000cZg>0<j]cP0Q
0<j]cP030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WI
f@3IfMT03P3IfMT00`000000cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>01l0cZg>00<000000<j]
cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003>[Lh0cZg>0280cZg>00<000000=WI
f@3IfMT03P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0=0=WIf@03
0000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0F0<j]cP03
0000003>[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh0903>[Lh00`000000fMWI0=WIf@0=0=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00d0fMWI00<000000<j]cP3>[Lh0
9@3>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003>[Lh0cZg>01@0cZg>00<000000<j]cP3>[Lh0
7@3>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0
:P3IfMT002/0fMWI00<000000=WIf@3IfMT0303IfMT00`000000cZg>0<j]cP0W0<j]cP030000003>
[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003>
[Lh0cZg>02L0cZg>00<000000=WIf@3IfMT0>@3IfMT002/0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000cZg>0<j]cP0Y0<j]cP030000003>[Lh0cZg>01`0cZg>00<000000<j]cP3>[Lh0503>[Lh0
0`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>02T0cZg>00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003>[Lh0cZg>
02X0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>
01X0cZg>00<000000<j]cP3>[Lh0:P3>[Lh00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
02X0fMWI000[0=WIf@030000003IfMT0fMWI00X0fMWI00<000000<j]cP3>[Lh0;03>[Lh00`000000
cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000
cZg>0<j]cP0/0<j]cP030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000cZg>0<j]cP0]0<j]cP030000003>[Lh0cZg>01X0cZg>
00<000000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>02d0cZg>
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WI
f@090=WIf@030000003>[Lh0cZg>02l0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]
cP0B0<j]cP030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0;`3>[Lh00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0<j]cP3>[Lh0<03>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>0100cZg>00<00000
0<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0`0<j]cP030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0203IfMT00`000000cZg>0<j]cP0b0<j]
cP030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0G0<j]
cP030000003>[Lh0cZg>0380cZg>00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0Z0=WI
f@00:`3IfMT00`000000fMWI0=WIf@070=WIf@030000003>[Lh0cZg>03@0cZg>00<000000<j]cP3>
[Lh05`3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>
[Lh0=03>[Lh00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000
003IfMT0fMWI00L0fMWI00<000000<j]cP3>[Lh0=@3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000
003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0e0<j]cP030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000cZg>0<j]cP0g0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh03P3>
[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>03L0cZg>00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT2000000L0fMWI00<000000<j]cP3>[Lh0>03>[Lh0
0`000000cZg>0<j]cP0D0<j]cQ@000005@3>[Lh00`000000cZg>0<j]cP0h0<j]cP030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000cZg>0<j]cP0j0<j]cP030000003>[Lh0cZg>0140cZg>0P00000C0=WIf@8000004`3>[Lh00`00
0000cZg>0<j]cP0j0<j]cP030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000cZg>0<j]cP0k0<j]cP030000003>[Lh0cZg>00l0
cZg>00<000000=WIf@3IfMT05@3IfMT200000100cZg>00<000000<j]cP3>[Lh0>`3>[Lh00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000<j]cP3>[Lh0?@3>[Lh00`000000cZg>0<j]cP0<0<j]cP8000006@3IfMT2000000h0cZg>
00<000000<j]cP3>[Lh0?@3>[Lh00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02X0fMWI
000[0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0?`3>[Lh00`000000cZg>0<j]
cP090<j]cP8000007@3IfMT2000000/0cZg>00<000000<j]cP3>[Lh0?`3>[Lh00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0<j]cP3>[Lh0@03>[Lh00`000000cZg>0<j]cP070<j]cP030000003IfMT0fMWI01l0fMWI0P000008
0<j]cP030000003>[Lh0cZg>0400cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0Z
0=WIf@00:`3IfMT00`000000fMWI0=WIf@020=WIf@<00000@P3>[Lh00`000000cZg>0<j]cP040<j]
cP8000008`3IfMT2000000H0cZg>00<000000<j]cP3>[Lh0@03>[Lh3000000@0fMWI00<000000=WI
f@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP04000003l0
cZg>00@000000<j]cP3>[Lh0cZg>0P00000W0=WIf@8000000`3>[Lh00`000000cZg>0<j]cP0m0<j]
cP@000000P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0103>[Lh3000003d0cZg>00<000000<j]cP00
0000:`3IfMT00`000000cZg>0000000m0<j]cP<000001P3>[Lh00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0
1`3>[Lh4000003X0cZg>00<000000=WIf@3IfMT0:`3IfMT00`000000cZg>0<j]cP0h0<j]cP@00000
2@3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003I
fMT0fMWI0080fMWI00<000000<j]cP3>[Lh02`3>[Lh4000003H0cZg>00<000000=WIf@3IfMT0:`3I
fMT00`000000cZg>0<j]cP0d0<j]cP@000003@3>[Lh00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh03`3>[Lh3
00000380cZg>00<000000=WIf@3IfMT0;@3IfMT00`000000cZg>0<j]cP0`0<j]cP<000004@3>[Lh0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI
0080fMWI00<000000<j]cP3>[Lh04P3>[Lh4000002d0cZg>00<000000=WIf@3IfMT0;`3IfMT00`00
0000cZg>0<j]cP0[0<j]cP@00000503>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh05P3>[Lh4000002T0
cZg>00<000000=WIf@3IfMT0;`3IfMT00`000000cZg>0<j]cP0W0<j]cP@00000603>[Lh00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI
00<000000<j]cP3>[Lh06P3>[Lh4000002@0cZg>00<000000=WIf@3IfMT0<@3IfMT00`000000cZg>
0<j]cP0R0<j]cP@00000703>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI
000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh07P3>[Lh300000200cZg>0P00
000c0=WIf@800000803>[Lh300000200cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0Z0=WIf@00:`3IfMT2000000<0fMWI00<000000<j]cP3>[Lh08@3>[Lh4000001`0cZg>00<00000
0=WIf@3IfMT0<`3IfMT00`000000cZg>0<j]cP0J0<j]cP@000008`3>[Lh00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]
cP3>[Lh09@3>[Lh4000001L0cZg>00<000000=WIf@3IfMT0=@3IfMT00`000000cZg>0<j]cP0E0<j]
cP@000009`3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0:@3>[Lh3000001@0cZg>00<000000=WIf@3I
fMT0=@3IfMT00`000000cZg>0<j]cP0B0<j]cP<00000:`3>[Lh00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0
;03>[Lh4000000l0cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>0<j]cP0=0<j]cP@00000
;P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003I
fMT0fMWI0080fMWI00<000000<j]cP3>[Lh0<03>[Lh4000000X0cZg>0P00000i0=WIf@8000002P3>
[Lh400000380cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>03@0cZg>0`0000070<j]cP030000003IfMT0
fMWI03T0fMWI00<000000<j]cP3>[Lh01@3>[Lh3000003H0cZg>00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>
03L0cZg>100000020<j]cP030000003IfMT0fMWI03/0fMWI00<000000<j]cP3>[Lh01000000i0<j]
cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000cZg>0<j]cP0k0<j]cP<00000?@3IfMT3000003d0cZg>00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT0?@3IfMT00`000000cZg>0<j]cP0l0<j]cP030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI03d0fMWI00<000000<j]cP3>[Lh0?03>
[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0
fMWI0080fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@0m0=WIf@030000003>[Lh0
cZg>03`0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT0?@3IfMT00`00
0000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI03d0
fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0
fMWI000;0=WIf@<000004`3IfMT3000000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>
0<j]cP0l0<j]cP030000003IfMT0fMWI03d0fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000<0=WIf@030000003IfMT0fMWI0140fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0
?03>[Lh00`000000fMWI0=WIf@0m0=WIf@030000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00303IfMT00`000000fMWI0=WIf@0A0=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>03`0cZg>
00<000000=WIf@3IfMT0?@3IfMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0:P3IfMT000`0fMWI00<000000=WIf@3IfMT04@3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI0`0000020=WIf@030000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT0
?@3IfMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
:P3IfMT000/0fMWI00<000000=WIf@0000004P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI03d0fMWI
00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI
000;0=WIf@030000003IfMT000000180fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000
003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@0m0=WIf@030000
003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@002P3I
fMT01@000000fMWI0=WIf@3IfMT000000140fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@0m0=WIf@03
0000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00
2@3IfMT3000000040=WIf@000000000000000140fMWI0`0000070=WIf@030000003IfMT0fMWI0080
fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@0m0=WIf@030000003>[Lh0cZg>03`0
cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT0?@3IfMT00`000000cZg>
0<j]cP0l0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0l0<j]cP030000003IfMT0fMWI03d0fMWI00<0
00000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[
0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0?03>[Lh00`000000fMWI0=WIf@0m
0=WIf@030000003>[Lh0cZg>03`0cZg>00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Z
0=WIf@00:`3IfMT00`000000fMWI0=WIf@020=WIf@030000003>[Lh0cZg>03X0cZg>1000000n0=WI
f@<00000?03>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0=P3>[Lh400000080cZg>00<000000=WIf@3I
fMT0?@3IfMT30<j]cP@00000>03>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0
fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0<`3>[Lh3000000L0cZg>
00<000000=WIf@3IfMT0>`3IfMT00`000000cZg>0<j]cP050<j]cP<00000=@3>[Lh00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000<j]cP3>[Lh0;`3>[Lh4000000/0cZg>00<000000=WIf@3IfMT0>@3IfMT00`000000cZg>0<j]
cP090<j]cP@00000<@3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[
0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0:`3>[Lh4000000l0cZg>00<00000
0=WIf@3IfMT0>@3IfMT00`000000cZg>0<j]cP0=0<j]cP@00000;@3>[Lh00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]
cP3>[Lh0:03>[Lh3000001@0cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>0<j]cP0B0<j]
cP<00000:P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0903>[Lh4000001L0cZg>00<000000=WIf@3I
fMT0=`3IfMT00`000000cZg>0<j]cP0E0<j]cP@000009P3>[Lh00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0080fMWI00<000000<j]cP3>[Lh0
803>[Lh4000001`0cZg>00<000000=WIf@3IfMT0=@3IfMT00`000000cZg>0<j]cP0J0<j]cP@00000
8P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@8000000`3I
fMT00`000000cZg>0<j]cP0L0<j]cP@000008@3>[Lh00`000000fMWI0=WIf@0c0=WIf@030000003>
[Lh0cZg>01l0cZg>1000000N0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3I
fMT002/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0I0<j]cP<000009@3>[Lh0
0`000000fMWI0=WIf@0c0=WIf@030000003>[Lh0cZg>02<0cZg>0`00000K0<j]cP030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000cZg>0<j]cP0E0<j]cP@00000:@3>[Lh00`000000fMWI0=WIf@0a0=WIf@030000003>[Lh0cZg>
02L0cZg>1000000G0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0A0<j]cP@00000;@3>[Lh00`000000
fMWI0=WIf@0a0=WIf@030000003>[Lh0cZg>02/0cZg>1000000C0<j]cP030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>
0<j]cP0>0<j]cP<00000<P3>[Lh00`000000fMWI0=WIf@0_0=WIf@030000003>[Lh0cZg>0300cZg>
0`00000@0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP0:0<j]cP@00000=P3>[Lh00`000000fMWI0=WI
f@0]0=WIf@030000003>[Lh0cZg>03@0cZg>1000000<0<j]cP030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000cZg>0<j]cP06
0<j]cP@00000>P3>[Lh00`000000fMWI0=WIf@0]0=WIf@030000003>[Lh0cZg>03P0cZg>10000008
0<j]cP030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000cZg>0<j]cP030<j]cP<00000?`3>[Lh2000002/0fMWI0P00000o0<j]
cP<000001@3>[Lh00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000<j]cP0000000`0000110<j]cP030000003>[Lh0cZg>0080
00009`3IfMT200000080cZg>00<000000<j]cP3>[Lh0?`3>[Lh300000080cZg>00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@020=WIf@800000
A03>[Lh00`000000cZg>0<j]cP030<j]cP030000003IfMT0fMWI02<0fMWI0P0000040<j]cP030000
003>[Lh0cZg>0480cZg>0P0000040=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003I
fMT0fMWI0080fMWI00<000000<j]cP3>[Lh0@P3>[Lh00`000000cZg>0<j]cP050<j]cP8000008@3I
fMT2000000L0cZg>00<000000<j]cP3>[Lh0@P3>[Lh00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0@03>[Lh0
0`000000cZg>0<j]cP080<j]cP8000007@3IfMT3000000T0cZg>00<000000<j]cP3>[Lh0@03>[Lh0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000<j]cP3>[Lh0?`3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003IfMT0fMWI
01T0fMWI0P00000<0<j]cP030000003>[Lh0cZg>03l0cZg>00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@040=WIf@030000003>[Lh0cZg>03d0
cZg>00<000000<j]cP3>[Lh03@3>[Lh2000001L0fMWI0P00000?0<j]cP030000003>[Lh0cZg>03d0
cZg>00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI
0=WIf@050=WIf@030000003>[Lh0cZg>03/0cZg>00<000000<j]cP3>[Lh0403>[Lh2000001<0fMWI
0`00000A0<j]cP030000003>[Lh0cZg>03/0cZg>00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@050=WIf@030000003>[Lh0cZg>03X0cZg>00<0
00000<j]cP3>[Lh04`3>[Lh200000100fMWI0P00000D0<j]cP030000003>[Lh0cZg>03X0cZg>00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT2000000L0fMWI00<00000
0<j]cP3>[Lh0>03>[Lh00`000000cZg>0<j]cP0E0<j]cQ8000005P3>[Lh00`000000cZg>0<j]cP0h
0<j]cP030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000cZg>0<j]cP0g0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]
cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>03L0cZg>00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003>[Lh0cZg>03D0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0>0<j]cP03
0000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh0=@3>[Lh00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00L0fMWI00<000000<j]cP3>[Lh0
=03>[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0
5P3>[Lh00`000000cZg>0<j]cP0d0<j]cP030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
:P3IfMT002/0fMWI00<000000=WIf@3IfMT0203IfMT00`000000cZg>0<j]cP0b0<j]cP030000003>
[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>
[Lh0cZg>0380cZg>00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT0
0`000000fMWI0=WIf@080=WIf@030000003>[Lh0cZg>0340cZg>00<000000<j]cP3>[Lh06@3>[Lh0
0`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0<@3>[Lh0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI
00T0fMWI00<000000<j]cP3>[Lh0;`3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>
0100cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0_0<j]cP030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
cZg>0<j]cP0]0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh04P3>[Lh00`000000
cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>02d0cZg>00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003>[Lh0cZg>02`0cZg>
00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>01X0cZg>
00<000000<j]cP3>[Lh0;03>[Lh00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI02X0fMWI
000[0=WIf@030000003IfMT0fMWI00/0fMWI00<000000<j]cP3>[Lh0:P3>[Lh00`000000cZg>0<j]
cP0L0<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]
cP0Z0<j]cP030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000cZg>0<j]cP0Y0<j]cP030000003>[Lh0cZg>01`0cZg>00<00000
0<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>02T0cZg>00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0<0=WI
f@030000003>[Lh0cZg>02L0cZg>00<000000<j]cP3>[Lh07@3>[Lh00`000000cZg>0<j]cP0D0<j]
cP030000003>[Lh0cZg>01`0cZg>00<000000<j]cP3>[Lh09`3>[Lh00`000000fMWI0=WIf@0<0=WI
f@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI00`0fMWI00<000000<j]cP3>
[Lh09P3>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003>[Lh0cZg>01@0cZg>00<000000<j]cP3>
[Lh07@3>[Lh00`000000cZg>0<j]cP0V0<j]cP030000003IfMT0fMWI00`0fMWI00<000000=WIf@3I
fMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000cZg>0<j]cP0T0<j]cP030000
003>[Lh0cZg>01l0cZg>00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0N0<j]cP030000
003>[Lh0cZg>02@0cZg>00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3I
fMT00`000000fMWI0=WIf@0=0=WIf@030000003>[Lh0cZg>02<0cZg>00<000000<j]cP3>[Lh07`3>
[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh08`3>
[Lh00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0
fMWI00h0fMWI00<000000<j]cP3>[Lh08@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0
cZg>01H0cZg>00<000000<j]cP3>[Lh07`3>[Lh00`000000cZg>0<j]cP0Q0<j]cP030000003IfMT0
fMWI00h0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI0P00000@0=WIf@030000003>[Lh0cZg>
01l0cZg>00<000000<j]cP3>[Lh08@3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>
0200cZg>00<000000<j]cP3>[Lh07`3>[Lh00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI
02X0fMWI000[0=WIf@030000003IfMT0fMWI00l0fMWI00<000000<j]cP3>[Lh07P3>[Lh00`000000
cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh08@3>[Lh00`000000
cZg>0<j]cP0N0<j]cP030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI
00<000000=WIf@3IfMT0403IfMT00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0cZg>0280cZg>
00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0Q0<j]cP030000003>[Lh0cZg>01`0cZg>
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WI
f@0@0=WIf@030000003>[Lh0cZg>01/0cZg>00<000000<j]cP3>[Lh08`3>[Lh00`000000cZg>0<j]
cP0H0<j]cP030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000fMWI0=WI
f@0@0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI0140fMWI00<00000
0<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0T0<j]cP030000003>[Lh0cZg>01P0cZg>00<00000
0<j]cP3>[Lh08`3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003IfMT0fMWI0140fMWI00<00000
0=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000cZg>0<j]cP0H0<j]
cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP0S0<j]
cP030000003>[Lh0cZg>01P0cZg>00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0Z0=WI
f@00:`3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>
[Lh09@3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>
[Lh05P3>[Lh00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000
003IfMT0fMWI0180fMWI00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0V0<j]cP030000
003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000
003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT04`3I
fMT00`000000cZg>0<j]cP0C0<j]cP030000003>[Lh0cZg>02L0cZg>00<000000<j]cP3>[Lh06P3>
[Lh00`000000cZg>0<j]cP0V0<j]cP030000003>[Lh0cZg>01<0cZg>00<000000=WIf@3IfMT04`3I
fMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003>[Lh0
cZg>0140cZg>00<000000<j]cP3>[Lh09`3>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0
cZg>02H0cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0
fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01@0fMWI00<000000<j]cP3>[Lh0403>[Lh00`00
0000cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>01`0cZg>00<000000<j]cP3>[Lh09`3>[Lh00`00
0000cZg>0<j]cP0@0<j]cP030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0
fMWI00<000000=WIf@3IfMT05@3IfMT00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>02T0
cZg>00<000000<j]cP3>[Lh0703>[Lh00`000000cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>00h0
cZg>00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI
0=WIf@0E0=WIf@030000003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh0:P3>[Lh00`000000cZg>
0<j]cP0L0<j]cP030000003>[Lh0cZg>02T0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000fMWI
0=WIf@0E0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01H0fMWI00<0
00000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP0Z0<j]cP030000003>[Lh0cZg>01h0cZg>00<0
00000<j]cP3>[Lh0:@3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003IfMT0fMWI01H0fMWI00<0
00000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000cZg>0<j]cP0:
0<j]cP030000003>[Lh0cZg>02/0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0Z
0<j]cP030000003>[Lh0cZg>00X0cZg>00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0Z
0=WIf@00:`3IfMT2000001P0fMWI00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP0/0<j]
cP030000003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh0:`3>[Lh00`000000cZg>0<j]cP080<j]
cP030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3I
fMT05`3IfMT00`000000cZg>0<j]cP070<j]cP030000003>[Lh0cZg>02`0cZg>00<000000<j]cP3>
[Lh0803>[Lh00`000000cZg>0<j]cP0[0<j]cP030000003>[Lh0cZg>00L0cZg>00<000000=WIf@3I
fMT05`3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0H0=WIf@030000
003>[Lh0cZg>00D0cZg>00<000000<j]cP3>[Lh0;@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000
003>[Lh0cZg>02`0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000fMWI0=WIf@0H0=WIf@030000
003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01T0fMWI00<000000<j]cP3>[Lh00`3>
[Lh00`000000cZg>0<j]cP0^0<j]cP030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh0;@3>
[Lh00`000000cZg>0<j]cP030<j]cP030000003IfMT0fMWI04H0fMWI000[0=WIf@030000003IfMT0
fMWI01T0fMWI00<000000<j]cP3>[Lh00P3>[Lh00`000000cZg>0<j]cP0_0<j]cP030000003>[Lh0
cZg>0200cZg>00<000000<j]cP3>[Lh0;P3>[Lh00`000000cZg>0<j]cP020<j]cP030000003IfMT0
fMWI01T0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT06P3IfMT01000
0000cZg>0<j]cP00000a0<j]cP030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0<@3>[Lh0
0`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI
01X0fMWI00<000000<j]cP000000<P3>[Lh00`000000cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>
0340cZg>00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000
fMWI0=WIf@0K0=WIf@800000<P3>[Lh00`000000cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>02l0
cZg>0P00000M0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI01d0fMWI
0P00000`0<j]cP030000003>[Lh0cZg>0280cZg>00<000000<j]cP3>[Lh0;@3>[Lh2000001l0fMWI
00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT07`3IfMT2000002d0cZg>00<0
00000<j]cP3>[Lh0903>[Lh00`000000cZg>0<j]cP0[0<j]cP030000003IfMT0fMWI01l0fMWI00<0
00000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000cZg>0<j]cP0Z
0<j]cP030000003>[Lh0cZg>02@0cZg>00<000000<j]cP3>[Lh0:@3>[Lh200000280fMWI00<00000
0=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT08P3IfMT2000002X0cZg>00<000000<j]
cP3>[Lh0903>[Lh00`000000cZg>0<j]cP0W0<j]cP800000903IfMT00`000000fMWI0=WIf@0Z0=WI
f@00:`3IfMT00`000000fMWI0=WIf@0T0=WIf@800000:03>[Lh00`000000cZg>0<j]cP0T0<j]cP03
0000003>[Lh0cZg>02D0cZg>0P00000V0=WIf@030000003IfMT0fMWI02X0fMWI000J0=WIf@@00000
0`3IfMT3000000L0fMWI00<000000=WIf@3IfMT09P3IfMT2000002D0cZg>00<000000<j]cP3>[Lh0
9P3>[Lh00`000000cZg>0<j]cP0S0<j]cP030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0
:P3IfMT001h0fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI02P0fMWI0P00000S0<j]cP030000003>[Lh0cZg>02H0cZg>00<000000<j]cP3>[Lh08@3>
[Lh2000002T0fMWI00<000000=WIf@3IfMT0:P3IfMT001h0fMWI00<000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02X0fMWI00<000000<j]cP3>[Lh0803>[Lh0
0`000000cZg>0<j]cP0V0<j]cP030000003>[Lh0cZg>01l0cZg>0P00000[0=WIf@030000003IfMT0
fMWI02X0fMWI000N0=WIf@030000003IfMT0000000<0fMWI00<000000=WIf@3IfMT0103IfMT30000
02/0fMWI0P00000O0<j]cP030000003>[Lh0cZg>02P0cZg>00<000000<j]cP3>[Lh0703>[Lh20000
02d0fMWI00<000000=WIf@3IfMT0:P3IfMT001h0fMWI00<000000=WIf@0000000`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI02d0fMWI0P00000M0<j]cP030000003>[Lh0cZg>02P0
cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI02X0
fMWI000J0=WIf@@000000P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT0;`3IfMT2000001/0cZg>00<000000<j]cP3>[Lh0:03>[Lh00`000000cZg>0<j]cP0I0<j]cP80
0000<03IfMT00`000000fMWI0=WIf@0Z0=WIf@006`3IfMT00`000000fMWI0=WIf@020=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@0a0=WIf@8000006@3>[Lh00`000000
cZg>0<j]cP0X0<j]cP030000003>[Lh0cZg>01L0cZg>0P00000b0=WIf@030000003IfMT0fMWI02X0
fMWI000K0=WIf@@000000P3IfMT3000000L0fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000cZg>
0<j]cP0E0<j]cP030000003>[Lh0cZg>02X0cZg>00<000000<j]cP3>[Lh0503>[Lh2000003@0fMWI
00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0=03IfMT2000001D0cZg>00<0
00000<j]cP3>[Lh0:P3>[Lh00`000000cZg>0<j]cP0B0<j]cP800000=P3IfMT00`000000fMWI0=WI
f@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@0f0=WIf@8000004`3>[Lh00`000000cZg>0<j]cP0Z
0<j]cP030000003>[Lh0cZg>0140cZg>00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@0Z
0=WIf@00:`3IfMT00`000000fMWI0=WIf@0h0=WIf@8000004@3>[Lh00`000000cZg>0<j]cP0Z0<j]
cP030000003>[Lh0cZg>00l0cZg>0P00000i0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@03
0000003IfMT0fMWI03X0fMWI0P00000>0<j]cP030000003>[Lh0cZg>02`0cZg>00<000000<j]cP3>
[Lh0303>[Lh2000003/0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0
?03IfMT00`000000cZg>0<j]cP0;0<j]cP030000003>[Lh0cZg>02`0cZg>00<000000<j]cP3>[Lh0
2P3>[Lh2000003d0fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI00<000000=WIf@3IfMT0?@3I
fMT2000000/0cZg>00<000000<j]cP3>[Lh0;03>[Lh00`000000cZg>0<j]cP090<j]cP030000003I
fMT0fMWI06X0fMWI000[0=WIf@030000003IfMT0fMWI03l0fMWI0P0000080<j]cP030000003>[Lh0
cZg>02h0cZg>00<000000<j]cP3>[Lh01P3>[Lh200000400fMWI00<000000=WIf@3IfMT0:P3IfMT0
02/0fMWI00<000000=WIf@3IfMT0@@3IfMT2000000H0cZg>00<000000<j]cP3>[Lh0;P3>[Lh00`00
0000cZg>0<j]cP040<j]cP800000@P3IfMT00`000000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000
fMWI0=WIf@130=WIf@800000103>[Lh00`000000cZg>0<j]cP0^0<j]cP030000003>[Lh0cZg>0080
cZg>0P0000140=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI04D0fMWI
00D000000<j]cP3>[Lh0cZg>0000000`0<j]cP050000003>[Lh0cZg>0<j]cP000000AP3IfMT00`00
0000fMWI0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@160=WIf@<00000<`3>[Lh2000004L0
fMWI00<000000=WIf@3IfMT0:P3IfMT002/0fMWI0P0000190=WIfC@00000B@3IfMT00`000000fMWI
0=WIf@0Z0=WIf@00:`3IfMT00`000000fMWI0=WIf@350=WIf@030000003IfMT0fMWI02X0fMWI000[
0=WIf@030000003IfMT0fMWI0<D0fMWI00<000000=WIf@3IfMT00`3IfMT500000080fMWI0`000007
0=WIf@H00000403IfMT002/0fMWI00<000000=WIf@3IfMT0a@3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0080000000<0fMWI0000003IfMT00P3IfMT00`000000fMWI0=WIf@050=WI
f@050000003IfMT0fMWI0=WIf@000000403IfMT002/0fMWI00<000000=WIf@3IfMT0a@3IfMT00`00
0000fMWI0=WIf@030=WIf@80000000D0fMWI000000000000fMWI000000030=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT04P3IfMT002/0fMWI2`0000000`3IfMT000000000000D0000
00030=WIf@000000000006X0000000<0fMWI000000000000500000000`3IfMT000000000000P0000
00D0fMWI00<000000=WIf@0000000P0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT04@3IfMT00?T0fMWI1@0000000`3IfMT000000=WIf@020=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0403IfMT00?T0fMWI00<000000=WIf@3IfMT0
0P0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
3`3IfMT00?T0fMWI00<000000=WIf@3IfMT00P0000000`3IfMT000000=WIf@020=WIf@030000003I
fMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000000A0=WIf@00nP3IfMT3000000<0fMWI0`00
00070=WIf@H00000403IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI8@3IfMT00?l0fMWI
8@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, 
  0.00348436, 0.00348436}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the field along x axis", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T3 = 
      Table[{x, radFld[cyl3, "\<By\>", {x, 0, Lz/2.}]}, {x, \(-rint\)*0.9, 
          rint*0.9, 1}]; \n
    MultipleListPlot[T3, PlotJoined \[Rule] {True, True}, \n\t\t
      PlotRange \[Rule] All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.026455 0.603319 0.670709 [
[.10317 .59082 -12.5 -14 ]
[.10317 .59082 12.5 0 ]
[.23545 .59082 -12.5 -14 ]
[.23545 .59082 12.5 0 ]
[.36772 .59082 -9.5 -14 ]
[.36772 .59082 9.5 0 ]
[.63228 .59082 -5 -14 ]
[.63228 .59082 5 0 ]
[.76455 .59082 -8 -14 ]
[.76455 .59082 8 0 ]
[.89683 .59082 -8 -14 ]
[.89683 .59082 8 0 ]
[.4875 .06675 -29 -7 ]
[.4875 .06675 0 7 ]
[.4875 .20089 -29 -7 ]
[.4875 .20089 0 7 ]
[.4875 .33504 -29 -7 ]
[.4875 .33504 0 7 ]
[.4875 .46918 -29 -7 ]
[.4875 .46918 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .60332 m
.10317 .60957 L
s
gsave
.10317 .59082 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.23545 .60332 m
.23545 .60957 L
s
gsave
.23545 .59082 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.36772 .60332 m
.36772 .60957 L
s
gsave
.36772 .59082 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.63228 .60332 m
.63228 .60957 L
s
gsave
.63228 .59082 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76455 .60332 m
.76455 .60957 L
s
gsave
.76455 .59082 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.89683 .60332 m
.89683 .60957 L
s
gsave
.89683 .59082 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.12963 .60332 m
.12963 .60707 L
s
.15608 .60332 m
.15608 .60707 L
s
.18254 .60332 m
.18254 .60707 L
s
.20899 .60332 m
.20899 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.28836 .60332 m
.28836 .60707 L
s
.31481 .60332 m
.31481 .60707 L
s
.34127 .60332 m
.34127 .60707 L
s
.39418 .60332 m
.39418 .60707 L
s
.42063 .60332 m
.42063 .60707 L
s
.44709 .60332 m
.44709 .60707 L
s
.47354 .60332 m
.47354 .60707 L
s
.52646 .60332 m
.52646 .60707 L
s
.55291 .60332 m
.55291 .60707 L
s
.57937 .60332 m
.57937 .60707 L
s
.60582 .60332 m
.60582 .60707 L
s
.65873 .60332 m
.65873 .60707 L
s
.68519 .60332 m
.68519 .60707 L
s
.71164 .60332 m
.71164 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.79101 .60332 m
.79101 .60707 L
s
.81746 .60332 m
.81746 .60707 L
s
.84392 .60332 m
.84392 .60707 L
s
.87037 .60332 m
.87037 .60707 L
s
.07672 .60332 m
.07672 .60707 L
s
.05026 .60332 m
.05026 .60707 L
s
.02381 .60332 m
.02381 .60707 L
s
.92328 .60332 m
.92328 .60707 L
s
.94974 .60332 m
.94974 .60707 L
s
.97619 .60332 m
.97619 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.5 .06675 m
.50625 .06675 L
s
gsave
.4875 .06675 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .20089 m
.50625 .20089 L
s
gsave
.4875 .20089 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .33504 m
.50625 .33504 L
s
gsave
.4875 .33504 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .46918 m
.50625 .46918 L
s
gsave
.4875 .46918 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.5 .10029 m
.50375 .10029 L
s
.5 .13382 m
.50375 .13382 L
s
.5 .16736 m
.50375 .16736 L
s
.5 .23443 m
.50375 .23443 L
s
.5 .26796 m
.50375 .26796 L
s
.5 .3015 m
.50375 .3015 L
s
.5 .36857 m
.50375 .36857 L
s
.5 .40211 m
.50375 .40211 L
s
.5 .43564 m
.50375 .43564 L
s
.5 .50271 m
.50375 .50271 L
s
.5 .53625 m
.50375 .53625 L
s
.5 .56978 m
.50375 .56978 L
s
.5 .03322 m
.50375 .03322 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.001 w
.02381 .01472 m
.05026 .07347 L
.07672 .13278 L
.10317 .19033 L
.12963 .24479 L
.15608 .29553 L
.18254 .34229 L
.20899 .385 L
.23545 .42369 L
.2619 .45841 L
.28836 .48925 L
.31481 .51628 L
.34127 .53956 L
.36772 .55915 L
.39418 .57511 L
.42063 .58748 L
.44709 .59629 L
.47354 .60156 L
.5 .60332 L
.52646 .60156 L
.55291 .59629 L
.57937 .58748 L
.60582 .57511 L
.63228 .55915 L
.65873 .53956 L
.68519 .51628 L
.71164 .48925 L
.7381 .45841 L
.76455 .42369 L
.79101 .385 L
.81746 .34229 L
.84392 .29553 L
.87037 .24479 L
.89683 .19033 L
.92328 .13278 L
.94974 .07347 L
.97619 .01472 L
s
.0001 w
.02381 .01472 -1.875 0 Mabsadd m
.02381 .01472 0 2.5 Mabsadd L
.02381 .01472 1.875 0 Mabsadd L
.02381 .01472 0 -2.5 Mabsadd L
.02381 .01472 -1.875 0 Mabsadd L closepath F
.05026 .07347 -1.875 0 Mabsadd m
.05026 .07347 0 2.5 Mabsadd L
.05026 .07347 1.875 0 Mabsadd L
.05026 .07347 0 -2.5 Mabsadd L
.05026 .07347 -1.875 0 Mabsadd L closepath F
.07672 .13278 -1.875 0 Mabsadd m
.07672 .13278 0 2.5 Mabsadd L
.07672 .13278 1.875 0 Mabsadd L
.07672 .13278 0 -2.5 Mabsadd L
.07672 .13278 -1.875 0 Mabsadd L closepath F
.10317 .19033 -1.875 0 Mabsadd m
.10317 .19033 0 2.5 Mabsadd L
.10317 .19033 1.875 0 Mabsadd L
.10317 .19033 0 -2.5 Mabsadd L
.10317 .19033 -1.875 0 Mabsadd L closepath F
.12963 .24479 -1.875 0 Mabsadd m
.12963 .24479 0 2.5 Mabsadd L
.12963 .24479 1.875 0 Mabsadd L
.12963 .24479 0 -2.5 Mabsadd L
.12963 .24479 -1.875 0 Mabsadd L closepath F
.15608 .29553 -1.875 0 Mabsadd m
.15608 .29553 0 2.5 Mabsadd L
.15608 .29553 1.875 0 Mabsadd L
.15608 .29553 0 -2.5 Mabsadd L
.15608 .29553 -1.875 0 Mabsadd L closepath F
.18254 .34229 -1.875 0 Mabsadd m
.18254 .34229 0 2.5 Mabsadd L
.18254 .34229 1.875 0 Mabsadd L
.18254 .34229 0 -2.5 Mabsadd L
.18254 .34229 -1.875 0 Mabsadd L closepath F
.20899 .385 -1.875 0 Mabsadd m
.20899 .385 0 2.5 Mabsadd L
.20899 .385 1.875 0 Mabsadd L
.20899 .385 0 -2.5 Mabsadd L
.20899 .385 -1.875 0 Mabsadd L closepath F
.23545 .42369 -1.875 0 Mabsadd m
.23545 .42369 0 2.5 Mabsadd L
.23545 .42369 1.875 0 Mabsadd L
.23545 .42369 0 -2.5 Mabsadd L
.23545 .42369 -1.875 0 Mabsadd L closepath F
.2619 .45841 -1.875 0 Mabsadd m
.2619 .45841 0 2.5 Mabsadd L
.2619 .45841 1.875 0 Mabsadd L
.2619 .45841 0 -2.5 Mabsadd L
.2619 .45841 -1.875 0 Mabsadd L closepath F
.28836 .48925 -1.875 0 Mabsadd m
.28836 .48925 0 2.5 Mabsadd L
.28836 .48925 1.875 0 Mabsadd L
.28836 .48925 0 -2.5 Mabsadd L
.28836 .48925 -1.875 0 Mabsadd L closepath F
.31481 .51628 -1.875 0 Mabsadd m
.31481 .51628 0 2.5 Mabsadd L
.31481 .51628 1.875 0 Mabsadd L
.31481 .51628 0 -2.5 Mabsadd L
.31481 .51628 -1.875 0 Mabsadd L closepath F
.34127 .53956 -1.875 0 Mabsadd m
.34127 .53956 0 2.5 Mabsadd L
.34127 .53956 1.875 0 Mabsadd L
.34127 .53956 0 -2.5 Mabsadd L
.34127 .53956 -1.875 0 Mabsadd L closepath F
.36772 .55915 -1.875 0 Mabsadd m
.36772 .55915 0 2.5 Mabsadd L
.36772 .55915 1.875 0 Mabsadd L
.36772 .55915 0 -2.5 Mabsadd L
.36772 .55915 -1.875 0 Mabsadd L closepath F
.39418 .57511 -1.875 0 Mabsadd m
.39418 .57511 0 2.5 Mabsadd L
.39418 .57511 1.875 0 Mabsadd L
.39418 .57511 0 -2.5 Mabsadd L
.39418 .57511 -1.875 0 Mabsadd L closepath F
.42063 .58748 -1.875 0 Mabsadd m
.42063 .58748 0 2.5 Mabsadd L
.42063 .58748 1.875 0 Mabsadd L
.42063 .58748 0 -2.5 Mabsadd L
.42063 .58748 -1.875 0 Mabsadd L closepath F
.44709 .59629 -1.875 0 Mabsadd m
.44709 .59629 0 2.5 Mabsadd L
.44709 .59629 1.875 0 Mabsadd L
.44709 .59629 0 -2.5 Mabsadd L
.44709 .59629 -1.875 0 Mabsadd L closepath F
.47354 .60156 -1.875 0 Mabsadd m
.47354 .60156 0 2.5 Mabsadd L
.47354 .60156 1.875 0 Mabsadd L
.47354 .60156 0 -2.5 Mabsadd L
.47354 .60156 -1.875 0 Mabsadd L closepath F
.5 .60332 -1.875 0 Mabsadd m
.5 .60332 0 2.5 Mabsadd L
.5 .60332 1.875 0 Mabsadd L
.5 .60332 0 -2.5 Mabsadd L
.5 .60332 -1.875 0 Mabsadd L closepath F
.52646 .60156 -1.875 0 Mabsadd m
.52646 .60156 0 2.5 Mabsadd L
.52646 .60156 1.875 0 Mabsadd L
.52646 .60156 0 -2.5 Mabsadd L
.52646 .60156 -1.875 0 Mabsadd L closepath F
.55291 .59629 -1.875 0 Mabsadd m
.55291 .59629 0 2.5 Mabsadd L
.55291 .59629 1.875 0 Mabsadd L
.55291 .59629 0 -2.5 Mabsadd L
.55291 .59629 -1.875 0 Mabsadd L closepath F
.57937 .58748 -1.875 0 Mabsadd m
.57937 .58748 0 2.5 Mabsadd L
.57937 .58748 1.875 0 Mabsadd L
.57937 .58748 0 -2.5 Mabsadd L
.57937 .58748 -1.875 0 Mabsadd L closepath F
.60582 .57511 -1.875 0 Mabsadd m
.60582 .57511 0 2.5 Mabsadd L
.60582 .57511 1.875 0 Mabsadd L
.60582 .57511 0 -2.5 Mabsadd L
.60582 .57511 -1.875 0 Mabsadd L closepath F
.63228 .55915 -1.875 0 Mabsadd m
.63228 .55915 0 2.5 Mabsadd L
.63228 .55915 1.875 0 Mabsadd L
.63228 .55915 0 -2.5 Mabsadd L
.63228 .55915 -1.875 0 Mabsadd L closepath F
.65873 .53956 -1.875 0 Mabsadd m
.65873 .53956 0 2.5 Mabsadd L
.65873 .53956 1.875 0 Mabsadd L
.65873 .53956 0 -2.5 Mabsadd L
.65873 .53956 -1.875 0 Mabsadd L closepath F
.68519 .51628 -1.875 0 Mabsadd m
.68519 .51628 0 2.5 Mabsadd L
.68519 .51628 1.875 0 Mabsadd L
.68519 .51628 0 -2.5 Mabsadd L
.68519 .51628 -1.875 0 Mabsadd L closepath F
.71164 .48925 -1.875 0 Mabsadd m
.71164 .48925 0 2.5 Mabsadd L
.71164 .48925 1.875 0 Mabsadd L
.71164 .48925 0 -2.5 Mabsadd L
.71164 .48925 -1.875 0 Mabsadd L closepath F
.7381 .45841 -1.875 0 Mabsadd m
.7381 .45841 0 2.5 Mabsadd L
.7381 .45841 1.875 0 Mabsadd L
.7381 .45841 0 -2.5 Mabsadd L
.7381 .45841 -1.875 0 Mabsadd L closepath F
.76455 .42369 -1.875 0 Mabsadd m
.76455 .42369 0 2.5 Mabsadd L
.76455 .42369 1.875 0 Mabsadd L
.76455 .42369 0 -2.5 Mabsadd L
.76455 .42369 -1.875 0 Mabsadd L closepath F
.79101 .385 -1.875 0 Mabsadd m
.79101 .385 0 2.5 Mabsadd L
.79101 .385 1.875 0 Mabsadd L
.79101 .385 0 -2.5 Mabsadd L
.79101 .385 -1.875 0 Mabsadd L closepath F
.81746 .34229 -1.875 0 Mabsadd m
.81746 .34229 0 2.5 Mabsadd L
.81746 .34229 1.875 0 Mabsadd L
.81746 .34229 0 -2.5 Mabsadd L
.81746 .34229 -1.875 0 Mabsadd L closepath F
.84392 .29553 -1.875 0 Mabsadd m
.84392 .29553 0 2.5 Mabsadd L
.84392 .29553 1.875 0 Mabsadd L
.84392 .29553 0 -2.5 Mabsadd L
.84392 .29553 -1.875 0 Mabsadd L closepath F
.87037 .24479 -1.875 0 Mabsadd m
.87037 .24479 0 2.5 Mabsadd L
.87037 .24479 1.875 0 Mabsadd L
.87037 .24479 0 -2.5 Mabsadd L
.87037 .24479 -1.875 0 Mabsadd L closepath F
.89683 .19033 -1.875 0 Mabsadd m
.89683 .19033 0 2.5 Mabsadd L
.89683 .19033 1.875 0 Mabsadd L
.89683 .19033 0 -2.5 Mabsadd L
.89683 .19033 -1.875 0 Mabsadd L closepath F
.92328 .13278 -1.875 0 Mabsadd m
.92328 .13278 0 2.5 Mabsadd L
.92328 .13278 1.875 0 Mabsadd L
.92328 .13278 0 -2.5 Mabsadd L
.92328 .13278 -1.875 0 Mabsadd L closepath F
.94974 .07347 -1.875 0 Mabsadd m
.94974 .07347 0 2.5 Mabsadd L
.94974 .07347 1.875 0 Mabsadd L
.94974 .07347 0 -2.5 Mabsadd L
.94974 .07347 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{372, 229.812},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005d0000iB000`400?l00000o`00003o^@3IfMT0
0`000000fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000
fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000fMWI0=WIf@2h0=WIf@002@3IfMT00`000000fMWI0=WI
f@2]0=WIf@030000003IfMT0fMWI0:d0fMWI00<000000=WIf@3IfMT0203IfMT000P0fMWI0`00002^
0=WIf@030000003IfMT0fMWI0:`0fMWI0`0000090=WIf@001`3IfMT400000:h0fMWI00<000000=WI
f@3IfMT0Z`3IfMT4000000T0fMWI00080=WIf@<00000[P3IfMT00`000000fMWI0=WIf@2/0=WIf@<0
00002@3IfMT000T0fMWI0P00002^0=WIf@030000003IfMT0fMWI0:`0fMWI0P00000:0=WIf@002P3I
fMT00`000000fMWI0=WIf@2/0=WIf@030000003IfMT0fMWI0:`0fMWI00<000000=WIf@3IfMT02@3I
fMT000/0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`000000fMWI0=WIf@2[0=WIf@030000003IfMT0
fMWI00X0fMWI000;0=WIf@030000003IfMT0fMWI0:/0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`00
0000fMWI0=WIf@0:0=WIf@00303IfMT00`000000fMWI0=WIf@2Z0=WIf@800000Z`3IfMT00`000000
fMWI0=WIf@0;0=WIf@00303IfMT00`000000fMWI0=WIf@2Z0=WIf@030000003IfMT0fMWI0:X0fMWI
00<000000=WIf@3IfMT02`3IfMT000`0fMWI00<000000=WIf@3IfMT0ZP3IfMT00`000000fMWI0=WI
f@2Z0=WIf@030000003IfMT0fMWI00/0fMWI000=0=WIf@030000003IfMT0fMWI0:T0fMWI00<00000
0=WIf@3IfMT0Z@3IfMT00`000000fMWI0=WIf@0<0=WIf@003@3IfMT00`000000fMWI0=WIf@2Y0=WI
f@030000003IfMT0fMWI0:T0fMWI00<000000=WIf@3IfMT0303IfMT000h0fMWI00<000000=WIf@3I
fMT0Z03IfMT00`000000fMWI0=WIf@2X0=WIf@030000003IfMT0fMWI00d0fMWI000>0=WIf@030000
003IfMT0fMWI0:P0fMWI00<000000=WIf@3IfMT0Z03IfMT00`000000fMWI0=WIf@0=0=WIf@003`3I
fMT00`000000fMWI0=WIf@2W0=WIf@030000003IfMT0fMWI0:L0fMWI00<000000=WIf@3IfMT03P3I
fMT000l0fMWI00<000000=WIf@3IfMT0Y`3IfMT00`000000fMWI0=WIf@2W0=WIf@030000003IfMT0
fMWI00h0fMWI000?0=WIf@030000003IfMT0fMWI0940fMWI0`0000030=WIf@030000003IfMT0fMWI
00<000002P3IfMT00`000000fMWI0=WIf@2W0=WIf@030000003IfMT0fMWI00h0fMWI000@0=WIf@03
0000003IfMT0fMWI08l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@050000003IfMT0fMWI
0=WIf@0000002@3IfMT00`000000fMWI0=WIf@2V0=WIf@030000003IfMT0fMWI00l0fMWI000@0=WI
f@030000003IfMT0fMWI08l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@050000003IfMT0
fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@2V0=WIf@030000003IfMT0fMWI00l0fMWI000A
0=WIf@030000003IfMT0fMWI08H0fMWI1`0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0
fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@<00000Y@3IfMT00`000000fMWI0=WI
f@0@0=WIf@004@3IfMT00`000000fMWI0=WIf@2>0=WIf@050000003IfMT0fMWI0=WIf@0000001@3I
fMT3000000X0fMWI00<000000=WIf@3IfMT0Y@3IfMT00`000000fMWI0=WIf@0@0=WIf@004@3IfMT2
000008l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@000000
2@3IfMT00`000000fMWI0=WIf@2T0=WIf@8000004P3IfMT00140fMWI0`00002>0=WIf@050000003I
fMT0fMWI0=WIf@000000103IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3I
fMT0X`3IfMT2000001<0fMWI000A0=WIf@<00000S`3IfMT3000000H0fMWI0`00000:0=WIf@030000
003IfMT0fMWI0:<0fMWI0P00000C0=WIf@004P3IfMT200000:D0fMWI00<000000=WIf@3IfMT0X`3I
fMT2000001<0fMWI000C0=WIf@030000003IfMT0fMWI0:<0fMWI00<000000=WIf@3IfMT0X`3IfMT0
0`000000fMWI0=WIf@0B0=WIf@00503IfMT00`000000fMWI0=WIf@2R0=WIf@030000003IfMT0fMWI
0:80fMWI00<000000=WIf@3IfMT04`3IfMT001@0fMWI00<000000=WIf@3IfMT0XP3IfMT00`000000
fMWI0=WIf@2R0=WIf@030000003IfMT0fMWI01<0fMWI000E0=WIf@030000003IfMT0fMWI0:40fMWI
00<000000=WIf@3IfMT0X@3IfMT00`000000fMWI0=WIf@0D0=WIf@005@3IfMT00`000000fMWI0=WI
f@2Q0=WIf@030000003IfMT0fMWI0:40fMWI00<000000=WIf@3IfMT0503IfMT001D0fMWI00<00000
0=WIf@3IfMT0X@3IfMT00`000000fMWI0=WIf@2Q0=WIf@030000003IfMT0fMWI01@0fMWI000F0=WI
f@030000003IfMT0fMWI0:00fMWI00<000000=WIf@3IfMT0X03IfMT00`000000fMWI0=WIf@0E0=WI
f@005P3IfMT00`000000fMWI0=WIf@2P0=WIf@800000X@3IfMT00`000000fMWI0=WIf@0E0=WIf@00
5`3IfMT00`000000fMWI0=WIf@2O0=WIf@030000003IfMT0fMWI09l0fMWI00<000000=WIf@3IfMT0
5P3IfMT001L0fMWI00<000000=WIf@3IfMT0W`3IfMT00`000000fMWI0=WIf@2O0=WIf@030000003I
fMT0fMWI01H0fMWI000H0=WIf@030000003IfMT0fMWI09h0fMWI00<000000=WIf@3IfMT0WP3IfMT0
0`000000fMWI0=WIf@0G0=WIf@00603IfMT00`000000fMWI0=WIf@2N0=WIf@030000003IfMT0fMWI
09h0fMWI00<000000=WIf@3IfMT05`3IfMT001T0fMWI00<000000=WIf@3IfMT0W@3IfMT00`000000
fMWI0=WIf@2M0=WIf@030000003IfMT0fMWI01P0fMWI000I0=WIf@030000003IfMT0fMWI09d0fMWI
00<000000=WIf@3IfMT0W@3IfMT00`000000fMWI0=WIf@0H0=WIf@006P3IfMT00`000000fMWI0=WI
f@2L0=WIf@030000003IfMT0fMWI09`0fMWI00<000000=WIf@3IfMT06@3IfMT001X0fMWI00<00000
0=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@2L0=WIf@030000003IfMT0fMWI01T0fMWI000J0=WI
f@030000003IfMT0fMWI09`0fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@0I0=WI
f@006`3IfMT00`000000fMWI0=WIf@2K0=WIf@030000003IfMT0fMWI09/0fMWI00<000000=WIf@3I
fMT06P3IfMT001/0fMWI0P00002L0=WIf@030000003IfMT0fMWI09X0fMWI0P00000L0=WIf@006`3I
fMT3000009/0fMWI0P00002J0=WIf@<00000703IfMT001/0fMWI0`00002K0=WIf@030000003IfMT0
fMWI09T0fMWI0`00000L0=WIf@00703IfMT2000009/0fMWI00<000000=WIf@3IfMT0V@3IfMT20000
01d0fMWI000M0=WIf@030000003IfMT0fMWI09T0fMWI00<000000=WIf@3IfMT0V@3IfMT00`000000
fMWI0=WIf@0L0=WIf@007P3IfMT00`000000fMWI0=WIf@2H0=WIf@030000003IfMT0fMWI09P0fMWI
00<000000=WIf@3IfMT07@3IfMT001h0fMWI00<000000=WIf@3IfMT0V03IfMT00`000000fMWI0=WI
f@2H0=WIf@030000003IfMT0fMWI01d0fMWI000O0=WIf@030000003IfMT0fMWI09L0fMWI00<00000
0=WIf@3IfMT0U`3IfMT00`000000fMWI0=WIf@0N0=WIf@007`3IfMT00`000000fMWI0=WIf@2G0=WI
f@030000003IfMT0fMWI09L0fMWI00<000000=WIf@3IfMT07P3IfMT00200fMWI00<000000=WIf@3I
fMT0UP3IfMT00`000000fMWI0=WIf@2F0=WIf@030000003IfMT0fMWI01l0fMWI000P0=WIf@030000
003IfMT0fMWI09H0fMWI00<000000=WIf@3IfMT0UP3IfMT00`000000fMWI0=WIf@0O0=WIf@008@3I
fMT00`000000fMWI0=WIf@2E0=WIf@030000003IfMT0fMWI09D0fMWI00<000000=WIf@3IfMT0803I
fMT00240fMWI00<000000=WIf@3IfMT0U@3IfMT00`000000fMWI0=WIf@2E0=WIf@030000003IfMT0
fMWI0200fMWI000Q0=WIf@030000003IfMT0fMWI09D0fMWI00<000000=WIf@3IfMT0U@3IfMT00`00
0000fMWI0=WIf@0P0=WIf@008P3IfMT00`000000fMWI0=WIf@2D0=WIf@800000U@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@008P3IfMT00`000000fMWI0=WIf@2D0=WIf@030000003IfMT0fMWI09@0fMWI
00<000000=WIf@3IfMT08@3IfMT002<0fMWI00<000000=WIf@3IfMT0T`3IfMT00`000000fMWI0=WI
f@2C0=WIf@030000003IfMT0fMWI0280fMWI000S0=WIf@030000003IfMT0fMWI09<0fMWI00<00000
0=WIf@3IfMT0T`3IfMT00`000000fMWI0=WIf@0R0=WIf@00903IfMT00`000000fMWI0=WIf@2B0=WI
f@030000003IfMT0fMWI0980fMWI00<000000=WIf@3IfMT08`3IfMT002@0fMWI00<000000=WIf@3I
fMT0TP3IfMT00`000000fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI02<0fMWI000U0=WIf@030000
003IfMT0fMWI0940fMWI00<000000=WIf@3IfMT0T@3IfMT00`000000fMWI0=WIf@0T0=WIf@009@3I
fMT200000980fMWI00<000000=WIf@3IfMT0T03IfMT2000002H0fMWI000U0=WIf@<00000T@3IfMT0
0`000000fMWI0=WIf@2?0=WIf@<000009P3IfMT002@0fMWI1000001k0=WIf@<000000`3IfMT00`00
0000fMWI0=WIf@03000000X0fMWI00<000000=WIf@3IfMT0SP3IfMT4000002H0fMWI000U0=WIf@<0
0000NP3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WIf@3IfMT0fMWI00000009
0=WIf@030000003IfMT0fMWI08l0fMWI0`00000V0=WIf@009P3IfMT2000007X0fMWI00D000000=WI
f@3IfMT0fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WI
f@2?0=WIf@8000009`3IfMT002P0fMWI00<000000=WIf@3IfMT0K`3IfMT7000000030=WIf@000000
fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI0`00
002>0=WIf@030000003IfMT0fMWI02L0fMWI000X0=WIf@030000003IfMT0fMWI07L0fMWI00D00000
0=WIf@3IfMT0fMWI000000040=WIf@@000002P3IfMT00`000000fMWI0=WIf@2>0=WIf@030000003I
fMT0fMWI02L0fMWI000Y0=WIf@030000003IfMT0fMWI07H0fMWI00D000000=WIf@3IfMT0fMWI0000
00050=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0S@3IfMT00`000000fMWI0=WI
f@0X0=WIf@00:@3IfMT00`000000fMWI0=WIf@1f0=WIf@050000003IfMT0fMWI0=WIf@0000001@3I
fMT2000000/0fMWI00<000000=WIf@3IfMT0S@3IfMT00`000000fMWI0=WIf@0X0=WIf@00:P3IfMT0
0`000000fMWI0=WIf@1f0=WIf@<00000203IfMT2000000T0fMWI00<000000=WIf@3IfMT0S03IfMT0
0`000000fMWI0=WIf@0Y0=WIf@00:P3IfMT00`000000fMWI0=WIf@2<0=WIf@030000003IfMT0fMWI
08`0fMWI00<000000=WIf@3IfMT0:@3IfMT002/0fMWI00<000000=WIf@3IfMT0R`3IfMT00`000000
fMWI0=WIf@2;0=WIf@030000003IfMT0fMWI02X0fMWI000[0=WIf@030000003IfMT0fMWI08/0fMWI
00<000000=WIf@3IfMT0R`3IfMT00`000000fMWI0=WIf@0Z0=WIf@00;03IfMT00`000000fMWI0=WI
f@2:0=WIf@030000003IfMT0fMWI08X0fMWI00<000000=WIf@3IfMT0:`3IfMT002`0fMWI00<00000
0=WIf@3IfMT0RP3IfMT00`000000fMWI0=WIf@2:0=WIf@030000003IfMT0fMWI02/0fMWI000]0=WI
f@030000003IfMT0fMWI08T0fMWI00<000000=WIf@3IfMT0R@3IfMT00`000000fMWI0=WIf@0/0=WI
f@00;@3IfMT00`000000fMWI0=WIf@290=WIf@030000003IfMT0fMWI08T0fMWI00<000000=WIf@3I
fMT0;03IfMT002h0fMWI00<000000=WIf@3IfMT0R03IfMT2000008T0fMWI00<000000=WIf@3IfMT0
;@3IfMT002h0fMWI00<000000=WIf@3IfMT0R03IfMT00`000000fMWI0=WIf@280=WIf@030000003I
fMT0fMWI02d0fMWI000_0=WIf@030000003IfMT0fMWI08L0fMWI00<000000=WIf@3IfMT0Q`3IfMT0
0`000000fMWI0=WIf@0^0=WIf@00;`3IfMT2000008P0fMWI00<000000=WIf@3IfMT0QP3IfMT20000
0300fMWI000_0=WIf@<00000Q`3IfMT00`000000fMWI0=WIf@250=WIf@<00000<03IfMT002h0fMWI
100000270=WIf@030000003IfMT0fMWI08@0fMWI1000000`0=WIf@00;`3IfMT3000008L0fMWI00<0
00000=WIf@3IfMT0Q@3IfMT300000300fMWI000`0=WIf@800000Q`3IfMT00`000000fMWI0=WIf@25
0=WIf@800000<@3IfMT00380fMWI00<000000=WIf@3IfMT0Q03IfMT00`000000fMWI0=WIf@240=WI
f@030000003IfMT0fMWI0340fMWI000b0=WIf@030000003IfMT0fMWI08@0fMWI00<000000=WIf@3I
fMT0Q03IfMT00`000000fMWI0=WIf@0a0=WIf@00<`3IfMT00`000000fMWI0=WIf@230=WIf@030000
003IfMT0fMWI08<0fMWI00<000000=WIf@3IfMT0<P3IfMT003<0fMWI00<000000=WIf@3IfMT0P`3I
fMT00`000000fMWI0=WIf@230=WIf@030000003IfMT0fMWI0380fMWI000d0=WIf@030000003IfMT0
fMWI0880fMWI00<000000=WIf@3IfMT0PP3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`00
0000fMWI0=WIf@220=WIf@800000P`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=@3IfMT00`000000
fMWI0=WIf@210=WIf@030000003IfMT0fMWI0840fMWI00<000000=WIf@3IfMT0=03IfMT003H0fMWI
00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@200=WIf@030000003IfMT0fMWI03D0fMWI
000f0=WIf@030000003IfMT0fMWI0800fMWI00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WI
f@0e0=WIf@00=`3IfMT00`000000fMWI0=WIf@1o0=WIf@030000003IfMT0fMWI07l0fMWI00<00000
0=WIf@3IfMT0=P3IfMT003L0fMWI00<000000=WIf@3IfMT0O`3IfMT00`000000fMWI0=WIf@1o0=WI
f@030000003IfMT0fMWI03H0fMWI000h0=WIf@030000003IfMT0fMWI07h0fMWI00<000000=WIf@3I
fMT0OP3IfMT00`000000fMWI0=WIf@0g0=WIf@00>03IfMT00`000000fMWI0=WIf@1n0=WIf@030000
003IfMT0fMWI07h0fMWI00<000000=WIf@3IfMT0=`3IfMT003T0fMWI00<000000=WIf@3IfMT0O@3I
fMT00`000000fMWI0=WIf@1m0=WIf@030000003IfMT0fMWI03P0fMWI000i0=WIf@800000OP3IfMT0
0`000000fMWI0=WIf@1l0=WIf@800000>P3IfMT003T0fMWI0`00001m0=WIf@030000003IfMT0fMWI
07/0fMWI0`00000j0=WIf@00>03IfMT4000007d0fMWI00<000000=WIf@3IfMT0NP3IfMT4000003X0
fMWI000i0=WIf@<00000O@3IfMT2000007`0fMWI0`00000j0=WIf@00>P3IfMT2000007d0fMWI00<0
00000=WIf@3IfMT0N`3IfMT2000003/0fMWI000l0=WIf@030000003IfMT0fMWI07X0fMWI00<00000
0=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@0k0=WIf@00?03IfMT00`000000fMWI0=WIf@1j0=WI
f@030000003IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0>`3IfMT003d0fMWI00<000000=WIf@3I
fMT0N@3IfMT00`000000fMWI0=WIf@1i0=WIf@030000003IfMT0fMWI03`0fMWI000m0=WIf@030000
003IfMT0fMWI07T0fMWI00<000000=WIf@3IfMT0N@3IfMT00`000000fMWI0=WIf@0l0=WIf@00?P3I
fMT00`000000fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI07P0fMWI00<000000=WIf@3IfMT0?@3I
fMT003l0fMWI00<000000=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@1g0=WIf@030000003IfMT0
fMWI03h0fMWI000o0=WIf@030000003IfMT0fMWI07L0fMWI00<000000=WIf@3IfMT0M`3IfMT00`00
0000fMWI0=WIf@0n0=WIf@00@03IfMT00`000000fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI07H0
fMWI00<000000=WIf@3IfMT0?`3IfMT00400fMWI00<000000=WIf@3IfMT0H03IfMT3000000<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI07H0fMWI
00<000000=WIf@3IfMT0?`3IfMT00440fMWI00<000000=WIf@3IfMT0GP3IfMT01@000000fMWI0=WI
f@3IfMT0000000L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@1e0=WIf@030000
003IfMT0fMWI0400fMWI00110=WIf@030000003IfMT0fMWI05h0fMWI00D000000=WIf@3IfMT0fMWI
000000040=WIf@H00000203IfMT00`000000fMWI0=WIf@1e0=WIf@030000003IfMT0fMWI0400fMWI
00120=WIf@030000003IfMT0fMWI05D0fMWI1`0000000`3IfMT000000=WIf@020=WIf@030000003I
fMT0fMWI0080fMWI00@000000=WIf@3IfMT000002P3IfMT3000007@0fMWI00<000000=WIf@3IfMT0
@@3IfMT00480fMWI0P00001N0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI
0000000:0=WIf@030000003IfMT0fMWI07@0fMWI00<000000=WIf@3IfMT0@@3IfMT004<0fMWI0P00
001M0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT2000000X0fMWI00<000000=WIf@3IfMT0
LP3IfMT2000004@0fMWI00120=WIf@<00000G@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
0P00000:0=WIf@030000003IfMT0fMWI0740fMWI0`0000140=WIf@00@`3IfMT2000005h0fMWI0`00
00080=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0LP3IfMT2000004@0fMWI0013
0=WIf@030000003IfMT0000007<0fMWI00<000000=WIf@3IfMT0L@3IfMT00`000000fMWI0=WIf@14
0=WIf@00A@3IfMT00`000000fMWI0=WIf@1a0=WIf@030000003IfMT0fMWI0740fMWI00<000000=WI
f@3IfMT0A03IfMT004H0fMWI00<000000=WIf@3IfMT0L03IfMT00`000000fMWI0=WIf@1`0=WIf@03
0000003IfMT0fMWI04D0fMWI00160=WIf@030000003IfMT0fMWI0700fMWI00<000000=WIf@3IfMT0
L03IfMT00`000000fMWI0=WIf@150=WIf@00A`3IfMT00`000000fMWI0=WIf@1_0=WIf@030000003I
fMT0fMWI06l0fMWI00<000000=WIf@3IfMT0AP3IfMT004P0fMWI00<000000=WIf@3IfMT0KP3IfMT0
0`000000fMWI0=WIf@1^0=WIf@030000003IfMT0fMWI04L0fMWI00180=WIf@030000003IfMT0fMWI
06h0fMWI00<000000=WIf@3IfMT0KP3IfMT00`000000fMWI0=WIf@170=WIf@00B@3IfMT00`000000
fMWI0=WIf@1]0=WIf@800000KP3IfMT00`000000fMWI0=WIf@180=WIf@00BP3IfMT00`000000fMWI
0=WIf@1/0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0B@3IfMT004X0fMWI00<0
00000=WIf@3IfMT0K03IfMT00`000000fMWI0=WIf@1/0=WIf@030000003IfMT0fMWI04T0fMWI001;
0=WIf@030000003IfMT0fMWI06/0fMWI00<000000=WIf@3IfMT0J`3IfMT00`000000fMWI0=WIf@1:
0=WIf@00B`3IfMT00`000000fMWI0=WIf@1[0=WIf@030000003IfMT0fMWI06/0fMWI00<000000=WI
f@3IfMT0BP3IfMT004`0fMWI0P00001[0=WIf@030000003IfMT0fMWI06T0fMWI0P00001=0=WIf@00
C03IfMT3000006X0fMWI00<000000=WIf@3IfMT0J03IfMT3000004d0fMWI001;0=WIf@@00000JP3I
fMT00`000000fMWI0=WIf@1W0=WIf@@00000C@3IfMT004`0fMWI0`00001Z0=WIf@030000003IfMT0
fMWI06P0fMWI0`00001=0=WIf@00C@3IfMT00`000000fMWI0000001Y0=WIf@030000003IfMT0fMWI
06L0fMWI00<000000=WIf@000000CP3IfMT004l0fMWI00<000000=WIf@3IfMT0I`3IfMT00`000000
fMWI0=WIf@1W0=WIf@030000003IfMT0fMWI04h0fMWI001@0=WIf@030000003IfMT0fMWI06H0fMWI
00<000000=WIf@3IfMT0IP3IfMT00`000000fMWI0=WIf@1?0=WIf@00D@3IfMT00`000000fMWI0=WI
f@1U0=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0D03IfMT00540fMWI00<00000
0=WIf@3IfMT0I@3IfMT2000006H0fMWI00<000000=WIf@3IfMT0D03IfMT00580fMWI00<000000=WI
f@3IfMT0I03IfMT00`000000fMWI0=WIf@1T0=WIf@030000003IfMT0fMWI0540fMWI001C0=WIf@03
0000003IfMT0fMWI06<0fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@1B0=WIf@00
D`3IfMT00`000000fMWI0=WIf@1S0=WIf@030000003IfMT0fMWI06<0fMWI00<000000=WIf@3IfMT0
DP3IfMT005@0fMWI00<000000=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@1R0=WIf@030000003I
fMT0fMWI05<0fMWI001E0=WIf@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT0H@3IfMT0
0`000000fMWI0=WIf@1D0=WIf@00E@3IfMT00`000000fMWI0=WIf@1Q0=WIf@030000003IfMT0fMWI
0640fMWI00<000000=WIf@3IfMT0E03IfMT005H0fMWI0P00001Q0=WIf@030000003IfMT0fMWI05l0
fMWI0P00001G0=WIf@00EP3IfMT300000600fMWI00<000000=WIf@3IfMT0GP3IfMT3000005L0fMWI
001F0=WIf@<00000H03IfMT00`000000fMWI0=WIf@1N0=WIf@<00000E`3IfMT005L0fMWI0P00001P
0=WIf@030000003IfMT0fMWI05h0fMWI0P00001H0=WIf@00F@3IfMT00`000000fMWI0=WIf@1M0=WI
f@030000003IfMT0fMWI05d0fMWI00<000000=WIf@3IfMT0F03IfMT005X0fMWI00<000000=WIf@3I
fMT0G03IfMT2000005d0fMWI00<000000=WIf@3IfMT0F@3IfMT005/0fMWI00<000000=WIf@3IfMT0
F`3IfMT00`000000fMWI0=WIf@1K0=WIf@030000003IfMT0fMWI05X0fMWI001L0=WIf@030000003I
fMT0fMWI05X0fMWI00<000000=WIf@3IfMT0FP3IfMT00`000000fMWI0=WIf@1K0=WIf@00G03IfMT0
0`000000fMWI0=WIf@1J0=WIf@030000003IfMT0fMWI05X0fMWI00<000000=WIf@3IfMT0F`3IfMT0
05d0fMWI00<000000=WIf@3IfMT0F@3IfMT00`000000fMWI0=WIf@1I0=WIf@030000003IfMT0fMWI
05`0fMWI001N0=WIf@030000003IfMT0fMWI05P0fMWI00<000000=WIf@3IfMT0F03IfMT00`000000
fMWI0=WIf@1M0=WIf@00G`3IfMT00`000000fMWI0=WIf@1G0=WIf@030000003IfMT0fMWI05L0fMWI
00<000000=WIf@3IfMT0GP3IfMT00600fMWI0P00001G0=WIf@030000003IfMT0fMWI05D0fMWI0P00
001Q0=WIf@00H03IfMT3000005H0fMWI00<000000=WIf@3IfMT0E03IfMT300000640fMWI001O0=WI
f@@00000@03IfMT3000000<0fMWI00<000000=WIf@0000000`00000:0=WIf@030000003IfMT0fMWI
05<0fMWI1000001Q0=WIf@00H03IfMT3000003l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WI
f@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@1D0=WIf@<00000H@3IfMT0
0640fMWI00<000000=WIf@000000?P3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@1C0=WIf@030000003IfMT000000680fMWI001T0=WI
f@030000003IfMT0fMWI03<0fMWI1`0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT300000580fMWI00<000000=WIf@3IfMT0H`3IfMT006D0
fMWI00<000000=WIf@3IfMT0>P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@1A0=WIf@030000003IfMT0fMWI06@0fMWI001V0=WIf@03
0000003IfMT0fMWI03T0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT0D03IfMT00`000000fMWI0=WIf@1U0=WIf@00IP3IfMT00`000000
fMWI0=WIf@0i0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT010000000fMWI0=WIf@00000:
0=WIf@030000003IfMT0fMWI0500fMWI00<000000=WIf@3IfMT0I@3IfMT006L0fMWI00<000000=WI
f@3IfMT0>@3IfMT3000000H0fMWI0P00000;0=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WI
f@3IfMT0IP3IfMT006P0fMWI00<000000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@1>0=WIf@03
0000003IfMT0fMWI06L0fMWI001Y0=WIf@030000003IfMT0fMWI04d0fMWI00<000000=WIf@3IfMT0
C@3IfMT00`000000fMWI0=WIf@1X0=WIf@00JP3IfMT2000004d0fMWI00<000000=WIf@3IfMT0B`3I
fMT2000006/0fMWI001Z0=WIf@<00000C03IfMT00`000000fMWI0=WIf@1:0=WIf@<00000J`3IfMT0
06X0fMWI0`00001<0=WIf@030000003IfMT0fMWI04X0fMWI0`00001[0=WIf@00J`3IfMT2000004`0
fMWI00<000000=WIf@3IfMT0BP3IfMT2000006`0fMWI001]0=WIf@030000003IfMT0fMWI04T0fMWI
00<000000=WIf@3IfMT0B@3IfMT00`000000fMWI0=WIf@1/0=WIf@00KP3IfMT00`000000fMWI0=WI
f@180=WIf@030000003IfMT0fMWI04P0fMWI00<000000=WIf@3IfMT0K@3IfMT006l0fMWI00<00000
0=WIf@3IfMT0A`3IfMT2000004P0fMWI00<000000=WIf@3IfMT0KP3IfMT00700fMWI00<000000=WI
f@3IfMT0AP3IfMT00`000000fMWI0=WIf@160=WIf@030000003IfMT0fMWI06l0fMWI001a0=WIf@03
0000003IfMT0fMWI04D0fMWI00<000000=WIf@3IfMT0A@3IfMT00`000000fMWI0=WIf@1`0=WIf@00
LP3IfMT00`000000fMWI0=WIf@140=WIf@030000003IfMT0fMWI04@0fMWI00<000000=WIf@3IfMT0
L@3IfMT007<0fMWI0P0000140=WIf@030000003IfMT0fMWI0480fMWI0P00001d0=WIf@00L`3IfMT3
000004<0fMWI00<000000=WIf@3IfMT0@@3IfMT2000007D0fMWI001c0=WIf@@00000@P3IfMT00`00
0000fMWI0=WIf@100=WIf@<00000M@3IfMT007@0fMWI00@000000=WIf@3IfMT00000@@3IfMT00`00
0000fMWI0=WIf@0o0=WIf@040000003IfMT0fMWI000007D0fMWI001h0=WIf@030000003IfMT0fMWI
03h0fMWI00<000000=WIf@3IfMT0?P3IfMT00`000000fMWI0=WIf@1g0=WIf@00N@3IfMT2000003h0
fMWI00<000000=WIf@3IfMT0?03IfMT2000007X0fMWI001k0=WIf@030000003IfMT0fMWI03/0fMWI
00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@1j0=WIf@00O03IfMT00`000000fMWI0=WI
f@0j0=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0N`3IfMT007d0fMWI0P00000j
0=WIf@800000>@3IfMT2000007h0fMWI001m0=WIf@<00000>@3IfMT00`000000fMWI0=WIf@0g0=WI
f@<00000OP3IfMT007`0fMWI1@00000h0=WIf@030000003IfMT0fMWI03H0fMWI1000001n0=WIf@00
O@3IfMT3000000030=WIf@000000fMWI03H0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI
00000002000007h0fMWI001n0=WIf@050000003IfMT0fMWI0=WIf@000000=P3IfMT00`000000fMWI
0=WIf@0d0=WIf@050000003IfMT0fMWI0=WIf@000000O`3IfMT008<0fMWI0P00000d0=WIf@030000
003IfMT0fMWI0380fMWI0P0000240=WIf@00Q@3IfMT00`000000fMWI0=WIf@0a0=WIf@030000003I
fMT0fMWI0340fMWI00<000000=WIf@3IfMT0Q03IfMT008H0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI08D0fMWI00270=WIf@800000<03IfMT00`00
0000fMWI0=WIf@0^0=WIf@800000R03IfMT008L0fMWI0`00000_0=WIf@030000003IfMT0fMWI02d0
fMWI0`0000280=WIf@009P3IfMT3000000030=WIf@000000000000800000:@3IfMT300000080fMWI
0`00000X0=WIf@H00000;03IfMT00`000000fMWI0=WIf@0[0=WIf@D00000:`3IfMT300000080fMWI
0`00000Y0=WIf@<0000000<0fMWI0000000000000P00000T0=WIf@009`3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI02L0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI
0=WIf@0V0=WIf@040000003IfMT0fMWI0=WIf@800000:`3IfMT00`000000fMWI0=WIf@0Z0=WIf@04
0000003IfMT0fMWI0=WIf@800000;03IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI02L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0Q0=WIf@009`3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI00@000000=WIf@3IfMT000000`3IfMT0
0`000000fMWI0=WIf@0[0=WIf@800000:P3IfMT00`000000fMWI0=WIf@0X0=WIf@8000001@3IfMT0
0`000000fMWI0=WIf@0Z0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT09`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0240fMWI000M0=WIf@L000000`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01d0fMWI1`0000030=WIf@040000003IfMT0
fMWI000000<0fMWI00<000000=WIf@3IfMT0803IfMT7000000@0fMWI00@000000=WIf@0000000000
:03IfMT2000002L0fMWI0P0000070=WIf@030000003IfMT0fMWI02X0fMWI00@000000=WIf@3IfMT0
00000`3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT08@3IfMT002L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W0=WIf@040000
003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT20000
02H0fMWI00<000000=WIf@3IfMT0903IfMT2000000T0fMWI00<000000=WIf@3IfMT0:P3IfMT01000
0000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@0Q0=WIf@009`3IfMT00`000000fMWI0=WIf@04000002X0fMWI00@000000=WI
f@3IfMT000000`3IfMT00`000000fMWI0=WIf@0W0=WIf@@00000103IfMT3000002D0fMWI00<00000
0=WIf@3IfMT08`3IfMT3000000D0fMWI1000000]0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@04000002@0fMWI000W0=WIf@050000003IfMT0
fMWI0=WIf@000000;03IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI02P0fMWI
00<000000=WIf@3IfMT0103IfMT600000280fMWI00<000000=WIf@3IfMT0803IfMT6000000H0fMWI
00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI02L0
fMWI00D000000=WIf@3IfMT0fMWI0000000V0=WIf@009P3IfMT2000000<0fMWI1000000X0=WIf@80
00000`3IfMT3000002/0fMWI100000040=WIf@030000003IfMT0fMWI0080fMWI0P00000P0=WIf@03
0000003IfMT0fMWI01h0fMWI0P0000040=WIf@030000003IfMT0fMWI00D0fMWI1000000[0=WIf@80
00000`3IfMT3000002T0fMWI0P0000030=WIf@@000008`3IfMT009T0fMWI0`00000M0=WIf@030000
003IfMT0fMWI01X0fMWI1000002J0=WIf@00V`3IfMT4000001X0fMWI00<000000=WIf@3IfMT06@3I
fMT3000009`0fMWI002J0=WIf@<000000P3IfMT3000001L0fMWI00<000000=WIf@3IfMT05P3IfMT6
000009`0fMWI002K0=WIf@8000001@3IfMT4000001<0fMWI00<000000=WIf@3IfMT04`3IfMT30000
00@0fMWI0P00002L0=WIf@00Y@3IfMT400000100fMWI00<000000=WIf@3IfMT03`3IfMT4000000L0
fMWI00<000000=WIf@3IfMT0V`3IfMT00:@0fMWI0`0000020=WIf@D0000000<0fMWI0000003IfMT0
203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P00000YP3IfMT00:D0fMWI0P00
00070=WIf@L00000103IfMT00`000000fMWI0=WIf@020=WIf@P000001P3IfMT200000:H0fMWI003o
000007@000000@3IfMT000T0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@060=WI
f@<000001P3IfMT4000000L0fMWI0`0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT0203IfMT002H0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0^0=WIf@03
0000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT01P3IfMT3000000P0fMWI00<000000=WIf@3I
fMT0903IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI02h0fMWI00<000000=WIf@3I
fMT09@3IfMT00;T0fMWI00<000000=WIf@3IfMT0^03IfMT00;T0fMWI00<000000=WIf@3IfMT0^03I
fMT00;T0fMWI00<000000=WIf@3IfMT0^03IfMT00001\
\>"],
  ImageRangeCache->{{{0, 371}, {228.812, 0}} -> {-18.9396, -0.899529, 0.1021, 
  0.00402717}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the modulus of B in the central plane", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2 = 
      ContourPlot[
        Sqrt[Apply[Plus, \((radFld[cyl3, "\<b\>", {x, y, Lz/2.}])\)^2]], {x, 
          \(-rint\), rint}, {y, \(-rint\), rint}, ColorFunction -> Hue]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0240385 0.5 0.0240385 [
[.01923 -0.0125 -12.5 -14 ]
[.01923 -0.0125 12.5 0 ]
[.25962 -0.0125 -12.5 -14 ]
[.25962 -0.0125 12.5 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.74038 -0.0125 -8 -14 ]
[.74038 -0.0125 8 0 ]
[.98077 -0.0125 -8 -14 ]
[.98077 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -25 -7 ]
[-0.0125 .01923 0 7 ]
[-0.0125 .25962 -25 -7 ]
[-0.0125 .25962 0 7 ]
[-0.0125 .5 -10 -7 ]
[-0.0125 .5 0 7 ]
[-0.0125 .74038 -16 -7 ]
[-0.0125 .74038 0 7 ]
[-0.0125 .98077 -16 -7 ]
[-0.0125 .98077 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.25962 0 m
.25962 .00625 L
s
gsave
.25962 -0.0125 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.74038 0 m
.74038 .00625 L
s
gsave
.74038 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .25962 m
.00625 .25962 L
s
gsave
-0.0125 .25962 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .74038 m
.00625 .74038 L
s
gsave
-0.0125 .74038 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 .4 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 1 1 r
.01923 .04281 m
.08791 .05767 L
.11023 .08791 L
.15659 .1193 L
.22527 .13822 L
.29381 .15659 L
.22527 .22181 L
.21977 .22527 L
.16433 .29396 L
.15659 .30677 L
.13238 .36264 L
.12546 .43132 L
.11481 .5 L
.12546 .56868 L
.13238 .63736 L
.15659 .69323 L
.16433 .70604 L
.21977 .77473 L
.22527 .77819 L
.29381 .84341 L
.29396 .84345 L
.36264 .86225 L
.43132 .88606 L
.5 .89359 L
.56868 .88606 L
.63736 .86225 L
.70604 .84345 L
.7255 .91209 L
.70604 .94514 L
.63736 .96494 L
.61878 .98077 L
.01923 .98077 L
F
0 g
.01923 .04281 m
.08791 .05767 L
.11023 .08791 L
.15659 .1193 L
.22527 .13822 L
.29381 .15659 L
.22527 .22181 L
.21977 .22527 L
.16433 .29396 L
.15659 .30677 L
.13238 .36264 L
.12546 .43132 L
.11481 .5 L
.12546 .56868 L
.13238 .63736 L
.15659 .69323 L
.16433 .70604 L
.21977 .77473 L
.22527 .77819 L
.29381 .84341 L
.29396 .84345 L
.36264 .86225 L
.43132 .88606 L
.5 .89359 L
.56868 .88606 L
.63736 .86225 L
.70604 .84345 L
.7255 .91209 L
.70604 .94514 L
.63736 .96494 L
.61878 .98077 L
s
0 .4 1 r
.01923 .60066 m
.08791 .61108 L
.09626 .63736 L
.1179 .70604 L
.15659 .75947 L
.17369 .77473 L
.22527 .81293 L
.23216 .84341 L
.29396 .87304 L
.36264 .89826 L
.39403 .91209 L
.43132 .92281 L
.5 .93539 L
.56868 .92281 L
.60203 .98077 L
.01923 .98077 L
F
0 g
.01923 .60066 m
.08791 .61108 L
.09626 .63736 L
.1179 .70604 L
.15659 .75947 L
.17369 .77473 L
.22527 .81293 L
.23216 .84341 L
.29396 .87304 L
.36264 .89826 L
.39403 .91209 L
.43132 .92281 L
.5 .93539 L
.56868 .92281 L
.60203 .98077 L
s
0 1 1 r
.01923 .94808 m
.03403 .91209 L
.08791 .86953 L
.15659 .87347 L
.22527 .84668 L
.288 .91209 L
.29396 .9273 L
.36264 .94012 L
.39797 .98077 L
.01923 .98077 L
F
0 g
.01923 .94808 m
.03403 .91209 L
.08791 .86953 L
.15659 .87347 L
.22527 .84668 L
.288 .91209 L
.29396 .9273 L
.36264 .94012 L
.39797 .98077 L
s
0 1 .4 r
.01923 .95719 m
.04185 .91209 L
.08791 .87855 L
.15659 .8807 L
.22527 .86178 L
.2745 .91209 L
.29396 .94514 L
.36264 .96494 L
.38122 .98077 L
.01923 .98077 L
F
0 g
.01923 .95719 m
.04185 .91209 L
.08791 .87855 L
.15659 .8807 L
.22527 .86178 L
.2745 .91209 L
.29396 .94514 L
.36264 .96494 L
.38122 .98077 L
s
.2 1 0 r
.01923 .03515 m
.08791 .04655 L
.12056 .08791 L
.15659 .11214 L
.22527 .12519 L
.26217 .08791 L
.29396 .04347 L
.36264 .02104 L
.36514 .01923 L
.01923 .01923 L
F
0 g
.01923 .03515 m
.08791 .04655 L
.12056 .08791 L
.15659 .11214 L
.22527 .12519 L
.26217 .08791 L
.29396 .04347 L
.36264 .02104 L
.36514 .01923 L
s
.2 1 0 r
.01923 .96485 m
.05093 .91209 L
.08791 .88745 L
.15659 .88786 L
.22527 .87481 L
.26217 .91209 L
.29396 .95653 L
.36264 .97896 L
.36514 .98077 L
.01923 .98077 L
F
0 g
.01923 .96485 m
.05093 .91209 L
.08791 .88745 L
.15659 .88786 L
.22527 .87481 L
.26217 .91209 L
.29396 .95653 L
.36264 .97896 L
.36514 .98077 L
s
.8 1 0 r
.01923 .02845 m
.08791 .03681 L
.131 .08791 L
.15659 .10489 L
.22527 .11276 L
.25008 .08791 L
.29396 .0346 L
.34695 .01923 L
.01923 .01923 L
F
0 g
.01923 .02845 m
.08791 .03681 L
.131 .08791 L
.15659 .10489 L
.22527 .11276 L
.25008 .08791 L
.29396 .0346 L
.34695 .01923 L
s
.8 1 0 r
.01923 .97155 m
.06192 .91209 L
.08791 .89655 L
.15659 .89511 L
.22527 .88724 L
.25008 .91209 L
.29396 .9654 L
.34695 .98077 L
.01923 .98077 L
F
0 g
.01923 .97155 m
.06192 .91209 L
.08791 .89655 L
.15659 .89511 L
.22527 .88724 L
.25008 .91209 L
.29396 .9654 L
.34695 .98077 L
s
1 .6 0 r
.01923 .02245 m
.08791 .02808 L
.14203 .08791 L
.15659 .09735 L
.22527 .10007 L
.23751 .08791 L
.29396 .02715 L
.32661 .01923 L
.01923 .01923 L
F
0 g
.01923 .02245 m
.08791 .02808 L
.14203 .08791 L
.15659 .09735 L
.22527 .10007 L
.23751 .08791 L
.29396 .02715 L
.32661 .01923 L
s
1 .6 0 r
.01923 .97755 m
.07646 .91209 L
.08791 .90621 L
.15659 .90265 L
.22527 .89993 L
.23751 .91209 L
.29396 .97285 L
.32661 .98077 L
.01923 .98077 L
F
0 g
.01923 .97755 m
.07646 .91209 L
.08791 .90621 L
.15659 .90265 L
.22527 .89993 L
.23751 .91209 L
.29396 .97285 L
.32661 .98077 L
s
0 .4 1 r
.01923 .39934 m
.08791 .38892 L
.09626 .36264 L
.1179 .29396 L
.15659 .24053 L
.17369 .22527 L
.22527 .18707 L
.23216 .15659 L
.22527 .15332 L
.15659 .12653 L
.09961 .08791 L
.08791 .07086 L
.01923 .05192 L
F
0 g
.01923 .39934 m
.08791 .38892 L
.09626 .36264 L
.1179 .29396 L
.15659 .24053 L
.17369 .22527 L
.22527 .18707 L
.23216 .15659 L
.22527 .15332 L
.15659 .12653 L
.09961 .08791 L
.08791 .07086 L
.01923 .05192 L
s
.2 0 1 r
.01923 .93653 m
.02709 .91209 L
.08791 .86007 L
.15659 .86598 L
.20945 .84341 L
.15659 .7847 L
.11887 .77473 L
.08791 .74871 L
.07072 .70604 L
.0678 .63736 L
.01923 .60753 L
F
0 g
.01923 .93653 m
.02709 .91209 L
.08791 .86007 L
.15659 .86598 L
.20945 .84341 L
.15659 .7847 L
.11887 .77473 L
.08791 .74871 L
.07072 .70604 L
.0678 .63736 L
.01923 .60753 L
s
.2 0 1 r
.01923 .39247 m
.0678 .36264 L
.07072 .29396 L
.08791 .25129 L
.11887 .22527 L
.15659 .2153 L
.20945 .15659 L
.15659 .13402 L
.08811 .08791 L
.08791 .08759 L
.01923 .06347 L
F
0 g
.01923 .39247 m
.0678 .36264 L
.07072 .29396 L
.08791 .25129 L
.11887 .22527 L
.15659 .2153 L
.20945 .15659 L
.15659 .13402 L
.08811 .08791 L
.08791 .08759 L
.01923 .06347 L
s
.8 0 1 r
.01923 .91932 m
.02082 .91209 L
.08791 .84962 L
.15659 .85797 L
.19082 .84341 L
.15659 .79983 L
.08791 .79429 L
.01923 .82734 L
F
0 g
.01923 .91932 m
.02082 .91209 L
.08791 .84962 L
.15659 .85797 L
.19082 .84341 L
.15659 .79983 L
.08791 .79429 L
.01923 .82734 L
s
.8 0 1 r
.01923 .17266 m
.08791 .19409 L
.15659 .20017 L
.19082 .15659 L
.15659 .14203 L
.08791 .11297 L
.07455 .08791 L
.01923 .08068 L
F
0 g
.01923 .17266 m
.08791 .19409 L
.15659 .20017 L
.19082 .15659 L
.15659 .14203 L
.08791 .11297 L
.07455 .08791 L
.01923 .08068 L
s
0 1 .4 r
.01923 .59385 m
.06029 .56868 L
.07017 .5 L
.06029 .43132 L
.01923 .40615 L
F
0 g
.01923 .59385 m
.06029 .56868 L
.07017 .5 L
.06029 .43132 L
.01923 .40615 L
s
.2 1 0 r
.01923 .58694 m
.04319 .56868 L
.04788 .5 L
.04319 .43132 L
.01923 .41306 L
F
0 g
.01923 .58694 m
.04319 .56868 L
.04788 .5 L
.04319 .43132 L
.01923 .41306 L
s
.8 0 1 r
.01923 .70553 m
.04642 .63736 L
.01923 .61461 L
F
0 g
.01923 .70553 m
.04642 .63736 L
.01923 .61461 L
s
.8 0 1 r
.01923 .38539 m
.04642 .36264 L
.01923 .29447 L
F
0 g
.01923 .38539 m
.04642 .36264 L
.01923 .29447 L
s
.8 1 0 r
.01923 .57979 m
.03171 .56868 L
.03486 .5 L
.03171 .43132 L
.01923 .42021 L
F
0 g
.01923 .57979 m
.03171 .56868 L
.03486 .5 L
.03171 .43132 L
.01923 .42021 L
s
1 0 .6 r
.01923 .68864 m
.0315 .63736 L
.01923 .62211 L
F
0 g
.01923 .68864 m
.0315 .63736 L
.01923 .62211 L
s
1 0 .6 r
.01923 .37789 m
.0315 .36264 L
.01923 .31136 L
F
0 g
.01923 .37789 m
.0315 .36264 L
.01923 .31136 L
s
1 .6 0 r
.01923 .57216 m
.02263 .56868 L
.02493 .5 L
.02263 .43132 L
.01923 .42784 L
F
0 g
.01923 .57216 m
.02263 .56868 L
.02493 .5 L
.02263 .43132 L
.01923 .42784 L
s
1 0 0 r
.01923 .6704 m
.02247 .63736 L
.01923 .63036 L
F
0 g
.01923 .6704 m
.02247 .63736 L
.01923 .63036 L
s
1 0 0 r
.01923 .36964 m
.02247 .36264 L
.01923 .3296 L
F
0 g
.01923 .36964 m
.02247 .36264 L
.01923 .3296 L
s
1 0 0 r
.30154 .98077 m
.29396 .97934 L
.22527 .91401 L
.22076 .91209 L
.15659 .91076 L
.10138 .91209 L
.08791 .91709 L
.07333 .98077 L
F
0 g
.30154 .98077 m
.29396 .97934 L
.22527 .91401 L
.22076 .91209 L
.15659 .91076 L
.10138 .91209 L
.08791 .91709 L
.07333 .98077 L
s
1 0 0 r
.30154 .01923 m
.29396 .02066 L
.22527 .08599 L
.22229 .08791 L
.15659 .08924 L
.15446 .08791 L
.08791 .02012 L
.07333 .01923 L
F
0 g
.30154 .01923 m
.29396 .02066 L
.22527 .08599 L
.22229 .08791 L
.15659 .08924 L
.15446 .08791 L
.08791 .02012 L
.07333 .01923 L
s
1 0 .6 r
.15659 .8182 m
.17034 .84341 L
.15659 .84895 L
.10902 .84341 L
F
0 g
.15659 .8182 m
.17034 .84341 L
.15659 .84895 L
.10902 .84341 L
.15659 .8182 L
s
1 0 .6 r
.15659 .15105 m
.17034 .15659 L
.15659 .1818 L
.10902 .15659 L
F
0 g
.15659 .15105 m
.17034 .15659 L
.15659 .1818 L
.10902 .15659 L
.15659 .15105 L
s
.2 1 0 r
.43132 .15503 m
.5 .1489 L
.56868 .15503 L
.58165 .15659 L
.63736 .17257 L
.70604 .21041 L
.72416 .22527 L
.77473 .28066 L
.78464 .29396 L
.8237 .36264 L
.84341 .41286 L
.84543 .43132 L
.85114 .5 L
.84543 .56868 L
.84341 .58714 L
.8237 .63736 L
.78464 .70604 L
.77473 .71934 L
.72416 .77473 L
.70604 .78959 L
.63736 .82743 L
.58165 .84341 L
.56868 .84497 L
.5 .8511 L
.43132 .84497 L
.41835 .84341 L
.36264 .82743 L
.29396 .78959 L
.27584 .77473 L
.22527 .71934 L
.21536 .70604 L
.1763 .63736 L
.15659 .58714 L
.15457 .56868 L
.14886 .5 L
.15457 .43132 L
.15659 .41286 L
.1763 .36264 L
.21536 .29396 L
.22527 .28066 L
.27584 .22527 L
.29396 .21041 L
.36264 .17257 L
.41835 .15659 L
F
0 g
.43132 .15503 m
.5 .1489 L
.56868 .15503 L
.58165 .15659 L
.63736 .17257 L
.70604 .21041 L
.72416 .22527 L
.77473 .28066 L
.78464 .29396 L
.8237 .36264 L
.84341 .41286 L
.84543 .43132 L
.85114 .5 L
.84543 .56868 L
.84341 .58714 L
.8237 .63736 L
.78464 .70604 L
.77473 .71934 L
.72416 .77473 L
.70604 .78959 L
.63736 .82743 L
.58165 .84341 L
.56868 .84497 L
.5 .8511 L
.43132 .84497 L
.41835 .84341 L
.36264 .82743 L
.29396 .78959 L
.27584 .77473 L
.22527 .71934 L
.21536 .70604 L
.1763 .63736 L
.15659 .58714 L
.15457 .56868 L
.14886 .5 L
.15457 .43132 L
.15659 .41286 L
.1763 .36264 L
.21536 .29396 L
.22527 .28066 L
.27584 .22527 L
.29396 .21041 L
.36264 .17257 L
.41835 .15659 L
.43132 .15503 L
s
.8 1 0 r
.43132 .20371 m
.5 .19695 L
.56868 .20371 L
.63434 .22527 L
.63736 .22666 L
.70604 .27527 L
.7238 .29396 L
.77006 .36264 L
.77473 .36597 L
.79694 .43132 L
.80624 .5 L
.79694 .56868 L
.77473 .63403 L
.77006 .63736 L
.7238 .70604 L
.70604 .72473 L
.63736 .77334 L
.63434 .77473 L
.56868 .79629 L
.5 .80305 L
.43132 .79629 L
.36566 .77473 L
.36264 .77334 L
.29396 .72473 L
.2762 .70604 L
.22994 .63736 L
.22527 .63403 L
.20306 .56868 L
.19376 .5 L
.20306 .43132 L
.22527 .36597 L
.22994 .36264 L
.2762 .29396 L
.29396 .27527 L
.36264 .22666 L
.36566 .22527 L
F
0 g
.43132 .20371 m
.5 .19695 L
.56868 .20371 L
.63434 .22527 L
.63736 .22666 L
.70604 .27527 L
.7238 .29396 L
.77006 .36264 L
.77473 .36597 L
.79694 .43132 L
.80624 .5 L
.79694 .56868 L
.77473 .63403 L
.77006 .63736 L
.7238 .70604 L
.70604 .72473 L
.63736 .77334 L
.63434 .77473 L
.56868 .79629 L
.5 .80305 L
.43132 .79629 L
.36566 .77473 L
.36264 .77334 L
.29396 .72473 L
.2762 .70604 L
.22994 .63736 L
.22527 .63403 L
.20306 .56868 L
.19376 .5 L
.20306 .43132 L
.22527 .36597 L
.22994 .36264 L
.2762 .29396 L
.29396 .27527 L
.36264 .22666 L
.36566 .22527 L
.43132 .20371 L
s
1 .6 0 r
.43132 .26473 m
.5 .25583 L
.56868 .26473 L
.63285 .29396 L
.63736 .29666 L
.70169 .36264 L
.70604 .36487 L
.73497 .43132 L
.74587 .5 L
.73497 .56868 L
.70604 .63513 L
.70169 .63736 L
.63736 .70334 L
.63285 .70604 L
.56868 .73527 L
.5 .74417 L
.43132 .73527 L
.36715 .70604 L
.36264 .70334 L
.29831 .63736 L
.29396 .63513 L
.26503 .56868 L
.25413 .5 L
.26503 .43132 L
.29396 .36487 L
.29831 .36264 L
.36264 .29666 L
.36715 .29396 L
F
0 g
.43132 .26473 m
.5 .25583 L
.56868 .26473 L
.63285 .29396 L
.63736 .29666 L
.70169 .36264 L
.70604 .36487 L
.73497 .43132 L
.74587 .5 L
.73497 .56868 L
.70604 .63513 L
.70169 .63736 L
.63736 .70334 L
.63285 .70604 L
.56868 .73527 L
.5 .74417 L
.43132 .73527 L
.36715 .70604 L
.36264 .70334 L
.29831 .63736 L
.29396 .63513 L
.26503 .56868 L
.25413 .5 L
.26503 .43132 L
.29396 .36487 L
.29831 .36264 L
.36264 .29666 L
.36715 .29396 L
.43132 .26473 L
s
0 1 1 r
.98077 .95719 m
.95815 .91209 L
.91209 .87855 L
.84341 .8807 L
.77473 .86178 L
.70619 .84341 L
.77473 .77819 L
.78023 .77473 L
.83567 .70604 L
.84341 .69323 L
.86762 .63736 L
.87454 .56868 L
.88519 .5 L
.87454 .43132 L
.86762 .36264 L
.84341 .30677 L
.83567 .29396 L
.78023 .22527 L
.77473 .22181 L
.70619 .15659 L
.70604 .15655 L
.63736 .13775 L
.56868 .11394 L
.5 .10641 L
.43132 .11394 L
.36264 .13775 L
.29396 .15655 L
.2745 .08791 L
.29396 .05486 L
.36264 .03506 L
.38122 .01923 L
.98077 .01923 L
F
0 g
.98077 .95719 m
.95815 .91209 L
.91209 .87855 L
.84341 .8807 L
.77473 .86178 L
.70619 .84341 L
.77473 .77819 L
.78023 .77473 L
.83567 .70604 L
.84341 .69323 L
.86762 .63736 L
.87454 .56868 L
.88519 .5 L
.87454 .43132 L
.86762 .36264 L
.84341 .30677 L
.83567 .29396 L
.78023 .22527 L
.77473 .22181 L
.70619 .15659 L
.70604 .15655 L
.63736 .13775 L
.56868 .11394 L
.5 .10641 L
.43132 .11394 L
.36264 .13775 L
.29396 .15655 L
.2745 .08791 L
.29396 .05486 L
.36264 .03506 L
.38122 .01923 L
s
0 .4 1 r
.29396 .0727 m
.36264 .05988 L
.39403 .08791 L
.36264 .10174 L
.29396 .12696 L
.288 .08791 L
F
0 g
.29396 .0727 m
.36264 .05988 L
.39403 .08791 L
.36264 .10174 L
.29396 .12696 L
.288 .08791 L
.29396 .0727 L
s
1 0 0 r
.43132 .35391 m
.5 .33799 L
.56868 .35391 L
.58361 .36264 L
.63736 .41728 L
.64553 .43132 L
.66251 .5 L
.64553 .56868 L
.63736 .58272 L
.58361 .63736 L
.56868 .64609 L
.5 .66201 L
.43132 .64609 L
.41639 .63736 L
.36264 .58272 L
.35447 .56868 L
.33749 .5 L
.35447 .43132 L
.36264 .41728 L
.41639 .36264 L
F
0 g
.43132 .35391 m
.5 .33799 L
.56868 .35391 L
.58361 .36264 L
.63736 .41728 L
.64553 .43132 L
.66251 .5 L
.64553 .56868 L
.63736 .58272 L
.58361 .63736 L
.56868 .64609 L
.5 .66201 L
.43132 .64609 L
.41639 .63736 L
.36264 .58272 L
.35447 .56868 L
.33749 .5 L
.35447 .43132 L
.36264 .41728 L
.41639 .36264 L
.43132 .35391 L
s
0 .4 1 r
.98077 .39934 m
.91209 .38892 L
.90374 .36264 L
.8821 .29396 L
.84341 .24053 L
.82631 .22527 L
.77473 .18707 L
.76784 .15659 L
.70604 .12696 L
.63736 .10174 L
.60597 .08791 L
.56868 .07719 L
.5 .06461 L
.43132 .07719 L
.39797 .01923 L
.98077 .01923 L
F
0 g
.98077 .39934 m
.91209 .38892 L
.90374 .36264 L
.8821 .29396 L
.84341 .24053 L
.82631 .22527 L
.77473 .18707 L
.76784 .15659 L
.70604 .12696 L
.63736 .10174 L
.60597 .08791 L
.56868 .07719 L
.5 .06461 L
.43132 .07719 L
.39797 .01923 L
s
.2 0 1 r
.4988 .98077 m
.43132 .95878 L
.41712 .98077 L
F
0 g
.4988 .98077 m
.43132 .95878 L
.41712 .98077 L
s
.2 0 1 r
.4988 .01923 m
.43132 .04122 L
.41712 .01923 L
F
0 g
.4988 .01923 m
.43132 .04122 L
.41712 .01923 L
s
.2 0 1 r
.58288 .01923 m
.56868 .04122 L
.5012 .01923 L
F
0 g
.58288 .01923 m
.56868 .04122 L
.5012 .01923 L
s
.2 0 1 r
.58288 .98077 m
.56868 .95878 L
.5012 .98077 L
F
0 g
.58288 .98077 m
.56868 .95878 L
.5012 .98077 L
s
0 1 1 r
.98077 .05192 m
.91209 .04978 L
.88628 .08791 L
.84341 .12653 L
.77473 .15332 L
.712 .08791 L
.70604 .0727 L
.63736 .05988 L
.60203 .01923 L
.98077 .01923 L
F
0 g
.98077 .05192 m
.91209 .04978 L
.88628 .08791 L
.84341 .12653 L
.77473 .15332 L
.712 .08791 L
.70604 .0727 L
.63736 .05988 L
.60203 .01923 L
s
0 .4 1 r
.63736 .89826 m
.70604 .87304 L
.712 .91209 L
.70604 .9273 L
.63736 .94012 L
.60597 .91209 L
F
0 g
.63736 .89826 m
.70604 .87304 L
.712 .91209 L
.70604 .9273 L
.63736 .94012 L
.60597 .91209 L
.63736 .89826 L
s
0 1 .4 r
.98077 .04281 m
.91209 .04226 L
.87842 .08791 L
.84341 .1193 L
.77473 .13822 L
.7255 .08791 L
.70604 .05486 L
.63736 .03506 L
.61878 .01923 L
.98077 .01923 L
F
0 g
.98077 .04281 m
.91209 .04226 L
.87842 .08791 L
.84341 .1193 L
.77473 .13822 L
.7255 .08791 L
.70604 .05486 L
.63736 .03506 L
.61878 .01923 L
s
.2 1 0 r
.98077 .96485 m
.94907 .91209 L
.91209 .88745 L
.84341 .88786 L
.77473 .87481 L
.73783 .91209 L
.70604 .95653 L
.63736 .97896 L
.63486 .98077 L
.98077 .98077 L
F
0 g
.98077 .96485 m
.94907 .91209 L
.91209 .88745 L
.84341 .88786 L
.77473 .87481 L
.73783 .91209 L
.70604 .95653 L
.63736 .97896 L
.63486 .98077 L
s
.2 1 0 r
.98077 .03515 m
.91209 .03573 L
.8706 .08791 L
.84341 .11214 L
.77473 .12519 L
.73783 .08791 L
.70604 .04347 L
.63736 .02104 L
.63486 .01923 L
.98077 .01923 L
F
0 g
.98077 .03515 m
.91209 .03573 L
.8706 .08791 L
.84341 .11214 L
.77473 .12519 L
.73783 .08791 L
.70604 .04347 L
.63736 .02104 L
.63486 .01923 L
s
.8 1 0 r
.98077 .97155 m
.93808 .91209 L
.91209 .89655 L
.84341 .89511 L
.77473 .88724 L
.74992 .91209 L
.70604 .9654 L
.65305 .98077 L
.98077 .98077 L
F
0 g
.98077 .97155 m
.93808 .91209 L
.91209 .89655 L
.84341 .89511 L
.77473 .88724 L
.74992 .91209 L
.70604 .9654 L
.65305 .98077 L
s
.8 1 0 r
.98077 .02845 m
.91209 .02991 L
.86261 .08791 L
.84341 .10489 L
.77473 .11276 L
.74992 .08791 L
.70604 .0346 L
.65305 .01923 L
.98077 .01923 L
F
0 g
.98077 .02845 m
.91209 .02991 L
.86261 .08791 L
.84341 .10489 L
.77473 .11276 L
.74992 .08791 L
.70604 .0346 L
.65305 .01923 L
s
1 .6 0 r
.98077 .97755 m
.92354 .91209 L
.91209 .90621 L
.84341 .90265 L
.77473 .89993 L
.76249 .91209 L
.70604 .97285 L
.67339 .98077 L
.98077 .98077 L
F
0 g
.98077 .97755 m
.92354 .91209 L
.91209 .90621 L
.84341 .90265 L
.77473 .89993 L
.76249 .91209 L
.70604 .97285 L
.67339 .98077 L
s
1 .6 0 r
.98077 .02245 m
.91209 .02463 L
.85419 .08791 L
.84341 .09735 L
.77473 .10007 L
.76249 .08791 L
.70604 .02715 L
.67339 .01923 L
.98077 .01923 L
F
0 g
.98077 .02245 m
.91209 .02463 L
.85419 .08791 L
.84341 .09735 L
.77473 .10007 L
.76249 .08791 L
.70604 .02715 L
.67339 .01923 L
s
1 0 0 r
.92667 .98077 m
.91209 .91709 L
.89862 .91209 L
.84341 .91076 L
.77924 .91209 L
.77473 .91401 L
.70604 .97934 L
.69846 .98077 L
F
0 g
.92667 .98077 m
.91209 .91709 L
.89862 .91209 L
.84341 .91076 L
.77924 .91209 L
.77473 .91401 L
.70604 .97934 L
.69846 .98077 L
s
1 0 0 r
.92667 .01923 m
.91209 .01978 L
.84495 .08791 L
.84341 .08924 L
.77741 .08791 L
.77473 .08599 L
.70604 .02066 L
.69846 .01923 L
F
0 g
.92667 .01923 m
.91209 .01978 L
.84495 .08791 L
.84341 .08924 L
.77741 .08791 L
.77473 .08599 L
.70604 .02066 L
.69846 .01923 L
s
0 .4 1 r
.98077 .94808 m
.96597 .91209 L
.91209 .86953 L
.84341 .87347 L
.77473 .84668 L
.76784 .84341 L
.77473 .81293 L
.82631 .77473 L
.84341 .75947 L
.8821 .70604 L
.90374 .63736 L
.91209 .61108 L
.98077 .60066 L
F
0 g
.98077 .94808 m
.96597 .91209 L
.91209 .86953 L
.84341 .87347 L
.77473 .84668 L
.76784 .84341 L
.77473 .81293 L
.82631 .77473 L
.84341 .75947 L
.8821 .70604 L
.90374 .63736 L
.91209 .61108 L
.98077 .60066 L
s
.2 0 1 r
.98077 .93653 m
.97291 .91209 L
.91209 .86007 L
.84341 .86598 L
.79055 .84341 L
.84341 .7847 L
.88113 .77473 L
.91209 .74871 L
.92928 .70604 L
.9322 .63736 L
.98077 .60753 L
F
0 g
.98077 .93653 m
.97291 .91209 L
.91209 .86007 L
.84341 .86598 L
.79055 .84341 L
.84341 .7847 L
.88113 .77473 L
.91209 .74871 L
.92928 .70604 L
.9322 .63736 L
.98077 .60753 L
s
.2 0 1 r
.98077 .39247 m
.9322 .36264 L
.92928 .29396 L
.91209 .25129 L
.88113 .22527 L
.84341 .2153 L
.79055 .15659 L
.84341 .13402 L
.89439 .08791 L
.91209 .0588 L
.98077 .06347 L
F
0 g
.98077 .39247 m
.9322 .36264 L
.92928 .29396 L
.91209 .25129 L
.88113 .22527 L
.84341 .2153 L
.79055 .15659 L
.84341 .13402 L
.89439 .08791 L
.91209 .0588 L
.98077 .06347 L
s
.8 0 1 r
.98077 .91932 m
.97918 .91209 L
.91209 .84962 L
.84341 .85797 L
.80918 .84341 L
.84341 .79983 L
.91209 .79429 L
.98077 .82734 L
F
0 g
.98077 .91932 m
.97918 .91209 L
.91209 .84962 L
.84341 .85797 L
.80918 .84341 L
.84341 .79983 L
.91209 .79429 L
.98077 .82734 L
s
.8 0 1 r
.98077 .17266 m
.91209 .19746 L
.84341 .20017 L
.80918 .15659 L
.84341 .14203 L
.90304 .08791 L
.91209 .07054 L
.98077 .08068 L
F
0 g
.98077 .17266 m
.91209 .19746 L
.84341 .20017 L
.80918 .15659 L
.84341 .14203 L
.90304 .08791 L
.91209 .07054 L
.98077 .08068 L
s
1 0 .6 r
.84341 .8182 m
.89098 .84341 L
.84341 .84895 L
.82966 .84341 L
F
0 g
.84341 .8182 m
.89098 .84341 L
.84341 .84895 L
.82966 .84341 L
.84341 .8182 L
s
1 0 .6 r
.84341 .15105 m
.89098 .15659 L
.84341 .1818 L
.82966 .15659 L
F
0 g
.84341 .15105 m
.89098 .15659 L
.84341 .1818 L
.82966 .15659 L
.84341 .15105 L
s
0 1 .4 r
.98077 .59385 m
.93971 .56868 L
.92983 .5 L
.93971 .43132 L
.98077 .40615 L
F
0 g
.98077 .59385 m
.93971 .56868 L
.92983 .5 L
.93971 .43132 L
.98077 .40615 L
s
.2 1 0 r
.98077 .58694 m
.95681 .56868 L
.95212 .5 L
.95681 .43132 L
.98077 .41306 L
F
0 g
.98077 .58694 m
.95681 .56868 L
.95212 .5 L
.95681 .43132 L
.98077 .41306 L
s
.8 0 1 r
.98077 .70553 m
.95358 .63736 L
.98077 .61461 L
F
0 g
.98077 .70553 m
.95358 .63736 L
.98077 .61461 L
s
.8 0 1 r
.98077 .38539 m
.95358 .36264 L
.98077 .29447 L
F
0 g
.98077 .38539 m
.95358 .36264 L
.98077 .29447 L
s
.8 1 0 r
.98077 .57979 m
.96829 .56868 L
.96514 .5 L
.96829 .43132 L
.98077 .42021 L
F
0 g
.98077 .57979 m
.96829 .56868 L
.96514 .5 L
.96829 .43132 L
.98077 .42021 L
s
1 0 .6 r
.98077 .68864 m
.9685 .63736 L
.98077 .62211 L
F
0 g
.98077 .68864 m
.9685 .63736 L
.98077 .62211 L
s
1 0 .6 r
.98077 .37789 m
.9685 .36264 L
.98077 .31136 L
F
0 g
.98077 .37789 m
.9685 .36264 L
.98077 .31136 L
s
1 .6 0 r
.98077 .57216 m
.97737 .56868 L
.97507 .5 L
.97737 .43132 L
.98077 .42784 L
F
0 g
.98077 .57216 m
.97737 .56868 L
.97507 .5 L
.97737 .43132 L
.98077 .42784 L
s
1 0 0 r
.98077 .6704 m
.97753 .63736 L
.98077 .63036 L
F
0 g
.98077 .6704 m
.97753 .63736 L
.98077 .63036 L
s
1 0 0 r
.98077 .36964 m
.97753 .36264 L
.98077 .3296 L
F
0 g
.98077 .36964 m
.97753 .36264 L
.98077 .3296 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@007`3IfMT4
000000<0fMWI0`00000e0=WIf@<000000P3IfMT3000003@0fMWI0`00000h0=WIf@<000000P3IfMT3
000003@0fMWI100000030=WIf@<000001@3IfMT001l0fMWI00L000000=WIf@3IfMT0fMWI0000003I
fMT0000000<0fMWI00<000000=WIf@3IfMT0<`3IfMT010000000fMWI0=WIf@0000030=WIf@030000
003IfMT0fMWI0300fMWI00D000000=WIf@3IfMT0fMWI0000000h0=WIf@040000003IfMT0fMWI0000
00<0fMWI00<000000=WIf@3IfMT0<@3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000000`3I
fMT00`000000fMWI0=WIf@020=WIf@00803IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0
fMWI0=WIf@000000=@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0300fMWI
00D000000=WIf@3IfMT0fMWI0000000h0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WI
f@3IfMT0<P3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT0
01L0fMWI1`0000030=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT00`000000fMWI0=WIf@0Y
0=WIf@L000000`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0300fMWI00D0
00000=WIf@3IfMT0fMWI0000000h0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3I
fMT0<`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00280
fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0c0=WIf@040000003IfMT0fMWI
000000<0fMWI00<000000=WIf@3IfMT0<03IfMT01@000000fMWI0=WIf@3IfMT0000003P0fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0d0=WIf@040000003IfMT0fMWI000000<0
fMWI00<000000=WIf@3IfMT00P3IfMT00280fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000
fMWI0=WIf@0c0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0<03IfMT01@00
0000fMWI0=WIf@3IfMT0000003P0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WI
f@0d0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001l0fMWI00@0
00000=WIf@3IfMT000000P3IfMT01@000000fMWI0=WIf@3IfMT0000003D0fMWI00@000000=WIf@3I
fMT000000`3IfMT00`000000fMWI0=WIf@0`0=WIf@050000003IfMT0fMWI0=WIf@000000>03IfMT0
10000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI0340fMWI00@000000=WIf@3IfMT00000
0P3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI000P0=WIf@800000103IfMT3000003D0fMWI
0P0000030=WIf@<00000=03IfMT3000003P0fMWI0P0000030=WIf@<00000=@3IfMT2000000@0fMWI
0`0000050=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00
o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00703IfMWo000000400000103IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00D000000=WI
f@3IfMT0fMWI000000040=WIf@002P3IfMT4000000<0fMWI0`0000080=WIf@030000003IfMT0fMWI
0?`0fMWI00<000000=WIf@3IfMT00P3IfMT000X0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0
000000<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3l0=WIf@030000003IfMT0
fMWI0080fMWI000;0=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI00000007
0=WIf@030000003IfMT0fMWI0?`0fMWI00<000000=WIf@3IfMT00P3IfMT000<0fMWI1`0000020=WI
f@050000003IfMT0fMWI0=WIf@0000000`3IfMT00`000000fMWI0=WIf@050=WIf@8000000`3IfMT5
000000P0fMWI1@00000c0=WIf@@000000`3IfMT300000080fMWI0`0000020=WIf@<000000P3IfMT2
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@H000004P3IfMT0
0`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI0=WIf@8000000P3IfMT300000080fMWI0`00
00020=WIf@<000000`3IfMT4000003<0fMWI1@0000040=WIf@X000000P3IfMT2000000@0fMWI000=
0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@020=WIf@D0c?l02@0000040?nI00030000003o0000o`0002l0o`0000@000000?nI003oV@00oiT0
100000020<co00<000000P0co`03000000@00?mV00<00000003oo`00ool00`00ool00`00000006Ko
001Vo`02001Vo`030000000c0?l0<`3o00d0<`3o0`000006001Vo`<000003`0c0?l00`00000006Ko
001Vo`02001Vo`0300000000ool00?oo00<00?oo00<00000003oIP00ofH00P00ofH300000080<ol0
0`0000020<co00@000000`3oV@000`000000o`000?l0000_0?l000X000002@3<o`040=WIf@030000
003IfMT0fMWI0080fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@020=WIf@D000002@3<o`04000000030?nI00000000o`0002h0o`00
00<000000?nI003oV@000P0000030<co00<000000P0co`03000000H00?mV00<00000003oo`00ool0
1@00ool00`00000006Ko001Vo`02001Vo`030000000c0?l0<`3o00P0<`3o1000000<001Vo`@00000
2P0c0?l00`00000006Ko001Vo`04001Vo`0300000000ool00?oo00<00?oo00<00000003oIP00ofH0
1000ofH300000080<ol00`0000030<co008000000P3oV@000`000000o`000?l0000]0?l000030000
003oV@000000018000000`3IfMT00`000000fMWI0=WIf@020=WIf@002P3IfMT010000000fMWI0=WI
f@0000020=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@020=WIf@D0
<ol02@0000030<co00040000003oV@00oiT0000002d0o`0000@000000?nI003oV@0000000P3<o`03
00000080<ol00`000008003oIP0300000000ool00?oo00L00?oo00<00000001Vo`00I_l00P00I_l0
0`000000<`3o03<0o`0403<0o`<000005000I_l3000000H0<`3o00<00000001Vo`00I_l01P00I_l0
0`0000000?oo003oo`03003oo`0300000000ofH00?mV00H00?mV0`00000203?o00<000000P3<o`00
10000000oiT00?nI0000000]0?l000040000003oV@00000000000140<ol0103IfMT00`000000fMWI
0=WIf@020=WIf@002`3IfMT2000000@0fMWI0`0000080=WIf@030000003IfMT0fMWI0080fMWI1000
000:03?o00D000000P3oV@000`000000o`000?l0000Y0?l000050000003oV@00oiT00000003<o`00
0P00000203?o00<000002000ofH3000000X00?oo00<00000001Vo`00I_l00`00I_l00`000000<`3o
03<0o`03000001X006Ko0`00000203<0o`0300000000I_l006Ko00P006Ko00<00000003oo`00ool0
0`00ool3000000P00?mV0`00000203?o0080000000D0c?l00000003oV@00oiT00000000[0?l00003
0000003oV@00000001@000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@@00?mV1P00000703?o00030000003<o`0000000080oiT000<000000?l0003o0000
9`3o000010000000oiT00?nI000000020<co00@000002000ofH3000000h00?oo00<00000001Vo`00
I_l00`00I_l20000020006Ko0P00000<001Vo`0300000000ool00?oo00D00?oo0`000008003oIP@0
00000P3<o`0010000000oiT00?nI0000000Y0?l000060000003oV@0000000000000co`0000004@00
ofH40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI10000006
003oIPD000000`0co`000`000000c?l0000000020?nI00030000003o0000o`0002D0o`0000@00000
0?nI003oV@0000000P3<o`02000000L00?mV1000000B003oo`0300000000I_l006Ko03<006Ko00<0
0000003oo`00ool01`00ool4000000L00?mV0P0000020<co00040000003oV@00oiT0000002L0o`00
00D000000?nI00000000000003?o000D000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI
00<000000=WIf@3IfMT00P3IfMT4003oo`H000001@00ofH30000000403?o00000000c?l000000080
oiT000<000000?l0003o00008`3o000010000000oiT00?nI000000020<co00030000000co`000000
00@00?mV0`00000F003oo`0300000000I_l006Ko03@006Ko00<00000003oo`00ool02P00ool30000
00@00?mV00<0000003?o000000000P3<o`0010000000oiT00?nI0000000U0?l000070000003oV@00
00000000000co`000000003oIP0:000000P00?oo103IfMT00`000000fMWI0=WIf@020=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@<000001`00ool5000000800?mV00H0000003?o000co`000000
0<co000000020?nI00030000003o0000o`000240o`0000@000000?nI003oV@0000000P3<o`000`00
0000<ol000000002003oIP<000006P00ool00`00000006Ko001Vo`0d001Vo`0300000000ool00?oo
00`00?oo0`000002003oIP030000000co`0000000080c?l000@000000?nI003oV@0000008`3o0000
1`000000oiT0000000000000<ol000000000ofH00P000009001Vo`T000000`3IfMT00`000000fMWI
0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<006Ko0`000009003oo`@000000P0c
o`000`000000c?l0000000020?nI00030000003o0000o`0001l0o`0000@000000?nI003oV@000000
0P3<o`0010000000<ol000000000ofH2000001d00?oo00<00000001Vo`00I_l0=@00I_l00`000000
0?oo003oo`0>003oo`80000000@00?mV0000000co`0000000P3<o`0010000000oiT00?nI0000000Q
0?l000070000003oV@0000000000000co`000000003oIP020000018006Ko103IfMT00`000000fMWI
0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@H006Ko10000007003oo`0300000000
ofH000000080<ol000<000000<co000000000P3oV@000`000000o`000?l0000M0?l000040000003o
V@00oiT000000080c?l000<0000003?o000000000P00ofH00`0000000?oo003oo`0;003oo`D00000
3@00ool00`00000006Ko001Vo`0e001Vo`@000003@00ool01P0000000?mV003oIP000000<ol00000
0080c?l000@000000?nI003oV@0000007`3o00001`000000oiT0000000000000<ol000000000ofH0
0P0000000`00I_l0000000000008000000P006Ko103IfMT00`000000fMWI0=WIf@020=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@8000002000I_l3000000D00?oo00<00000003oIP0000000P0c
o`000`000000c?l0000000020?nI00030000003o0000o`0001/0o`0000@000000?nI003oV@000000
0P3<o`001P000000<ol003?o000000000?mV000000P00?oo1P000005001Vo`0300000000ool00?oo
00/00?oo00<00000001Vo`00I_l03P00I_l7000002<006Ko1P000008003oo`0300000000ofH00000
0080<ol000@000000<co003<o`0000000P3oV@000`000000o`000?l0000K0?l000040000003oV@00
00000<co0080000000H00?mV00000000ool00000001Vo`00000903<0o`T000000`3IfMT00`000000
fMWI0=WIf@020=WIf@00703IfMT2000000<0fMWI0P0c0?l3000000P006Ko0`000003003oo`050000
0000ofH0000003?o000000000P3<o`0010000000oiT00?nI0000000K0?l000040000003oV@00oiT0
000000<0c?l000D0000003?o000000000?mV00000004003oo`D000003000I_l00`0000000?oo003o
o`0:003oo`0300000000I_l006Ko00P006Ko1P000007003oo`H000008`00I_l5000000@00?oo00D0
0000003oIP000000<ol0000000030<co00040000003oV@00oiT0000001/0o`0000H000000?nI0000
0000c?l00000000co`0200000004003oo`00000006Ko00000180<`3o0`3IfMT2000000@0fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI1@0c0?l3000000P006Ko0P000002003oo`0500000000ofH0
000003?o000000000P3<o`0010000000oiT00?nI0000000I0?l000040000003oV@00oiT0000000<0
c?l000<0000003?o000000000P00ofH00`0000000?oo000000020000018006Ko00<00000003oo`00
ool02P00ool01000000006Ko001Vo`00I_l6000001<00?oo1@00000S001Vo`<0000000L00?oo0000
0000ofH00?mV0000000co`00000000<0c?l000@000000?nI003oV@0000006@3o000020000000oiT0
0000003<o`00000003?o000000000?mV0P0000000`00I_l0000003<0o`06000000`0<`3o103IfMT0
0`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@P0<`3o0`000006001V
o`0400000000ool00?oo000000800?mV00<0000003?o000000000P3<o`0010000000oiT00?nI0000
000G0?l000040000003oV@00oiT0000000<0c?l000H0000003?o000co`000000003oIP000002003o
o`0300000000I_l006Ko01<006Ko00<00000003oo`00ool02P00ool3000001h00?oo1@00000P001V
o`0600000000ool00?oo00000000ofH000000P0co`001@000000c?l00<co003<o`0000000080oiT0
00<000000?l0003o00005@3o000020000000oiT00000003<o`00000003?o000000000?mV0P000000
1@00I_l0000003<0o`0c0?l0000000D0c03o2@00000303<0o`@0fMWI00<000000=WIf@3IfMT00P3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT5000000H0<`3o0`000004001Vo`0400000000ool0
0?oo000000800?mV00<0000003?o000000000P3<o`0010000000oiT00?nI0000000E0?l000040000
003oV@00oiT0000000<0c?l000@0000003?o000co`0000000P00ofH00`0000000?oo0000000G001V
o`0300000000ool00?oo02l00?oo0`00000N001Vo`0300000000ool0000000800?mV00@0000003?o
000co`0000000`3<o`0010000000oiT00?nI0000000E0?l0000?0000003oV@0000000<co00000000
<ol000000000ofH00000003oo`00000006Ko0000000c0?l0000000l0c03o100000030=WIf@030000
003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1@3<0?l700000080<`3o0`00
0002001Vo`0400000000ool00?oo000000800?mV00<0000003?o000000000P3<o`0010000000oiT0
0?nI0000000C0?l000040000003oV@00oiT0000000<0c?l000@0000003?o000co`0000000P00ofH0
100000000?oo003oo`00000H001Vo`0300000000ool00?oo03400?oo0`00000K001Vo`0400000000
ool00?oo000000800?mV00@0000003?o000co`0000000`3<o`0010000000oiT00?nI0000000C0?l0
000=0000003oV@0000000<co00000000<ol000000000ofH00000003oo`00000006Ko0000000203<0
o`030000003<0?l0c03o0100c03o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@`0c03o0`00000203<0o`80000000@006Ko0000000000000?oo0P0000000`00
ofH0000000000002000000050<co0000000000000?nI000000002@3o000900000080oiT000D00000
0<co003<o`00c?l00000000203?o000400000000ofH00?mV000000800?oo00<00000001Vo`00I_l0
5`00I_l2000003D00?oo0`00000I001Vo`0400000000ool00?oo000000800?mV00@0000003?o000c
o`0000000`3<o`000`000000oiT00?nI000:000000P0o`0000@000000?nI00000000c?l02@000000
0`0c0?l000000000000C0<`0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT>0<`0o`030000000c0?l0<`3o0080<`3o00@00000001Vo`00I_l000000P00ool0
1P0000000?mV003oIP000000<ol000000080c?l000<000000?nI000000002000000:0?nI00050000
003<o`00c?l00<co000000000P0co`001@0000000?mV003oIP00ofH0000000800?oo00<00000001V
o`00I_l05@00I_l2000003X00?oo0P00000G001Vo`0500000000ool00?oo003oo`0000000P00ofH0
10000000<ol003?o000000030<co00030000003oV@00oiT000T0oiT0200000000`3oV@0000000<co
000200000006003oIP0000000?oo00000000I_l000000P0c0?l00`000000c03o0<`0o`0C0<`0o`@0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT?0<`0o`030000
000c0?l0<`3o0080<`3o0P0000001000I_l0000000000000ool200000003003oIP00000000000080
000000<0c?l00000003oV@004@3oV@001@000000c?l00<co003<o`0000000080<ol000<00000003o
IP00ofH00P00ofH0100000000?oo003oo`00000E001Vo`800000?P00ool2000001H006Ko00D00000
003oo`00ool00?oo00000002003oIP040000000co`00<ol0000000<0c?l000<000000?nI003oV@00
403oV@002P000000c?l00000000000000?mV00000000ool00000001Vo`00000203<0o`030000003<
0?l0c03o01@0c03o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@l0c03o00<0000003<0o`0c0?l0100c0?l01000000006Ko001Vo`000002003oo`0700000000
ofH00?mV0000000co`0000000<co000B000000<0c?l000@0000003?o000co`0000001P00ofH01000
00000?oo003oo`00000B001Vo`800000@P00ool2000001D006Ko00D00000003oo`00ool00?oo0000
0002003oIP040000000co`00<ol0000000<0c?l04P0000002@3<o`00000000000000ofH00000003o
o`00000006Ko0000000203<0o`030000003<0?l0c03o01D0c03o103IfMT00`000000fMWI0=WIf@02
0=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA00c03o00<0000003<0o`0c0?l0100c0?l20000
0004001Vo`0000000000003oo`80000000@00?mV0000000000000000503<o`0010000000<ol003?o
00000007003oIP0400000000ool00?oo0000010006Ko0P000016003oo`8000005000I_l01@000000
0?oo003oo`00ool0000000800?mV00@0000003?o000co`000000503<o`0200000006003oIP000000
0?oo00000000I_l000000P0c0?l00`000000c03o0<`0o`0F0<`0o`@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT@0<`0o`030000000c0?l0<`3o00H0<`3o00@0
0000001Vo`00I_l000000P00ool00`0000000?mV003oIP06000000h0c?l000@0000003?o000co`00
00002000ofH0100000000?oo003oo`00000=001Vo`<000008@00ool9000002000?oo0`00000B001V
o`0500000000ool00?oo003oo`0000000P00ofH010000000<ol003?o0000000>0<co00H0000000H0
0?mV00000000ool00000001Vo`00000203<0o`030000003<0?l0c03o01L0c03o103IfMT00`000000
fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA00c03o00<0000003<0o`0c0?l0
1`0c0?l200000004001Vo`0000000000003oo`80000000@00?mV00000000000000000P0co`090000
00@0c?l000@0000003?o000co`0000002P00ofH00`0000000?oo0000000:001Vo`<000006`00ool9
000000T00?mV2@00000J003oo`<000004000I_l01@0000000?oo003oo`00ool0000000800?mV00@0
000003?o000co`000000103<o`0900000080<ol00`0000001P00ofH00000003oo`00000006Ko0000
0080<`3o00<000000<`0o`3<0?l0603<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@80
00000`3IfMTA0<`0o`8000002@0c0?l01000000006Ko001Vo`000002003oo`0400000000ofH00?mV
003oIP@000001`0co`0400000080<ol000<00000003oIP00ofH02@00ofH00`0000000?oo00000007
001Vo`<000006000ool6000001/00?mV1P00000G003oo`<000003P00I_l01@0000000?oo003oo`00
ool0000000800?mV00<0000003?o000co`001000000703?o00@000000`00ofH01P0000000?oo0000
0000I_l0000003<0o`8000006`3<0?l30=WIf@800000103IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMTC0<`0o`<000001`0c0?l200000004001Vo`0000000000003oo`<000001000ofH5000000L0
<ol000<00000003oIP00ofH02P00ofH0100000000?oo003oo`000003001Vo`<000006000ool30000
02L00?mV0`00000G003oo`<000003000I_l01@0000000?oo003oo`00ool0000000800?mV00<00000
03?o000co`001@0co`05000000@00?mV0`0000001P00ool00000001Vo`000000<`3o000001d0c03o
103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAH0c03o0P00
000703<0o`0400000000I_l006Ko000000<00?oo0`000006003oIP@000000P0co`000`0000000?mV
003oIP0;003oIP0300000000ool00?oo00@000006000ool3000002d00?mV0`00000G003oo`<00000
2P00I_l01@0000000?oo003oo`00ool0000000800?mV00<0000003?o000co`0010000006003oIP<0
00000`00ool01@00000006Ko0000000c0?l0000001h0c03o103IfMT00`000000fMWI0=WIf@020=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIfAP0c03o0`00000503<0o`80000000<006Ko00000000
00001000ool4000000H00?mV0P00000?003oIP0300000000ool0000001P00?oo0`00000c003oIP<0
00005`00ool2000000T006Ko00D00000003oo`00ool00?oo00000002003oIP8000001P00ofH40000
00@00?oo0P0000001000I_l0000003<0o`00000O0<`0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMTK0<`0o`<00000100c0?l00`00000006Ko001Vo`030000
00D00?oo0`00000D003oIP0300000000ool00?oo01D00?oo0`00000i003oIP<000005P00ool20000
00P006Ko00D00000003oo`00ool00?oo00000006003oIP<000001@00ool30000008006Ko00<00000
03<0o`000000803<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI7P3<0?l2000000<0<`3o0P000003001Vo`8000001P00ool3000001400?mV00<00000003o
o`00ool04P00ool3000003l00?mV0`00000E003oo`8000001`00I_l01@0000000?oo003oo`00ool0
000000800?mV0`000006003oo`8000000`00I_l20000000303<0o`000000c03o0200c03o103IfMT0
0`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfB00c03o0`00000203<0
o`8000000`00I_l3000000H00?oo1000000=003oIP0300000000ool00?oo00h00?oo10000015003o
IP<000005000ool2000000H006Ko00@00000003oo`00ool00?oo0P000006003oo`<000000`00I_l2
00000080<`3o00<000000<`0o`3<0?l0803<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI8`3<0?l200000080<`3o0P000004001Vo`8000002000ool30000
00/00?mV00<00000003oo`00ool02P00ool3000004`00?mV0`00000C003oo`8000001@00I_l00`00
00000?oo003oo`06003oo`8000001000I_l200000080<`3o0P00000S0<`0o`@0fMWI00<000000=WI
f@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTU0<`0o`8000000P0c0?l3000000<0
06Ko0P000009003oo`@000001`00ofH00`0000000?oo003oo`06003oo`@00000DP00ofH400000140
0?oo0P000004001Vo`0300000000ool00?oo00<00?oo0P000003001Vo`<000000P0c0?l2000002D0
c03o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfB00c03o
1@0000020<`0o`8000000`0c0?l2000000<006Ko0`00000:003oo`@000000`00ofH00`0000000?oo
003oo`03003oo`<000009000ofHC000002<00?mV0`00000@003oo`8000000`00I_l00`0000000?oo
00000002000000<006Ko0P00000303<0o`8000000P3<0?l500000200c03o103IfMT00`000000fMWI
0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAX0c03o1P0000050?l0V@040000003<
0?l0c03o0<`0o`8000000`0c0?l2000000@006Ko0P00000<003oo`<0000000<00?mV00000000ool0
0`00000M003oIPX000004`0co`0:000001`00?mV0`00000?003oo`8000000P00I_l00`00000006Ko
001Vo`02001Vo`8000000`0c0?l2000000<0c03o00<000000?l0V@3o09T00`3o09T7000001T0c03o
103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAL0c03o0`00
000<0?l0V@030000003<0?l0c03o0080c03o00<0000003<0o`0c0?l00P0c0?l00`00000006Ko001V
o`03001Vo`0300000000ool00?oo00`00?oo0`00000L003oIP@000009`0co`03000001`00?mV0`00
000>003oo`0300000000I_l006Ko00<006Ko00<0000003<0o`0c0?l00P0c0?l00`000000c03o0<`0
o`020<`0o`030000003o09T0o`2I00/0o`2I0`00000F0<`0o`@0fMWI00<000000=WIf@3IfMT00P3I
fMT001`0fMWI0P0000030=WIfAT0c03o0P00000;0?l0V@030000003<0?l0c03o0080c03o00<00000
03<0o`0c0?l00P0c0?l00`00000006Ko001Vo`03001Vo`0300000000ool00?oo00/00?oo00<00000
003oIP00ofH06@00ofH4000002h0<ol01000000K003oIP0300000000ool00?oo00/00?oo00<00000
001Vo`00I_l00`00I_l00`000000<`3o03<0o`0203<0o`030000003<0?l0c03o0080c03o00<00000
0?l0V@3o09T02P3o09T2000001P0c03o0`3IfMT2000000@0fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI6`3<0?l2000000P0o`2I00<000000<`0o`3<0?l00P3<0?l00`000000<`3o03<0o`0203<0
o`0300000000I_l006Ko00@006Ko00<00000003oo`00ool02P00ool00`0000000?mV003oIP0G003o
IP<00000=P0co`03000001T00?mV00<00000003oo`00ool02P00ool00`00000006Ko001Vo`04001V
o`030000000c0?l0<`3o0080<`3o00<000000<`0o`3<0?l00P3<0?l00`000000o`2I0?l0V@070?l0
V@8000006P3<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI7@3<0?l2000000H0o`2I00D000000<`0o`3<0?l0c03o0000000403<0o`0300000000I_l006Ko
00@006Ko00<00000003oo`00ool02P00ool00`0000000?mV003oIP0D003oIP@00000?00co`040000
01H00?mV00<00000003oo`00ool02P00ool00`00000006Ko001Vo`04001Vo`030000000c0?l0<`3o
0080<`3o00D000000<`0o`3<0?l0c03o000000060?l0V@<00000703<0?l40=WIf@030000003IfMT0
fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI0`00000L0<`0o`8000000`3o09T01@00
0000c03o0<`0o`3<0?l0000000@0<`3o00<00000001Vo`00I_l01@00I_l00`0000000?oo003oo`09
003oo`0300000000ofH00?mV01800?mV0`00001403?o00<000005000ofH00`0000000?oo003oo`09
003oo`0300000000I_l006Ko00D006Ko00<0000003<0o`0c0?l00P0c0?l01@000000c03o0<`0o`3<
0?l0000000<0o`2I0P00000N0<`0o`8000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIf@<0<`3o0`00000K0<`0o`80000000<0o`2I0000003<0?l00P3<0?l0
1@000000<`3o03<0o`0c0?l0000000P006Ko00<00000003oo`00ool02000ool00`0000000?mV003o
IP0A003oIP800000BP0co`02000001<00?mV00<00000003oo`00ool02000ool00`00000006Ko001V
o`06001Vo`050000000c0?l0<`3o03<0o`0000000`3<0?l010000000o`2I00000000000M0<`0o`<0
000000<0<`3o0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@H0<`3o1000000I0<`0o`050000003<0?l0c03o0<`0o`0000000`0c0?l00`000000
06Ko001Vo`07001Vo`0300000000ool00?oo00L00?oo00<00000003oIP00ofH04@00ofH00`000000
<ol003?o001<03?o000300000000ofH00?mV01400?mV00<00000003oo`00ool01`00ool00`000000
06Ko001Vo`07001Vo`050000000c0?l0<`3o03<0o`0000000`3<0?l00`000000c03o0<`0o`0J0<`0
o`<00000100c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI2P0c0?l3000001T0c03o00D0000003<0o`0c0?l0<`3o00000009001Vo`0300000000ool00?oo
00L00?oo00<00000003oIP00ofH04000ofH200000500<ol00P00000B003oIP0300000000ool00?oo
00L00?oo00<00000001Vo`00I_l01`00I_l01@000000<`3o03<0o`0c0?l0000001`0c03o0`000007
03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT=03<0
o`<000005P3<0?l010000000<`3o03<0o`000009001Vo`8000001`00ool2000001400?mV0P00001D
03?o008000004@00ofH2000000L00?oo0P000009001Vo`040000000c0?l0<`3o000001T0c03o0`00
000:03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT@
03<0o`L000003P3<0?l01@000000<`3o03<0o`0c0?l0000000P006Ko00<00000003oo`00ool01P00
ool00`0000000?mV003oIP0@003oIP030000000co`00<ol005H0<ol000<00000003oIP00ofH04000
ofH00`0000000?oo003oo`06003oo`0300000000I_l006Ko00H006Ko00D0000003<0o`0c0?l0<`3o
0000000E0<`0o`<000003@0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI5`0c0?l9000000@0c03o00D0000003<0o`0c0?l0<`3o00000007001Vo`800000
2000ool00`0000000?mV003oIP0?003oIP800000:@0co`09000002P0<ol00P00000A003oIP030000
0000ool00?oo00H00?oo0P000007001Vo`050000000c0?l0<`3o03<0o`0000002@3<0?l;00000100
<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfB00<`3o
1000000303<0o`0300000000I_l006Ko00D006Ko00<00000003oo`00ool01`00ool00`0000000?mV
003oIP0>003oIP8000008P0co`09000000T0c?l02@00000Q03?o008000004000ofH00`0000000?oo
003oo`07003oo`0300000000I_l006Ko00D006Ko00@0000003<0o`0c0?l0<`3o2@00000K03<0o`@0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTV03<0o`030000
0000I_l006Ko00@006Ko0P000009003oo`0300000000ofH00?mV00h00?mV00<0000003?o000co`00
6`0co`07000001/0c?l01P00000M03?o000300000000ofH00?mV00h00?mV00<00000003oo`00ool0
1`00ool2000000H006Ko00<0000003<0o`0c0?l0900c0?l40=WIf@030000003IfMT0fMWI0080fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI9@0c0?l00`00000006Ko001Vo`04001Vo`0300000000
ool00?oo00P00?oo00<00000003oIP00ofH03@00ofH2000001/0<ol00`00000X0<co00<000006`0c
o`02000000l00?mV00<00000003oo`00ool02000ool00`00000006Ko001Vo`04001Vo`030000000c
0?l0<`3o02<0<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT2000000<0fMWI900c0?l0
0`00000006Ko001Vo`04001Vo`0300000000ool00?oo00P00?oo00<00000003oIP00ofH03000ofH2
000001T0<ol01000000^0<co00@000006@0co`02000000h00?mV00<00000003oo`00ool02000ool0
0`00000006Ko001Vo`04001Vo`030000000c0?l0<`3o0280<`3o0`3IfMT2000000@0fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI8@0c0?l3000000D006Ko0P00000:003oo`0300000000ofH00?mV
00/00?mV0P00000H03?o00<00000=P3<o`03000001P0<ol00P00000=003oIP0300000000ool00?oo
00P00?oo0P000005001Vo`@00000800c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI700c0?l5000000L006Ko00<00000003oo`00ool02@00ool00`000000
0?mV003oIP0;003oIP030000000co`00<ol001D0<ol00`00000l0<co00<000005`0co`000`000000
0?mV003oIP0;003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l01P00I_l5000001/0
<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAP0<`3o
1000000;001Vo`0300000000ool00?oo00T00?oo00<00000003oIP00ofH02`00ofH00`000000<ol0
03?o000D03?o00800000@P3<o`02000001H0<ol000<00000003oIP00ofH02`00ofH00`0000000?oo
003oo`09003oo`0300000000I_l006Ko00X006Ko0`00000H03<0o`@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTG03<0o`0300000000I_l006Ko00`006Ko00<0
0000003oo`00ool02P00ool00`0000000?mV003oIP0;003oIP030000000co`00<ol00180<ol00P00
00160<co00800000500co`000`0000000?mV003oIP0;003oIP0300000000ool00?oo00X00?oo00<0
0000001Vo`00I_l03000I_l00`000000<`3o03<0o`0E03<0o`@0fMWI00<000000=WIf@3IfMT00P3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTF03<0o`0300000000I_l006Ko00`006Ko00<00000
003oo`00ool02P00ool00`0000000?mV003oIP0;003oIP030000000co`00<ol00180<ol000<00000
0<co003<o`00B03<o`000`000000<ol003?o000B03?o000300000000ofH00?mV00/00?mV00<00000
003oo`00ool02P00ool00`00000006Ko001Vo`0<001Vo`030000000c0?l0<`3o01@0<`3o103IfMT0
0`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAD0<`3o00<00000001V
o`00I_l03000I_l00`0000000?oo003oo`0:003oo`0300000000ofH00?mV00/00?mV00<0000003?o
000co`004@0co`02000004`0c?l00P00000C03?o000300000000ofH00?mV00/00?mV00<00000003o
o`00ool02P00ool00`00000006Ko001Vo`0<001Vo`030000000c0?l0<`3o01<0<`3o103IfMT00`00
0000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfA@0<`3o00<00000001Vo`00
I_l03000I_l00`0000000?oo003oo`0:003oo`0300000000ofH00?mV00/00?mV00<0000003?o000c
o`004@0co`000`000000c?l00<co001>0<co00030000000co`00<ol00140<ol000<00000003oIP00
ofH02`00ofH00`0000000?oo003oo`0:003oo`0300000000I_l006Ko00`006Ko00<0000003<0o`0c
0?l04P0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI
4`0c0?l00`00000006Ko001Vo`0=001Vo`0300000000ool00?oo00T00?oo00<00000003oIP00ofH0
2`00ofH00`000000<ol003?o000A03?o00030000003<o`00c?l00500c?l000<0000003?o000co`00
4@0co`000`0000000?mV003oIP0;003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l0
3@00I_l00`000000<`3o03<0o`0A03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT000`0fMWI0`00
00020=WIf@<00000203IfMT00`000000fMWI0=WIf@020=WIfA80<`3o00<00000001Vo`00I_l03@00
I_l00`0000000?oo003oo`0:003oo`0300000000ofH00?mV00X00?mV00<0000003?o000co`00400c
o`02000005@0c?l00P00000B03?o000300000000ofH00?mV00X00?mV00<00000003oo`00ool02P00
ool00`00000006Ko001Vo`0=001Vo`030000000c0?l0<`3o0100<`3o103IfMT00`000000fMWI0=WI
f@020=WIf@003@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT00P3IfMTA03<0o`0300000000I_l006Ko00d006Ko00<00000003oo`00ool02P00
ool00`0000000?mV003oIP0:003oIP030000000co`00<ol00100<ol000<000000<co003<o`00EP3<
o`000`000000<ol003?o000@03?o000300000000ofH00?mV00X00?mV00<00000003oo`00ool02P00
ool00`00000006Ko001Vo`0=001Vo`030000000c0?l0<`3o00l0<`3o103IfMT00`000000fMWI0=WI
f@020=WIf@003@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT00P3IfMTA03<0o`0300000000I_l006Ko00`006Ko00<00000003oo`00ool02P00
ool00`0000000?mV003oIP0:003oIP030000000co`00<ol000l0<ol00P00000Y0<co00T00000:03<
o`0200000140<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`0:003oo`0300000000
I_l006Ko00`006Ko00<0000003<0o`0c0?l03`0c0?l40=WIf@030000003IfMT0fMWI0080fMWI0003
0=WIf@L000000`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00D0fMWI0P00
00030=WIfA00<`3o00<00000001Vo`00I_l03@00I_l00`0000000?oo003oo`09003oo`0300000000
ofH00?mV00X00?mV00<0000003?o000co`003`0co`000`000000c?l00<co000P0<co00T000002@3o
V@0900000240c?l000<0000003?o000co`003`0co`000`0000000?mV003oIP0:003oIP0300000000
ool00?oo00T00?oo00<00000001Vo`00I_l03@00I_l00`000000<`3o03<0o`0>03<0o`<0fMWI0P00
00040=WIf@003@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT00P3IfMT@03<0o`0300000000I_l006Ko00`006Ko00<00000003oo`00ool02P00
ool00`0000000?mV003oIP09003oIP030000000co`00<ol000l0<ol000<000000<co003<o`006`3<
o`06000001/0oiT01@00000M0<co00030000000co`00<ol000l0<ol000<00000003oIP00ofH02@00
ofH00`0000000?oo003oo`0:003oo`0300000000I_l006Ko00`006Ko00<0000003<0o`0c0?l03P0c
0?l40=WIf@030000003IfMT0fMWI0080fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@020=WIfA00<`3o00<00000001Vo`00I_l02`00
I_l00`0000000?oo003oo`0:003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`003P0c
o`02000001`0c?l00P00000V0?nI00800000703<o`0200000100<ol000<00000003oIP00ofH02@00
ofH00`0000000?oo003oo`0:003oo`0300000000I_l006Ko00/006Ko00<0000003<0o`0c0?l03P0c
0?l40=WIf@030000003IfMT0fMWI0080fMWI000=0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@020=WIf@l0<`3o00<00000001Vo`00I_l03000
I_l00`0000000?oo003oo`09003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`003P0c
o`000`000000c?l00<co000J0<co00800000:P3oV@02000001`0c?l000<0000003?o000co`003P0c
o`000`0000000?mV003oIP09003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l03000
I_l00`000000<`3o03<0o`0=03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT000`0fMWI0P000003
0=WIf@<00000203IfMT00`000000fMWI0=WIf@020=WIf@l0<`3o00<00000001Vo`00I_l02`00I_l0
0`0000000?oo003oo`09003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`003P0co`00
0`000000c?l00<co000I0<co00800000;P3oV@02000001/0c?l000<0000003?o000co`003P0co`00
0`0000000?mV003oIP09003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l02`00I_l0
0`000000<`3o03<0o`0=03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT?03<0o`0300000000I_l006Ko00X006Ko00<00000003oo`00ool02@00ool00`00
00000?mV003oIP09003oIP030000000co`00<ol000h0<ol000<000000<co003<o`00603<o`020000
0380oiT00`00000I0<co00030000000co`00<ol000h0<ol000<00000003oIP00ofH02@00ofH00`00
00000?oo003oo`09003oo`0300000000I_l006Ko00X006Ko00<0000003<0o`0c0?l03@0c0?l40=WI
f@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI3P0c0?l00`000000
06Ko001Vo`0:001Vo`0300000000ool00?oo00X00?oo00<00000003oIP00ofH02@00ofH00`000000
<ol003?o000=03?o00030000003<o`00c?l001L0c?l00P00000g0?nI00800000603<o`000`000000
<ol003?o000=03?o000300000000ofH00?mV00T00?mV00<00000003oo`00ool02P00ool00`000000
06Ko001Vo`0:001Vo`030000000c0?l0<`3o00`0<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00
703IfMT00`000000fMWI0=WIf@020=WIf@h0<`3o00<00000001Vo`00I_l02P00I_l00`0000000?oo
003oo`09003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`003@0co`000`000000c?l0
0<co000F0<co00800000>`3oV@02000001L0c?l000<0000003?o000co`003@0co`000`0000000?mV
003oIP09003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l02P00I_l00`000000<`3o
03<0o`0<03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT>03<0o`0300000000I_l006Ko00T006Ko00<00000003oo`00ool02@00ool00`0000000?mV003o
IP0:003oIP030000000co`00<ol000`0<ol000<000000<co003<o`005@3<o`02000003l0oiT00P00
000F0<co00030000000co`00<ol000`0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003o
o`09003oo`0300000000I_l006Ko00T006Ko00<0000003<0o`0c0?l0300c0?l40=WIf@030000003I
fMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0000003<0o`0c0?l02P0c0?l0
0`00000006Ko001Vo`09001Vo`0300000000ool00?oo00T00?oo00<00000003oIP00ofH02P00ofH0
0`000000<ol003?o000<03?o00030000003<o`00c?l001@0c?l00P0000130?nI00030000003<o`00
c?l001@0c?l000<0000003?o000co`00300co`000`0000000?mV003oIP0:003oIP0300000000ool0
0?oo00T00?oo00<00000001Vo`00I_l02@00I_l00`000000<`3o03<0o`0;03<0o`050000003IfMT0
fMWI0=WIf@000000103IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000<`3o03<0o`0:
03<0o`0300000000I_l006Ko00T006Ko00<00000003oo`00ool02@00ool00`0000000?mV003oIP0:
003oIP030000000co`00<ol000`0<ol000<000000<co003<o`004`3<o`000`000000oiT00?nI0014
0?nI00030000003<o`00c?l001<0c?l000<0000003?o000co`00300co`000`0000000?mV003oIP0:
003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l02@00I_l00`000000<`3o03<0o`0;
03<0o`050000003IfMT0fMWI0=WIf@000000103IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`3<0?l0000003<0o`0:03<0o`0300000000I_l006Ko00P006Ko00<00000003oo`00ool02@00ool0
0`0000000?mV003oIP0:003oIP030000000co`00<ol000`0<ol000<000000<co003<o`004`3<o`00
0`000000oiT00?nI00160?nI00030000003<o`00c?l001<0c?l000<0000003?o000co`00300co`00
0`0000000?mV003oIP0:003oIP0300000000ool00?oo00T00?oo00<00000001Vo`00I_l02000I_l0
0`000000<`3o03<0o`0:03<0o`030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT0
01`0fMWI0P0000030=WIf@030<`0o`000000<`3o00X0<`3o00<00000001Vo`00I_l02000I_l00`00
00000?oo003oo`08003oo`0300000000ofH00?mV00/00?mV00<0000003?o000co`002`0co`000`00
0000c?l00<co000C0<co00030000003oV@00oiT004P0oiT000<000000<co003<o`004`3<o`000`00
0000<ol003?o000;03?o000300000000ofH00?mV00/00?mV00<00000003oo`00ool02000ool00`00
000006Ko001Vo`08001Vo`030000000c0?l0<`3o00X0<`3o00@000000=WIf@3IfMT0fMWI0P000004
0=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@8000002`0c0?l00`00000006Ko001Vo`08001V
o`0300000000ool00?oo00P00?oo00<00000003oIP00ofH02P00ofH00`000000<ol003?o000<03?o
00030000003<o`00c?l00180c?l000<000000?nI003oV@00BP3oV@000`000000c?l00<co000B0<co
00030000000co`00<ol000`0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`08003o
o`0300000000I_l006Ko00P006Ko00<0000003<0o`0c0?l02P0c0?l2000000<0fMWI00<000000=WI
f@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000c03o0000000:03<0o`03
00000000I_l006Ko00L006Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP0:003oIP03
0000000co`00<ol000`0<ol000<000000<co003<o`004P3<o`000`000000oiT00?nI001<0?nI0003
0000003<o`00c?l00180c?l000<0000003?o000co`00300co`000`0000000?mV003oIP0:003oIP03
00000000ool00?oo00P00?oo00<00000001Vo`00I_l01`00I_l00`000000<`3o03<0o`0903<0o`03
0000003<0?l0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000c03o0000000:03<0o`0300000000I_l006Ko00L006Ko00<00000003oo`00ool0
2000ool00`0000000?mV003oIP0:003oIP030000000co`00<ol000/0<ol000<000000<co003<o`00
4P3<o`000`000000oiT00?nI001>0?nI00030000003<o`00c?l00180c?l000<0000003?o000co`00
2`0co`000`0000000?mV003oIP0:003oIP0300000000ool00?oo00P00?oo00<00000001Vo`00I_l0
1`00I_l00`000000<`3o03<0o`0903<0o`030000003<0?l0000000<0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0103o09T000000<`0o`00000903<0o`030000
0000I_l006Ko00L006Ko00<00000003oo`00ool01`00ool00`0000000?mV003oIP0:003oIP030000
000co`00<ol000/0<ol000<000000<co003<o`004P3<o`000`000000oiT00?nI001@0?nI00030000
003<o`00c?l00180c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP0:003oIP030000
0000ool00?oo00L00?oo00<00000001Vo`00I_l01`00I_l00`000000<`3o03<0o`0803<0o`030000
003<0?l0000000@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT0103o09T000000<`0o`00000903<0o`0300000000I_l006Ko00H006Ko00<00000003oo`00ool0
2000ool00`0000000?mV003oIP0:003oIP030000000co`00<ol000/0<ol000<000000<co003<o`00
4@3<o`000`000000oiT00?nI001B0?nI00030000003<o`00c?l00140c?l000<0000003?o000co`00
2`0co`000`0000000?mV003oIP0:003oIP0300000000ool00?oo00P00?oo00<00000001Vo`00I_l0
1P00I_l00`000000<`3o03<0o`0803<0o`030000003<0?l0000000@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT200000080c03o00<0000003<0o`0c0?l01@0c
0?l00`00000006Ko001Vo`07001Vo`0300000000ool00?oo00P00?oo00<00000003oIP00ofH02@00
ofH00`000000<ol003?o000;03?o00030000003<o`00c?l00140c?l000<000000?nI003oV@00E03o
V@000`000000c?l00<co000A0<co00030000000co`00<ol000/0<ol000<00000003oIP00ofH02P00
ofH00`0000000?oo003oo`07003oo`0300000000I_l006Ko00L006Ko00<0000003<0o`0c0?l01P0c
0?l00`000000c03o0<`0o`02000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT200000080c03o00<0000003<0o`0c0?l01@0c0?l00`00000006Ko001Vo`07
001Vo`0300000000ool00?oo00L00?oo00<00000003oIP00ofH02@00ofH00`000000<ol003?o000;
03?o00030000003<o`00c?l00140c?l000<000000?nI003oV@00EP3oV@000`000000c?l00<co000A
0<co00030000000co`00<ol000/0<ol000<00000003oIP00ofH02@00ofH00`0000000?oo003oo`07
003oo`0300000000I_l006Ko00L006Ko00<0000003<0o`0c0?l01P0c0?l01@000000c03o0000003o
09T0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0
1@000000o`2I0000003<0?l0000000L0<`3o00<00000001Vo`00I_l01P00I_l00`0000000?oo003o
o`08003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`002`0co`000`000000c?l00<co
000@0<co00030000003oV@00oiT002T0oiT01@00000Z0?nI00030000003<o`00c?l00100c?l000<0
000003?o000co`002`0co`000`0000000?mV003oIP0:003oIP0300000000ool00?oo00L00?oo00<0
0000001Vo`00I_l01P00I_l00`000000<`3o03<0o`0603<0o`050000003<0?l000000?l0V@000000
0`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030000003o
09T000000080c03o00<0000003<0o`0c0?l0100c0?l00`00000006Ko001Vo`06001Vo`0300000000
ool00?oo00L00?oo00<00000003oIP00ofH02@00ofH00`000000<ol003?o000;03?o00030000003<
o`00c?l00100c?l000<000000?nI003oV@009@3oV@05000000D0o`001000000W0?nI00030000003<
o`00c?l00100c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP09003oIP0300000000
ool00?oo00L00?oo00<00000001Vo`00I_l01P00I_l00`000000<`3o03<0o`0503<0o`060000003<
0?l0c03o0000003o09T000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@030000003o09T000000080c03o00<0000003<0o`0c0?l0100c0?l00`00000006Ko
001Vo`06001Vo`0300000000ool00?oo00L00?oo00<00000003oIP00ofH02@00ofH00`000000<ol0
03?o000:03?o00030000003<o`00c?l00100c?l000<000000?nI003oV@008P3oV@04000000h0o`00
1@00000S0?nI00030000003<o`00c?l00100c?l000<0000003?o000co`002P0co`000`0000000?mV
003oIP0:003oIP0300000000ool00?oo00H00?oo00<00000001Vo`00I_l01P00I_l00`000000<`3o
03<0o`0503<0o`030000003<0?l000000080o`2I00D000000=WIf@3IfMT0fMWI000000040=WIf@00
703IfMT00`000000fMWI0=WIf@020=WIf@030000003o09T0000000<0c03o00<0000003<0o`0c0?l0
0`0c0?l00`00000006Ko001Vo`05001Vo`0300000000ool00?oo00L00?oo00<00000003oIP00ofH0
2@00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l00100c?l000<000000?nI003oV@00
7P3oV@05000001L0o`001000000P0?nI00030000003<o`00c?l00100c?l000<0000003?o000co`00
2P0co`000`0000000?mV003oIP09003oIP0300000000ool00?oo00L00?oo00<00000001Vo`00I_l0
1@00I_l00`000000<`3o03<0o`0403<0o`060000003<0?l0c03o0000003o09T00000103IfMT00`00
0000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030000003o09T0000000<0
c03o00<0000003<0o`0c0?l00`0c0?l00`00000006Ko001Vo`05001Vo`0300000000ool00?oo00L0
0?oo00<00000003oIP00ofH02000ofH00`000000<ol003?o000;03?o00030000003<o`00c?l000l0
c?l000<000000?nI003oV@00703oV@0300000200o`000`00000N0?nI00030000003<o`00c?l000l0
c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP09003oIP0300000000ool00?oo00H0
0?oo00<00000001Vo`00I_l01@00I_l00`000000<`3o03<0o`0403<0o`060000003<0?l0c03o0000
003o09T00000103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT2000000<0fMWI00@000000?l0
V@3o09T000000P3<0?l00`000000<`3o03<0o`0303<0o`0300000000I_l006Ko00D006Ko00<00000
003oo`00ool01`00ool00`0000000?mV003oIP08003oIP030000000co`00<ol000X0<ol000<00000
0<co003<o`003`3<o`000`000000oiT00?nI000K0?nI008000009P3o0002000001d0oiT000<00000
0<co003<o`003`3<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00T00?mV00<00000
003oo`00ool01P00ool00`00000006Ko001Vo`05001Vo`030000000c0?l0<`3o00@0<`3o00<00000
0<`0o`0000000P3o09T010000000fMWI0=WIf@3IfMT2000000@0fMWI000L0=WIf@030000003IfMT0
fMWI0080fMWI00@000000?l0V@3o09T000000P3<0?l2000000<0<`3o0P000006001Vo`0300000000
ool00?oo00L00?oo00<00000003oIP00ofH02000ofH00`000000<ol003?o000:03?o00030000003<
o`00c?l000l0c?l000<000000?nI003oV@006`3oV@000`000000o`000?l0000X0?l000030000003o
V@00oiT001/0oiT000<000000<co003<o`003`3<o`000`000000<ol003?o000:03?o000300000000
ofH00?mV00T00?mV00<00000003oo`00ool01P00ool00`00000006Ko001Vo`04001Vo`800000100c
0?l2000000050<`0o`000000o`2I0?l0V@000000103IfMT00`000000fMWI0=WIf@020=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@060000003o09T0o`2I0000003<0?l00000100c0?l00`000000
06Ko001Vo`06001Vo`0300000000ool00?oo00L00?oo00<00000003oIP00ofH02000ofH00`000000
<ol003?o000903?o00030000003<o`00c?l000l0c?l000<000000?nI003oV@006`3oV@000`000000
o`000?l0000Z0?l000030000003oV@00oiT001/0oiT000<000000<co003<o`003`3<o`000`000000
<ol003?o000903?o000300000000ofH00?mV00T00?mV00<00000003oo`00ool01P00ool00`000000
06Ko001Vo`06001Vo`030000000c0?l0<`3o00<0<`3o00D000000<`0o`000000o`2I000000040=WI
f@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00D000000?l0V@00
0000c03o0000000303<0o`8000002@00I_l00`0000000?oo003oo`07003oo`0300000000ofH00?mV
00L00?mV00<0000003?o000co`002P0co`000`000000c?l00<co000?0<co00030000003oV@00oiT0
01X0oiT000<000000?l0003o0000;03o00000`000000oiT00?nI000J0?nI00030000003<o`00c?l0
00l0c?l000<0000003?o000co`002P0co`000`0000000?mV003oIP08003oIP0300000000ool00?oo
00H00?oo00<00000001Vo`00I_l01`00I_l2000000@0<`3o00D000000<`0o`000000o`2I00000003
0=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@0o`2I0000
003<0?l000000`0c0?l00`00000006Ko001Vo`08001Vo`0300000000ool00?oo00P00?oo00<00000
003oIP00ofH01`00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000h0c?l000<00000
0?nI003oV@006P3oV@000`000000o`000?l0000^0?l000030000003oV@00oiT001X0oiT000<00000
0<co003<o`003P3<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00P00?mV00<00000
003oo`00ool01`00ool00`00000006Ko001Vo`08001Vo`8000000`0c0?l00`000000c03o00000004
0=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<000000<`0
o`0000000P0c0?l2000000/006Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP07003o
IP030000000co`00<ol000T0<ol000<000000<co003<o`003`3<o`000`000000oiT00?nI000I0?nI
00030000003o0000o`000300o`0000<000000?nI003oV@006@3oV@000`000000c?l00<co000?0<co
00030000000co`00<ol000T0<ol000<00000003oIP00ofH02000ofH00`0000000?oo003oo`07003o
o`0300000000I_l006Ko00X006Ko00L0000003<0o`0c0?l0<`3o0000003<0?l0000000<0fMWI00<0
00000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT01@3<0?l0000003<0o`0c
0?l0000000d006Ko00<00000003oo`00ool01`00ool00`0000000?mV003oIP07003oIP030000000c
o`00<ol000X0<ol000<000000<co003<o`003P3<o`000`000000oiT00?nI000I0?nI00030000003o
0000o`000380o`0000<000000?nI003oV@006@3oV@000`000000c?l00<co000>0<co00030000000c
o`00<ol000X0<ol000<00000003oIP00ofH01`00ofH00`0000000?oo003oo`07003oo`0300000000
I_l006Ko00/006Ko0P00000203<0o`030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT010000000<`3o00000000000=001Vo`0300000000
ool00?oo00P00?oo00<00000003oIP00ofH01`00ofH00`000000<ol003?o000:03?o00030000003<
o`00c?l000h0c?l000<000000?nI003oV@00603oV@000`000000o`000?l0000d0?l000030000003o
V@00oiT001P0oiT000<000000<co003<o`003P3<o`000`000000<ol003?o000:03?o000300000000
ofH00?mV00L00?mV00<00000003oo`00ool02000ool00`00000006Ko001Vo`0<001Vo`80000000<0
<`3o0000003IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIf@0303<0o`00000006Ko00/006Ko1000000:003oo`0300000000ofH00?mV00H00?mV00<00000
03?o000co`002P0co`000`000000c?l00<co000>0<co00030000003oV@00oiT001P0oiT000<00000
0?l0003o0000=P3o00000`000000oiT00?nI000H0?nI00030000003<o`00c?l000h0c?l000<00000
03?o000co`002P0co`000`0000000?mV003oIP06003oIP0300000000ool00?oo00P00?oo1000000=
001Vo`030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT00`00000006Ko001Vo`05001Vo`H000003P00ool00`0000000?mV003oIP06003o
IP030000000co`00<ol000X0<ol000<000000<co003<o`003P3<o`000`000000oiT00?nI000G0?nI
00030000003o0000o`0003P0o`0000<000000?nI003oV@005`3oV@000`000000c?l00<co000>0<co
00030000000co`00<ol000X0<ol000<00000003oIP00ofH01P00ofH00`0000000?oo003oo`0<003o
o`H000002000I_l01@000000fMWI0=WIf@3IfMT0000000@0fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI0`00I_l5000001@00?oo00<00000003oIP00ofH01P00ofH00`000000<ol003?o000:03?o
00030000003<o`00c?l000d0c?l000<000000?nI003oV@005`3oV@000`000000o`000?l0000j0?l0
00030000003oV@00oiT001L0oiT000<000000<co003<o`003@3<o`000`000000<ol003?o000:03?o
000300000000ofH00?mV00H00?mV00<00000003oo`00ool04P00ool60000008006Ko103IfMT00`00
0000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<000006@00ool00`000000
0?mV003oIP05003oIP030000000co`00<ol000X0<ol000<000000<co003<o`003P3<o`000`000000
oiT00?nI000F0?nI00030000003o0000o`0003`0o`0000<000000?nI003oV@005P3oV@000`000000
c?l00<co000>0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH01P00ofH00`000000
0?oo003oo`0G003oo`<000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT2000000<0fMWI
7000ool00`0000000?mV003oIP05003oIP030000000co`00<ol000X0<ol000<000000<co003<o`00
3P3<o`000`000000oiT00?nI000E0?nI00030000003o0000o`0003h0o`0000<000000?nI003oV@00
5@3oV@000`000000c?l00<co000>0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH0
1P00ofH00`0000000?oo003oo`0I003oo`<0fMWI0P0000040=WIf@00703IfMT00`000000fMWI0=WI
f@020=WIf@8000006P00ool00`0000000?mV003oIP05003oIP030000000co`00<ol000X0<ol000<0
00000<co003<o`003@3<o`000`000000oiT00?nI000E0?nI00030000003o0000o`000400o`0000<0
00000?nI003oV@005@3oV@000`000000c?l00<co000=0<co00030000000co`00<ol000X0<ol000<0
0000003oIP00ofH01P00ofH00`0000000?oo003oo`0H003oo`8000000`3IfMT00`000000fMWI0=WI
f@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@@000006000ool00`0000000?mV003oIP04
003oIP030000000co`00<ol000/0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000D
0?nI00030000003o0000o`000480o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000=
0<co00030000000co`00<ol000/0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0F
003oo`@000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WI
f@80<ol000<00000003oIP0000005P00ool00`0000000?mV003oIP05003oIP030000000co`00<ol0
00X0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000D0?nI00030000003o0000o`00
04@0o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000=0<co00030000000co`00<ol0
00X0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0D003oo`80000000<00?mV0000
000co`00103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@05
0000000co`00<ol000000000ofH00P00000D003oo`0300000000ofH00?mV00D00?mV00<0000003?o
000co`002P0co`000`000000c?l00<co000=0<co00030000003oV@00oiT001@0oiT000<000000?l0
003o0000A03o00000`000000oiT00?nI000D0?nI00030000003<o`00c?l000d0c?l000<0000003?o
000co`002P0co`000`0000000?mV003oIP05003oIP0300000000ool00?oo01<00?oo00D00000003o
IP000000000003?o0002000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT01@3<o`00000003?o000co`00000000800?mV0P00000B003oo`0300000000ofH0
0?mV00@00?mV00<0000003?o000co`002`0co`000`000000c?l00<co000<0<co00030000003oV@00
oiT001@0oiT000<000000?l0003o0000AP3o00000`000000oiT00?nI000D0?nI00030000003<o`00
c?l000`0c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP04003oIP0300000000ool0
0?oo01400?oo0P0000001P00ofH0000003?o000co`0000000<co00@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000c?l00000000203?o000500000000
ofH00?mV003oIP0000004@00ool00`0000000?mV003oIP04003oIP030000000co`00<ol000X0<ol0
00<000000<co003<o`003@3<o`000`000000oiT00?nI000D0?nI00030000003o0000o`0004H0o`00
00<000000?nI003oV@00503oV@000`000000c?l00<co000=0<co00030000000co`00<ol000X0<ol0
00<00000003oIP00ofH01000ofH00`0000000?oo003oo`0?003oo`8000000P00ofH010000000<ol0
03?o000000020<co00050000003IfMT0fMWI0=WIf@000000103IfMT001`0fMWI00<000000=WIf@3I
fMT00P3IfMT010000000c?l00<co0000000203?o000500000000ofH00?mV003oIP0000004000ool0
0`0000000?mV003oIP04003oIP030000000co`00<ol000X0<ol000<000000<co003<o`00303<o`00
0`000000oiT00?nI000D0?nI00030000003o0000o`0004P0o`0000<000000?nI003oV@00503oV@00
0`000000c?l00<co000<0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH01000ofH0
0`0000000?oo003oo`0>003oo`0500000000ofH00?mV003oIP0000000P0co`0010000000c?l00<co
000000040=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@0
00000<co003<o`0000000P0co`001@0000000?mV003oIP00ofH0000001000?oo00<00000003oIP00
ofH01000ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000`0c?l000<000000?nI003o
V@00503oV@000`000000o`000?l000180?l000030000003oV@00oiT001@0oiT000<000000<co003<
o`00303<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00@00?mV00<00000003oo`00
ool03P00ool01@0000000?mV003oIP00ofH000000080<ol000@000000<co003<o`000000103IfMT0
0`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@040000003<o`00c?l0
00000080<ol000D00000003oIP00ofH00?mV0000000@003oo`0300000000ofH00?mV00@00?mV00<0
000003?o000co`002P0co`000`000000c?l00<co000<0<co00030000003oV@00oiT001@0oiT000<0
00000?l0003o0000B03o00000`000000oiT00?nI000D0?nI00030000003<o`00c?l000`0c?l000<0
000003?o000co`002P0co`000`0000000?mV003oIP04003oIP0300000000ool00?oo00h00?oo00D0
0000003oIP00ofH00?mV0000000203?o00040000003<o`00c?l0000000@0fMWI00<000000=WIf@3I
fMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT010000000c?l00<co0000000203?o0005
00000000ofH00?mV003oIP0000004000ool00`0000000?mV003oIP04003oIP030000000co`00<ol0
00X0<ol000<000000<co003<o`00303<o`000`000000oiT00?nI000C0?nI00030000003o0000o`00
04X0o`0000<000000?nI003oV@004`3oV@000`000000c?l00<co000<0<co00030000000co`00<ol0
00X0<ol000<00000003oIP00ofH01000ofH00`0000000?oo003oo`0>003oo`0500000000ofH00?mV
003oIP0000000P0co`0010000000c?l00<co000000040=WIf@030000003IfMT0fMWI0080fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI00@000000<co003<o`0000000P0co`000`0000000?mV003o
IP02003oIP0300000000ool00?oo00`00?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o
000903?o00030000003<o`00c?l000d0c?l000<000000?nI003oV@004`3oV@000`000000o`000?l0
001:0?l000030000003oV@00oiT001<0oiT000<000000<co003<o`003@3<o`000`000000<ol003?o
000903?o000300000000ofH00?mV00D00?mV00<00000003oo`00ool03000ool00`0000000?mV003o
IP02003oIP040000000co`00<ol000000080c?l000<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@020=WIf@00703IfMT2000000<0fMWI00@000000<co003<o`0000000P0co`000`0000000?mV
003oIP02003oIP0300000000ool00?oo00`00?oo00<00000003oIP00ofH01@00ofH00`000000<ol0
03?o000903?o00030000003<o`00c?l000`0c?l000<000000?nI003oV@00503oV@000`000000o`00
0?l0001:0?l000030000003oV@00oiT001@0oiT000<000000<co003<o`00303<o`000`000000<ol0
03?o000903?o000300000000ofH00?mV00D00?mV00<00000003oo`00ool03000ool00`0000000?mV
003oIP02003oIP040000000co`00<ol000000080c?l000@000000=WIf@3IfMT0fMWI0P0000040=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIf@040000003<o`00c?l000000080<ol000<00000003o
IP00ofH00P00ofH00`0000000?oo003oo`0<003oo`0300000000ofH00?mV00D00?mV00<0000003?o
000co`002@0co`000`000000c?l00<co000<0<co00030000003oV@00oiT001@0oiT000<000000?l0
003o0000BP3o00000`000000oiT00?nI000D0?nI00030000003<o`00c?l000`0c?l000<0000003?o
000co`002@0co`000`0000000?mV003oIP05003oIP0300000000ool00?oo00`00?oo00<00000003o
IP00ofH00P00ofH010000000<ol003?o000000020<co00030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT010000000c?l00<co00000002
03?o000300000000ofH00?mV00800?mV00<00000003oo`00ool03000ool00`0000000?mV003oIP05
003oIP030000000co`00<ol000T0<ol000<000000<co003<o`00303<o`000`000000oiT00?nI000D
0?nI00030000003o0000o`0004X0o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000<
0<co00030000000co`00<ol000T0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0<
003oo`0300000000ofH00?mV00800?mV00@0000003?o000co`0000000P3<o`000`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@00000
0<co003<o`0000000P0co`000`0000000?mV003oIP02003oIP0300000000ool00?oo00`00?oo00<0
0000003oIP00ofH01@00ofH00`000000<ol003?o000903?o00030000003<o`00c?l000`0c?l000<0
00000?nI003oV@004`3oV@000`000000o`000?l0001<0?l000030000003oV@00oiT001<0oiT000<0
00000<co003<o`00303<o`000`000000<ol003?o000903?o000300000000ofH00?mV00D00?mV00<0
0000003oo`00ool03000ool00`0000000?mV003oIP02003oIP040000000co`00<ol000000080c?l0
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WI
f@020=WIf@040000003<o`00c?l000000080<ol000<00000003oIP00ofH00P00ofH00`0000000?oo
003oo`0<003oo`0300000000ofH00?mV00D00?mV00<0000003?o000co`002@0co`000`000000c?l0
0<co000<0<co00030000003oV@00oiT001<0oiT000<000000?l0003o0000C03o00000`000000oiT0
0?nI000C0?nI00030000003<o`00c?l000`0c?l000<0000003?o000co`002@0co`000`0000000?mV
003oIP05003oIP0300000000ool00?oo00`00?oo00<00000003oIP00ofH00P00ofH010000000<ol0
03?o000000020<co00030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI
00<000000=WIf@3IfMT00P3IfMT01@3oV@0000000<co003<o`0000000080<ol000<00000003oIP00
ofH00P00ofH00`0000000?oo003oo`0:003oo`0300000000ofH00?mV00D00?mV00<0000003?o000c
o`002@0co`000`000000c?l00<co000=0<co00030000003oV@00oiT001<0oiT000<000000?l0003o
0000C03o00000`000000oiT00?nI000C0?nI00030000003<o`00c?l000d0c?l000<0000003?o000c
o`002@0co`000`0000000?mV003oIP05003oIP0300000000ool00?oo00X00?oo00<00000003oIP00
ofH00P00ofH020000000<ol003?o000co`0000000<co00000000oiT0103IfMT00`000000fMWI0=WI
f@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@050?nI00000000c?l00<co000000000P0c
o`000`0000000?mV003oIP02003oIP0300000000ool00?oo00X00?oo00<00000003oIP00ofH01@00
ofH00`000000<ol003?o000903?o00030000003<o`00c?l000d0c?l000<000000?nI003oV@004`3o
V@000`000000o`000?l0001<0?l000030000003oV@00oiT001<0oiT000<000000<co003<o`003@3<
o`000`000000<ol003?o000903?o000300000000ofH00?mV00D00?mV00<00000003oo`00ool02P00
ool00`0000000?mV003oIP02003oIP080000000co`00<ol003?o00000000c?l00000003oV@040=WI
f@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00D0oiT00000003<
o`00c?l00000000203?o000300000000ofH00?mV00800?mV00<00000003oo`00ool02P00ool00`00
00000?mV003oIP05003oIP030000000co`00<ol000T0<ol000<000000<co003<o`003@3<o`000`00
0000oiT00?nI000B0?nI00030000003o0000o`0004h0o`0000<000000?nI003oV@004P3oV@000`00
0000c?l00<co000=0<co00030000000co`00<ol000T0<ol000<00000003oIP00ofH01@00ofH00`00
00000?oo003oo`0:003oo`0300000000ofH00?mV00800?mV00P0000003?o000co`00<ol00000003<
o`0000000?nI00@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT01@3oV@0000000<co003<o`0000000080<ol000<00000003oIP00ofH00P00ofH00`0000000?oo
003oo`0:003oo`0300000000ofH00?mV00D00?mV00<0000003?o000co`002@0co`000`000000c?l0
0<co000=0<co00030000003oV@00oiT00180oiT000<000000?l0003o0000CP3o00000`000000oiT0
0?nI000B0?nI00030000003<o`00c?l000d0c?l000<0000003?o000co`002@0co`000`0000000?mV
003oIP05003oIP0300000000ool00?oo00X00?oo00<00000003oIP00ofH00P00ofH020000000<ol0
03?o000co`0000000<co00000000oiT0103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`00
0000fMWI0=WIf@020=WIf@050?nI00000000c?l00<co000000000P0co`000`0000000?mV003oIP02
003oIP0300000000ool00?oo00X00?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o0009
03?o00030000003<o`00c?l000`0c?l000<000000?nI003oV@004`3oV@000`000000o`000?l0001>
0?l000030000003oV@00oiT001<0oiT000<000000<co003<o`00303<o`000`000000<ol003?o0009
03?o000300000000ofH00?mV00D00?mV00<00000003oo`00ool02P00ool00`0000000?mV003oIP02
003oIP080000000co`00<ol003?o00000000c?l00000003oV@040=WIf@030000003IfMT0fMWI0080
fMWI000B0=WIf@<000001`3IfMT00`000000fMWI0=WIf@020=WIf@050?nI00000000c?l00<co0000
00000P0co`000`0000000?mV003oIP02003oIP0300000000ool00?oo00X00?oo00<00000003oIP00
ofH01@00ofH00`000000<ol003?o000903?o00030000003<o`00c?l000`0c?l000<000000?nI003o
V@004`3oV@000`000000o`000?l0001>0?l000030000003oV@00oiT001<0oiT000<000000<co003<
o`00303<o`000`000000<ol003?o000903?o000300000000ofH00?mV00D00?mV00<00000003oo`00
ool02P00ool00`0000000?mV003oIP02003oIP080000000co`00<ol003?o00000000c?l00000003o
V@040=WIf@030000003IfMT0fMWI0080fMWI000A0=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT00`000000fMWI0=WIf@020=WIf@050?nI00000000c?l00<co000000000P0co`000`0000000?mV
003oIP03003oIP0300000000ool00?oo00P00?oo00<00000003oIP00ofH01P00ofH00`000000<ol0
03?o000803?o00030000003<o`00c?l000d0c?l000<000000?nI003oV@004`3oV@000`000000o`00
0?l0001>0?l000030000003oV@00oiT001<0oiT000<000000<co003<o`003@3<o`000`000000<ol0
03?o000803?o000300000000ofH00?mV00H00?mV00<00000003oo`00ool02000ool00`0000000?mV
003oIP03003oIP080000000co`00<ol003?o00000000c?l00000003oV@040=WIf@030000003IfMT0
fMWI0080fMWI000A0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@02
0=WIf@050?nI00000000c?l00<co000000000P0co`000`0000000?mV003oIP03003oIP0300000000
ool00?oo00P00?oo00<00000003oIP00ofH01P00ofH00`000000<ol003?o000803?o00030000003<
o`00c?l000d0c?l000<000000?nI003oV@004P3oV@000`000000o`000?l0001@0?l000030000003o
V@00oiT00180oiT000<000000<co003<o`003@3<o`000`000000<ol003?o000803?o000300000000
ofH00?mV00H00?mV00<00000003oo`00ool02000ool00`0000000?mV003oIP03003oIP080000000c
o`00<ol003?o00000000c?l00000003oV@040=WIf@030000003IfMT0fMWI0080fMWI000A0=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT2000000<0fMWI00D0oiT00000003<o`00c?l000000002
03?o000300000000ofH00?mV00<00?mV00<00000003oo`00ool02000ool00`0000000?mV003oIP06
003oIP030000000co`00<ol000P0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000B
0?nI00030000003o0000o`000500o`0000<000000?nI003oV@004P3oV@000`000000c?l00<co000=
0<co00030000000co`00<ol000P0<ol000<00000003oIP00ofH01P00ofH00`0000000?oo003oo`08
003oo`0300000000ofH00?mV00<00?mV00P0000003?o000co`00<ol00000003<o`0000000?nI00<0
fMWI0P0000040=WIf@004@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT00P3IfMT01@3oV@0000000<co003<o`0000000080<ol000<00000003oIP00ofH00`00ofH00`00
00000?oo003oo`08003oo`0300000000ofH00?mV00H00?mV00<0000003?o000co`00200co`000`00
0000c?l00<co000=0<co00030000003oV@00oiT00180oiT000<000000?l0003o0000D03o00000`00
0000oiT00?nI000B0?nI00030000003<o`00c?l000d0c?l000<0000003?o000co`00200co`000`00
00000?mV003oIP06003oIP0300000000ool00?oo00P00?oo00<00000003oIP00ofH00`00ofH02000
0000<ol003?o000co`0000000<co00000000oiT0103IfMT00`000000fMWI0=WIf@020=WIf@004@3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT01@3oV@000000
0<co003<o`0000000080<ol000<00000003oIP00ofH00`00ofH00`0000000?oo003oo`08003oo`03
00000000ofH00?mV00H00?mV00<0000003?o000co`00200co`000`000000c?l00<co000=0<co0003
0000003oV@00oiT00180oiT000<000000?l0003o0000D03o00000`000000oiT00?nI000B0?nI0003
0000003<o`00c?l000d0c?l000<0000003?o000co`00200co`000`0000000?mV003oIP06003oIP03
00000000ool00?oo00P00?oo00<00000003oIP00ofH00`00ofH020000000<ol003?o000co`000000
0<co00000000oiT0103IfMT00`000000fMWI0=WIf@020=WIf@004@3IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT01@3oV@0000000<co003<o`0000000080<ol0
00<00000003oIP00ofH00`00ofH00`0000000?oo003oo`08003oo`0300000000ofH00?mV00H00?mV
00<0000003?o000co`00200co`000`000000c?l00<co000=0<co00030000003oV@00oiT001<0oiT0
00<000000?l0003o0000CP3o00000`000000oiT00?nI000C0?nI00030000003<o`00c?l000d0c?l0
00<0000003?o000co`00200co`000`0000000?mV003oIP06003oIP0300000000ool00?oo00P00?oo
00<00000003oIP00ofH00`00ofH020000000<ol003?o000co`0000000<co00000000oiT0103IfMT0
0`000000fMWI0=WIf@020=WIf@004P3IfMT3000000L0fMWI00<000000=WIf@3IfMT00P3IfMT01@3o
V@0000000<co003<o`0000000080<ol000<00000003oIP00ofH00P00ofH00`0000000?oo003oo`0:
003oo`0300000000ofH00?mV00D00?mV00<0000003?o000co`002@0co`000`000000c?l00<co000<
0<co00030000003oV@00oiT001<0oiT000<000000?l0003o0000CP3o00000`000000oiT00?nI000C
0?nI00030000003<o`00c?l000`0c?l000<0000003?o000co`002@0co`000`0000000?mV003oIP05
003oIP0300000000ool00?oo00X00?oo00<00000003oIP00ofH00P00ofH020000000<ol003?o000c
o`0000000<co00000000oiT0103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@050?nI00000000c?l00<co000000000P0co`000`0000000?mV003oIP02003oIP03
00000000ool00?oo00X00?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o000903?o0003
0000003<o`00c?l000d0c?l000<000000?nI003oV@004P3oV@000`000000o`000?l0001>0?l00003
0000003oV@00oiT00180oiT000<000000<co003<o`003@3<o`000`000000<ol003?o000903?o0003
00000000ofH00?mV00D00?mV00<00000003oo`00ool02P00ool00`0000000?mV003oIP02003oIP08
0000000co`00<ol003?o00000000c?l00000003oV@040=WIf@030000003IfMT0fMWI0080fMWI000L
0=WIf@030000003IfMT0fMWI0080fMWI00D0oiT00000003<o`00c?l00000000203?o000300000000
ofH00?mV00800?mV00<00000003oo`00ool02P00ool00`0000000?mV003oIP05003oIP030000000c
o`00<ol000T0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000B0?nI00030000003o
0000o`0004h0o`0000<000000?nI003oV@004P3oV@000`000000c?l00<co000=0<co00030000000c
o`00<ol000T0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0:003oo`0300000000
ofH00?mV00800?mV00P0000003?o000co`00<ol00000003<o`0000000?nI00@0fMWI00<000000=WI
f@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT01@3oV@0000000<co003<o`000000
0080<ol000<00000003oIP00ofH00P00ofH00`0000000?oo003oo`0:003oo`0300000000ofH00?mV
00D00?mV00<0000003?o000co`002@0co`000`000000c?l00<co000=0<co00030000003oV@00oiT0
01<0oiT000<000000?l0003o0000C03o00000`000000oiT00?nI000C0?nI00030000003<o`00c?l0
00d0c?l000<0000003?o000co`002@0co`000`0000000?mV003oIP05003oIP0300000000ool00?oo
00X00?oo00<00000003oIP00ofH00P00ofH020000000<ol003?o000co`0000000<co00000000oiT0
103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@050?nI0000
0000c?l00<co000000000P0co`000`0000000?mV003oIP02003oIP0300000000ool00?oo00X00?oo
00<00000003oIP00ofH01@00ofH00`000000<ol003?o000903?o00030000003<o`00c?l000d0c?l0
00<000000?nI003oV@004`3oV@000`000000o`000?l0001<0?l000030000003oV@00oiT001<0oiT0
00<000000<co003<o`003@3<o`000`000000<ol003?o000903?o000300000000ofH00?mV00D00?mV
00<00000003oo`00ool02P00ool00`0000000?mV003oIP02003oIP080000000co`00<ol003?o0000
0000c?l00000003oV@040=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI00@000000<co003<o`0000000P0co`000`0000000?mV003oIP02003oIP0300000000ool0
0?oo00`00?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o000903?o00030000003<o`00
c?l000`0c?l000<000000?nI003oV@004`3oV@000`000000o`000?l0001<0?l000030000003oV@00
oiT001<0oiT000<000000<co003<o`00303<o`000`000000<ol003?o000903?o000300000000ofH0
0?mV00D00?mV00<00000003oo`00ool03000ool00`0000000?mV003oIP02003oIP040000000co`00
<ol000000080c?l000<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT0
0`000000fMWI0=WIf@020=WIf@040000003<o`00c?l000000080<ol000<00000003oIP00ofH00P00
ofH00`0000000?oo003oo`0<003oo`0300000000ofH00?mV00D00?mV00<0000003?o000co`002@0c
o`000`000000c?l00<co000<0<co00030000003oV@00oiT001<0oiT000<000000?l0003o0000C03o
00000`000000oiT00?nI000C0?nI00030000003<o`00c?l000`0c?l000<0000003?o000co`002@0c
o`000`0000000?mV003oIP05003oIP0300000000ool00?oo00`00?oo00<00000003oIP00ofH00P00
ofH010000000<ol003?o000000020<co00030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT010000000c?l00<co0000000203?o00030000
0000ofH00?mV00800?mV00<00000003oo`00ool03000ool00`0000000?mV003oIP05003oIP030000
000co`00<ol000T0<ol000<000000<co003<o`00303<o`000`000000oiT00?nI000C0?nI00030000
003o0000o`0004`0o`0000<000000?nI003oV@004`3oV@000`000000c?l00<co000<0<co00030000
000co`00<ol000T0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0<003oo`030000
0000ofH00?mV00800?mV00@0000003?o000co`0000000P3<o`000`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0080fMWI000L0=WIf@8000000`3IfMT010000000c?l00<co0000000203?o0003
00000000ofH00?mV00800?mV00<00000003oo`00ool03000ool00`0000000?mV003oIP05003oIP03
0000000co`00<ol000T0<ol000<000000<co003<o`00303<o`000`000000oiT00?nI000D0?nI0003
0000003o0000o`0004X0o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000<0<co0003
0000000co`00<ol000T0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0<003oo`03
00000000ofH00?mV00800?mV00@0000003?o000co`0000000P3<o`0010000000fMWI0=WIf@3IfMT2
000000@0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@000000<co003<o`0000000P0co`00
0`0000000?mV003oIP02003oIP0300000000ool00?oo00`00?oo00<00000003oIP00ofH01@00ofH0
0`000000<ol003?o000903?o00030000003<o`00c?l000`0c?l000<000000?nI003oV@00503oV@00
0`000000o`000?l0001:0?l000030000003oV@00oiT001@0oiT000<000000<co003<o`00303<o`00
0`000000<ol003?o000903?o000300000000ofH00?mV00D00?mV00<00000003oo`00ool03000ool0
0`0000000?mV003oIP02003oIP040000000co`00<ol000000080c?l000<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@040000003<o`00
c?l000000080<ol000<00000003oIP00ofH00P00ofH00`0000000?oo003oo`0<003oo`0300000000
ofH00?mV00D00?mV00<0000003?o000co`002@0co`000`000000c?l00<co000=0<co00030000003o
V@00oiT001<0oiT000<000000?l0003o0000BP3o00000`000000oiT00?nI000C0?nI00030000003<
o`00c?l000d0c?l000<0000003?o000co`002@0co`000`0000000?mV003oIP05003oIP0300000000
ool00?oo00`00?oo00<00000003oIP00ofH00P00ofH010000000<ol003?o000000020<co00030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3I
fMT010000000c?l00<co0000000203?o000500000000ofH00?mV003oIP0000004000ool00`000000
0?mV003oIP04003oIP030000000co`00<ol000X0<ol000<000000<co003<o`00303<o`000`000000
oiT00?nI000C0?nI00030000003o0000o`0004X0o`0000<000000?nI003oV@004`3oV@000`000000
c?l00<co000<0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH01000ofH00`000000
0?oo003oo`0>003oo`0500000000ofH00?mV003oIP0000000P0co`0010000000c?l00<co00000004
0=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00@000000<co
003<o`0000000P0co`001@0000000?mV003oIP00ofH0000001000?oo00<00000003oIP00ofH01000
ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000`0c?l000<000000?nI003oV@00503o
V@000`000000o`000?l000180?l000030000003oV@00oiT001@0oiT000<000000<co003<o`00303<
o`000`000000<ol003?o000:03?o000300000000ofH00?mV00@00?mV00<00000003oo`00ool03P00
ool01@0000000?mV003oIP00ofH000000080<ol000@000000<co003<o`000000103IfMT00`000000
fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@050000003<o`00c?l00000000c
o`000P000002003oIP8000004000ool00`0000000?mV003oIP04003oIP030000000co`00<ol000X0
<ol000<000000<co003<o`00303<o`000`000000oiT00?nI000D0?nI00030000003o0000o`0004P0
o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000<0<co00030000000co`00<ol000X0
<ol000<00000003oIP00ofH01000ofH00`0000000?oo003oo`0>003oo`8000000P00ofH200000005
03?o0000000000000<co00000000103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000
fMWI0=WIf@020=WIf@050000003<o`00000003?o000000000`00ofH00`0000000?oo003oo`0@003o
o`0300000000ofH00?mV00@00?mV00<0000003?o000co`002P0co`000`000000c?l00<co000<0<co
00030000003oV@00oiT001@0oiT000<000000?l0003o0000B03o00000`000000oiT00?nI000D0?nI
00030000003<o`00c?l000`0c?l000<0000003?o000co`002P0co`000`0000000?mV003oIP04003o
IP0300000000ool00?oo01000?oo00D00000003oIP00ofH00?mV0000000203?o00030000003<o`00
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0103<
o`00000003?o00000002003oIP8000004`00ool00`0000000?mV003oIP04003oIP030000000co`00
<ol000X0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000D0?nI00030000003o0000
o`0004H0o`0000<000000?nI003oV@00503oV@000`000000c?l00<co000=0<co00030000000co`00
<ol000X0<ol000<00000003oIP00ofH01000ofH00`0000000?oo003oo`0A003oo`8000000P00ofH2
0000000303?o00000000fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000<ol000000002003oIP0300000000ool00?oo01<00?oo00<00000003o
IP00ofH01@00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000`0c?l000<000000?nI
003oV@00503oV@000`000000o`000?l000160?l000030000003oV@00oiT001@0oiT000<000000<co
003<o`00303<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00D00?mV00<00000003o
o`00ool04`00ool2000000800?mV00<0000003?o000000000`3IfMT00`000000fMWI0=WIf@020=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIf@0503?o000000000?mV003oIP0000005P00ool00`00
00000?mV003oIP05003oIP030000000co`00<ol000X0<ol000<000000<co003<o`003@3<o`000`00
0000oiT00?nI000D0?nI00030000003o0000o`0004@0o`0000<000000?nI003oV@00503oV@000`00
0000c?l00<co000=0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH01@00ofH00`00
00000?oo003oo`0E003oo`0400000000ofH00?mV000000@0fMWI00<000000=WIf@3IfMT00P3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT0100000000?mV00000000000H003oo`0300000000ofH0
0?mV00@00?mV00<0000003?o000co`002P0co`000`000000c?l00<co000=0<co00030000003oV@00
oiT001D0oiT000<000000?l0003o0000@P3o00000`000000oiT00?nI000E0?nI00030000003<o`00
c?l000d0c?l000<0000003?o000co`002P0co`000`0000000?mV003oIP05003oIP0300000000ool0
0?oo01H00?oo0P0000000`00ofH000000=WIf@020=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI00<00?mV00000000ool06@00ool00`0000000?mV003oIP04003o
IP030000000co`00<ol000/0<ol000<000000<co003<o`003@3<o`000`000000oiT00?nI000E0?nI
00030000003o0000o`000400o`0000<000000?nI003oV@005@3oV@000`000000c?l00<co000=0<co
00030000000co`00<ol000/0<ol000<00000003oIP00ofH01@00ofH00`0000000?oo003oo`0H003o
o`030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI0P0000030=WIf@03
00000000ool00?oo01T00?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o000:03?o0003
0000003<o`00c?l000d0c?l000<000000?nI003oV@005P3oV@000`000000o`000?l0000n0?l00003
0000003oV@00oiT001H0oiT000<000000<co003<o`003@3<o`000`000000<ol003?o000:03?o0003
00000000ofH00?mV00H00?mV00<00000003oo`00ool06@00ool00`000000fMWI0=WIf@02000000@0
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1000000H003oo`0300000000ofH00?mV00D00?mV
00<0000003?o000co`002P0co`000`000000c?l00<co000>0<co00030000003oV@00oiT001H0oiT0
00<000000?l0003o0000?03o00000`000000oiT00?nI000F0?nI00030000003<o`00c?l000h0c?l0
00<0000003?o000co`002P0co`000`0000000?mV003oIP06003oIP0300000000ool00?oo01H00?oo
100000030=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1000
I_l6000001800?oo00<00000003oIP00ofH01@00ofH00`000000<ol003?o000;03?o00030000003<
o`00c?l000d0c?l000<000000?nI003oV@005`3oV@000`000000o`000?l0000j0?l000030000003o
V@00oiT001L0oiT000<000000<co003<o`003@3<o`000`000000<ol003?o000;03?o000300000000
ofH00?mV00H00?mV00<00000003oo`00ool04000ool6000000<006Ko103IfMT00`000000fMWI0=WI
f@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@8000002000I_l5000000d00?oo00<00000
003oIP00ofH01P00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000d0c?l000<00000
0?nI003oV@00603oV@000`000000o`000?l0000h0?l000030000003oV@00oiT001P0oiT000<00000
0<co003<o`003@3<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00H00?mV00<00000
003oo`00ool02`00ool6000000P006Ko0P0000030=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI0P0c0?l00`00000006Ko001Vo`0:001Vo`<000002P00ool00`00
00000?mV003oIP06003oIP030000000co`00<ol000X0<ol000<000000<co003<o`003P3<o`000`00
0000oiT00?nI000H0?nI00030000003o0000o`0003H0o`0000<000000?nI003oV@00603oV@000`00
0000c?l00<co000>0<co00030000000co`00<ol000X0<ol000<00000003oIP00ofH01P00ofH00`00
00000?oo003oo`08003oo`<000003@00I_l00`000000<`3o0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI0P0000000`0c0?l000000000000<001Vo`03
00000000ool00?oo00P00?oo00<00000003oIP00ofH01`00ofH00`000000<ol003?o000903?o0003
0000003<o`00c?l000h0c?l000<000000?nI003oV@006@3oV@000`000000o`000?l0000d0?l00003
0000003oV@00oiT001T0oiT000<000000<co003<o`003P3<o`000`000000<ol003?o000903?o0003
00000000ofH00?mV00L00?mV00<00000003oo`00ool02000ool00`00000006Ko001Vo`0;001Vo`80
000000<0<`3o0000000000000`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI
0=WIf@020=WIf@80c03o00@0000003<0o`0c0?l000002`00I_l00`0000000?oo003oo`08003oo`03
00000000ofH00?mV00L00?mV00<0000003?o000co`002P0co`000`000000c?l00<co000>0<co0003
0000003oV@00oiT001T0oiT000<000000?l0003o0000<P3o00000`000000oiT00?nI000I0?nI0003
0000003<o`00c?l000h0c?l000<0000003?o000co`002P0co`000`0000000?mV003oIP07003oIP03
00000000ool00?oo00P00?oo00<00000001Vo`00I_l02@00I_l200000080<`3o00<000000<`0o`3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@040000
003<0?l0c03o00000080<`3o0P00000:001Vo`0300000000ool00?oo00P00?oo00<00000003oIP00
ofH01P00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000h0c?l000<000000?nI003o
V@006P3oV@000`000000o`000?l0000`0?l000030000003oV@00oiT001X0oiT000<000000<co003<
o`003P3<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00L00?mV00<00000003oo`00
ool01`00ool00`00000006Ko001Vo`09001Vo`050000000c0?l0<`3o03<0o`0000000P3<0?l01@00
0000fMWI0=WIf@3IfMT0000000@0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00D000000<`0
o`3<0?l0c03o0000000303<0o`0300000000I_l006Ko00L006Ko00<00000003oo`00ool02000ool0
0`0000000?mV003oIP07003oIP030000000co`00<ol000T0<ol000<000000<co003<o`003`3<o`00
0`000000oiT00?nI000J0?nI00030000003o0000o`0002h0o`0000<000000?nI003oV@006P3oV@00
0`000000c?l00<co000?0<co00030000000co`00<ol000T0<ol000<00000003oIP00ofH02000ofH0
0`0000000?oo003oo`07003oo`0300000000I_l006Ko00L006Ko0P00000303<0o`040000003<0?l0
c03o000000@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT2
000000<0c03o00@0000003<0o`0c0?l0<`3o0P000007001Vo`0300000000ool00?oo00P00?oo00<0
0000003oIP00ofH01`00ofH00`000000<ol003?o000:03?o00030000003<o`00c?l000h0c?l000<0
00000?nI003oV@006`3oV@000`000000o`000?l0000/0?l000030000003oV@00oiT001/0oiT000<0
00000<co003<o`003P3<o`000`000000<ol003?o000:03?o000300000000ofH00?mV00P00?mV00<0
0000003oo`00ool01`00ool00`00000006Ko001Vo`05001Vo`800000100c0?l01P000000c03o0<`0
o`000000o`2I000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000o`2I000000030<`0o`030000000c0?l0<`3o0080<`3o00<00000001Vo`00I_l0
1@00I_l00`0000000?oo003oo`07003oo`0300000000ofH00?mV00L00?mV00<0000003?o000co`00
2P0co`000`000000c?l00<co000?0<co00030000003oV@00oiT001/0oiT000<000000?l0003o0000
:P3o00000`000000oiT00?nI000K0?nI00030000003<o`00c?l000l0c?l000<0000003?o000co`00
2P0co`000`0000000?mV003oIP08003oIP0300000000ool00?oo00H00?oo00<00000001Vo`00I_l0
1@00I_l00`000000<`3o03<0o`0303<0o`040000003<0?l0c03o00000080o`2I00D000000=WIf@3I
fMT0fMWI000000040=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@040000003o09T0o`2I0000
00<0c03o00<0000003<0o`0c0?l00P0c0?l00`00000006Ko001Vo`04001Vo`0300000000ool00?oo
00L00?oo00<00000003oIP00ofH02000ofH00`000000<ol003?o000:03?o00030000003<o`00c?l0
00l0c?l000<000000?nI003oV@006`3oV@02000002P0o`000P00000M0?nI00030000003<o`00c?l0
00l0c?l000<0000003?o000co`002P0co`000`0000000?mV003oIP09003oIP0300000000ool00?oo
00H00?oo00<00000001Vo`00I_l01000I_l00`000000<`3o03<0o`0303<0o`040000003<0?l0c03o
00000080o`2I00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT20000
00<0fMWI00@000000?l0V@3o09T000000`3<0?l00`000000<`3o03<0o`0203<0o`0300000000I_l0
06Ko00@006Ko00<00000003oo`00ool01`00ool00`0000000?mV003oIP08003oIP030000000co`00
<ol000X0<ol000<000000<co003<o`003`3<o`000`000000oiT00?nI000M0?nI00800000903o0002
000001l0oiT000<000000<co003<o`003`3<o`000`000000<ol003?o000:03?o000300000000ofH0
0?mV00T00?mV00<00000003oo`00ool01P00ool00`00000006Ko001Vo`04001Vo`030000000c0?l0
<`3o00<0<`3o00@000000<`0o`3<0?l000000P3o09T010000000fMWI0=WIf@3IfMT2000000@0fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI00@000000?l0V@3o09T000000P3<0?l00`000000<`3o
03<0o`0303<0o`0300000000I_l006Ko00D006Ko00<00000003oo`00ool01`00ool00`0000000?mV
003oIP08003oIP030000000co`00<ol000X0<ol000<000000<co003<o`003`3<o`000`000000oiT0
0?nI000N0?nI00<000007P3o000300000200oiT000<000000<co003<o`003`3<o`000`000000<ol0
03?o000:03?o000300000000ofH00?mV00T00?mV00<00000003oo`00ool01P00ool00`00000006Ko
001Vo`05001Vo`030000000c0?l0<`3o00@0<`3o00<000000<`0o`0000000P3o09T00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000?l0V@0000000`3<0?l00`000000<`3o03<0o`0303<0o`0300000000I_l006Ko00D006Ko00<0
0000003oo`00ool01`00ool00`0000000?mV003oIP08003oIP030000000co`00<ol000/0<ol000<0
00000<co003<o`003`3<o`000`000000oiT00?nI000P0?nI00D000005@3o000400000280oiT000<0
00000<co003<o`003`3<o`000`000000<ol003?o000;03?o000300000000ofH00?mV00T00?mV00<0
0000003oo`00ool01P00ool00`00000006Ko001Vo`05001Vo`030000000c0?l0<`3o00@0<`3o00H0
00000<`0o`3<0?l000000?l0V@0000040=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI00<000000?l0V@0000000`3<0?l00`000000<`3o03<0o`0303<0o`030000
0000I_l006Ko00D006Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP08003oIP030000
000co`00<ol000X0<ol000<000000<co003<o`00403<o`000`000000oiT00?nI000T0?nI00@00000
303o0005000002D0oiT000<000000<co003<o`00403<o`000`000000<ol003?o000:03?o00030000
0000ofH00?mV00T00?mV00<00000003oo`00ool01`00ool00`00000006Ko001Vo`05001Vo`030000
000c0?l0<`3o00@0<`3o00H000000<`0o`3<0?l000000?l0V@0000040=WIf@030000003IfMT0fMWI
0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<000000?l0V@0000000P3<0?l00`000000
<`3o03<0o`0403<0o`0300000000I_l006Ko00H006Ko00<00000003oo`00ool01`00ool00`000000
0?mV003oIP09003oIP030000000co`00<ol000X0<ol000<000000<co003<o`00403<o`000`000000
oiT00?nI000W0?nI00D000000`3o0004000002T0oiT000<000000<co003<o`00403<o`000`000000
<ol003?o000:03?o000300000000ofH00?mV00X00?mV00<00000003oo`00ool01P00ool00`000000
06Ko001Vo`06001Vo`030000000c0?l0<`3o00D0<`3o00<000000<`0o`0000000P3o09T01@000000
fMWI0=WIf@3IfMT0000000@0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00<000000?l0V@00
00000P3<0?l00`000000<`3o03<0o`0403<0o`0300000000I_l006Ko00H006Ko00<00000003oo`00
ool01`00ool00`0000000?mV003oIP09003oIP030000000co`00<ol000/0<ol000<000000<co003<
o`00403<o`000`000000oiT00?nI000[0?nI00<00000;03oV@000`000000c?l00<co000@0<co0003
0000000co`00<ol000/0<ol000<00000003oIP00ofH02@00ofH00`0000000?oo003oo`07003oo`03
00000000I_l006Ko00H006Ko00<0000003<0o`0c0?l01@0c0?l01P000000c03o0<`0o`000000o`2I
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT20000
0080c03o00<0000003<0o`0c0?l01@0c0?l00`00000006Ko001Vo`06001Vo`0300000000ool00?oo
00P00?oo00<00000003oIP00ofH02@00ofH00`000000<ol003?o000;03?o00030000003<o`00c?l0
0100c?l000<000000?nI003oV@00F03oV@000`000000c?l00<co000@0<co00030000000co`00<ol0
00/0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`07003oo`0300000000I_l006Ko
00H006Ko00<0000003<0o`0c0?l01P0c0?l01@000000c03o0000003o09T0000000<0fMWI00<00000
0=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT200000080c03o00<0000003<0
o`0c0?l01@0c0?l00`00000006Ko001Vo`07001Vo`0300000000ool00?oo00L00?oo00<00000003o
IP00ofH02@00ofH00`000000<ol003?o000;03?o00030000003<o`00c?l00140c?l000<000000?nI
003oV@00EP3oV@000`000000c?l00<co000A0<co00030000000co`00<ol000/0<ol000<00000003o
IP00ofH02@00ofH00`0000000?oo003oo`07003oo`0300000000I_l006Ko00L006Ko00<0000003<0
o`0c0?l01P0c0?l01@000000c03o0000003o09T0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT0103o09T000000<`0o`00000903<0o`0300000000I_l0
06Ko00H006Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP09003oIP030000000co`00
<ol000/0<ol000<000000<co003<o`004@3<o`000`000000oiT00?nI001D0?nI00030000003<o`00
c?l00140c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP0:003oIP0300000000ool0
0?oo00L00?oo00<00000001Vo`00I_l01P00I_l00`000000<`3o03<0o`0803<0o`030000003<0?l0
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0103o
09T000000<`0o`00000903<0o`0300000000I_l006Ko00H006Ko00<00000003oo`00ool02000ool0
0`0000000?mV003oIP0:003oIP030000000co`00<ol000/0<ol000<000000<co003<o`004@3<o`00
0`000000oiT00?nI001B0?nI00030000003<o`00c?l00140c?l000<0000003?o000co`002`0co`00
0`0000000?mV003oIP0:003oIP0300000000ool00?oo00P00?oo00<00000001Vo`00I_l01P00I_l0
0`000000<`3o03<0o`0803<0o`030000003<0?l0000000@0fMWI00<000000=WIf@3IfMT00P3IfMT0
01`0fMWI00<000000=WIf@3IfMT00P3IfMT0103o09T000000<`0o`00000903<0o`0300000000I_l0
06Ko00L006Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP09003oIP030000000co`00
<ol000/0<ol000<000000<co003<o`004P3<o`000`000000oiT00?nI001@0?nI00030000003<o`00
c?l00180c?l000<0000003?o000co`002`0co`000`0000000?mV003oIP0:003oIP0300000000ool0
0?oo00L00?oo00<00000001Vo`00I_l01`00I_l00`000000<`3o03<0o`0803<0o`030000003<0?l0
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000c03o0000000:03<0o`0300000000I_l006Ko00L006Ko00<00000003oo`00ool02000ool00`00
00000?mV003oIP0:003oIP030000000co`00<ol000/0<ol000<000000<co003<o`004P3<o`000`00
0000oiT00?nI001>0?nI00030000003<o`00c?l00180c?l000<0000003?o000co`002`0co`000`00
00000?mV003oIP0:003oIP0300000000ool00?oo00P00?oo00<00000001Vo`00I_l01`00I_l00`00
0000<`3o03<0o`0903<0o`030000003<0?l0000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000c03o0000000:03<0o`0300000000I_l006Ko00L0
06Ko00<00000003oo`00ool02000ool00`0000000?mV003oIP0:003oIP030000000co`00<ol000`0
<ol000<000000<co003<o`004P3<o`000`000000oiT00?nI001<0?nI00030000003<o`00c?l00180
c?l000<0000003?o000co`00300co`000`0000000?mV003oIP0:003oIP0300000000ool00?oo00P0
0?oo00<00000001Vo`00I_l01`00I_l00`000000<`3o03<0o`0903<0o`030000003<0?l0000000<0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI0P0000030=WIf@030<`0o`000000<`3o00X0<`3o
00<00000001Vo`00I_l02000I_l00`0000000?oo003oo`08003oo`0300000000ofH00?mV00X00?mV
00<0000003?o000co`00300co`000`000000c?l00<co000B0<co00030000003oV@00oiT004X0oiT0
00<000000<co003<o`004P3<o`000`000000<ol003?o000<03?o000300000000ofH00?mV00X00?mV
00<00000003oo`00ool02000ool00`00000006Ko001Vo`08001Vo`030000000c0?l0<`3o00X0<`3o
00@000000=WIf@3IfMT0fMWI0P0000040=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030<`0
o`000000<`3o00X0<`3o00<00000001Vo`00I_l02000I_l00`0000000?oo003oo`08003oo`030000
0000ofH00?mV00/00?mV00<0000003?o000co`002`0co`000`000000c?l00<co000C0<co00030000
003oV@00oiT004P0oiT000<000000<co003<o`004`3<o`000`000000<ol003?o000;03?o00030000
0000ofH00?mV00/00?mV00<00000003oo`00ool02000ool00`00000006Ko001Vo`08001Vo`030000
000c0?l0<`3o00X0<`3o00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIf@030<`0o`000000<`3o00X0<`3o00<00000001Vo`00I_l02000
I_l00`0000000?oo003oo`09003oo`0300000000ofH00?mV00X00?mV00<0000003?o000co`00300c
o`000`000000c?l00<co000C0<co00030000003oV@00oiT004H0oiT000<000000<co003<o`004`3<
o`000`000000<ol003?o000<03?o000300000000ofH00?mV00X00?mV00<00000003oo`00ool02@00
ool00`00000006Ko001Vo`08001Vo`030000000c0?l0<`3o00X0<`3o00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030000000c0?l0
<`3o00X0<`3o00<00000001Vo`00I_l02@00I_l00`0000000?oo003oo`09003oo`0300000000ofH0
0?mV00X00?mV00<0000003?o000co`00300co`000`000000c?l00<co000C0<co00@00000@@3oV@03
000001D0c?l000<0000003?o000co`00300co`000`0000000?mV003oIP0:003oIP0300000000ool0
0?oo00T00?oo00<00000001Vo`00I_l02@00I_l00`000000<`3o03<0o`0;03<0o`050000003IfMT0
fMWI0=WIf@000000103IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT=03<0o`0300000000I_l0
06Ko00T006Ko00<00000003oo`00ool02@00ool00`0000000?mV003oIP0:003oIP030000000co`00
<ol000d0<ol000<000000<co003<o`005P3<o`02000003d0oiT00P00000G0<co00030000000co`00
<ol000d0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`09003oo`0300000000I_l0
06Ko00T006Ko00<0000003<0o`0c0?l02`0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI3P0c0?l00`00000006Ko001Vo`09001Vo`0300000000ool00?oo
00T00?oo00<00000003oIP00ofH02P00ofH00`000000<ol003?o000=03?o00030000003<o`00c?l0
01L0c?l00P00000i0?nI00800000603<o`000`000000<ol003?o000=03?o000300000000ofH00?mV
00X00?mV00<00000003oo`00ool02@00ool00`00000006Ko001Vo`09001Vo`030000000c0?l0<`3o
00`0<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@h0
<`3o00<00000001Vo`00I_l02P00I_l00`0000000?oo003oo`09003oo`0300000000ofH00?mV00T0
0?mV00<0000003?o000co`003P0co`000`000000c?l00<co000H0<co00800000=@3oV@02000001T0
c?l000<0000003?o000co`003P0co`000`0000000?mV003oIP09003oIP0300000000ool00?oo00T0
0?oo00<00000001Vo`00I_l02P00I_l00`000000<`3o03<0o`0<03<0o`@0fMWI00<000000=WIf@3I
fMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT>03<0o`0300000000I_l006Ko00/006Ko
00<00000003oo`00ool02@00ool00`0000000?mV003oIP09003oIP030000000co`00<ol000h0<ol0
00<000000<co003<o`006@3<o`0200000300oiT00`00000J0<co00030000000co`00<ol000h0<ol0
00<00000003oIP00ofH02@00ofH00`0000000?oo003oo`09003oo`0300000000I_l006Ko00/006Ko
00<0000003<0o`0c0?l0300c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003I
fMT0fMWI0080fMWI3`0c0?l00`00000006Ko001Vo`0:001Vo`0300000000ool00?oo00X00?oo00<0
0000003oIP00ofH02000ofH00`000000<ol003?o000?03?o008000006`3<o`02000002`0oiT00P00
000K0<co008000004@0co`000`0000000?mV003oIP08003oIP0300000000ool00?oo00X00?oo00<0
0000001Vo`00I_l02P00I_l00`000000<`3o03<0o`0=03<0o`@0fMWI00<000000=WIf@3IfMT00P3I
fMT000d0fMWI0`0000020=WIf@<000001`3IfMT00`000000fMWI0=WIf@020=WIf@l0<`3o00<00000
001Vo`00I_l02`00I_l00`0000000?oo003oo`09003oo`0300000000ofH00?mV00T00?mV00<00000
03?o000co`00400co`000`000000c?l00<co000J0<co00800000:03oV@02000001`0c?l000<00000
03?o000co`00400co`000`0000000?mV003oIP09003oIP0300000000ool00?oo00T00?oo00<00000
001Vo`00I_l02`00I_l00`000000<`3o03<0o`0=03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT0
00h0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0080fMWI3`0c0?l00`00000006Ko001Vo`0<001Vo`0300000000ool00?oo00T00?oo00<00000
003oIP00ofH02@00ofH00`000000<ol003?o000@03?o00800000703<o`02000002@0oiT00P00000L
0<co008000004P0co`000`0000000?mV003oIP09003oIP0300000000ool00?oo00T00?oo00<00000
001Vo`00I_l03000I_l00`000000<`3o03<0o`0=03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT0
00h0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0080fMWI400c0?l00`00000006Ko001Vo`0;001Vo`0300000000ool00?oo00X00?oo00<00000
003oIP00ofH02@00ofH00`000000<ol003?o000A03?o00030000003<o`00c?l001/0c?l01P00000I
0?nI00D000007@3<o`000`000000<ol003?o000A03?o000300000000ofH00?mV00T00?mV00<00000
003oo`00ool02P00ool00`00000006Ko001Vo`0;001Vo`030000000c0?l0<`3o00h0<`3o103IfMT0
0`000000fMWI0=WIf@020=WIf@003P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00@0fMWI0P0000030=WIfA00<`3o00<00000001Vo`00I_l03000I_l00`0000000?oo003oo`0:
003oo`0300000000ofH00?mV00T00?mV00<0000003?o000co`004@0co`000`000000c?l00<co000P
0<co00T000001`3oV@0900000240c?l000<0000003?o000co`004@0co`000`0000000?mV003oIP09
003oIP0300000000ool00?oo00X00?oo00<00000001Vo`00I_l03000I_l00`000000<`3o03<0o`0>
03<0o`<0fMWI0P0000040=WIf@003P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT@03<0o`0300000000I_l006Ko00d006Ko00<00000
003oo`00ool02@00ool00`0000000?mV003oIP0:003oIP030000000co`00<ol00140<ol00P00000Y
0<co00L00000:03<o`02000001<0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`09
003oo`0300000000I_l006Ko00d006Ko00<0000003<0o`0c0?l03P0c0?l40=WIf@030000003IfMT0
fMWI0080fMWI000>0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@020=WIfA40<`3o0P00000>001Vo`0300000000ool00?oo00T00?oo00<00000
003oIP00ofH02P00ofH00`000000<ol003?o000B03?o00030000003<o`00c?l005@0c?l000<00000
03?o000co`004P0co`000`0000000?mV003oIP0:003oIP0300000000ool00?oo00T00?oo00<00000
001Vo`00I_l03000I_l200000140<`3o103IfMT00`000000fMWI0=WIf@020=WIf@003P3IfMT01000
0000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMTC
03<0o`0300000000I_l006Ko00/006Ko00<00000003oo`00ool02P00ool00`0000000?mV003oIP0:
003oIP030000000co`00<ol00180<ol00P00001B0<co00800000500co`000`0000000?mV003oIP0:
003oIP0300000000ool00?oo00X00?oo00<00000001Vo`00I_l02`00I_l00`000000<`3o03<0o`0A
03<0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT000d0fMWI0P0000030=WIf@<000001`3IfMT00`00
0000fMWI0=WIf@020=WIfA@0<`3o00<00000001Vo`00I_l02`00I_l00`0000000?oo003oo`0:003o
o`0300000000ofH00?mV00X00?mV00<0000003?o000co`004`0co`000`000000c?l00<co001>0<co
00030000000co`00<ol001<0<ol000<00000003oIP00ofH02P00ofH00`0000000?oo003oo`0:003o
o`0300000000I_l006Ko00/006Ko00<0000003<0o`0c0?l04P0c0?l40=WIf@030000003IfMT0fMWI
0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI5@0c0?l00`00000006Ko001Vo`0;001Vo`03
00000000ool00?oo00X00?oo00<00000003oIP00ofH02P00ofH00`000000<ol003?o000C03?o0003
0000003<o`00c?l004`0c?l000<0000003?o000co`004`0co`000`0000000?mV003oIP0:003oIP03
00000000ool00?oo00X00?oo00<00000001Vo`00I_l02`00I_l00`000000<`3o03<0o`0C03<0o`@0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTF03<0o`030000
0000I_l006Ko00/006Ko00<00000003oo`00ool02@00ool00`0000000?mV003oIP0;003oIP030000
000co`00<ol001<0<ol00P00001:0<co008000005@0co`000`0000000?mV003oIP0;003oIP030000
0000ool00?oo00T00?oo00<00000001Vo`00I_l02`00I_l00`000000<`3o03<0o`0D03<0o`@0fMWI
00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTG03<0o`0300000000
I_l006Ko00/006Ko00<00000003oo`00ool02@00ool00`0000000?mV003oIP0;003oIP030000000c
o`00<ol001@0<ol000<000000<co003<o`00AP3<o`000`000000<ol003?o000D03?o000300000000
ofH00?mV00/00?mV00<00000003oo`00ool02@00ool00`00000006Ko001Vo`0;001Vo`030000000c
0?l0<`3o01D0<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@02
0=WIfAP0<`3o00<00000001Vo`00I_l02`00I_l00`0000000?oo003oo`09003oo`0300000000ofH0
0?mV00/00?mV00<0000003?o000co`00500co`000`000000c?l00<co00140<co00030000000co`00
<ol001@0<ol000<00000003oIP00ofH02`00ofH00`0000000?oo003oo`09003oo`0300000000I_l0
06Ko00/006Ko00<0000003<0o`0c0?l05P0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI6@0c0?l4000000X006Ko0P00000:003oo`0300000000ofH00?mV
00/00?mV0P00000E03?o00<00000@03<o`03000001D0<ol00P00000=003oIP0300000000ool00?oo
00P00?oo0P00000;001Vo`<000006@0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI7@0c0?l5000000L006Ko00<00000003oo`00ool02000ool2000000d0
0?mV00<0000003?o000co`005@0co`03000003X0c?l00`00000G03?o000300000000ofH00?mV00/0
0?mV0P00000:003oo`0300000000I_l006Ko00H006Ko1@00000L03<0o`@0fMWI00<000000=WIf@3I
fMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTR03<0o`8000001P00I_l00`0000000?oo
003oo`09003oo`0300000000ofH00?mV00/00?mV00<0000003?o000co`005`0co`0400000380c?l0
1000000I03?o000300000000ofH00?mV00/00?mV00<00000003oo`00ool02@00ool00`00000006Ko
001Vo`04001Vo`<000008@0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@8000000`3I
fMTS03<0o`0300000000I_l006Ko00D006Ko0P00000:003oo`0300000000ofH00?mV00/00?mV00<0
000003?o000co`006P0co`03000002`0c?l00`00000L03?o000300000000ofH00?mV00/00?mV00<0
0000003oo`00ool02000ool2000000L006Ko00<0000003<0o`0c0?l08@0c0?l30=WIf@800000103I
fMT001`0fMWI00<000000=WIf@3IfMT00P3IfMTT03<0o`0300000000I_l006Ko00H006Ko00<00000
003oo`00ool02000ool00`0000000?mV003oIP0;003oIP8000007@0co`03000002H0c?l00`00000M
03?o008000003@00ofH00`0000000?oo003oo`08003oo`0300000000I_l006Ko00H006Ko00<00000
03<0o`0c0?l08P0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI400c0?l;000000X0<`3o00<00000001Vo`00I_l01P00I_l00`0000000?oo003oo`08003o
o`0300000000ofH00?mV00`00?mV0P00000N03?o00L000006@3<o`06000001h0<ol00P00000>003o
IP0300000000ool00?oo00P00?oo00<00000001Vo`00I_l01P00I_l00`000000<`3o03<0o`0803<0
o`/00000400c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080
fMWI3P0c0?l2000000/0c03o2@00000203<0o`0300000000I_l006Ko00H006Ko00<00000003oo`00
ool02000ool00`0000000?mV003oIP0=003oIP8000008`0co`09000000L0c?l02@00000R03?o0080
00003`00ofH00`0000000?oo003oo`08003oo`0300000000I_l006Ko00H006Ko00<0000003<0o`0c
0?l02@00000;0<`0o`8000003P0c0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000
003IfMT0fMWI0080fMWI300c0?l2000001D0c03o00D0000003<0o`0c0?l0<`3o00000008001Vo`80
00002@00ool00`0000000?mV003oIP0>003oIP800000:P0co`07000002T0<ol00P00000@003oIP03
00000000ool00?oo00L00?oo0P000008001Vo`050000000c0?l0<`3o03<0o`0000005@3<0?l30000
00/0<`3o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@X0
<`3o0P00000H0<`0o`050000000c0?l0<`3o03<0o`0000002@00I_l00`0000000?oo003oo`07003o
o`0300000000ofH00?mV00l00?mV0P00001F03?o008000004@00ofH00`0000000?oo003oo`07003o
o`0300000000I_l006Ko00L006Ko00D0000003<0o`0c0?l0<`3o0000000I0<`0o`8000002@0c0?l4
0=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI1`0c0?l30000
01/0c03o00D0000003<0o`0c0?l0<`3o00000009001Vo`0300000000ool00?oo00L00?oo0P00000A
003oIP030000000co`00<ol00580<ol000<00000003oIP00ofH03`00ofH2000000T00?oo00<00000
001Vo`00I_l01`00I_l01@000000<`3o03<0o`0c0?l0000001`0c03o0P00000703<0o`@0fMWI00<0
00000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT503<0o`8000007`3<0?l0
1@000000<`3o03<0o`0c0?l0000000T006Ko00<00000003oo`00ool02000ool00`0000000?mV003o
IP0?003oIP800000D00co`02000001400?mV00<00000003oo`00ool02000ool00`00000006Ko001V
o`07001Vo`050000000c0?l0<`3o03<0o`0000007`3<0?l2000000D0<`3o103IfMT00`000000fMWI
0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<0<`3o0P00000M0<`0o`8000000P3<
0?l01@000000<`3o03<0o`0c0?l0000000T006Ko00<00000003oo`00ool02@00ool00`0000000?mV
003oIP0@003oIP800000C00co`02000001800?mV00<00000003oo`00ool02@00ool00`00000006Ko
001Vo`07001Vo`050000000c0?l0<`3o03<0o`0000000P3<0?l2000001d0c03o0`00000203<0o`@0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT00`0c0?l00000
0000000M0<`0o`80000000<0o`2I0000003<0?l00P3<0?l01@000000<`3o03<0o`0c0?l0000000P0
06Ko00<00000003oo`00ool02P00ool00`0000000?mV003oIP0A003oIP800000B00co`02000001<0
0?mV00<00000003oo`00ool02P00ool00`00000006Ko001Vo`06001Vo`050000000c0?l0<`3o03<0
o`0000000`3<0?l010000000o`2I00000000000N0<`0o`800000103IfMT00`000000fMWI0=WIf@02
0=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@030000003<0?l0c03o01/0c03o0P0000040?l0
V@050000003<0?l0c03o0<`0o`0000000`0c0?l00`00000006Ko001Vo`06001Vo`0300000000ool0
0?oo00X00?oo00<00000003oIP00ofH04P00ofH300000480<ol00`00000D003oIP0300000000ool0
0?oo00X00?oo00<00000001Vo`00I_l01P00I_l01@000000<`3o03<0o`0c0?l0000000<0c03o00<0
00000?l0V@3o09T00P3o09T2000001h0c03o00D000000=WIf@3IfMT0fMWI000000040=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIfA`0c03o0P0000060?l0V@050000003<0?l0c03o0<`0o`000000
100c0?l00`00000006Ko001Vo`05001Vo`0300000000ool00?oo00/00?oo00<00000003oIP00ofH0
5000ofH4000003X0<ol01000000F003oIP0300000000ool00?oo00/00?oo00<00000001Vo`00I_l0
1@00I_l00`000000<`3o03<0o`0203<0o`050000003<0?l0c03o0<`0o`0000001P3o09T3000001/0
c03o103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIfAX0c03o
0P0000090?l0V@050000003<0?l0c03o0<`0o`000000100c0?l00`00000006Ko001Vo`04001Vo`03
00000000ool00?oo00`00?oo00<00000003oIP00ofH05`00ofH3000003@0<ol00`00000I003oIP03
00000000ool00?oo00`00?oo00<00000001Vo`00I_l01000I_l00`000000<`3o03<0o`0203<0o`05
0000003<0?l0c03o0<`0o`0000002P3o09T2000001T0c03o103IfMT00`000000fMWI0=WIf@020=WI
f@00703IfMT2000000<0fMWI603<0?l2000000/0o`2I00<000000<`0o`3<0?l00P3<0?l00`000000
<`3o03<0o`0203<0o`0300000000I_l006Ko00@006Ko00<00000003oo`00ool03000ool00`000000
0?mV003oIP0I003oIP@00000;00co`04000001/00?mV00<00000003oo`00ool03000ool00`000000
06Ko001Vo`04001Vo`030000000c0?l0<`3o0080<`3o00<000000<`0o`3<0?l00P3<0?l00`000000
o`2I0?l0V@0:0?l0V@8000005`3<0?l30=WIf@800000103IfMT001`0fMWI00<000000=WIf@3IfMT0
0P3IfMTG0<`0o`@000002P3o09T2000000<0c03o0P00000303<0o`8000001@00I_l2000000h00?oo
0`00000L003oIP@000009@0co`03000001`00?mV1@00000=003oo`8000001000I_l2000000<0<`3o
0P0000030<`0o`8000002`3o09T4000001H0c03o103IfMT00`000000fMWI0=WIf@020=WIf@00703I
fMT00`000000fMWI0=WIf@020=WIfA/0c03o1P0000030?l0V@040000003<0?l0c03o0<`0o`800000
0`0c0?l2000000@006Ko0P000003001Vo`8000003`00ool3000001d00?mV2P00000A03?o00X00000
7000ofH3000000800?oo00<00000003oIP00ofH00`00000<003oo`8000001000I_l2000000<0<`3o
0P0000030<`0o`040000003o09T0o`2I0?l0V@L000006P3<0?l40=WIf@030000003IfMT0fMWI0080
fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI403<0?l7000000X0c03o0`0000020<`0o`800000
0`0c0?l2000000<006Ko0`0000000`00ool00000001Vo`04001Vo`8000004000ool4000002<00?mV
4@00000R003oIP@000001@00ool00`0000000?mV003oIP03003oIP@000002P00ool3000000<006Ko
0P00000303<0o`8000000P3<0?l3000000/0c03o1P00000@0<`0o`@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT?0<`0o`030000000c0?l0<`3o00D0<`3o2@00
00040<`0o`8000000P0c0?l3000000<006Ko0P000005003oo`0300000000I_l006Ko00@006Ko0P00
000B003oo`<00000D000ofH3000000X00?oo00<00000003oIP00ofH01P00ofH4000000T00?oo0P00
0003001Vo`<000000P0c0?l2000000D0c03o2@00000603<0o`030000003<0?l0c03o00d0c03o103I
fMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@h0c03o00<00000
03<0o`0c0?l03`0c0?l400000080<`3o0P000003001Vo`<000002000ool00`00000006Ko001Vo`05
001Vo`8000004`00ool3000004X00?mV0`00000=003oo`0300000000ofH00?mV00X00?mV0`000008
003oo`<000000`00I_l200000080<`3o1@00000@03<0o`030000003<0?l0c03o00`0c03o103IfMT0
0`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@d0c03o00<0000003<0
o`0c0?l02`00000903<0o`8000000`00I_l2000000L00?oo0`000002003oo`0300000000I_l006Ko
00H006Ko0P00000D003oo`@00000@`00ofH3000001000?oo00<00000003oIP00ofH03@00ofH40000
00L00?oo0P000003001Vo`8000002@0c0?l;00000080<`3o00<000000<`0o`3<0?l02`3<0?l40=WI
f@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI303<0?l010000000
<`3o03<0o`00000;001Vo`T000000`00I_l2000000H00?oo0`000003003oIP0400000000ool00?oo
000000T006Ko0P00000F003oo`<00000?@00ofH3000001@00?oo00<00000003oIP00ofH04000ofH3
000000H00?oo0P000003001Vo`T000002`00I_l010000000<`3o03<0o`00000<0<`0o`@0fMWI00<0
00000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT;0<`0o`050000000c0?l0
<`3o00000000I_l02`000009001Vo`<000001000ool4000000L00?mV00@00000003oo`00ool00000
2P00I_l2000001L00?oo0`00000g003oIP<000005`00ool00`0000000?mV003oIP0C003oIP@00000
1000ool3000000T006Ko2`0000001@00I_l0000003<0o`0c0?l0000000/0c03o103IfMT00`000000
fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@X0c03o00H0000003<0o`0c0?l0
0000001Vo`00000;003oo`T000001000ool3000000L00?mV0`000002003oIP0400000000ool00?oo
000000/006Ko0P00000H003oo`<00000<@00ofH3000001L00?oo0P0000000`00ool00000003oIP0>
003oIP<000001`00ofH3000000@00?oo2@00000;003oo`0300000000I_l000000080<`3o00<00000
0<`0o`3<0?l0203<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI
0080fMWI2@3<0?l01`000000<`3o03<0o`00000006Ko00000000ool02`00000:003oo`<000001P00
ofH4000000<0<ol000@00000003oIP00ofH000000P00ool00`00000006Ko001Vo`0:001Vo`<00000
6000ool3000002/00?mV0`00000G003oo`<0000000@006Ko00000000ool000003P00ofH010000000
<ol003?o000co`04000000H00?mV0`00000:003oo`/0000000@00?oo00000000I_l000000P0c0?l0
0`000000c03o0<`0o`070<`0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WI
f@3IfMT00P3IfMT80<`0o`080000000c0?l0<`3o00000000I_l00000003oo`00000;003oIPX00000
1000ofH5000000P0<ol000@00000003oIP00ofH000000P00ool00`00000006Ko001Vo`0<001Vo`<0
00006000ool3000002D00?mV0`00000G003oo`<000001000I_l0100000000?oo003oo`00000<003o
IP030000000co`00<ol000H0<ol01@000004003oIPX000002`00ofH01@0000000?oo00000000I_l0
00000080<`3o00<000000<`0o`3<0?l01P3<0?l40=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@8000000`3IfMT70<`0o`030000000c0?l0000000<0000000<00?oo00000000ofH05@00ofH40000
00h0<ol000@00000003oIP00ofH000000P00ool00`00000006Ko001Vo`0>001Vo`<000006000ool6
000001T00?mV1P00000G003oo`<000002000I_l00`0000000?oo0000000;003oIP030000000co`00
<ol000`0<ol01000000F003oIP0300000000ool0000000<0000000<0<`3o0000003<0?l01P3<0?l3
0=WIf@800000103IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT60<`0o`060000000c0?l00000
001Vo`0000000?oo0P000002003oIQD000002`0co`0600000080<ol000@00000003oIP00ofH00000
0P00ool00`00000006Ko001Vo`0@001Vo`<000006`00ool9000000L00?mV2@00000J003oo`<00000
2`00I_l00`0000000?oo0000000:003oIP030000000co`00<ol000H000002`0co`0E000000800?mV
0P0000001P00ool00000001Vo`000000<`3o000000H0c03o103IfMT00`000000fMWI0=WIf@020=WI
f@00703IfMT00`000000fMWI0=WIf@020=WIf@D0c03o00L0000003<0o`00000006Ko00000000ool0
000000<00?mV00<0000003?o000co`005@0co`09000000H0c?l000@0000003?o000co`0000000P00
ofH0100000000?oo003oo`00000D001Vo`<000008@00ool7000002000?oo0`00000>001Vo`030000
0000ool0000000T00?mV00@0000003?o000co`0000001P3<o`09000001L0<ol000/00000003oIP00
ofH00?mV00000000ool00000001Vo`000000<`3o000000050<`0o`@0fMWI00<000000=WIf@3IfMT0
0P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT40<`0o`030000000c0?l000000080000000@0
0?oo00000000ofH00?mV0P0000000`0co`0000000000000E00000100c?l000@0000003?o000co`00
00000P00ofH0100000000?oo003oo`00000F001Vo`800000A000ool20000014006Ko00@00000003o
o`00ool000001`00ofH010000000<ol003?o0000000@0<co01L0000000<0<ol00000000000000P00
ofH00`0000000?oo000000020000000303<0o`000000c03o00<0c03o103IfMT00`000000fMWI0=WI
f@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<0c03o00D0000003<0o`0000000000003o
o`02000000800?mV00@0000003?o000co`000000703<o`09000000<0c?l000@0000003?o000co`00
00000P00ofH0100000000?oo003oo`00000G001Vo`800000@000ool2000001<006Ko00@00000003o
o`00ool000001P00ofH010000000<ol003?o000000030<co00X000006`3<o`020000000403?o0000
00000?mV003oIP80000000D00?oo000000000000<`3o000000030<`0o`@0fMWI00<000000=WIf@3I
fMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT20<`0o`060000000c0?l0000000000000
ool000000P00ofH20000000403?o0000000000000<co01`000002@3oV@001@000000c?l00<co003<
o`0000000080<ol000@00000003oIP00ofH000000P00ool00`00000006Ko001Vo`0F001Vo`800000
?000ool2000001H006Ko00<00000003oo`0000001@00ofH010000000<ol003?o000000030<co0003
0000003oV@00oiT000P0oiT06`0000020<co00040000000co`000000000000800?mV00H00000003o
o`000000000003<0o`0000020<`0o`@0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`3<0?l0000003<0o`0200000005003oo`0000000?mV003oIP0000000P0c
o`0010000000c?l00<co0000000V0?nI00050000003<o`00c?l00<co000000000P0co`0010000000
0?mV003oIP000002003oo`0300000000I_l006Ko01L006Ko0P00000h003oo`8000006000I_l01000
00000?oo003oo`000003003oIP040000000co`00<ol0000000<0c?l000<000000?nI003oV@00903o
V@000`000000c?l00<co00020000000603?o000000000?mV003oIP0000000?oo0P0000000`0c0?l0
00000<`0o`040=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI
00H0000003<0o`0000000000003oo`000002003oIP040000000co`00<ol000000080c?l000<00000
0?nI003oV@000P3oV@0S000000030?nI00000000c?l00080c?l000@0000003?o000co`0000000P00
ofH0100000000?oo003oo`00000J001Vo`<00000=000ool2000001T006Ko00@00000003oo`00ool0
00000P00ofH010000000<ol003?o000000030<co00030000003oV@00000002800000103oV@001`00
0000c?l00<co003<o`00000003?o000000000P00ofH01P0000000?oo000000000000<`3o000000@0
fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT01P000000<`3o
0000000000000?oo000000800?mV00@0000003?o000co`0000000P3<o`000`000000oiT00?nI0002
000002<0o`0000<000000?nI000000000P3<o`0010000000<ol003?o00000002003oIP0400000000
ool00?oo000001d006Ko0`00000c003oo`0300000000I_l006Ko01H006Ko00@00000003oo`00ool0
00000P00ofH010000000<ol003?o000000020<co00030000003oV@00000002<0o`000P0000020?nI
00070000003<o`00c?l00<co00000000<ol000000002003oIP0600000000ool000000000000c0?l0
0000103IfMT00`000000fMWI0=WIf@020=WIf@00703IfMT00`000000fMWI0=WIf@020=WIf@<00000
00D00?oo00000000ofH00?mV0000000203?o00040000003<o`00c?l0000000<0oiT000<000000?l0
003o00008`3o00000`000000oiT0000000020<co00040000000co`00<ol0000000800?mV00@00000
003oo`00ool000007`00I_l3000003400?oo00<00000001Vo`00I_l05000I_l0100000000?oo003o
o`000002003oIP040000000co`00<ol000000080c?l000<000000?nI000000009@3o00001@000000
oiT00?nI003oV@00000000<0c?l000<0000003?o000000000P00ofH01P0000000?oo000000000000
<`3o000000<0fMWI00<000000=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT0
1`0c0?l0000000000000ool00000003oIP0000000P0co`0010000000c?l00<co000000040?nI0003
0000003o0000o`0002@0o`0000<000000?nI000000000P3<o`0010000000<ol003?o00000002003o
IP0300000000ool00000028006Ko1@00000L003oo`@000003@00ool00`00000006Ko001Vo`0C001V
o`0300000000ool0000000800?mV00@0000003?o000co`0000000P3<o`000`000000oiT00000000V
0?l000030000003oV@00oiT00080oiT000X000000<co003<o`00c?l00000000co`000000003oIP00
00000?oo0P0000000`0c0?l0fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@03
0000003IfMT0fMWI0080fMWI00@0<`3o00000000000000000P00ofH00`000000<ol0000000020<co
00030000003oV@00oiT00080oiT000<000000?l0003o00009P3o00000`000000oiT0000000020<co
00060000000co`00<ol000000000ofH000000P00ool4000002<006Ko1P00000@003oo`H000000`00
I_l00`0000000?oo003oo`0<003oo`0300000000I_l006Ko00h006Ko10000002003oo`0300000000
ofH000000080<ol000H000000<co003<o`0000000?nI0000000X0?l000030000003oV@00oiT00080
oiT000@000000<co003<o`00c?l00P000002003oIP0400000000ool00000000000@0fMWI00<00000
0=WIf@3IfMT00P3IfMT001`0fMWI0P0000030=WIf@80000000@00?oo00000000ofH000000P0co`00
0`000000c?l0000000050?nI00030000003o0000o`0002L0o`0000<000000?nI000000000P3<o`00
0`000000<ol000000002003oIP0300000000ool00?oo00<00?oo1P00000S001Vo`H000001@00ool5
000000X006Ko00<00000003oo`00ool03000ool00`00000006Ko001Vo`07001Vo`H000001@00ool0
1P0000000?mV003oIP000000<ol000000080c?l000<000000?nI00000000:@3o00000`000000oiT0
0?nI00030?nI00090000003<o`00c?l00000000co`000000003oIP0000000?oo008000000`3IfMT2
000000@0fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI0`000002003oIP050000000co`000000
0<co000000001P3oV@000`000000o`000?l0000X0?l000050000003oV@0000000<co000000000P0c
o`000`0000000?mV0000000;003oo`D000009000I_l50000010006Ko00<00000003oo`00ool03000
ool01000000006Ko001Vo`00I_l5000000/00?oo00<00000003oIP0000000P0co`001@000000c?l0
0000003oV@00000002X0o`0000<000000?nI003oV@00103oV@001`000000c?l00<co00000000<ol0
00000000ofH00P0000000`00I_l000000=WIf@020=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI00L006Ko0000000000000?mV0000000co`0000000080c?l000<0
00000?nI003oV@00103oV@000`000000o`000?l0000Y0?l000050000003oV@0000000<co00000000
0P0co`000`0000000?mV0000000?003oo`<00000=P00I_l00`0000000?oo003oo`0=003oo`<00000
3`00ool00`0000000?mV0000000203?o00050000003<o`0000000?nI00000000:`3o00000`000000
oiT00?nI00050?nI00070000003<o`00c?l00000000co`000000003oIP02000000@0fMWI00<00000
0=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT01P0000000?oo000000000000
<ol000000080c?l000<000000?nI003oV@00103oV@000`000000o`000?l0000[0?l000070000003o
V@0000000<co00000000<ol000000002003oIP<000003P00ool00`00000006Ko001Vo`0e001Vo`03
00000000ool00?oo01/00?oo0`000002003oIP070000000co`0000000<co00000000oiT00000000]
0?l000030000003oV@00oiT000D0oiT000<000000<co003<o`000P0000000`00ofH0000000000004
0=WIf@030000003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI0P0000001P00
ofH0000003?o00000000c?l0000000L0oiT000<000000?l0003o0000;03o00001`000000oiT00000
003<o`00000003?o000000001000ofH3000000`00?oo00<00000001Vo`00I_l0=@00I_l00`000000
0?oo003oo`0G003oo`<000001000ofH01`000000<ol00000003<o`0000000?nI00000000;P3o0000
0`000000oiT00?nI00060?nI00060000003<o`00000003?o000000000?mV0P0000030=WIf@030000
003IfMT0fMWI0080fMWI000L0=WIf@030000003IfMT0fMWI0080fMWI00L00?oo000000000000<ol0
0000003<o`00000000P0oiT000<000000?l0003o0000;@3o000010000000oiT000000000000203?o
000300000000ofH00?mV00@00?mV10000009003oo`0300000000I_l006Ko03@006Ko00<00000003o
o`00ool04`00ool4000000H00?mV00<0000003?o000co`000P0000000`3oV@0000000?l0000^0?l0
00030000003oV@00oiT000H0oiT000D000000<co003<o`00000003?o0002000000@0fMWI00<00000
0=WIf@3IfMT00P3IfMT001`0fMWI00<000000=WIf@3IfMT00P3IfMT01P0000000?mV000000000000
c?l0000000T0oiT000<000000?l0003o0000;P3o000010000000oiT000000000000203?o00800000
2000ofH3000000L00?oo00<00000001Vo`00I_l0=000I_l00`0000000?oo003oo`0?003oo`<00000
2000ofH200000080<ol00P0000000`3oV@0000000?l0000_0?l000030000003oV@00oiT000L0oiT0
00<000000<co003<o`000P0000000`00ofH000000=WIf@020=WIf@030000003IfMT0fMWI0080fMWI
000L0=WIf@030000003IfMT0fMWI0080fMWI00H00?mV0000000co`0000000<co000000080?nI0003
0000003o0000o`000300o`0000@000000?nI0000000000000`0co`03000000P00?mV0`000005003o
o`0300000000I_l006Ko00/006Ko0`00000N001Vo`<000001000I_l00`0000000?oo003oo`0<003o
o`<000002000ofH3000000<0<ol00P0000000`3oV@0000000?l0000a0?l000030000003oV@00oiT0
00L0oiT000D000000<co00000000<ol0000000040=WIf@030000003IfMT0fMWI0080fMWI000L0=WI
f@030000003IfMT0fMWI0080fMWI00D0000003?o00000000c?l0000000090?nI00030000003o0000
o`000340o`0000@000000?nI0000000000001@0co`03000000P00?mV0`000003003oo`0300000000
I_l006Ko00X006Ko00<0000003<0o`0c0?l00`00000H001Vo`<000000P0c0?l00`00000006Ko001V
o`03001Vo`0300000000ool00?oo00P00?oo0`000008003oIP<000001@0co`02000000030?nI0000
0000o`000380o`0000<000000?nI003oV@00203oV@001@000000c?l00000000co`00000000<0fMWI
00<000000=WIf@3IfMT00P3IfMT000/0fMWI100000030=WIf@<000001`3IfMT00`000000fMWI0=WI
f@020=WIf@0403?o00000000c?l0000000X0oiT000<000000?l0003o0000<P3o00000`000000oiT0
00000003000000D0<ol00`000008003oIP0500000000ool00?oo003oo`0000002P00I_l00`000000
<`3o03<0o`0403<0o`@000004000I_l4000000H0<`3o00<00000001Vo`00I_l00`00I_l00`000000
0?oo003oo`06003oo`0300000000ofH00?mV00H00?mV0`00000503?o00@0000000<0oiT00000003o
0000<`3o00000`000000oiT00?nI00090?nI00030000003<o`00000000@0fMWI00<000000=WIf@3I
fMT00P3IfMT000/0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000000<0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003<o`00000000/0oiT000<000000?l0
003o0000<`3o00000`000000oiT000000007000000<0<ol00`000006003oIP0500000000ool00?oo
003oo`0000002000I_l00`000000<`3o03<0o`0903<0o`<000002P00I_l3000000/0<`3o00<00000
001Vo`00I_l00P00I_l00`0000000?oo003oo`05003oo`0300000000ofH00?mV00@00?mV0`000003
03?o00P0000000<0oiT00000003o0000=03o00000`000000oiT00?nI000:0?nI00030000003<o`00
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT000`0fMWI00<000000=WIf@3IfMT00P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`3<o`0000000?nI000:
0?nI00030000003o0000o`0003D0o`0000@000000?nI003oV@00oiT0100000000`3<o`0000000000
000200000080<ol00`000004003oIP0500000000ool00?oo003oo`0000001P00I_l00`000000<`3o
03<0o`0=03<0o`<000001000I_l3000000l0<`3o00<00000001Vo`00I_l00P00I_l00`0000000?oo
003oo`03003oo`0300000000ofH00?mV00800?mV0`00000203?o00@0000000<0c?l0000000000000
0P0000030?nI00030000003o0000o`0003D0o`0000<000000?nI003oV@002P3oV@000`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI000=0=WIf@050000003IfMT0fMWI0=WIf@000000
0`3IfMT00`000000fMWI0=WIf@040=WIf@8000000`3IfMT00`000000oiT00?nI000:0?nI00030000
003o0000o`0003H0o`000`0000040?nI008000000`3<o`02000000<0<ol00P000003003oIP050000
0000ool00?oo003oo`0000001000I_l00`000000<`3o03<0o`0A03<0o`@000004`0c0?l00`000000
06Ko001Vo`02001Vo`0500000000ool00?oo003oo`0000000`00ofH2000000<0<ol00P0000030<co
00800000103oV@03000003P0o`0000<000000?nI003oV@002`3oV@000`000000fMWI0=WIf@020000
00@0fMWI000>0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@3l0=WIf@030000003IfMT0fMWI0080fMWI000>0=WIf@040000003IfMT0fMWI0000
00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3l0=WIf@030000003IfMT0fMWI
0080fMWI000;0=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0?`0fMWI00<000000=WIf@3IfMT00P3IfMT000`0fMWI0P0000040=WI
f@<000001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT02P3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI000L0=WIfOl000000@0000040=WI
f@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-25.3871, -24.5737, 0.162679, 
  0.162679}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Relaxation of the Sextupole", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(radUtiDelAll[]; \nPrec = 0.0001; \nNmax = 10; \nnseg = 12; \nrint = 20; 
    \nrext = 60; \nLz = 30; \nphi1 = \(-Pi\)/nseg; \nphi2 = phi1 + 2\ Pi; \n
    nz = 2; \nnr = {3, 2}; \npt = {0, 0, 0}; \ndphi = \((phi2 - phi1)\)/nseg; 
    \nbr = 1.2; \nmaterial = radMatLin[{0.06, 0.17}, br]; \n
    mag = {0, br, 0, 4}; \n
    a0 = RadCylinder[pt, rint, rext, phi1, phi2, Lz, nr, nseg, nz, mag]; \n\n
     (*remove\ unnecessary\ parts*) \n\n
    a1 = \(radObjCutMag[a0, {0, 0, 0}, {0, 1, 0}]\)[\([2]\)]; \n
    cyl4 = \(radObjCutMag[a1, {0, 0, 0}, {Sin[Pi/6], \(-Cos[Pi/6]\), 0}]\)[
        \([2]\)]; \n\n (*apply\ symmetries, \ reduce\ size\ of\ matrix\ *) \n
    \nsym1 = radTrfPlSym[{0, 0, 0}, {\(-Sin[Pi/6]\), Cos[Pi/6], 0}]; \n
    radTrfMlt[cyl4, sym1, 2]; \nrt1 = radTrfRot[{0, 0, 0}, {0, 0, 1}, Pi/3]; 
    \nt2 = radTrfInv[]; \ntf = radTrfCmbL[rt1, t2]; \nradTrfMlt[cyl4, tf, 6]; 
    \nradMatApl[cyl4, material]; \nMtrx = radRlxPre[cyl4]; \n
    radRlxAuto[Mtrx, Prec, Nmax]\), 
    \(\(radUtiDel[Mtrx]; \)\n\n\)}], "Input"],

Cell[BoxData[
    \({0.0000247199345931154734`, 1.20267616365501184`, 1.06677433358852091`, 
      2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Show", "[", 
        RowBox[{
          RowBox[{"Graphics3D", "[", 
            RowBox[{
              StyleBox["radObjDrw",
                FontColor->RGBColor[1, 0, 0]], "[", "cyl4", "]"}], "]"}], 
          "\n", ",", \(ViewPoint -> {0, 0, 1000}\)}], "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.22365 .1393 -12.5 -14 ]
[.22365 .1393 12.5 0 ]
[.5 .1393 -5 -14 ]
[.5 .1393 5 0 ]
[.77635 .1393 -8 -14 ]
[.77635 .1393 8 0 ]
[.5 .0768 -8 -14 ]
[.5 .0768 8 0 ]
[.1393 .22365 -25 -7 ]
[.1393 .22365 0 7 ]
[.1393 .5 -10 -7 ]
[.1393 .5 0 7 ]
[.1393 .77635 -16 -7 ]
[.1393 .77635 0 7 ]
[.0768 .5 -15 -7 ]
[.0768 .5 0 7 ]
[.13939 .15189 -10 -7 ]
[.13939 .15189 0 7 ]
[.13936 .15186 -16 -7 ]
[.13936 .15186 0 7 ]
[.13933 .15183 -16 -7 ]
[.13933 .15183 0 7 ]
[.1393 .1518 -16 -7 ]
[.1393 .1518 0 7 ]
[.07684 .15184 -14 -7 ]
[.07684 .15184 0 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.1518 .1518 m
.8482 .1518 L
s
.25 Mabswid
.22365 .1518 m
.22365 .15805 L
s
gsave
.22365 .1393 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .1518 m
.5 .15805 L
s
gsave
.5 .1393 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77635 .1518 m
.77635 .15805 L
s
gsave
.77635 .1393 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.27892 .1518 m
.27892 .15555 L
s
.33419 .1518 m
.33419 .15555 L
s
.38946 .1518 m
.38946 .15555 L
s
.44473 .1518 m
.44473 .15555 L
s
.55527 .1518 m
.55527 .15555 L
s
.61054 .1518 m
.61054 .15555 L
s
.66581 .1518 m
.66581 .15555 L
s
.72108 .1518 m
.72108 .15555 L
s
.16838 .1518 m
.16838 .15555 L
s
.83162 .1518 m
.83162 .15555 L
s
gsave
.5 .0768 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
75.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.1518 .1518 m
.1518 .8482 L
s
.25 Mabswid
.1518 .22365 m
.15805 .22365 L
s
gsave
.1393 .22365 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.1518 .5 m
.15805 .5 L
s
gsave
.1393 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.1518 .77635 m
.15805 .77635 L
s
gsave
.1393 .77635 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.1518 .27892 m
.15555 .27892 L
s
.1518 .33419 m
.15555 .33419 L
s
.1518 .38946 m
.15555 .38946 L
s
.1518 .44473 m
.15555 .44473 L
s
.1518 .55527 m
.15555 .55527 L
s
.1518 .61054 m
.15555 .61054 L
s
.1518 .66581 m
.15555 .66581 L
s
.1518 .72108 m
.15555 .72108 L
s
.1518 .16838 m
.15555 .16838 L
s
.1518 .83162 m
.15555 .83162 L
s
gsave
.0768 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.15189 .15189 m
.1518 .1518 L
s
.25 Mabswid
.15189 .15189 m
.15814 .15189 L
s
gsave
.13939 .15189 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15186 .15186 m
.15811 .15186 L
s
gsave
.13936 .15186 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.15183 .15183 m
.15808 .15183 L
s
gsave
.13933 .15183 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.1518 .1518 m
.15805 .1518 L
s
gsave
.1393 .1518 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.15188 .15188 m
.15563 .15188 L
s
.15188 .15188 m
.15563 .15188 L
s
.15187 .15187 m
.15562 .15187 L
s
.15186 .15186 m
.15561 .15186 L
s
.15185 .15185 m
.1556 .15185 L
s
.15185 .15185 m
.1556 .15185 L
s
.15184 .15184 m
.15559 .15184 L
s
.15184 .15184 m
.15559 .15184 L
s
.15183 .15183 m
.15558 .15183 L
s
.15182 .15182 m
.15557 .15182 L
s
.15181 .15181 m
.15556 .15181 L
s
.15181 .15181 m
.15556 .15181 L
s
gsave
.07684 .15184 -75 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.15189 .15189 m
.1518 .1518 L
s
.1518 .1518 m
.1518 .8482 L
s
.1518 .8482 m
.15189 .84811 L
s
.15189 .84811 m
.15189 .15189 L
s
.84811 .15189 m
.84811 .84811 L
s
.84811 .84811 m
.8482 .8482 L
s
.8482 .8482 m
.8482 .1518 L
s
.8482 .1518 m
.84811 .15189 L
s
.15189 .15189 m
.1518 .1518 L
s
.1518 .1518 m
.8482 .1518 L
s
.8482 .1518 m
.84811 .15189 L
s
.84811 .15189 m
.15189 .15189 L
s
.15189 .84811 m
.84811 .84811 L
s
.84811 .84811 m
.8482 .8482 L
s
.8482 .8482 m
.1518 .8482 L
s
.1518 .8482 m
.15189 .84811 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.70042 .38429 m .70039 .3843 L .78712 .33423 L p .454 .889 .712 r
F P
0 g
s
.70039 .3843 m .70042 .38429 L .63909 .4197 L p .454 .889 .712 r
F P
0 g
s
.63909 .4197 m .63907 .41971 L .70039 .3843 L p .454 .889 .712 r
F P
0 g
s
.83154 .41116 m .83158 .41115 L .73142 .43799 L p .1 .1 .1 r
F P
0 g
s
.73142 .43799 m .73139 .438 L .83154 .41116 L p .1 .1 .1 r
F P
0 g
s
.70039 .3843 m .70042 .38429 L .78715 .33421 L p .1 .1 .1 r
F P
0 g
s
.78715 .33421 m .78712 .33423 L .70039 .3843 L p .1 .1 .1 r
F P
0 g
s
.70042 .38429 m .70039 .3843 L .63907 .41971 L p .1 .1 .1 r
F P
0 g
s
.74273 .25727 m .7427 .2573 L .66939 .33061 L p .6 .916 .6 r
F P
0 g
s
.5 .26858 m .5 .26861 L .5 .16846 L p .807 .677 .1 r
F P
0 g
s
.5 .26861 m .5 .26858 L .5 .3394 L p .1 .1 .1 r
F P
0 g
s
.5 .26861 m .5 .33942 L .5 .3394 L p .1 .1 .1 r
F P
0 g
s
.58884 .16846 m .58885 .16842 L .56201 .26858 L p .1 .1 .1 r
F P
0 g
s
.56201 .26858 m .562 .26861 L .58884 .16846 L p .1 .1 .1 r
F P
0 g
s
.5 .26861 m .5 .26858 L .5 .16842 L p .1 .1 .1 r
F P
0 g
s
.5 .16842 m .5 .16846 L .5 .26861 L p .1 .1 .1 r
F P
0 g
s
.5 .26858 m .5 .26861 L .5 .33942 L p .807 .677 .1 r
F P
0 g
s
.41115 .16842 m .41116 .16846 L .438 .26861 L p .783 .508 .1 r
F P
0 g
s
.29958 .38429 m .29961 .3843 L .21288 .33423 L p .454 .1 .1 r
F P
0 g
s
.29961 .3843 m .29958 .38429 L .36091 .4197 L p .454 .1 .1 r
F P
0 g
s
.36091 .4197 m .36093 .41971 L .29961 .3843 L p .454 .1 .1 r
F P
0 g
s
.2573 .2573 m .25727 .25727 L .33059 .33059 L p .1 .1 .6 r
F P
0 g
s
.2573 .2573 m .33061 .33061 L .33059 .33059 L p .1 .1 .6 r
F P
0 g
s
.29961 .3843 m .29958 .38429 L .21285 .33421 L p .1 .311 .712 r
F P
0 g
s
.21285 .33421 m .21288 .33423 L .29961 .3843 L p .1 .311 .712 r
F P
0 g
s
.29958 .38429 m .29961 .3843 L .36093 .41971 L p .454 .1 .1 r
F P
0 g
s
.16842 .41115 m .16846 .41116 L .26861 .438 L p .1 .508 .783 r
F P
0 g
s
.29958 .61571 m .29961 .6157 L .21288 .66577 L p .1 .1 .1 r
F P
0 g
s
.29961 .6157 m .29958 .61571 L .36091 .5803 L p .454 .889 .712 r
F P
0 g
s
.36091 .5803 m .36093 .58029 L .29961 .6157 L p .454 .889 .712 r
F P
0 g
s
.16846 .58884 m .16842 .58885 L .26858 .56201 L p .283 .807 .783 r
F P
0 g
s
.26858 .56201 m .26861 .562 L .16846 .58884 L p .283 .807 .783 r
F P
0 g
s
.29961 .6157 m .29958 .61571 L .21285 .66579 L p .454 .889 .712 r
F P
0 g
s
.21285 .66579 m .21288 .66577 L .29961 .6157 L p .454 .889 .712 r
F P
0 g
s
.29958 .61571 m .29961 .6157 L .36093 .58029 L p .1 .1 .1 r
F P
0 g
s
.25727 .74273 m .2573 .7427 L .33061 .66939 L p .6 .916 .6 r
F P
0 g
s
.5 .73142 m .5 .73139 L .5 .83154 L p .807 .677 .1 r
F P
0 g
s
.5 .73139 m .5 .73142 L .5 .6606 L p .807 .677 .1 r
F P
0 g
s
.5 .6606 m .5 .66058 L .5 .73139 L p .807 .677 .1 r
F P
0 g
s
.41116 .83154 m .41115 .83158 L .43799 .73142 L p .1 .1 .1 r
F P
0 g
s
.43799 .73142 m .438 .73139 L .41116 .83154 L p .1 .1 .1 r
F P
0 g
s
.5 .73139 m .5 .73142 L .5 .83158 L p .807 .677 .1 r
F P
0 g
s
.5 .83158 m .5 .83154 L .5 .73139 L p .807 .677 .1 r
F P
0 g
s
.5 .73142 m .5 .73139 L .5 .66058 L p .807 .677 .1 r
F P
0 g
s
.58885 .83158 m .58884 .83154 L .562 .73139 L p .783 .508 .1 r
F P
0 g
s
.70042 .61571 m .70039 .6157 L .78712 .66577 L p .454 .1 .1 r
F P
0 g
s
.70039 .6157 m .70042 .61571 L .63909 .5803 L p .454 .1 .1 r
F P
0 g
s
.63909 .5803 m .63907 .58029 L .70039 .6157 L p .454 .1 .1 r
F P
0 g
s
.7427 .7427 m .74273 .74273 L .66941 .66941 L p .6 .1 .1 r
F P
0 g
s
.7427 .7427 m .66939 .66939 L .66941 .66941 L p .6 .1 .1 r
F P
0 g
s
.70039 .6157 m .70042 .61571 L .78715 .66579 L p .454 .1 .1 r
F P
0 g
s
.78715 .66579 m .78712 .66577 L .70039 .6157 L p .454 .1 .1 r
F P
0 g
s
.70042 .61571 m .70039 .6157 L .63907 .58029 L p .1 .311 .712 r
F P
0 g
s
.83158 .58885 m .83154 .58884 L .73139 .562 L p .1 .508 .783 r
F P
0 g
s
.78712 .33423 m .78715 .33421 L .70042 .38429 L p .454 .889 .712 r
F P
0 g
s
.83154 .41116 m .83158 .41115 L .78715 .33421 L p .1 .157 .723 r
F P
0 g
s
.78715 .33421 m .78712 .33423 L .83154 .41116 L p .1 .157 .723 r
F P
0 g
s
.83154 .41116 m .78712 .33423 L .70039 .3843 L p .807 .677 .807 r
F P
0 g
s
.70039 .3843 m .73139 .438 L .83154 .41116 L p .807 .677 .807 r
F P
0 g
s
.73139 .438 m .70039 .3843 L .63907 .41971 L p .807 .677 .807 r
F P
0 g
s
.63907 .41971 m .66058 .45697 L .73139 .438 L p .807 .677 .807 r
F P
0 g
s
.63907 .41971 m .63909 .4197 L .59572 .44474 L p .1 .1 .1 r
F P
0 g
s
.59572 .44474 m .59571 .44474 L .63907 .41971 L p .1 .1 .1 r
F P
0 g
s
.66058 .45697 m .63907 .41971 L .59571 .44474 L p .807 .677 .807 r
F P
0 g
s
.59571 .44474 m .61051 .47039 L .66058 .45697 L p .807 .677 .807 r
F P
0 g
s
.61051 .47039 m .59571 .44474 L .59572 .44474 L p .1 .1 .56 r
F P
0 g
s
.59572 .44474 m .61053 .47038 L .61051 .47039 L p .1 .1 .56 r
F P
0 g
s
.61051 .47039 m .61053 .47038 L .6606 .45697 L p .1 .1 .1 r
F P
0 g
s
.6606 .45697 m .66058 .45697 L .61051 .47039 L p .1 .1 .1 r
F P
0 g
s
.73139 .5 m .73142 .5 L .83158 .5 L p .1 .1 .1 r
F P
0 g
s
.83158 .5 m .83154 .5 L .73139 .5 L p .1 .1 .1 r
F P
0 g
s
.83154 .41116 m .83154 .5 L .83158 .5 L p .1 .1 .404 r
F P
0 g
s
.83158 .5 m .83158 .41115 L .83154 .41116 L p .1 .1 .404 r
F P
0 g
s
.83154 .41116 m .73139 .438 L .73139 .5 L p .807 .677 .807 r
F P
0 g
s
.73139 .5 m .83154 .5 L .83154 .41116 L p .807 .677 .807 r
F P
0 g
s
.73142 .5 m .6606 .5 L .66058 .5 L p .1 .677 .807 r
F P
0 g
s
.66058 .5 m .73139 .5 L .73142 .5 L p .1 .677 .807 r
F P
0 g
s
.66058 .45697 m .73139 .438 L .73142 .43799 L p .1 .1 .1 r
F P
0 g
s
.73139 .438 m .66058 .45697 L .66058 .5 L p .807 .677 .807 r
F P
0 g
s
.66058 .5 m .73139 .5 L .73139 .438 L p .807 .677 .807 r
F P
0 g
s
.6606 .5 m .61053 .5 L .61051 .5 L p .1 .677 .807 r
F P
0 g
s
.61051 .5 m .66058 .5 L .6606 .5 L p .1 .677 .807 r
F P
0 g
s
.66058 .45697 m .61051 .47039 L .61051 .5 L p .807 .677 .807 r
F P
0 g
s
.61051 .5 m .66058 .5 L .66058 .45697 L p .807 .677 .807 r
F P
0 g
s
.61051 .47039 m .61053 .47038 L .61053 .5 L p .1 .1 .211 r
F P
0 g
s
.61053 .5 m .61051 .5 L .61051 .47039 L p .1 .1 .211 r
F P
0 g
s
.61051 .47039 m .66058 .45697 L .6606 .45697 L p .1 .1 .1 r
F P
0 g
s
.6606 .45697 m .61053 .47038 L .61051 .47039 L p .1 .1 .1 r
F P
0 g
s
.74273 .25727 m .7427 .2573 L .78712 .33423 L p .1 .157 .723 r
F P
0 g
s
.66939 .33061 m .70039 .3843 L .78712 .33423 L p .807 .677 .807 r
F P
0 g
s
.78712 .33423 m .7427 .2573 L .66939 .33061 L p .807 .677 .807 r
F P
0 g
s
.63907 .41971 m .63909 .4197 L .70042 .38429 L p .1 .1 .1 r
F P
0 g
s
.61756 .38244 m .63907 .41971 L .70039 .3843 L p .807 .677 .807 r
F P
0 g
s
.70039 .3843 m .66939 .33061 L .61756 .38244 L p .807 .677 .807 r
F P
0 g
s
.59571 .44474 m .59572 .44474 L .63909 .4197 L p .454 .889 .712 r
F P
0 g
s
.63909 .4197 m .63907 .41971 L .59571 .44474 L p .454 .889 .712 r
F P
0 g
s
.5809 .4191 m .59571 .44474 L .63907 .41971 L p .807 .677 .807 r
F P
0 g
s
.63907 .41971 m .61756 .38244 L .5809 .4191 L p .807 .677 .807 r
F P
0 g
s
.58091 .41909 m .59572 .44474 L .59571 .44474 L p .1 .1 .56 r
F P
0 g
s
.59571 .44474 m .5809 .4191 L .58091 .41909 L p .1 .1 .56 r
F P
0 g
s
.58091 .41909 m .5809 .4191 L .61756 .38244 L p .6 .916 .6 r
F P
0 g
s
.66577 .21288 m .66579 .21285 L .61571 .29958 L p .1 .1 .1 r
F P
0 g
s
.61571 .29958 m .6157 .29961 L .66577 .21288 L p .1 .1 .1 r
F P
0 g
s
.66939 .33061 m .66941 .33059 L .74273 .25727 L p .6 .916 .6 r
F P
0 g
s
.74273 .25727 m .66579 .21285 L .66577 .21288 L p .1 .539 .957 r
F P
0 g
s
.66577 .21288 m .7427 .2573 L .74273 .25727 L p .1 .539 .957 r
F P
0 g
s
.66577 .21288 m .6157 .29961 L .66939 .33061 L p .807 .677 .807 r
F P
0 g
s
.66939 .33061 m .7427 .2573 L .66577 .21288 L p .807 .677 .807 r
F P
0 g
s
.6157 .29961 m .61571 .29958 L .5803 .36091 L p .1 .1 .1 r
F P
0 g
s
.5803 .36091 m .58029 .36093 L .6157 .29961 L p .1 .1 .1 r
F P
0 g
s
.61757 .38243 m .66941 .33059 L .66939 .33061 L p .6 .916 .6 r
F P
0 g
s
.66939 .33061 m .61756 .38244 L .61757 .38243 L p .6 .916 .6 r
F P
0 g
s
.6157 .29961 m .58029 .36093 L .61756 .38244 L p .807 .677 .807 r
F P
0 g
s
.61756 .38244 m .66939 .33061 L .6157 .29961 L p .807 .677 .807 r
F P
0 g
s
.58029 .36093 m .5803 .36091 L .55526 .40428 L p .712 .889 .454 r
F P
0 g
s
.55526 .40428 m .55526 .40429 L .58029 .36093 L p .712 .889 .454 r
F P
0 g
s
.58029 .36093 m .55526 .40429 L .5809 .4191 L p .807 .677 .807 r
F P
0 g
s
.5809 .4191 m .61756 .38244 L .58029 .36093 L p .807 .677 .807 r
F P
0 g
s
.55526 .40429 m .55526 .40428 L .58091 .41909 L p .1 .399 .816 r
F P
0 g
s
.58091 .41909 m .5809 .4191 L .55526 .40429 L p .1 .399 .816 r
F P
0 g
s
.61756 .38244 m .5809 .4191 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.5 .16846 m .5 .16842 L .5 .26858 L p .807 .677 .1 r
F P
0 g
s
.58884 .16846 m .58885 .16842 L .5 .16842 L p .404 .869 1 r
F P
0 g
s
.5 .16842 m .5 .16846 L .58884 .16846 L p .404 .869 1 r
F P
0 g
s
.58884 .16846 m .5 .16846 L .5 .26861 L p .807 .677 .807 r
F P
0 g
s
.5 .26861 m .562 .26861 L .58884 .16846 L p .807 .677 .807 r
F P
0 g
s
.562 .26861 m .5 .26861 L .5 .33942 L p .807 .677 .807 r
F P
0 g
s
.5 .33942 m .54303 .33942 L .562 .26861 L p .807 .677 .807 r
F P
0 g
s
.5 .33942 m .5 .3394 L .5 .38947 L p .1 .1 .1 r
F P
0 g
s
.5 .33942 m .5 .38949 L .5 .38947 L p .1 .1 .1 r
F P
0 g
s
.54303 .33942 m .5 .33942 L .5 .38949 L p .807 .677 .807 r
F P
0 g
s
.5 .38949 m .52961 .38949 L .54303 .33942 L p .807 .677 .807 r
F P
0 g
s
.52961 .38949 m .5 .38949 L .5 .38947 L p .211 .761 .909 r
F P
0 g
s
.5 .38947 m .52962 .38947 L .52961 .38949 L p .211 .761 .909 r
F P
0 g
s
.52961 .38949 m .52962 .38947 L .54303 .3394 L p .1 .1 .1 r
F P
0 g
s
.54303 .3394 m .54303 .33942 L .52961 .38949 L p .1 .1 .1 r
F P
0 g
s
.6157 .29961 m .61571 .29958 L .66579 .21285 L p .1 .1 .1 r
F P
0 g
s
.66579 .21285 m .66577 .21288 L .6157 .29961 L p .1 .1 .1 r
F P
0 g
s
.58884 .16846 m .66577 .21288 L .66579 .21285 L p .1 .539 .957 r
F P
0 g
s
.66579 .21285 m .58885 .16842 L .58884 .16846 L p .1 .539 .957 r
F P
0 g
s
.58884 .16846 m .562 .26861 L .6157 .29961 L p .807 .677 .807 r
F P
0 g
s
.6157 .29961 m .66577 .21288 L .58884 .16846 L p .807 .677 .807 r
F P
0 g
s
.58029 .36093 m .5803 .36091 L .61571 .29958 L p .712 .889 .454 r
F P
0 g
s
.61571 .29958 m .6157 .29961 L .58029 .36093 L p .712 .889 .454 r
F P
0 g
s
.54303 .33942 m .562 .26861 L .56201 .26858 L p .1 .1 .1 r
F P
0 g
s
.562 .26861 m .54303 .33942 L .58029 .36093 L p .807 .677 .807 r
F P
0 g
s
.58029 .36093 m .6157 .29961 L .562 .26861 L p .807 .677 .807 r
F P
0 g
s
.55526 .40429 m .55526 .40428 L .5803 .36091 L p .712 .889 .454 r
F P
0 g
s
.5803 .36091 m .58029 .36093 L .55526 .40429 L p .712 .889 .454 r
F P
0 g
s
.54303 .33942 m .52961 .38949 L .55526 .40429 L p .807 .677 .807 r
F P
0 g
s
.55526 .40429 m .58029 .36093 L .54303 .33942 L p .807 .677 .807 r
F P
0 g
s
.52961 .38949 m .52962 .38947 L .55526 .40428 L p .1 .399 .816 r
F P
0 g
s
.55526 .40428 m .55526 .40429 L .52961 .38949 L p .1 .399 .816 r
F P
0 g
s
.52961 .38949 m .54303 .33942 L .54303 .3394 L p .1 .1 .1 r
F P
0 g
s
.54303 .3394 m .52962 .38947 L .52961 .38949 L p .1 .1 .1 r
F P
0 g
s
.41115 .16842 m .41116 .16846 L .5 .16846 L p .404 .869 1 r
F P
0 g
s
.438 .26861 m .5 .26861 L .5 .16846 L p .807 .677 .807 r
F P
0 g
s
.5 .16846 m .41116 .16846 L .438 .26861 L p .807 .677 .807 r
F P
0 g
s
.5 .33942 m .5 .3394 L .5 .26858 L p .807 .677 .1 r
F P
0 g
s
.45697 .33942 m .5 .33942 L .5 .26861 L p .807 .677 .807 r
F P
0 g
s
.5 .26861 m .438 .26861 L .45697 .33942 L p .807 .677 .807 r
F P
0 g
s
.5 .38949 m .5 .38947 L .5 .3394 L p .807 .677 .1 r
F P
0 g
s
.5 .3394 m .5 .33942 L .5 .38949 L p .807 .677 .1 r
F P
0 g
s
.47039 .38949 m .5 .38949 L .5 .33942 L p .807 .677 .807 r
F P
0 g
s
.5 .33942 m .45697 .33942 L .47039 .38949 L p .807 .677 .807 r
F P
0 g
s
.47038 .38947 m .5 .38947 L .5 .38949 L p .211 .761 .909 r
F P
0 g
s
.5 .38949 m .47039 .38949 L .47038 .38947 L p .211 .761 .909 r
F P
0 g
s
.47038 .38947 m .47039 .38949 L .45697 .33942 L p .783 .508 .1 r
F P
0 g
s
.33423 .21288 m .33421 .21285 L .38429 .29958 L p .1 .1 .454 r
F P
0 g
s
.38429 .29958 m .3843 .29961 L .33423 .21288 L p .1 .1 .454 r
F P
0 g
s
.438 .26861 m .43799 .26858 L .41115 .16842 L p .783 .508 .1 r
F P
0 g
s
.41115 .16842 m .33421 .21285 L .33423 .21288 L p .723 1 .957 r
F P
0 g
s
.33423 .21288 m .41116 .16846 L .41115 .16842 L p .723 1 .957 r
F P
0 g
s
.33423 .21288 m .3843 .29961 L .438 .26861 L p .807 .677 .807 r
F P
0 g
s
.438 .26861 m .41116 .16846 L .33423 .21288 L p .807 .677 .807 r
F P
0 g
s
.3843 .29961 m .38429 .29958 L .4197 .36091 L p .712 .311 .1 r
F P
0 g
s
.4197 .36091 m .41971 .36093 L .3843 .29961 L p .712 .311 .1 r
F P
0 g
s
.45697 .3394 m .43799 .26858 L .438 .26861 L p .1 .1 .283 r
F P
0 g
s
.438 .26861 m .45697 .33942 L .45697 .3394 L p .1 .1 .283 r
F P
0 g
s
.3843 .29961 m .41971 .36093 L .45697 .33942 L p .807 .677 .807 r
F P
0 g
s
.45697 .33942 m .438 .26861 L .3843 .29961 L p .807 .677 .807 r
F P
0 g
s
.44474 .40428 m .4197 .36091 L .41971 .36093 L p .712 .311 .1 r
F P
0 g
s
.44474 .40428 m .44474 .40429 L .41971 .36093 L p .712 .311 .1 r
F P
0 g
s
.41971 .36093 m .44474 .40429 L .47039 .38949 L p .807 .677 .807 r
F P
0 g
s
.47039 .38949 m .45697 .33942 L .41971 .36093 L p .807 .677 .807 r
F P
0 g
s
.44474 .40429 m .44474 .40428 L .47038 .38947 L p .56 .969 .816 r
F P
0 g
s
.47038 .38947 m .47039 .38949 L .44474 .40429 L p .56 .969 .816 r
F P
0 g
s
.45697 .33942 m .47039 .38949 L .47038 .38947 L p .783 .508 .1 r
F P
0 g
s
.21288 .33423 m .21285 .33421 L .29958 .38429 L p .454 .1 .1 r
F P
0 g
s
.2573 .2573 m .25727 .25727 L .21285 .33421 L p .957 1 .723 r
F P
0 g
s
.21285 .33421 m .21288 .33423 L .2573 .2573 L p .957 1 .723 r
F P
0 g
s
.2573 .2573 m .21288 .33423 L .29961 .3843 L p .807 .677 .807 r
F P
0 g
s
.29961 .3843 m .33061 .33061 L .2573 .2573 L p .807 .677 .807 r
F P
0 g
s
.33061 .33061 m .29961 .3843 L .36093 .41971 L p .807 .677 .807 r
F P
0 g
s
.36093 .41971 m .38244 .38244 L .33061 .33061 L p .807 .677 .807 r
F P
0 g
s
.36093 .41971 m .36091 .4197 L .40428 .44474 L p .1 .311 .712 r
F P
0 g
s
.40428 .44474 m .40429 .44474 L .36093 .41971 L p .1 .311 .712 r
F P
0 g
s
.38244 .38244 m .36093 .41971 L .40429 .44474 L p .807 .677 .807 r
F P
0 g
s
.40429 .44474 m .4191 .4191 L .38244 .38244 L p .807 .677 .807 r
F P
0 g
s
.4191 .4191 m .40429 .44474 L .40428 .44474 L p .816 .969 .56 r
F P
0 g
s
.40428 .44474 m .41909 .41909 L .4191 .4191 L p .816 .969 .56 r
F P
0 g
s
.4191 .4191 m .41909 .41909 L .38243 .38243 L p .1 .1 .6 r
F P
0 g
s
.38243 .38243 m .38244 .38244 L .4191 .4191 L p .1 .1 .6 r
F P
0 g
s
.3843 .29961 m .38429 .29958 L .33421 .21285 L p .1 .1 .454 r
F P
0 g
s
.33421 .21285 m .33423 .21288 L .3843 .29961 L p .1 .1 .454 r
F P
0 g
s
.2573 .2573 m .33423 .21288 L .33421 .21285 L p .723 1 .957 r
F P
0 g
s
.33421 .21285 m .25727 .25727 L .2573 .2573 L p .723 1 .957 r
F P
0 g
s
.2573 .2573 m .33061 .33061 L .3843 .29961 L p .807 .677 .807 r
F P
0 g
s
.3843 .29961 m .33423 .21288 L .2573 .2573 L p .807 .677 .807 r
F P
0 g
s
.38429 .29958 m .4197 .36091 L .41971 .36093 L p .1 .1 .454 r
F P
0 g
s
.38429 .29958 m .3843 .29961 L .41971 .36093 L p .1 .1 .454 r
F P
0 g
s
.38244 .38244 m .33061 .33061 L .33059 .33059 L p .1 .1 .6 r
F P
0 g
s
.33061 .33061 m .38244 .38244 L .41971 .36093 L p .807 .677 .807 r
F P
0 g
s
.41971 .36093 m .3843 .29961 L .33061 .33061 L p .807 .677 .807 r
F P
0 g
s
.44474 .40429 m .44474 .40428 L .4197 .36091 L p .712 .311 .1 r
F P
0 g
s
.4197 .36091 m .41971 .36093 L .44474 .40429 L p .712 .311 .1 r
F P
0 g
s
.38244 .38244 m .4191 .4191 L .44474 .40429 L p .807 .677 .807 r
F P
0 g
s
.44474 .40429 m .41971 .36093 L .38244 .38244 L p .807 .677 .807 r
F P
0 g
s
.4191 .4191 m .41909 .41909 L .44474 .40428 L p .56 .969 .816 r
F P
0 g
s
.44474 .40428 m .44474 .40429 L .4191 .4191 L p .56 .969 .816 r
F P
0 g
s
.4191 .4191 m .38244 .38244 L .38243 .38243 L p .6 .1 .1 r
F P
0 g
s
.38243 .38243 m .41909 .41909 L .4191 .4191 L p .6 .1 .1 r
F P
0 g
s
.16842 .41115 m .16846 .41116 L .21288 .33423 L p .957 1 .723 r
F P
0 g
s
.26861 .438 m .29961 .3843 L .21288 .33423 L p .807 .677 .807 r
F P
0 g
s
.21288 .33423 m .16846 .41116 L .26861 .438 L p .807 .677 .807 r
F P
0 g
s
.36093 .41971 m .36091 .4197 L .29958 .38429 L p .454 .1 .1 r
F P
0 g
s
.33942 .45697 m .36093 .41971 L .29961 .3843 L p .807 .677 .807 r
F P
0 g
s
.29961 .3843 m .26861 .438 L .33942 .45697 L p .807 .677 .807 r
F P
0 g
s
.40429 .44474 m .40428 .44474 L .36091 .4197 L p .454 .1 .1 r
F P
0 g
s
.36091 .4197 m .36093 .41971 L .40429 .44474 L p .454 .1 .1 r
F P
0 g
s
.38949 .47039 m .40429 .44474 L .36093 .41971 L p .807 .677 .807 r
F P
0 g
s
.36093 .41971 m .33942 .45697 L .38949 .47039 L p .807 .677 .807 r
F P
0 g
s
.38947 .47038 m .40428 .44474 L .40429 .44474 L p .816 .969 .56 r
F P
0 g
s
.40429 .44474 m .38949 .47039 L .38947 .47038 L p .816 .969 .56 r
F P
0 g
s
.38947 .47038 m .38949 .47039 L .33942 .45697 L p .1 .508 .783 r
F P
0 g
s
.16846 .5 m .16842 .5 L .26858 .5 L p .1 .677 .807 r
F P
0 g
s
.26858 .5 m .26861 .5 L .16846 .5 L p .1 .677 .807 r
F P
0 g
s
.26861 .438 m .26858 .43799 L .16842 .41115 L p .1 .508 .783 r
F P
0 g
s
.16842 .41115 m .16842 .5 L .16846 .5 L p 1 .869 .404 r
F P
0 g
s
.16846 .5 m .16846 .41116 L .16842 .41115 L p 1 .869 .404 r
F P
0 g
s
.16846 .5 m .26861 .5 L .26861 .438 L p .807 .677 .807 r
F P
0 g
s
.26861 .438 m .16846 .41116 L .16846 .5 L p .807 .677 .807 r
F P
0 g
s
.26861 .5 m .26858 .5 L .3394 .5 L p .1 .677 .807 r
F P
0 g
s
.3394 .5 m .33942 .5 L .26861 .5 L p .1 .677 .807 r
F P
0 g
s
.3394 .45697 m .26858 .43799 L .26861 .438 L p .1 .508 .783 r
F P
0 g
s
.26861 .438 m .33942 .45697 L .3394 .45697 L p .1 .508 .783 r
F P
0 g
s
.26861 .5 m .33942 .5 L .33942 .45697 L p .807 .677 .807 r
F P
0 g
s
.33942 .45697 m .26861 .438 L .26861 .5 L p .807 .677 .807 r
F P
0 g
s
.33942 .5 m .3394 .5 L .38947 .5 L p .1 .677 .807 r
F P
0 g
s
.38947 .5 m .38949 .5 L .33942 .5 L p .1 .677 .807 r
F P
0 g
s
.33942 .5 m .38949 .5 L .38949 .47039 L p .807 .677 .807 r
F P
0 g
s
.38949 .47039 m .33942 .45697 L .33942 .5 L p .807 .677 .807 r
F P
0 g
s
.38949 .5 m .38947 .5 L .38947 .47038 L p .909 .761 .211 r
F P
0 g
s
.38947 .47038 m .38949 .47039 L .38949 .5 L p .909 .761 .211 r
F P
0 g
s
.33942 .45697 m .38949 .47039 L .38947 .47038 L p .1 .508 .783 r
F P
0 g
s
.21288 .66577 m .21285 .66579 L .29958 .61571 L p .1 .1 .1 r
F P
0 g
s
.16846 .58884 m .16842 .58885 L .21285 .66579 L p .957 .539 .1 r
F P
0 g
s
.21285 .66579 m .21288 .66577 L .16846 .58884 L p .957 .539 .1 r
F P
0 g
s
.16846 .58884 m .21288 .66577 L .29961 .6157 L p .807 .677 .807 r
F P
0 g
s
.29961 .6157 m .26861 .562 L .16846 .58884 L p .807 .677 .807 r
F P
0 g
s
.26861 .562 m .29961 .6157 L .36093 .58029 L p .807 .677 .807 r
F P
0 g
s
.36093 .58029 m .33942 .54303 L .26861 .562 L p .807 .677 .807 r
F P
0 g
s
.40428 .55526 m .36091 .5803 L .36093 .58029 L p .454 .889 .712 r
F P
0 g
s
.40428 .55526 m .40429 .55526 L .36093 .58029 L p .454 .889 .712 r
F P
0 g
s
.33942 .54303 m .36093 .58029 L .40429 .55526 L p .807 .677 .807 r
F P
0 g
s
.40429 .55526 m .38949 .52961 L .33942 .54303 L p .807 .677 .807 r
F P
0 g
s
.38949 .52961 m .40429 .55526 L .40428 .55526 L p .816 .399 .1 r
F P
0 g
s
.40428 .55526 m .38947 .52962 L .38949 .52961 L p .816 .399 .1 r
F P
0 g
s
.38949 .52961 m .38947 .52962 L .3394 .54303 L p .1 .1 .1 r
F P
0 g
s
.3394 .54303 m .33942 .54303 L .38949 .52961 L p .1 .1 .1 r
F P
0 g
s
.26861 .5 m .26858 .5 L .16842 .5 L p .1 .677 .807 r
F P
0 g
s
.16842 .5 m .16846 .5 L .26861 .5 L p .1 .677 .807 r
F P
0 g
s
.16846 .58884 m .16846 .5 L .16842 .5 L p 1 .869 .404 r
F P
0 g
s
.16842 .5 m .16842 .58885 L .16846 .58884 L p 1 .869 .404 r
F P
0 g
s
.16846 .58884 m .26861 .562 L .26861 .5 L p .807 .677 .807 r
F P
0 g
s
.26861 .5 m .16846 .5 L .16846 .58884 L p .807 .677 .807 r
F P
0 g
s
.33942 .5 m .3394 .5 L .26858 .5 L p .1 .677 .807 r
F P
0 g
s
.26858 .5 m .26861 .5 L .33942 .5 L p .1 .677 .807 r
F P
0 g
s
.33942 .54303 m .26861 .562 L .26858 .56201 L p .1 .1 .1 r
F P
0 g
s
.26861 .562 m .33942 .54303 L .33942 .5 L p .807 .677 .807 r
F P
0 g
s
.33942 .5 m .26861 .5 L .26861 .562 L p .807 .677 .807 r
F P
0 g
s
.3394 .5 m .38947 .5 L .38949 .5 L p .1 .1 .1 r
F P
0 g
s
.38949 .5 m .33942 .5 L .3394 .5 L p .1 .1 .1 r
F P
0 g
s
.33942 .54303 m .38949 .52961 L .38949 .5 L p .807 .677 .807 r
F P
0 g
s
.38949 .5 m .33942 .5 L .33942 .54303 L p .807 .677 .807 r
F P
0 g
s
.38949 .52961 m .38947 .52962 L .38947 .5 L p .909 .761 .211 r
F P
0 g
s
.38947 .5 m .38949 .5 L .38949 .52961 L p .909 .761 .211 r
F P
0 g
s
.38949 .52961 m .33942 .54303 L .3394 .54303 L p .283 .807 .783 r
F P
0 g
s
.3394 .54303 m .38947 .52962 L .38949 .52961 L p .283 .807 .783 r
F P
0 g
s
.25727 .74273 m .2573 .7427 L .21288 .66577 L p .957 .539 .1 r
F P
0 g
s
.33061 .66939 m .29961 .6157 L .21288 .66577 L p .807 .677 .807 r
F P
0 g
s
.21288 .66577 m .2573 .7427 L .33061 .66939 L p .807 .677 .807 r
F P
0 g
s
.36093 .58029 m .36091 .5803 L .29958 .61571 L p .1 .1 .1 r
F P
0 g
s
.38244 .61756 m .36093 .58029 L .29961 .6157 L p .807 .677 .807 r
F P
0 g
s
.29961 .6157 m .33061 .66939 L .38244 .61756 L p .807 .677 .807 r
F P
0 g
s
.40429 .55526 m .40428 .55526 L .36091 .5803 L p .1 .1 .1 r
F P
0 g
s
.36091 .5803 m .36093 .58029 L .40429 .55526 L p .1 .1 .1 r
F P
0 g
s
.4191 .5809 m .40429 .55526 L .36093 .58029 L p .807 .677 .807 r
F P
0 g
s
.36093 .58029 m .38244 .61756 L .4191 .5809 L p .807 .677 .807 r
F P
0 g
s
.41909 .58091 m .40428 .55526 L .40429 .55526 L p .816 .399 .1 r
F P
0 g
s
.40429 .55526 m .4191 .5809 L .41909 .58091 L p .816 .399 .1 r
F P
0 g
s
.41909 .58091 m .4191 .5809 L .38244 .61756 L p .6 .916 .6 r
F P
0 g
s
.33423 .78712 m .33421 .78715 L .38429 .70042 L p .1 .1 .1 r
F P
0 g
s
.38429 .70042 m .3843 .70039 L .33423 .78712 L p .1 .1 .1 r
F P
0 g
s
.33061 .66939 m .33059 .66941 L .25727 .74273 L p .6 .916 .6 r
F P
0 g
s
.25727 .74273 m .33421 .78715 L .33423 .78712 L p .723 .157 .1 r
F P
0 g
s
.33423 .78712 m .2573 .7427 L .25727 .74273 L p .723 .157 .1 r
F P
0 g
s
.33423 .78712 m .3843 .70039 L .33061 .66939 L p .807 .677 .807 r
F P
0 g
s
.33061 .66939 m .2573 .7427 L .33423 .78712 L p .807 .677 .807 r
F P
0 g
s
.3843 .70039 m .38429 .70042 L .4197 .63909 L p .712 .889 .454 r
F P
0 g
s
.4197 .63909 m .41971 .63907 L .3843 .70039 L p .712 .889 .454 r
F P
0 g
s
.38243 .61757 m .33059 .66941 L .33061 .66939 L p .6 .916 .6 r
F P
0 g
s
.33061 .66939 m .38244 .61756 L .38243 .61757 L p .6 .916 .6 r
F P
0 g
s
.3843 .70039 m .41971 .63907 L .38244 .61756 L p .807 .677 .807 r
F P
0 g
s
.38244 .61756 m .33061 .66939 L .3843 .70039 L p .807 .677 .807 r
F P
0 g
s
.41971 .63907 m .4197 .63909 L .44474 .59572 L p .712 .889 .454 r
F P
0 g
s
.44474 .59572 m .44474 .59571 L .41971 .63907 L p .712 .889 .454 r
F P
0 g
s
.41971 .63907 m .44474 .59571 L .4191 .5809 L p .807 .677 .807 r
F P
0 g
s
.4191 .5809 m .38244 .61756 L .41971 .63907 L p .807 .677 .807 r
F P
0 g
s
.44474 .59571 m .44474 .59572 L .41909 .58091 L p .56 .1 .1 r
F P
0 g
s
.41909 .58091 m .4191 .5809 L .44474 .59571 L p .56 .1 .1 r
F P
0 g
s
.38244 .61756 m .4191 .5809 L .41909 .58091 L p .6 .916 .6 r
F P
0 g
s
.5 .83154 m .5 .83158 L .5 .73142 L p .807 .677 .1 r
F P
0 g
s
.41116 .83154 m .41115 .83158 L .5 .83158 L p .404 .1 .1 r
F P
0 g
s
.5 .83158 m .5 .83154 L .41116 .83154 L p .404 .1 .1 r
F P
0 g
s
.41116 .83154 m .5 .83154 L .5 .73139 L p .807 .677 .807 r
F P
0 g
s
.5 .73139 m .438 .73139 L .41116 .83154 L p .807 .677 .807 r
F P
0 g
s
.438 .73139 m .5 .73139 L .5 .66058 L p .807 .677 .807 r
F P
0 g
s
.5 .66058 m .45697 .66058 L .438 .73139 L p .807 .677 .807 r
F P
0 g
s
.5 .61053 m .5 .6606 L .5 .66058 L p .807 .677 .1 r
F P
0 g
s
.5 .66058 m .5 .61051 L .5 .61053 L p .807 .677 .1 r
F P
0 g
s
.45697 .66058 m .5 .66058 L .5 .61051 L p .807 .677 .807 r
F P
0 g
s
.5 .61051 m .47039 .61051 L .45697 .66058 L p .807 .677 .807 r
F P
0 g
s
.47039 .61051 m .5 .61051 L .5 .61053 L p .211 .1 .1 r
F P
0 g
s
.5 .61053 m .47038 .61053 L .47039 .61051 L p .211 .1 .1 r
F P
0 g
s
.47039 .61051 m .47038 .61053 L .45697 .6606 L p .1 .1 .1 r
F P
0 g
s
.45697 .6606 m .45697 .66058 L .47039 .61051 L p .1 .1 .1 r
F P
0 g
s
.3843 .70039 m .38429 .70042 L .33421 .78715 L p .712 .889 .454 r
F P
0 g
s
.33421 .78715 m .33423 .78712 L .3843 .70039 L p .712 .889 .454 r
F P
0 g
s
.41116 .83154 m .33423 .78712 L .33421 .78715 L p .723 .157 .1 r
F P
0 g
s
.33421 .78715 m .41115 .83158 L .41116 .83154 L p .723 .157 .1 r
F P
0 g
s
.41116 .83154 m .438 .73139 L .3843 .70039 L p .807 .677 .807 r
F P
0 g
s
.3843 .70039 m .33423 .78712 L .41116 .83154 L p .807 .677 .807 r
F P
0 g
s
.41971 .63907 m .4197 .63909 L .38429 .70042 L p .1 .1 .1 r
F P
0 g
s
.38429 .70042 m .3843 .70039 L .41971 .63907 L p .1 .1 .1 r
F P
0 g
s
.45697 .66058 m .438 .73139 L .43799 .73142 L p .1 .1 .1 r
F P
0 g
s
.438 .73139 m .45697 .66058 L .41971 .63907 L p .807 .677 .807 r
F P
0 g
s
.41971 .63907 m .3843 .70039 L .438 .73139 L p .807 .677 .807 r
F P
0 g
s
.44474 .59571 m .44474 .59572 L .4197 .63909 L p .712 .889 .454 r
F P
0 g
s
.4197 .63909 m .41971 .63907 L .44474 .59571 L p .712 .889 .454 r
F P
0 g
s
.45697 .66058 m .47039 .61051 L .44474 .59571 L p .807 .677 .807 r
F P
0 g
s
.44474 .59571 m .41971 .63907 L .45697 .66058 L p .807 .677 .807 r
F P
0 g
s
.47039 .61051 m .47038 .61053 L .44474 .59572 L p .56 .1 .1 r
F P
0 g
s
.44474 .59572 m .44474 .59571 L .47039 .61051 L p .56 .1 .1 r
F P
0 g
s
.47039 .61051 m .45697 .66058 L .45697 .6606 L p .783 .807 .283 r
F P
0 g
s
.45697 .6606 m .47038 .61053 L .47039 .61051 L p .783 .807 .283 r
F P
0 g
s
.58885 .83158 m .58884 .83154 L .5 .83154 L p .404 .1 .1 r
F P
0 g
s
.562 .73139 m .5 .73139 L .5 .83154 L p .807 .677 .807 r
F P
0 g
s
.5 .83154 m .58884 .83154 L .562 .73139 L p .807 .677 .807 r
F P
0 g
s
.5 .66058 m .5 .6606 L .5 .73142 L p .807 .677 .1 r
F P
0 g
s
.54303 .66058 m .5 .66058 L .5 .73139 L p .807 .677 .807 r
F P
0 g
s
.5 .73139 m .562 .73139 L .54303 .66058 L p .807 .677 .807 r
F P
0 g
s
.5 .6606 m .5 .61053 L .5 .61051 L p .1 .1 .1 r
F P
0 g
s
.5 .61051 m .5 .66058 L .5 .6606 L p .1 .1 .1 r
F P
0 g
s
.52961 .61051 m .5 .61051 L .5 .66058 L p .807 .677 .807 r
F P
0 g
s
.5 .66058 m .54303 .66058 L .52961 .61051 L p .807 .677 .807 r
F P
0 g
s
.52962 .61053 m .5 .61053 L .5 .61051 L p .211 .1 .1 r
F P
0 g
s
.5 .61051 m .52961 .61051 L .52962 .61053 L p .211 .1 .1 r
F P
0 g
s
.52962 .61053 m .52961 .61051 L .54303 .66058 L p .783 .508 .1 r
F P
0 g
s
.66577 .78712 m .66579 .78715 L .61571 .70042 L p .1 .1 .454 r
F P
0 g
s
.61571 .70042 m .6157 .70039 L .66577 .78712 L p .1 .1 .454 r
F P
0 g
s
.562 .73139 m .56201 .73142 L .58885 .83158 L p .783 .508 .1 r
F P
0 g
s
.58885 .83158 m .66579 .78715 L .66577 .78712 L p .1 .1 .1 r
F P
0 g
s
.66577 .78712 m .58884 .83154 L .58885 .83158 L p .1 .1 .1 r
F P
0 g
s
.66577 .78712 m .6157 .70039 L .562 .73139 L p .807 .677 .807 r
F P
0 g
s
.562 .73139 m .58884 .83154 L .66577 .78712 L p .807 .677 .807 r
F P
0 g
s
.6157 .70039 m .61571 .70042 L .5803 .63909 L p .712 .311 .1 r
F P
0 g
s
.5803 .63909 m .58029 .63907 L .6157 .70039 L p .712 .311 .1 r
F P
0 g
s
.54303 .6606 m .56201 .73142 L .562 .73139 L p .1 .1 .283 r
F P
0 g
s
.562 .73139 m .54303 .66058 L .54303 .6606 L p .1 .1 .283 r
F P
0 g
s
.6157 .70039 m .58029 .63907 L .54303 .66058 L p .807 .677 .807 r
F P
0 g
s
.54303 .66058 m .562 .73139 L .6157 .70039 L p .807 .677 .807 r
F P
0 g
s
.58029 .63907 m .5803 .63909 L .55526 .59572 L p .712 .311 .1 r
F P
0 g
s
.55526 .59572 m .55526 .59571 L .58029 .63907 L p .712 .311 .1 r
F P
0 g
s
.58029 .63907 m .55526 .59571 L .52961 .61051 L p .807 .677 .807 r
F P
0 g
s
.52961 .61051 m .54303 .66058 L .58029 .63907 L p .807 .677 .807 r
F P
0 g
s
.55526 .59571 m .55526 .59572 L .52962 .61053 L p .1 .1 .1 r
F P
0 g
s
.52962 .61053 m .52961 .61051 L .55526 .59571 L p .1 .1 .1 r
F P
0 g
s
.54303 .66058 m .52961 .61051 L .52962 .61053 L p .783 .508 .1 r
F P
0 g
s
.78712 .66577 m .78715 .66579 L .70042 .61571 L p .454 .1 .1 r
F P
0 g
s
.7427 .7427 m .74273 .74273 L .78715 .66579 L p .1 .1 .1 r
F P
0 g
s
.78715 .66579 m .78712 .66577 L .7427 .7427 L p .1 .1 .1 r
F P
0 g
s
.7427 .7427 m .78712 .66577 L .70039 .6157 L p .807 .677 .807 r
F P
0 g
s
.70039 .6157 m .66939 .66939 L .7427 .7427 L p .807 .677 .807 r
F P
0 g
s
.66939 .66939 m .70039 .6157 L .63907 .58029 L p .807 .677 .807 r
F P
0 g
s
.63907 .58029 m .61756 .61756 L .66939 .66939 L p .807 .677 .807 r
F P
0 g
s
.63907 .58029 m .63909 .5803 L .59572 .55526 L p .1 .311 .712 r
F P
0 g
s
.59572 .55526 m .59571 .55526 L .63907 .58029 L p .1 .311 .712 r
F P
0 g
s
.61756 .61756 m .63907 .58029 L .59571 .55526 L p .807 .677 .807 r
F P
0 g
s
.59571 .55526 m .5809 .5809 L .61756 .61756 L p .807 .677 .807 r
F P
0 g
s
.5809 .5809 m .59571 .55526 L .59572 .55526 L p .1 .1 .1 r
F P
0 g
s
.59572 .55526 m .58091 .58091 L .5809 .5809 L p .1 .1 .1 r
F P
0 g
s
.61757 .61757 m .58091 .58091 L .5809 .5809 L p .1 .1 .6 r
F P
0 g
s
.61757 .61757 m .61756 .61756 L .5809 .5809 L p .1 .1 .6 r
F P
0 g
s
.6157 .70039 m .61571 .70042 L .66579 .78715 L p .712 .311 .1 r
F P
0 g
s
.66579 .78715 m .66577 .78712 L .6157 .70039 L p .712 .311 .1 r
F P
0 g
s
.7427 .7427 m .66577 .78712 L .66579 .78715 L p .1 .1 .1 r
F P
0 g
s
.66579 .78715 m .74273 .74273 L .7427 .7427 L p .1 .1 .1 r
F P
0 g
s
.7427 .7427 m .66939 .66939 L .6157 .70039 L p .807 .677 .807 r
F P
0 g
s
.6157 .70039 m .66577 .78712 L .7427 .7427 L p .807 .677 .807 r
F P
0 g
s
.58029 .63907 m .5803 .63909 L .61571 .70042 L p .712 .311 .1 r
F P
0 g
s
.61571 .70042 m .6157 .70039 L .58029 .63907 L p .712 .311 .1 r
F P
0 g
s
.61756 .61756 m .66939 .66939 L .66941 .66941 L p .1 .1 .6 r
F P
0 g
s
.66939 .66939 m .61756 .61756 L .58029 .63907 L p .807 .677 .807 r
F P
0 g
s
.58029 .63907 m .6157 .70039 L .66939 .66939 L p .807 .677 .807 r
F P
0 g
s
.55526 .59571 m .55526 .59572 L .5803 .63909 L p .712 .311 .1 r
F P
0 g
s
.5803 .63909 m .58029 .63907 L .55526 .59571 L p .712 .311 .1 r
F P
0 g
s
.61756 .61756 m .5809 .5809 L .55526 .59571 L p .807 .677 .807 r
F P
0 g
s
.55526 .59571 m .58029 .63907 L .61756 .61756 L p .807 .677 .807 r
F P
0 g
s
.5809 .5809 m .58091 .58091 L .55526 .59572 L p .1 .1 .1 r
F P
0 g
s
.55526 .59572 m .55526 .59571 L .5809 .5809 L p .1 .1 .1 r
F P
0 g
s
.5809 .5809 m .61756 .61756 L .61757 .61757 L p .6 .1 .1 r
F P
0 g
s
.5809 .5809 m .58091 .58091 L .61757 .61757 L p .6 .1 .1 r
F P
0 g
s
.83158 .58885 m .83154 .58884 L .78712 .66577 L p .1 .1 .1 r
F P
0 g
s
.73139 .562 m .70039 .6157 L .78712 .66577 L p .807 .677 .807 r
F P
0 g
s
.78712 .66577 m .83154 .58884 L .73139 .562 L p .807 .677 .807 r
F P
0 g
s
.63907 .58029 m .63909 .5803 L .70042 .61571 L p .1 .311 .712 r
F P
0 g
s
.66058 .54303 m .63907 .58029 L .70039 .6157 L p .807 .677 .807 r
F P
0 g
s
.70039 .6157 m .73139 .562 L .66058 .54303 L p .807 .677 .807 r
F P
0 g
s
.59571 .55526 m .59572 .55526 L .63909 .5803 L p .1 .311 .712 r
F P
0 g
s
.63909 .5803 m .63907 .58029 L .59571 .55526 L p .1 .311 .712 r
F P
0 g
s
.61051 .52961 m .59571 .55526 L .63907 .58029 L p .807 .677 .807 r
F P
0 g
s
.63907 .58029 m .66058 .54303 L .61051 .52961 L p .807 .677 .807 r
F P
0 g
s
.61053 .52962 m .59572 .55526 L .59571 .55526 L p .1 .1 .1 r
F P
0 g
s
.59571 .55526 m .61051 .52961 L .61053 .52962 L p .1 .1 .1 r
F P
0 g
s
.61053 .52962 m .61051 .52961 L .66058 .54303 L p .1 .508 .783 r
F P
0 g
s
.73142 .5 m .83158 .5 L .83154 .5 L p .1 .1 .1 r
F P
0 g
s
.83154 .5 m .73139 .5 L .73142 .5 L p .1 .1 .1 r
F P
0 g
s
.73139 .562 m .73142 .56201 L .83158 .58885 L p .1 .508 .783 r
F P
0 g
s
.83158 .58885 m .83158 .5 L .83154 .5 L p .1 .1 .404 r
F P
0 g
s
.83154 .5 m .83154 .58884 L .83158 .58885 L p .1 .1 .404 r
F P
0 g
s
.83154 .5 m .73139 .5 L .73139 .562 L p .807 .677 .807 r
F P
0 g
s
.73139 .562 m .83154 .58884 L .83154 .5 L p .807 .677 .807 r
F P
0 g
s
.6606 .5 m .73142 .5 L .73139 .5 L p .1 .1 .1 r
F P
0 g
s
.73139 .5 m .66058 .5 L .6606 .5 L p .1 .1 .1 r
F P
0 g
s
.6606 .54303 m .73142 .56201 L .73139 .562 L p .283 .1 .1 r
F P
0 g
s
.73139 .562 m .66058 .54303 L .6606 .54303 L p .283 .1 .1 r
F P
0 g
s
.73139 .5 m .66058 .5 L .66058 .54303 L p .807 .677 .807 r
F P
0 g
s
.66058 .54303 m .73139 .562 L .73139 .5 L p .807 .677 .807 r
F P
0 g
s
.61053 .5 m .6606 .5 L .66058 .5 L p .1 .1 .1 r
F P
0 g
s
.66058 .5 m .61051 .5 L .61053 .5 L p .1 .1 .1 r
F P
0 g
s
.66058 .5 m .61051 .5 L .61051 .52961 L p .807 .677 .807 r
F P
0 g
s
.61051 .52961 m .66058 .54303 L .66058 .5 L p .807 .677 .807 r
F P
0 g
s
.61051 .5 m .61053 .5 L .61053 .52962 L p .1 .1 .211 r
F P
0 g
s
.61053 .52962 m .61051 .52961 L .61051 .5 L p .1 .1 .211 r
F P
0 g
s
.66058 .54303 m .61051 .52961 L .61053 .52962 L p .1 .508 .783 r
F P
0 g
s
.83154 .41116 m .73139 .438 L .73142 .43799 L p .283 .807 .783 r
F P
0 g
s
.73142 .43799 m .83158 .41115 L .83154 .41116 L p .283 .807 .783 r
F P
0 g
s
.73139 .438 m .66058 .45697 L .6606 .45697 L p .1 .1 .1 r
F P
0 g
s
.6606 .45697 m .73142 .43799 L .73139 .438 L p .1 .1 .1 r
F P
0 g
s
.73142 .43799 m .6606 .45697 L .66058 .45697 L p .1 .1 .1 r
F P
0 g
s
.78712 .33423 m .78715 .33421 L .74273 .25727 L p .1 .157 .723 r
F P
0 g
s
.74273 .25727 m .66941 .33059 L .66939 .33061 L p .6 .916 .6 r
F P
0 g
s
.66939 .33061 m .7427 .2573 L .74273 .25727 L p .6 .916 .6 r
F P
0 g
s
.66941 .33059 m .61757 .38243 L .61756 .38244 L p .1 .1 .1 r
F P
0 g
s
.66941 .33059 m .66939 .33061 L .61756 .38244 L p .1 .1 .1 r
F P
0 g
s
.61756 .38244 m .61757 .38243 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.58091 .41909 m .61757 .38243 L .61756 .38244 L p .6 .916 .6 r
F P
0 g
s
.58884 .16846 m .562 .26861 L .56201 .26858 L p .783 .807 .283 r
F P
0 g
s
.56201 .26858 m .58885 .16842 L .58884 .16846 L p .783 .807 .283 r
F P
0 g
s
.562 .26861 m .54303 .33942 L .54303 .3394 L p .1 .1 .1 r
F P
0 g
s
.54303 .3394 m .56201 .26858 L .562 .26861 L p .1 .1 .1 r
F P
0 g
s
.54303 .33942 m .54303 .3394 L .56201 .26858 L p .1 .1 .1 r
F P
0 g
s
.5 .16846 m .5 .16842 L .41115 .16842 L p .404 .869 1 r
F P
0 g
s
.41115 .16842 m .43799 .26858 L .438 .26861 L p .783 .508 .1 r
F P
0 g
s
.438 .26861 m .41116 .16846 L .41115 .16842 L p .783 .508 .1 r
F P
0 g
s
.43799 .26858 m .45697 .3394 L .45697 .33942 L p .1 .1 .283 r
F P
0 g
s
.45697 .33942 m .438 .26861 L .43799 .26858 L p .1 .1 .283 r
F P
0 g
s
.45697 .33942 m .45697 .3394 L .47038 .38947 L p .783 .508 .1 r
F P
0 g
s
.47038 .38947 m .45697 .3394 L .45697 .33942 L p .783 .508 .1 r
F P
0 g
s
.2573 .2573 m .33061 .33061 L .33059 .33059 L p .6 .1 .1 r
F P
0 g
s
.33059 .33059 m .25727 .25727 L .2573 .2573 L p .6 .1 .1 r
F P
0 g
s
.33061 .33061 m .38244 .38244 L .38243 .38243 L p .1 .1 .6 r
F P
0 g
s
.38243 .38243 m .33059 .33059 L .33061 .33061 L p .1 .1 .6 r
F P
0 g
s
.33059 .33059 m .38243 .38243 L .38244 .38244 L p .1 .1 .6 r
F P
0 g
s
.21288 .33423 m .21285 .33421 L .16842 .41115 L p .957 1 .723 r
F P
0 g
s
.16842 .41115 m .26858 .43799 L .26861 .438 L p .1 .508 .783 r
F P
0 g
s
.26861 .438 m .16846 .41116 L .16842 .41115 L p .1 .508 .783 r
F P
0 g
s
.26858 .43799 m .3394 .45697 L .33942 .45697 L p .283 .1 .1 r
F P
0 g
s
.33942 .45697 m .26861 .438 L .26858 .43799 L p .283 .1 .1 r
F P
0 g
s
.33942 .45697 m .3394 .45697 L .38947 .47038 L p .1 .508 .783 r
F P
0 g
s
.38947 .47038 m .3394 .45697 L .33942 .45697 L p .1 .508 .783 r
F P
0 g
s
.16846 .58884 m .26861 .562 L .26858 .56201 L p .283 .807 .783 r
F P
0 g
s
.26858 .56201 m .16842 .58885 L .16846 .58884 L p .283 .807 .783 r
F P
0 g
s
.26861 .562 m .33942 .54303 L .3394 .54303 L p .283 .807 .783 r
F P
0 g
s
.3394 .54303 m .26858 .56201 L .26861 .562 L p .283 .807 .783 r
F P
0 g
s
.26858 .56201 m .3394 .54303 L .33942 .54303 L p .1 .1 .1 r
F P
0 g
s
.21288 .66577 m .21285 .66579 L .25727 .74273 L p .957 .539 .1 r
F P
0 g
s
.33061 .66939 m .33059 .66941 L .25727 .74273 L p .6 .916 .6 r
F P
0 g
s
.33061 .66939 m .2573 .7427 L .25727 .74273 L p .6 .916 .6 r
F P
0 g
s
.33059 .66941 m .38243 .61757 L .38244 .61756 L p .6 .916 .6 r
F P
0 g
s
.33059 .66941 m .33061 .66939 L .38244 .61756 L p .6 .916 .6 r
F P
0 g
s
.38244 .61756 m .38243 .61757 L .41909 .58091 L p .6 .916 .6 r
F P
0 g
s
.41909 .58091 m .38243 .61757 L .38244 .61756 L p .6 .916 .6 r
F P
0 g
s
.41116 .83154 m .438 .73139 L .43799 .73142 L p .783 .807 .283 r
F P
0 g
s
.43799 .73142 m .41115 .83158 L .41116 .83154 L p .783 .807 .283 r
F P
0 g
s
.438 .73139 m .45697 .66058 L .45697 .6606 L p .1 .1 .1 r
F P
0 g
s
.45697 .6606 m .43799 .73142 L .438 .73139 L p .1 .1 .1 r
F P
0 g
s
.43799 .73142 m .45697 .6606 L .45697 .66058 L p .1 .1 .1 r
F P
0 g
s
.5 .83154 m .5 .83158 L .58885 .83158 L p .404 .1 .1 r
F P
0 g
s
.58885 .83158 m .56201 .73142 L .562 .73139 L p .783 .508 .1 r
F P
0 g
s
.562 .73139 m .58884 .83154 L .58885 .83158 L p .783 .508 .1 r
F P
0 g
s
.56201 .73142 m .54303 .6606 L .54303 .66058 L p .1 .1 .283 r
F P
0 g
s
.54303 .66058 m .562 .73139 L .56201 .73142 L p .1 .1 .283 r
F P
0 g
s
.54303 .66058 m .54303 .6606 L .52962 .61053 L p .783 .508 .1 r
F P
0 g
s
.52962 .61053 m .54303 .6606 L .54303 .66058 L p .783 .508 .1 r
F P
0 g
s
.7427 .7427 m .66939 .66939 L .66941 .66941 L p .6 .1 .1 r
F P
0 g
s
.66941 .66941 m .74273 .74273 L .7427 .7427 L p .6 .1 .1 r
F P
0 g
s
.66939 .66939 m .61756 .61756 L .61757 .61757 L p .6 .1 .1 r
F P
0 g
s
.61757 .61757 m .66941 .66941 L .66939 .66939 L p .6 .1 .1 r
F P
0 g
s
.66941 .66941 m .61757 .61757 L .61756 .61756 L p .1 .1 .6 r
F P
0 g
s
.78712 .66577 m .78715 .66579 L .83158 .58885 L p .1 .1 .1 r
F P
0 g
s
.83158 .58885 m .73142 .56201 L .73139 .562 L p .1 .508 .783 r
F P
0 g
s
.73139 .562 m .83154 .58884 L .83158 .58885 L p .1 .508 .783 r
F P
0 g
s
.73142 .56201 m .6606 .54303 L .66058 .54303 L p .1 .508 .783 r
F P
0 g
s
.66058 .54303 m .73139 .562 L .73142 .56201 L p .1 .508 .783 r
F P
0 g
s
.66058 .54303 m .6606 .54303 L .61053 .52962 L p .1 .508 .783 r
F P
0 g
s
.61053 .52962 m .6606 .54303 L .66058 .54303 L p .1 .508 .783 r
F P
0 g
s
.70044 .38428 m .70042 .38429 L .78715 .33421 L p .1 .1 .1 r
F P
0 g
s
.83162 .5 m .83158 .5 L .73142 .5 L p .1 .677 .807 r
F P
0 g
s
.73142 .5 m .73145 .5 L .83162 .5 L p .1 .677 .807 r
F P
0 g
s
.83158 .41115 m .83158 .5 L .83162 .5 L p .1 .1 .404 r
F P
0 g
s
.83162 .5 m .83162 .41114 L .83158 .41115 L p .1 .1 .404 r
F P
0 g
s
.73145 .5 m .73142 .5 L .6606 .5 L p .1 .1 .1 r
F P
0 g
s
.61054 .47038 m .61053 .47038 L .6606 .45697 L p .283 .807 .783 r
F P
0 g
s
.78719 .33419 m .78715 .33421 L .70042 .38429 L p .454 .889 .712 r
F P
0 g
s
.70042 .38429 m .70044 .38428 L .78719 .33419 L p .454 .889 .712 r
F P
0 g
s
.61572 .29956 m .61571 .29958 L .66579 .21285 L p .1 .1 .1 r
F P
0 g
s
.66579 .21285 m .66581 .21281 L .61572 .29956 L p .1 .1 .1 r
F P
0 g
s
.74276 .25724 m .66581 .21281 L .66579 .21285 L p .1 .539 .957 r
F P
0 g
s
.66579 .21285 m .74273 .25727 L .74276 .25724 L p .1 .539 .957 r
F P
0 g
s
.58031 .3609 m .5803 .36091 L .61571 .29958 L p .1 .1 .1 r
F P
0 g
s
.61571 .29958 m .61572 .29956 L .58031 .3609 L p .1 .1 .1 r
F P
0 g
s
.61758 .38242 m .61757 .38243 L .58091 .41909 L p .6 .916 .6 r
F P
0 g
s
.58091 .41909 m .58092 .41908 L .61758 .38242 L p .6 .916 .6 r
F P
0 g
s
.5 .26855 m .5 .26858 L .5 .16842 L p .1 .1 .1 r
F P
0 g
s
.66581 .21281 m .66579 .21285 L .61571 .29958 L p .1 .1 .1 r
F P
0 g
s
.61571 .29958 m .61572 .29956 L .66581 .21281 L p .1 .1 .1 r
F P
0 g
s
.58885 .16842 m .66579 .21285 L .66581 .21281 L p .1 .539 .957 r
F P
0 g
s
.66581 .21281 m .58886 .16838 L .58885 .16842 L p .1 .539 .957 r
F P
0 g
s
.61572 .29956 m .61571 .29958 L .5803 .36091 L p .1 .1 .1 r
F P
0 g
s
.52962 .38946 m .52962 .38947 L .54303 .3394 L p .783 .807 .283 r
F P
0 g
s
.5 .16838 m .5 .16842 L .5 .26858 L p .807 .677 .1 r
F P
0 g
s
.5 .26858 m .5 .26855 L .5 .16838 L p .807 .677 .1 r
F P
0 g
s
.38428 .29956 m .38429 .29958 L .33421 .21285 L p .712 .311 .1 r
F P
0 g
s
.33421 .21285 m .33419 .21281 L .38428 .29956 L p .712 .311 .1 r
F P
0 g
s
.41114 .16838 m .33419 .21281 L .33421 .21285 L p .723 1 .957 r
F P
0 g
s
.33421 .21285 m .41115 .16842 L .41114 .16838 L p .723 1 .957 r
F P
0 g
s
.38429 .29958 m .4197 .36091 L .41969 .3609 L p .712 .311 .1 r
F P
0 g
s
.38429 .29958 m .38428 .29956 L .41969 .3609 L p .712 .311 .1 r
F P
0 g
s
.45696 .33938 m .45697 .3394 L .47038 .38947 L p .1 .1 .283 r
F P
0 g
s
.47038 .38947 m .47038 .38946 L .45696 .33938 L p .1 .1 .283 r
F P
0 g
s
.29956 .38428 m .29958 .38429 L .21285 .33421 L p .454 .1 .1 r
F P
0 g
s
.33419 .21281 m .33421 .21285 L .38429 .29958 L p .712 .311 .1 r
F P
0 g
s
.38429 .29958 m .38428 .29956 L .33419 .21281 L p .712 .311 .1 r
F P
0 g
s
.25727 .25727 m .33421 .21285 L .33419 .21281 L p .723 1 .957 r
F P
0 g
s
.33419 .21281 m .25724 .25724 L .25727 .25727 L p .723 1 .957 r
F P
0 g
s
.38428 .29956 m .38429 .29958 L .4197 .36091 L p .712 .311 .1 r
F P
0 g
s
.41908 .41908 m .41909 .41909 L .38243 .38243 L p .6 .1 .1 r
F P
0 g
s
.21281 .33419 m .21285 .33421 L .29958 .38429 L p .1 .311 .712 r
F P
0 g
s
.29958 .38429 m .29956 .38428 L .21281 .33419 L p .1 .311 .712 r
F P
0 g
s
.26855 .5 m .26858 .5 L .16842 .5 L p .1 .677 .807 r
F P
0 g
s
.16842 .5 m .16838 .5 L .26855 .5 L p .1 .677 .807 r
F P
0 g
s
.16838 .41114 m .16838 .5 L .16842 .5 L p 1 .869 .404 r
F P
0 g
s
.16842 .5 m .16842 .41115 L .16838 .41114 L p 1 .869 .404 r
F P
0 g
s
.26858 .5 m .3394 .5 L .33938 .5 L p .1 .677 .807 r
F P
0 g
s
.33938 .5 m .26855 .5 L .26858 .5 L p .1 .677 .807 r
F P
0 g
s
.33938 .45696 m .3394 .45697 L .38947 .47038 L p .1 .508 .783 r
F P
0 g
s
.38947 .47038 m .38946 .47038 L .33938 .45696 L p .1 .508 .783 r
F P
0 g
s
.29956 .61572 m .29958 .61571 L .21285 .66579 L p .1 .1 .1 r
F P
0 g
s
.26858 .5 m .16842 .5 L .16838 .5 L p .1 .1 .1 r
F P
0 g
s
.16838 .5 m .26855 .5 L .26858 .5 L p .1 .1 .1 r
F P
0 g
s
.16842 .58885 m .16842 .5 L .16838 .5 L p 1 .869 .404 r
F P
0 g
s
.16838 .5 m .16838 .58886 L .16842 .58885 L p 1 .869 .404 r
F P
0 g
s
.26855 .5 m .26858 .5 L .3394 .5 L p .1 .677 .807 r
F P
0 g
s
.38946 .52962 m .38947 .52962 L .3394 .54303 L p .283 .807 .783 r
F P
0 g
s
.21281 .66581 m .21285 .66579 L .29958 .61571 L p .454 .889 .712 r
F P
0 g
s
.29958 .61571 m .29956 .61572 L .21281 .66581 L p .454 .889 .712 r
F P
0 g
s
.38428 .70044 m .38429 .70042 L .33421 .78715 L p .712 .889 .454 r
F P
0 g
s
.33421 .78715 m .33419 .78719 L .38428 .70044 L p .712 .889 .454 r
F P
0 g
s
.25724 .74276 m .33419 .78719 L .33421 .78715 L p .723 .157 .1 r
F P
0 g
s
.33421 .78715 m .25727 .74273 L .25724 .74276 L p .723 .157 .1 r
F P
0 g
s
.41969 .6391 m .4197 .63909 L .38429 .70042 L p .712 .889 .454 r
F P
0 g
s
.38429 .70042 m .38428 .70044 L .41969 .6391 L p .712 .889 .454 r
F P
0 g
s
.41909 .58091 m .38243 .61757 L .38242 .61758 L p .6 .916 .6 r
F P
0 g
s
.41909 .58091 m .41908 .58092 L .38242 .61758 L p .6 .916 .6 r
F P
0 g
s
.5 .73145 m .5 .73142 L .5 .83158 L p .807 .677 .1 r
F P
0 g
s
.33419 .78719 m .33421 .78715 L .38429 .70042 L p .712 .889 .454 r
F P
0 g
s
.38429 .70042 m .38428 .70044 L .33419 .78719 L p .712 .889 .454 r
F P
0 g
s
.41115 .83158 m .33421 .78715 L .33419 .78719 L p .723 .157 .1 r
F P
0 g
s
.33419 .78719 m .41114 .83162 L .41115 .83158 L p .723 .157 .1 r
F P
0 g
s
.38428 .70044 m .38429 .70042 L .4197 .63909 L p .712 .889 .454 r
F P
0 g
s
.47038 .61054 m .47038 .61053 L .45697 .6606 L p .783 .807 .283 r
F P
0 g
s
.5 .73142 m .5 .83158 L .5 .83162 L p .1 .1 .1 r
F P
0 g
s
.5 .83162 m .5 .73145 L .5 .73142 L p .1 .1 .1 r
F P
0 g
s
.61572 .70044 m .61571 .70042 L .66579 .78715 L p .1 .1 .454 r
F P
0 g
s
.66579 .78715 m .66581 .78719 L .61572 .70044 L p .1 .1 .454 r
F P
0 g
s
.58886 .83162 m .66581 .78719 L .66579 .78715 L p .1 .1 .1 r
F P
0 g
s
.66579 .78715 m .58885 .83158 L .58886 .83162 L p .1 .1 .1 r
F P
0 g
s
.58031 .6391 m .5803 .63909 L .61571 .70042 L p .712 .311 .1 r
F P
0 g
s
.61571 .70042 m .61572 .70044 L .58031 .6391 L p .712 .311 .1 r
F P
0 g
s
.54304 .66062 m .54303 .6606 L .52962 .61053 L p .1 .1 .283 r
F P
0 g
s
.52962 .61053 m .52962 .61054 L .54304 .66062 L p .1 .1 .283 r
F P
0 g
s
.70044 .61572 m .70042 .61571 L .78715 .66579 L p .454 .1 .1 r
F P
0 g
s
.66581 .78719 m .66579 .78715 L .61571 .70042 L p .712 .311 .1 r
F P
0 g
s
.61571 .70042 m .61572 .70044 L .66581 .78719 L p .712 .311 .1 r
F P
0 g
s
.74273 .74273 m .66579 .78715 L .66581 .78719 L p .1 .1 .1 r
F P
0 g
s
.66581 .78719 m .74276 .74276 L .74273 .74273 L p .1 .1 .1 r
F P
0 g
s
.61572 .70044 m .61571 .70042 L .5803 .63909 L p .1 .1 .454 r
F P
0 g
s
.61757 .61757 m .58091 .58091 L .58092 .58092 L p .6 .1 .1 r
F P
0 g
s
.78719 .66581 m .78715 .66579 L .70042 .61571 L p .454 .1 .1 r
F P
0 g
s
.70042 .61571 m .70044 .61572 L .78719 .66581 L p .454 .1 .1 r
F P
0 g
s
.83158 .5 m .73142 .5 L .73145 .5 L p .1 .1 .1 r
F P
0 g
s
.73145 .5 m .83162 .5 L .83158 .5 L p .1 .1 .1 r
F P
0 g
s
.83162 .58886 m .83162 .5 L .83158 .5 L p .1 .1 .404 r
F P
0 g
s
.83158 .5 m .83158 .58885 L .83162 .58886 L p .1 .1 .404 r
F P
0 g
s
.73142 .5 m .6606 .5 L .66062 .5 L p .1 .1 .1 r
F P
0 g
s
.66062 .5 m .73145 .5 L .73142 .5 L p .1 .1 .1 r
F P
0 g
s
.66062 .54304 m .6606 .54303 L .61053 .52962 L p .283 .1 .1 r
F P
0 g
s
.61053 .52962 m .61054 .52962 L .66062 .54304 L p .283 .1 .1 r
F P
0 g
s
.78715 .33421 m .78719 .33419 L .70044 .38428 L p .1 .1 .1 r
F P
0 g
s
.73145 .43798 m .73142 .43799 L .6606 .45697 L p .283 .807 .783 r
F P
0 g
s
.6606 .45697 m .66062 .45696 L .73145 .43798 L p .283 .807 .783 r
F P
0 g
s
.59573 .44473 m .59572 .44474 L .63909 .4197 L p .454 .889 .712 r
F P
0 g
s
.61053 .47038 m .59572 .44474 L .59573 .44473 L p .1 .1 .56 r
F P
0 g
s
.83158 .41115 m .83162 .41114 L .73145 .43798 L p .283 .807 .783 r
F P
0 g
s
.73145 .43798 m .73142 .43799 L .83158 .41115 L p .283 .807 .783 r
F P
0 g
s
.6606 .5 m .66062 .5 L .73145 .5 L p .1 .1 .1 r
F P
0 g
s
.66062 .45696 m .6606 .45697 L .73142 .43799 L p .283 .807 .783 r
F P
0 g
s
.73142 .43799 m .73145 .43798 L .66062 .45696 L p .283 .807 .783 r
F P
0 g
s
.61053 .5 m .6606 .5 L .66062 .5 L p .1 .677 .807 r
F P
0 g
s
.66062 .5 m .61054 .5 L .61053 .5 L p .1 .677 .807 r
F P
0 g
s
.61053 .47038 m .61054 .47038 L .61054 .5 L p .1 .1 .211 r
F P
0 g
s
.61054 .5 m .61053 .5 L .61053 .47038 L p .1 .1 .211 r
F P
0 g
s
.61758 .38242 m .61757 .38243 L .66941 .33059 L p .6 .916 .6 r
F P
0 g
s
.6391 .41969 m .63909 .4197 L .59572 .44474 L p .454 .889 .712 r
F P
0 g
s
.59572 .44474 m .59573 .44473 L .6391 .41969 L p .454 .889 .712 r
F P
0 g
s
.58092 .41908 m .59573 .44473 L .59572 .44474 L p .1 .1 .56 r
F P
0 g
s
.59572 .44474 m .58091 .41909 L .58092 .41908 L p .1 .1 .56 r
F P
0 g
s
.66941 .33059 m .66943 .33057 L .74276 .25724 L p .6 .916 .6 r
F P
0 g
s
.74276 .25724 m .74273 .25727 L .66941 .33059 L p .6 .916 .6 r
F P
0 g
s
.66943 .33057 m .66941 .33059 L .61757 .38243 L p .1 .1 .1 r
F P
0 g
s
.61757 .38243 m .61758 .38242 L .66943 .33057 L p .1 .1 .1 r
F P
0 g
s
.55527 .40427 m .55526 .40428 L .5803 .36091 L p .712 .889 .454 r
F P
0 g
s
.5803 .36091 m .58031 .3609 L .55527 .40427 L p .712 .889 .454 r
F P
0 g
s
.55526 .40428 m .55527 .40427 L .58092 .41908 L p .1 .399 .816 r
F P
0 g
s
.58092 .41908 m .58091 .41909 L .55526 .40428 L p .1 .399 .816 r
F P
0 g
s
.5 .16842 m .5 .16838 L .5 .26855 L p .1 .1 .1 r
F P
0 g
s
.56202 .26855 m .56201 .26858 L .54303 .3394 L p .783 .807 .283 r
F P
0 g
s
.54303 .3394 m .54304 .33938 L .56202 .26855 L p .783 .807 .283 r
F P
0 g
s
.5 .3394 m .5 .38947 L .5 .38946 L p .807 .677 .1 r
F P
0 g
s
.52962 .38947 m .5 .38947 L .5 .38946 L p .211 .761 .909 r
F P
0 g
s
.58885 .16842 m .58886 .16838 L .56202 .26855 L p .783 .807 .283 r
F P
0 g
s
.56202 .26855 m .56201 .26858 L .58885 .16842 L p .783 .807 .283 r
F P
0 g
s
.5803 .36091 m .58031 .3609 L .61572 .29956 L p .1 .1 .1 r
F P
0 g
s
.54304 .33938 m .54303 .3394 L .56201 .26858 L p .783 .807 .283 r
F P
0 g
s
.56201 .26858 m .56202 .26855 L .54304 .33938 L p .783 .807 .283 r
F P
0 g
s
.58031 .3609 m .5803 .36091 L .55526 .40428 L p .1 .1 .1 r
F P
0 g
s
.55526 .40428 m .55527 .40427 L .58031 .3609 L p .1 .1 .1 r
F P
0 g
s
.52962 .38947 m .52962 .38946 L .55527 .40427 L p .1 .399 .816 r
F P
0 g
s
.55527 .40427 m .55526 .40428 L .52962 .38947 L p .1 .399 .816 r
F P
0 g
s
.45696 .33938 m .45697 .3394 L .43799 .26858 L p .783 .508 .1 r
F P
0 g
s
.5 .33938 m .5 .3394 L .5 .38947 L p .807 .677 .1 r
F P
0 g
s
.5 .38947 m .5 .38946 L .5 .33938 L p .807 .677 .1 r
F P
0 g
s
.47038 .38946 m .5 .38946 L .5 .38947 L p .211 .761 .909 r
F P
0 g
s
.5 .38947 m .47038 .38947 L .47038 .38946 L p .211 .761 .909 r
F P
0 g
s
.43799 .26858 m .43798 .26855 L .41114 .16838 L p .783 .508 .1 r
F P
0 g
s
.41114 .16838 m .41115 .16842 L .43799 .26858 L p .783 .508 .1 r
F P
0 g
s
.43798 .26855 m .43799 .26858 L .45697 .3394 L p .783 .508 .1 r
F P
0 g
s
.45697 .3394 m .45696 .33938 L .43798 .26855 L p .783 .508 .1 r
F P
0 g
s
.44473 .40427 m .44474 .40428 L .4197 .36091 L p .1 .1 .454 r
F P
0 g
s
.4197 .36091 m .41969 .3609 L .44473 .40427 L p .1 .1 .454 r
F P
0 g
s
.44474 .40428 m .44473 .40427 L .47038 .38946 L p .56 .969 .816 r
F P
0 g
s
.47038 .38946 m .47038 .38947 L .44474 .40428 L p .56 .969 .816 r
F P
0 g
s
.21285 .33421 m .21281 .33419 L .29956 .38428 L p .454 .1 .1 r
F P
0 g
s
.33057 .33057 m .33059 .33059 L .38243 .38243 L p .6 .1 .1 r
F P
0 g
s
.38243 .38243 m .38242 .38242 L .33057 .33057 L p .6 .1 .1 r
F P
0 g
s
.40427 .44473 m .40428 .44474 L .36091 .4197 L p .1 .311 .712 r
F P
0 g
s
.41909 .41909 m .40428 .44474 L .40427 .44473 L p .816 .969 .56 r
F P
0 g
s
.25727 .25727 m .25724 .25724 L .33057 .33057 L p .6 .1 .1 r
F P
0 g
s
.33057 .33057 m .33059 .33059 L .25727 .25727 L p .6 .1 .1 r
F P
0 g
s
.4197 .36091 m .41969 .3609 L .38428 .29956 L p .712 .311 .1 r
F P
0 g
s
.38242 .38242 m .38243 .38243 L .33059 .33059 L p .6 .1 .1 r
F P
0 g
s
.33059 .33059 m .33057 .33057 L .38242 .38242 L p .6 .1 .1 r
F P
0 g
s
.41969 .3609 m .4197 .36091 L .44474 .40428 L p .712 .311 .1 r
F P
0 g
s
.44474 .40428 m .44473 .40427 L .41969 .3609 L p .712 .311 .1 r
F P
0 g
s
.41909 .41909 m .41908 .41908 L .44473 .40427 L p .56 .969 .816 r
F P
0 g
s
.44473 .40427 m .44474 .40428 L .41909 .41909 L p .56 .969 .816 r
F P
0 g
s
.33938 .45696 m .3394 .45697 L .26858 .43799 L p .1 .508 .783 r
F P
0 g
s
.3609 .41969 m .36091 .4197 L .40428 .44474 L p .454 .1 .1 r
F P
0 g
s
.40428 .44474 m .40427 .44473 L .3609 .41969 L p .454 .1 .1 r
F P
0 g
s
.38946 .47038 m .40427 .44473 L .40428 .44474 L p .816 .969 .56 r
F P
0 g
s
.40428 .44474 m .38947 .47038 L .38946 .47038 L p .816 .969 .56 r
F P
0 g
s
.26858 .43799 m .26855 .43798 L .16838 .41114 L p .283 .1 .1 r
F P
0 g
s
.16838 .41114 m .16842 .41115 L .26858 .43799 L p .283 .1 .1 r
F P
0 g
s
.26855 .43798 m .26858 .43799 L .3394 .45697 L p .1 .508 .783 r
F P
0 g
s
.3394 .45697 m .33938 .45696 L .26855 .43798 L p .1 .508 .783 r
F P
0 g
s
.38946 .5 m .38947 .5 L .3394 .5 L p .1 .677 .807 r
F P
0 g
s
.3394 .5 m .33938 .5 L .38946 .5 L p .1 .677 .807 r
F P
0 g
s
.38947 .5 m .38946 .5 L .38946 .47038 L p .909 .761 .211 r
F P
0 g
s
.38946 .47038 m .38947 .47038 L .38947 .5 L p .909 .761 .211 r
F P
0 g
s
.21285 .66579 m .21281 .66581 L .29956 .61572 L p .1 .1 .1 r
F P
0 g
s
.26855 .56202 m .26858 .56201 L .3394 .54303 L p .283 .807 .783 r
F P
0 g
s
.3394 .54303 m .33938 .54304 L .26855 .56202 L p .283 .807 .783 r
F P
0 g
s
.40427 .55527 m .40428 .55526 L .36091 .5803 L p .454 .889 .712 r
F P
0 g
s
.38947 .52962 m .40428 .55526 L .40427 .55527 L p .816 .399 .1 r
F P
0 g
s
.16842 .58885 m .16838 .58886 L .26855 .56202 L p .283 .807 .783 r
F P
0 g
s
.26855 .56202 m .26858 .56201 L .16842 .58885 L p .283 .807 .783 r
F P
0 g
s
.3394 .5 m .33938 .5 L .26855 .5 L p .1 .677 .807 r
F P
0 g
s
.33938 .54304 m .3394 .54303 L .26858 .56201 L p .283 .807 .783 r
F P
0 g
s
.26858 .56201 m .26855 .56202 L .33938 .54304 L p .283 .807 .783 r
F P
0 g
s
.33938 .5 m .3394 .5 L .38947 .5 L p .1 .677 .807 r
F P
0 g
s
.38947 .5 m .38946 .5 L .33938 .5 L p .1 .677 .807 r
F P
0 g
s
.38947 .52962 m .38946 .52962 L .38946 .5 L p .909 .761 .211 r
F P
0 g
s
.38946 .5 m .38947 .5 L .38947 .52962 L p .909 .761 .211 r
F P
0 g
s
.38242 .61758 m .38243 .61757 L .33059 .66941 L p .6 .916 .6 r
F P
0 g
s
.3609 .58031 m .36091 .5803 L .40428 .55526 L p .1 .1 .1 r
F P
0 g
s
.40428 .55526 m .40427 .55527 L .3609 .58031 L p .1 .1 .1 r
F P
0 g
s
.41908 .58092 m .40427 .55527 L .40428 .55526 L p .816 .399 .1 r
F P
0 g
s
.40428 .55526 m .41909 .58091 L .41908 .58092 L p .816 .399 .1 r
F P
0 g
s
.33059 .66941 m .33057 .66943 L .25724 .74276 L p .6 .916 .6 r
F P
0 g
s
.25724 .74276 m .25727 .74273 L .33059 .66941 L p .6 .916 .6 r
F P
0 g
s
.33057 .66943 m .33059 .66941 L .38243 .61757 L p .1 .1 .1 r
F P
0 g
s
.38243 .61757 m .38242 .61758 L .33057 .66943 L p .1 .1 .1 r
F P
0 g
s
.44473 .59573 m .44474 .59572 L .4197 .63909 L p .712 .889 .454 r
F P
0 g
s
.4197 .63909 m .41969 .6391 L .44473 .59573 L p .712 .889 .454 r
F P
0 g
s
.44474 .59572 m .44473 .59573 L .41908 .58092 L p .56 .1 .1 r
F P
0 g
s
.41908 .58092 m .41909 .58091 L .44474 .59572 L p .56 .1 .1 r
F P
0 g
s
.5 .83158 m .5 .83162 L .5 .73145 L p .807 .677 .1 r
F P
0 g
s
.43798 .73145 m .43799 .73142 L .45697 .6606 L p .1 .1 .1 r
F P
0 g
s
.45697 .6606 m .45696 .66062 L .43798 .73145 L p .1 .1 .1 r
F P
0 g
s
.5 .61054 m .5 .61053 L .5 .6606 L p .807 .677 .1 r
F P
0 g
s
.47038 .61053 m .5 .61053 L .5 .61054 L p .211 .1 .1 r
F P
0 g
s
.41115 .83158 m .41114 .83162 L .43798 .73145 L p .783 .807 .283 r
F P
0 g
s
.43798 .73145 m .43799 .73142 L .41115 .83158 L p .783 .807 .283 r
F P
0 g
s
.4197 .63909 m .41969 .6391 L .38428 .70044 L p .712 .889 .454 r
F P
0 g
s
.45696 .66062 m .45697 .6606 L .43799 .73142 L p .783 .807 .283 r
F P
0 g
s
.43799 .73142 m .43798 .73145 L .45696 .66062 L p .783 .807 .283 r
F P
0 g
s
.41969 .6391 m .4197 .63909 L .44474 .59572 L p .712 .889 .454 r
F P
0 g
s
.44474 .59572 m .44473 .59573 L .41969 .6391 L p .712 .889 .454 r
F P
0 g
s
.47038 .61053 m .47038 .61054 L .44473 .59573 L p .56 .1 .1 r
F P
0 g
s
.44473 .59573 m .44474 .59572 L .47038 .61053 L p .56 .1 .1 r
F P
0 g
s
.54304 .66062 m .54303 .6606 L .56201 .73142 L p .783 .508 .1 r
F P
0 g
s
.5 .61053 m .5 .6606 L .5 .66062 L p .1 .1 .1 r
F P
0 g
s
.5 .66062 m .5 .61054 L .5 .61053 L p .1 .1 .1 r
F P
0 g
s
.52962 .61054 m .5 .61054 L .5 .61053 L p .211 .1 .1 r
F P
0 g
s
.5 .61053 m .52962 .61053 L .52962 .61054 L p .211 .1 .1 r
F P
0 g
s
.56201 .73142 m .56202 .73145 L .58886 .83162 L p .1 .1 .283 r
F P
0 g
s
.58886 .83162 m .58885 .83158 L .56201 .73142 L p .1 .1 .283 r
F P
0 g
s
.56202 .73145 m .56201 .73142 L .54303 .6606 L p .1 .1 .283 r
F P
0 g
s
.54303 .6606 m .54304 .66062 L .56202 .73145 L p .1 .1 .283 r
F P
0 g
s
.55527 .59573 m .55526 .59572 L .5803 .63909 L p .712 .311 .1 r
F P
0 g
s
.5803 .63909 m .58031 .6391 L .55527 .59573 L p .712 .311 .1 r
F P
0 g
s
.55526 .59572 m .55527 .59573 L .52962 .61054 L p .1 .1 .1 r
F P
0 g
s
.52962 .61054 m .52962 .61053 L .55526 .59572 L p .1 .1 .1 r
F P
0 g
s
.78715 .66579 m .78719 .66581 L .70044 .61572 L p .454 .1 .1 r
F P
0 g
s
.61757 .61757 m .66941 .66941 L .66943 .66943 L p .6 .1 .1 r
F P
0 g
s
.61757 .61757 m .61758 .61758 L .66943 .66943 L p .6 .1 .1 r
F P
0 g
s
.59573 .55527 m .59572 .55526 L .63909 .5803 L p .454 .1 .1 r
F P
0 g
s
.58091 .58091 m .59572 .55526 L .59573 .55527 L p .1 .1 .1 r
F P
0 g
s
.66943 .66943 m .74276 .74276 L .74273 .74273 L p .1 .1 .6 r
F P
0 g
s
.66943 .66943 m .66941 .66941 L .74273 .74273 L p .1 .1 .6 r
F P
0 g
s
.5803 .63909 m .58031 .6391 L .61572 .70044 L p .1 .1 .454 r
F P
0 g
s
.66941 .66941 m .61757 .61757 L .61758 .61758 L p .6 .1 .1 r
F P
0 g
s
.61758 .61758 m .66943 .66943 L .66941 .66941 L p .6 .1 .1 r
F P
0 g
s
.58031 .6391 m .5803 .63909 L .55526 .59572 L p .1 .1 .454 r
F P
0 g
s
.55526 .59572 m .55527 .59573 L .58031 .6391 L p .1 .1 .454 r
F P
0 g
s
.58091 .58091 m .58092 .58092 L .55527 .59573 L p .1 .1 .1 r
F P
0 g
s
.55527 .59573 m .55526 .59572 L .58091 .58091 L p .1 .1 .1 r
F P
0 g
s
.66062 .54304 m .6606 .54303 L .73142 .56201 L p .1 .508 .783 r
F P
0 g
s
.6391 .58031 m .63909 .5803 L .59572 .55526 L p .454 .1 .1 r
F P
0 g
s
.59572 .55526 m .59573 .55527 L .6391 .58031 L p .454 .1 .1 r
F P
0 g
s
.61054 .52962 m .59573 .55527 L .59572 .55526 L p .1 .1 .1 r
F P
0 g
s
.59572 .55526 m .61053 .52962 L .61054 .52962 L p .1 .1 .1 r
F P
0 g
s
.73142 .56201 m .73145 .56202 L .83162 .58886 L p .283 .1 .1 r
F P
0 g
s
.83162 .58886 m .83158 .58885 L .73142 .56201 L p .283 .1 .1 r
F P
0 g
s
.73145 .56202 m .73142 .56201 L .6606 .54303 L p .1 .508 .783 r
F P
0 g
s
.6606 .54303 m .66062 .54304 L .73145 .56202 L p .1 .508 .783 r
F P
0 g
s
.6606 .5 m .61053 .5 L .61054 .5 L p .1 .1 .1 r
F P
0 g
s
.61054 .5 m .66062 .5 L .6606 .5 L p .1 .1 .1 r
F P
0 g
s
.61053 .5 m .61054 .5 L .61054 .52962 L p .1 .1 .211 r
F P
0 g
s
.61054 .52962 m .61053 .52962 L .61053 .5 L p .1 .1 .211 r
F P
0 g
s
.83158 .41115 m .83162 .41114 L .78719 .33419 L p .1 .157 .723 r
F P
0 g
s
.78719 .33419 m .78715 .33421 L .83158 .41115 L p .1 .157 .723 r
F P
0 g
s
.6391 .41969 m .63909 .4197 L .70042 .38429 L p .454 .889 .712 r
F P
0 g
s
.70042 .38429 m .70044 .38428 L .6391 .41969 L p .454 .889 .712 r
F P
0 g
s
.61053 .47038 m .61054 .47038 L .66062 .45696 L p .283 .807 .783 r
F P
0 g
s
.66062 .45696 m .6606 .45697 L .61053 .47038 L p .283 .807 .783 r
F P
0 g
s
.6606 .45697 m .66062 .45696 L .61054 .47038 L p .283 .807 .783 r
F P
0 g
s
.78715 .33421 m .78719 .33419 L .74276 .25724 L p .1 .157 .723 r
F P
0 g
s
.74276 .25724 m .74273 .25727 L .78715 .33421 L p .1 .157 .723 r
F P
0 g
s
.70044 .38428 m .70042 .38429 L .63909 .4197 L p .454 .889 .712 r
F P
0 g
s
.63909 .4197 m .6391 .41969 L .70044 .38428 L p .454 .889 .712 r
F P
0 g
s
.58092 .41908 m .58091 .41909 L .61757 .38243 L p .6 .916 .6 r
F P
0 g
s
.58885 .16842 m .58886 .16838 L .5 .16838 L p .404 .869 1 r
F P
0 g
s
.5 .16838 m .5 .16842 L .58885 .16842 L p .404 .869 1 r
F P
0 g
s
.5 .33938 m .5 .3394 L .5 .26858 L p .1 .1 .1 r
F P
0 g
s
.5 .33938 m .5 .26855 L .5 .26858 L p .1 .1 .1 r
F P
0 g
s
.52962 .38947 m .52962 .38946 L .54304 .33938 L p .783 .807 .283 r
F P
0 g
s
.54304 .33938 m .54303 .3394 L .52962 .38947 L p .783 .807 .283 r
F P
0 g
s
.54303 .3394 m .54304 .33938 L .52962 .38946 L p .783 .807 .283 r
F P
0 g
s
.5 .16842 m .5 .16838 L .41114 .16838 L p .404 .869 1 r
F P
0 g
s
.41114 .16838 m .41115 .16842 L .5 .16842 L p .404 .869 1 r
F P
0 g
s
.5 .26855 m .5 .26858 L .5 .3394 L p .1 .1 .1 r
F P
0 g
s
.5 .3394 m .5 .33938 L .5 .26855 L p .1 .1 .1 r
F P
0 g
s
.47038 .38946 m .47038 .38947 L .45697 .3394 L p .1 .1 .283 r
F P
0 g
s
.25727 .25727 m .25724 .25724 L .21281 .33419 L p .957 1 .723 r
F P
0 g
s
.21281 .33419 m .21285 .33421 L .25727 .25727 L p .957 1 .723 r
F P
0 g
s
.3609 .41969 m .36091 .4197 L .29958 .38429 L p .1 .311 .712 r
F P
0 g
s
.29958 .38429 m .29956 .38428 L .3609 .41969 L p .1 .311 .712 r
F P
0 g
s
.41909 .41909 m .41908 .41908 L .38242 .38242 L p .6 .1 .1 r
F P
0 g
s
.38242 .38242 m .38243 .38243 L .41909 .41909 L p .6 .1 .1 r
F P
0 g
s
.38243 .38243 m .38242 .38242 L .41908 .41908 L p .6 .1 .1 r
F P
0 g
s
.21285 .33421 m .21281 .33419 L .16838 .41114 L p .957 1 .723 r
F P
0 g
s
.16838 .41114 m .16842 .41115 L .21285 .33421 L p .957 1 .723 r
F P
0 g
s
.29956 .38428 m .29958 .38429 L .36091 .4197 L p .454 .1 .1 r
F P
0 g
s
.36091 .4197 m .3609 .41969 L .29956 .38428 L p .454 .1 .1 r
F P
0 g
s
.38946 .47038 m .38947 .47038 L .3394 .45697 L p .1 .508 .783 r
F P
0 g
s
.16842 .58885 m .16838 .58886 L .21281 .66581 L p .957 .539 .1 r
F P
0 g
s
.21281 .66581 m .21285 .66579 L .16842 .58885 L p .957 .539 .1 r
F P
0 g
s
.3609 .58031 m .36091 .5803 L .29958 .61571 L p .454 .889 .712 r
F P
0 g
s
.29958 .61571 m .29956 .61572 L .3609 .58031 L p .454 .889 .712 r
F P
0 g
s
.38947 .52962 m .38946 .52962 L .33938 .54304 L p .283 .807 .783 r
F P
0 g
s
.33938 .54304 m .3394 .54303 L .38947 .52962 L p .283 .807 .783 r
F P
0 g
s
.3394 .54303 m .33938 .54304 L .38946 .52962 L p .283 .807 .783 r
F P
0 g
s
.21285 .66579 m .21281 .66581 L .25724 .74276 L p .957 .539 .1 r
F P
0 g
s
.25724 .74276 m .25727 .74273 L .21285 .66579 L p .957 .539 .1 r
F P
0 g
s
.29956 .61572 m .29958 .61571 L .36091 .5803 L p .454 .889 .712 r
F P
0 g
s
.36091 .5803 m .3609 .58031 L .29956 .61572 L p .454 .889 .712 r
F P
0 g
s
.41908 .58092 m .41909 .58091 L .38243 .61757 L p .6 .916 .6 r
F P
0 g
s
.41115 .83158 m .41114 .83162 L .5 .83162 L p .404 .1 .1 r
F P
0 g
s
.5 .83162 m .5 .83158 L .41115 .83158 L p .404 .1 .1 r
F P
0 g
s
.5 .73142 m .5 .6606 L .5 .66062 L p .807 .677 .1 r
F P
0 g
s
.5 .66062 m .5 .73145 L .5 .73142 L p .807 .677 .1 r
F P
0 g
s
.47038 .61053 m .47038 .61054 L .45696 .66062 L p .1 .1 .1 r
F P
0 g
s
.45696 .66062 m .45697 .6606 L .47038 .61053 L p .1 .1 .1 r
F P
0 g
s
.45697 .6606 m .45696 .66062 L .47038 .61054 L p .783 .807 .283 r
F P
0 g
s
.5 .83158 m .5 .83162 L .58886 .83162 L p .404 .1 .1 r
F P
0 g
s
.58886 .83162 m .58885 .83158 L .5 .83158 L p .404 .1 .1 r
F P
0 g
s
.5 .6606 m .5 .73142 L .5 .73145 L p .1 .1 .1 r
F P
0 g
s
.5 .73145 m .5 .66062 L .5 .6606 L p .1 .1 .1 r
F P
0 g
s
.52962 .61054 m .52962 .61053 L .54303 .6606 L p .1 .1 .283 r
F P
0 g
s
.74273 .74273 m .74276 .74276 L .78719 .66581 L p .1 .1 .1 r
F P
0 g
s
.78719 .66581 m .78715 .66579 L .74273 .74273 L p .1 .1 .1 r
F P
0 g
s
.6391 .58031 m .63909 .5803 L .70042 .61571 L p .1 .311 .712 r
F P
0 g
s
.70042 .61571 m .70044 .61572 L .6391 .58031 L p .1 .311 .712 r
F P
0 g
s
.61758 .61758 m .58092 .58092 L .58091 .58091 L p .6 .1 .1 r
F P
0 g
s
.61758 .61758 m .61757 .61757 L .58091 .58091 L p .6 .1 .1 r
F P
0 g
s
.58092 .58092 m .61758 .61758 L .61757 .61757 L p .6 .1 .1 r
F P
0 g
s
.78715 .66579 m .78719 .66581 L .83162 .58886 L p .1 .1 .1 r
F P
0 g
s
.83162 .58886 m .83158 .58885 L .78715 .66579 L p .1 .1 .1 r
F P
0 g
s
.70044 .61572 m .70042 .61571 L .63909 .5803 L p .454 .1 .1 r
F P
0 g
s
.63909 .5803 m .6391 .58031 L .70044 .61572 L p .454 .1 .1 r
F P
0 g
s
.61054 .52962 m .61053 .52962 L .6606 .54303 L p .283 .1 .1 r
F P
0 g
s
.83162 .41114 m .83158 .41115 L .73142 .43799 L p .283 .807 .783 r
F P
0 g
s
.73142 .43799 m .73145 .43798 L .83162 .41114 L p .283 .807 .783 r
F P
0 g
s
.63909 .4197 m .6391 .41969 L .59573 .44473 L p .454 .889 .712 r
F P
0 g
s
.59573 .44473 m .61054 .47038 L .61053 .47038 L p .1 .1 .56 r
F P
0 g
s
.66943 .33057 m .66941 .33059 L .74273 .25727 L p .1 .1 .1 r
F P
0 g
s
.74273 .25727 m .74276 .25724 L .66943 .33057 L p .1 .1 .1 r
F P
0 g
s
.66941 .33059 m .66943 .33057 L .61758 .38242 L p .6 .916 .6 r
F P
0 g
s
.61757 .38243 m .61758 .38242 L .58092 .41908 L p .6 .916 .6 r
F P
0 g
s
.58886 .16838 m .58885 .16842 L .56201 .26858 L p .783 .807 .283 r
F P
0 g
s
.56201 .26858 m .56202 .26855 L .58886 .16838 L p .783 .807 .283 r
F P
0 g
s
.5 .3394 m .5 .33938 L .5 .38946 L p .807 .677 .1 r
F P
0 g
s
.5 .38946 m .52962 .38946 L .52962 .38947 L p .211 .761 .909 r
F P
0 g
s
.43798 .26855 m .43799 .26858 L .41115 .16842 L p .783 .508 .1 r
F P
0 g
s
.41115 .16842 m .41114 .16838 L .43798 .26855 L p .783 .508 .1 r
F P
0 g
s
.43799 .26858 m .43798 .26855 L .45696 .33938 L p .783 .508 .1 r
F P
0 g
s
.45697 .3394 m .45696 .33938 L .47038 .38946 L p .1 .1 .283 r
F P
0 g
s
.25724 .25724 m .25727 .25727 L .33059 .33059 L p .1 .1 .6 r
F P
0 g
s
.33059 .33059 m .33057 .33057 L .25724 .25724 L p .1 .1 .6 r
F P
0 g
s
.36091 .4197 m .3609 .41969 L .40427 .44473 L p .1 .311 .712 r
F P
0 g
s
.40427 .44473 m .41908 .41908 L .41909 .41909 L p .816 .969 .56 r
F P
0 g
s
.26855 .43798 m .26858 .43799 L .16842 .41115 L p .283 .1 .1 r
F P
0 g
s
.16842 .41115 m .16838 .41114 L .26855 .43798 L p .283 .1 .1 r
F P
0 g
s
.26858 .43799 m .26855 .43798 L .33938 .45696 L p .1 .508 .783 r
F P
0 g
s
.3394 .45697 m .33938 .45696 L .38946 .47038 L p .1 .508 .783 r
F P
0 g
s
.16838 .58886 m .16842 .58885 L .26858 .56201 L p .283 .807 .783 r
F P
0 g
s
.26858 .56201 m .26855 .56202 L .16838 .58886 L p .283 .807 .783 r
F P
0 g
s
.36091 .5803 m .3609 .58031 L .40427 .55527 L p .454 .889 .712 r
F P
0 g
s
.40427 .55527 m .38946 .52962 L .38947 .52962 L p .816 .399 .1 r
F P
0 g
s
.33057 .66943 m .33059 .66941 L .25727 .74273 L p .6 .916 .6 r
F P
0 g
s
.25727 .74273 m .25724 .74276 L .33057 .66943 L p .6 .916 .6 r
F P
0 g
s
.33059 .66941 m .33057 .66943 L .38242 .61758 L p .6 .916 .6 r
F P
0 g
s
.38243 .61757 m .38242 .61758 L .41908 .58092 L p .6 .916 .6 r
F P
0 g
s
.41114 .83162 m .41115 .83158 L .43799 .73142 L p .783 .807 .283 r
F P
0 g
s
.43799 .73142 m .43798 .73145 L .41114 .83162 L p .783 .807 .283 r
F P
0 g
s
.5 .6606 m .5 .66062 L .5 .61054 L p .807 .677 .1 r
F P
0 g
s
.5 .61054 m .47038 .61054 L .47038 .61053 L p .211 .1 .1 r
F P
0 g
s
.56202 .73145 m .56201 .73142 L .58885 .83158 L p .1 .1 .283 r
F P
0 g
s
.58885 .83158 m .58886 .83162 L .56202 .73145 L p .1 .1 .283 r
F P
0 g
s
.56201 .73142 m .56202 .73145 L .54304 .66062 L p .783 .508 .1 r
F P
0 g
s
.54303 .6606 m .54304 .66062 L .52962 .61054 L p .1 .1 .283 r
F P
0 g
s
.66941 .66941 m .74273 .74273 L .74276 .74276 L p .1 .1 .6 r
F P
0 g
s
.74276 .74276 m .66943 .66943 L .66941 .66941 L p .1 .1 .6 r
F P
0 g
s
.63909 .5803 m .6391 .58031 L .59573 .55527 L p .454 .1 .1 r
F P
0 g
s
.59573 .55527 m .58092 .58092 L .58091 .58091 L p .1 .1 .1 r
F P
0 g
s
.73145 .56202 m .73142 .56201 L .83158 .58885 L p .283 .1 .1 r
F P
0 g
s
.83158 .58885 m .83162 .58886 L .73145 .56202 L p .283 .1 .1 r
F P
0 g
s
.73142 .56201 m .73145 .56202 L .66062 .54304 L p .1 .508 .783 r
F P
0 g
s
.6606 .54303 m .66062 .54304 L .61054 .52962 L p .283 .1 .1 r
F P
0 g
s
.83162 .41114 m .73145 .43798 L .70044 .38428 L p .807 .677 .807 r
F P
0 g
s
.70044 .38428 m .78719 .33419 L .83162 .41114 L p .807 .677 .807 r
F P
0 g
s
.73145 .43798 m .66062 .45696 L .6391 .41969 L p .807 .677 .807 r
F P
0 g
s
.6391 .41969 m .70044 .38428 L .73145 .43798 L p .807 .677 .807 r
F P
0 g
s
.66062 .45696 m .61054 .47038 L .59573 .44473 L p .807 .677 .807 r
F P
0 g
s
.59573 .44473 m .6391 .41969 L .66062 .45696 L p .807 .677 .807 r
F P
0 g
s
.83162 .41114 m .83162 .5 L .73145 .5 L p .807 .677 .807 r
F P
0 g
s
.73145 .5 m .73145 .43798 L .83162 .41114 L p .807 .677 .807 r
F P
0 g
s
.73145 .43798 m .73145 .5 L .66062 .5 L p .807 .677 .807 r
F P
0 g
s
.66062 .5 m .66062 .45696 L .73145 .43798 L p .807 .677 .807 r
F P
0 g
s
.66062 .45696 m .66062 .5 L .61054 .5 L p .807 .677 .807 r
F P
0 g
s
.61054 .5 m .61054 .47038 L .66062 .45696 L p .807 .677 .807 r
F P
0 g
s
.78719 .33419 m .70044 .38428 L .66943 .33057 L p .807 .677 .807 r
F P
0 g
s
.66943 .33057 m .74276 .25724 L .78719 .33419 L p .807 .677 .807 r
F P
0 g
s
.70044 .38428 m .6391 .41969 L .61758 .38242 L p .807 .677 .807 r
F P
0 g
s
.61758 .38242 m .66943 .33057 L .70044 .38428 L p .807 .677 .807 r
F P
0 g
s
.6391 .41969 m .59573 .44473 L .58092 .41908 L p .807 .677 .807 r
F P
0 g
s
.58092 .41908 m .61758 .38242 L .6391 .41969 L p .807 .677 .807 r
F P
0 g
s
.66943 .33057 m .61572 .29956 L .66581 .21281 L p .807 .677 .807 r
F P
0 g
s
.66581 .21281 m .74276 .25724 L .66943 .33057 L p .807 .677 .807 r
F P
0 g
s
.61758 .38242 m .58031 .3609 L .61572 .29956 L p .807 .677 .807 r
F P
0 g
s
.61572 .29956 m .66943 .33057 L .61758 .38242 L p .807 .677 .807 r
F P
0 g
s
.58092 .41908 m .55527 .40427 L .58031 .3609 L p .807 .677 .807 r
F P
0 g
s
.58031 .3609 m .61758 .38242 L .58092 .41908 L p .807 .677 .807 r
F P
0 g
s
.58886 .16838 m .56202 .26855 L .5 .26855 L p .807 .677 .807 r
F P
0 g
s
.5 .26855 m .5 .16838 L .58886 .16838 L p .807 .677 .807 r
F P
0 g
s
.56202 .26855 m .54304 .33938 L .5 .33938 L p .807 .677 .807 r
F P
0 g
s
.5 .33938 m .5 .26855 L .56202 .26855 L p .807 .677 .807 r
F P
0 g
s
.54304 .33938 m .52962 .38946 L .5 .38946 L p .807 .677 .807 r
F P
0 g
s
.5 .38946 m .5 .33938 L .54304 .33938 L p .807 .677 .807 r
F P
0 g
s
.58886 .16838 m .66581 .21281 L .61572 .29956 L p .807 .677 .807 r
F P
0 g
s
.61572 .29956 m .56202 .26855 L .58886 .16838 L p .807 .677 .807 r
F P
0 g
s
.56202 .26855 m .61572 .29956 L .58031 .3609 L p .807 .677 .807 r
F P
0 g
s
.58031 .3609 m .54304 .33938 L .56202 .26855 L p .807 .677 .807 r
F P
0 g
s
.54304 .33938 m .58031 .3609 L .55527 .40427 L p .807 .677 .807 r
F P
0 g
s
.55527 .40427 m .52962 .38946 L .54304 .33938 L p .807 .677 .807 r
F P
0 g
s
.5 .16838 m .5 .26855 L .43798 .26855 L p .807 .677 .807 r
F P
0 g
s
.43798 .26855 m .41114 .16838 L .5 .16838 L p .807 .677 .807 r
F P
0 g
s
.5 .26855 m .5 .33938 L .45696 .33938 L p .807 .677 .807 r
F P
0 g
s
.45696 .33938 m .43798 .26855 L .5 .26855 L p .807 .677 .807 r
F P
0 g
s
.5 .33938 m .5 .38946 L .47038 .38946 L p .807 .677 .807 r
F P
0 g
s
.47038 .38946 m .45696 .33938 L .5 .33938 L p .807 .677 .807 r
F P
0 g
s
.43798 .26855 m .38428 .29956 L .33419 .21281 L p .807 .677 .807 r
F P
0 g
s
.33419 .21281 m .41114 .16838 L .43798 .26855 L p .807 .677 .807 r
F P
0 g
s
.45696 .33938 m .41969 .3609 L .38428 .29956 L p .807 .677 .807 r
F P
0 g
s
.38428 .29956 m .43798 .26855 L .45696 .33938 L p .807 .677 .807 r
F P
0 g
s
.47038 .38946 m .44473 .40427 L .41969 .3609 L p .807 .677 .807 r
F P
0 g
s
.41969 .3609 m .45696 .33938 L .47038 .38946 L p .807 .677 .807 r
F P
0 g
s
.25724 .25724 m .33057 .33057 L .29956 .38428 L p .807 .677 .807 r
F P
0 g
s
.29956 .38428 m .21281 .33419 L .25724 .25724 L p .807 .677 .807 r
F P
0 g
s
.33057 .33057 m .38242 .38242 L .3609 .41969 L p .807 .677 .807 r
F P
0 g
s
.3609 .41969 m .29956 .38428 L .33057 .33057 L p .807 .677 .807 r
F P
0 g
s
.38242 .38242 m .41908 .41908 L .40427 .44473 L p .807 .677 .807 r
F P
0 g
s
.40427 .44473 m .3609 .41969 L .38242 .38242 L p .807 .677 .807 r
F P
0 g
s
.25724 .25724 m .33419 .21281 L .38428 .29956 L p .807 .677 .807 r
F P
0 g
s
.38428 .29956 m .33057 .33057 L .25724 .25724 L p .807 .677 .807 r
F P
0 g
s
.33057 .33057 m .38428 .29956 L .41969 .3609 L p .807 .677 .807 r
F P
0 g
s
.41969 .3609 m .38242 .38242 L .33057 .33057 L p .807 .677 .807 r
F P
0 g
s
.38242 .38242 m .41969 .3609 L .44473 .40427 L p .807 .677 .807 r
F P
0 g
s
.44473 .40427 m .41908 .41908 L .38242 .38242 L p .807 .677 .807 r
F P
0 g
s
.21281 .33419 m .29956 .38428 L .26855 .43798 L p .807 .677 .807 r
F P
0 g
s
.26855 .43798 m .16838 .41114 L .21281 .33419 L p .807 .677 .807 r
F P
0 g
s
.29956 .38428 m .3609 .41969 L .33938 .45696 L p .807 .677 .807 r
F P
0 g
s
.33938 .45696 m .26855 .43798 L .29956 .38428 L p .807 .677 .807 r
F P
0 g
s
.3609 .41969 m .40427 .44473 L .38946 .47038 L p .807 .677 .807 r
F P
0 g
s
.38946 .47038 m .33938 .45696 L .3609 .41969 L p .807 .677 .807 r
F P
0 g
s
.26855 .43798 m .26855 .5 L .16838 .5 L p .807 .677 .807 r
F P
0 g
s
.16838 .5 m .16838 .41114 L .26855 .43798 L p .807 .677 .807 r
F P
0 g
s
.33938 .45696 m .33938 .5 L .26855 .5 L p .807 .677 .807 r
F P
0 g
s
.26855 .5 m .26855 .43798 L .33938 .45696 L p .807 .677 .807 r
F P
0 g
s
.38946 .47038 m .38946 .5 L .33938 .5 L p .807 .677 .807 r
F P
0 g
s
.33938 .5 m .33938 .45696 L .38946 .47038 L p .807 .677 .807 r
F P
0 g
s
.16838 .58886 m .26855 .56202 L .29956 .61572 L p .807 .677 .807 r
F P
0 g
s
.29956 .61572 m .21281 .66581 L .16838 .58886 L p .807 .677 .807 r
F P
0 g
s
.26855 .56202 m .33938 .54304 L .3609 .58031 L p .807 .677 .807 r
F P
0 g
s
.3609 .58031 m .29956 .61572 L .26855 .56202 L p .807 .677 .807 r
F P
0 g
s
.33938 .54304 m .38946 .52962 L .40427 .55527 L p .807 .677 .807 r
F P
0 g
s
.40427 .55527 m .3609 .58031 L .33938 .54304 L p .807 .677 .807 r
F P
0 g
s
.16838 .58886 m .16838 .5 L .26855 .5 L p .807 .677 .807 r
F P
0 g
s
.26855 .5 m .26855 .56202 L .16838 .58886 L p .807 .677 .807 r
F P
0 g
s
.26855 .56202 m .26855 .5 L .33938 .5 L p .807 .677 .807 r
F P
0 g
s
.33938 .5 m .33938 .54304 L .26855 .56202 L p .807 .677 .807 r
F P
0 g
s
.33938 .54304 m .33938 .5 L .38946 .5 L p .807 .677 .807 r
F P
0 g
s
.38946 .5 m .38946 .52962 L .33938 .54304 L p .807 .677 .807 r
F P
0 g
s
.21281 .66581 m .29956 .61572 L .33057 .66943 L p .807 .677 .807 r
F P
0 g
s
.33057 .66943 m .25724 .74276 L .21281 .66581 L p .807 .677 .807 r
F P
0 g
s
.29956 .61572 m .3609 .58031 L .38242 .61758 L p .807 .677 .807 r
F P
0 g
s
.38242 .61758 m .33057 .66943 L .29956 .61572 L p .807 .677 .807 r
F P
0 g
s
.3609 .58031 m .40427 .55527 L .41908 .58092 L p .807 .677 .807 r
F P
0 g
s
.41908 .58092 m .38242 .61758 L .3609 .58031 L p .807 .677 .807 r
F P
0 g
s
.33057 .66943 m .38428 .70044 L .33419 .78719 L p .807 .677 .807 r
F P
0 g
s
.33419 .78719 m .25724 .74276 L .33057 .66943 L p .807 .677 .807 r
F P
0 g
s
.38242 .61758 m .41969 .6391 L .38428 .70044 L p .807 .677 .807 r
F P
0 g
s
.38428 .70044 m .33057 .66943 L .38242 .61758 L p .807 .677 .807 r
F P
0 g
s
.41908 .58092 m .44473 .59573 L .41969 .6391 L p .807 .677 .807 r
F P
0 g
s
.41969 .6391 m .38242 .61758 L .41908 .58092 L p .807 .677 .807 r
F P
0 g
s
.41114 .83162 m .43798 .73145 L .5 .73145 L p .807 .677 .807 r
F P
0 g
s
.5 .73145 m .5 .83162 L .41114 .83162 L p .807 .677 .807 r
F P
0 g
s
.43798 .73145 m .45696 .66062 L .5 .66062 L p .807 .677 .807 r
F P
0 g
s
.5 .66062 m .5 .73145 L .43798 .73145 L p .807 .677 .807 r
F P
0 g
s
.45696 .66062 m .47038 .61054 L .5 .61054 L p .807 .677 .807 r
F P
0 g
s
.5 .61054 m .5 .66062 L .45696 .66062 L p .807 .677 .807 r
F P
0 g
s
.41114 .83162 m .33419 .78719 L .38428 .70044 L p .807 .677 .807 r
F P
0 g
s
.38428 .70044 m .43798 .73145 L .41114 .83162 L p .807 .677 .807 r
F P
0 g
s
.43798 .73145 m .38428 .70044 L .41969 .6391 L p .807 .677 .807 r
F P
0 g
s
.41969 .6391 m .45696 .66062 L .43798 .73145 L p .807 .677 .807 r
F P
0 g
s
.45696 .66062 m .41969 .6391 L .44473 .59573 L p .807 .677 .807 r
F P
0 g
s
.44473 .59573 m .47038 .61054 L .45696 .66062 L p .807 .677 .807 r
F P
0 g
s
.5 .83162 m .5 .73145 L .56202 .73145 L p .807 .677 .807 r
F P
0 g
s
.56202 .73145 m .58886 .83162 L .5 .83162 L p .807 .677 .807 r
F P
0 g
s
.5 .73145 m .5 .66062 L .54304 .66062 L p .807 .677 .807 r
F P
0 g
s
.54304 .66062 m .56202 .73145 L .5 .73145 L p .807 .677 .807 r
F P
0 g
s
.5 .66062 m .5 .61054 L .52962 .61054 L p .807 .677 .807 r
F P
0 g
s
.52962 .61054 m .54304 .66062 L .5 .66062 L p .807 .677 .807 r
F P
0 g
s
.56202 .73145 m .61572 .70044 L .66581 .78719 L p .807 .677 .807 r
F P
0 g
s
.66581 .78719 m .58886 .83162 L .56202 .73145 L p .807 .677 .807 r
F P
0 g
s
.54304 .66062 m .58031 .6391 L .61572 .70044 L p .807 .677 .807 r
F P
0 g
s
.61572 .70044 m .56202 .73145 L .54304 .66062 L p .807 .677 .807 r
F P
0 g
s
.52962 .61054 m .55527 .59573 L .58031 .6391 L p .807 .677 .807 r
F P
0 g
s
.58031 .6391 m .54304 .66062 L .52962 .61054 L p .807 .677 .807 r
F P
0 g
s
.74276 .74276 m .66943 .66943 L .70044 .61572 L p .807 .677 .807 r
F P
0 g
s
.70044 .61572 m .78719 .66581 L .74276 .74276 L p .807 .677 .807 r
F P
0 g
s
.66943 .66943 m .61758 .61758 L .6391 .58031 L p .807 .677 .807 r
F P
0 g
s
.6391 .58031 m .70044 .61572 L .66943 .66943 L p .807 .677 .807 r
F P
0 g
s
.61758 .61758 m .58092 .58092 L .59573 .55527 L p .807 .677 .807 r
F P
0 g
s
.59573 .55527 m .6391 .58031 L .61758 .61758 L p .807 .677 .807 r
F P
0 g
s
.74276 .74276 m .66581 .78719 L .61572 .70044 L p .807 .677 .807 r
F P
0 g
s
.61572 .70044 m .66943 .66943 L .74276 .74276 L p .807 .677 .807 r
F P
0 g
s
.66943 .66943 m .61572 .70044 L .58031 .6391 L p .807 .677 .807 r
F P
0 g
s
.58031 .6391 m .61758 .61758 L .66943 .66943 L p .807 .677 .807 r
F P
0 g
s
.61758 .61758 m .58031 .6391 L .55527 .59573 L p .807 .677 .807 r
F P
0 g
s
.55527 .59573 m .58092 .58092 L .61758 .61758 L p .807 .677 .807 r
F P
0 g
s
.78719 .66581 m .70044 .61572 L .73145 .56202 L p .807 .677 .807 r
F P
0 g
s
.73145 .56202 m .83162 .58886 L .78719 .66581 L p .807 .677 .807 r
F P
0 g
s
.70044 .61572 m .6391 .58031 L .66062 .54304 L p .807 .677 .807 r
F P
0 g
s
.66062 .54304 m .73145 .56202 L .70044 .61572 L p .807 .677 .807 r
F P
0 g
s
.6391 .58031 m .59573 .55527 L .61054 .52962 L p .807 .677 .807 r
F P
0 g
s
.61054 .52962 m .66062 .54304 L .6391 .58031 L p .807 .677 .807 r
F P
0 g
s
.73145 .56202 m .73145 .5 L .83162 .5 L p .807 .677 .807 r
F P
0 g
s
.83162 .5 m .83162 .58886 L .73145 .56202 L p .807 .677 .807 r
F P
0 g
s
.66062 .54304 m .66062 .5 L .73145 .5 L p .807 .677 .807 r
F P
0 g
s
.73145 .5 m .73145 .56202 L .66062 .54304 L p .807 .677 .807 r
F P
0 g
s
.61054 .52962 m .61054 .5 L .66062 .5 L p .807 .677 .807 r
F P
0 g
s
.66062 .5 m .66062 .54304 L .61054 .52962 L p .807 .677 .807 r
F P
0 g
s
.003 w
.1518 .1518 m
.1518 .8482 L
s
.25 Mabswid
.1518 .22365 m
.15805 .22365 L
s
gsave
.1393 .22365 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.1518 .5 m
.15805 .5 L
s
gsave
.1393 .5 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.1518 .77635 m
.15805 .77635 L
s
gsave
.1393 .77635 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.1518 .27892 m
.15555 .27892 L
s
.1518 .33419 m
.15555 .33419 L
s
.1518 .38946 m
.15555 .38946 L
s
.1518 .44473 m
.15555 .44473 L
s
.1518 .55527 m
.15555 .55527 L
s
.1518 .61054 m
.15555 .61054 L
s
.1518 .66581 m
.15555 .66581 L
s
.1518 .72108 m
.15555 .72108 L
s
.1518 .16838 m
.15555 .16838 L
s
.1518 .83162 m
.15555 .83162 L
s
gsave
.0768 .5 -76 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{348, 348},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L0001G2000`400?l00000o`00003oo`3IfMUM
0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM
0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM
0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM0=WIf@00o`3IfMUM
0=WIf@00o`3IfMUM0=WIf@00Y`3IfMT300000080fMWI0`00002]0=WIf@00Z@3IfMT010000000fMWI
0=WIf@00002_0=WIf@00Z@3IfMT010000000fMWI0=WIf@00002_0=WIf@00ZP3IfMT200000;00fMWI
002Z0=WIf@800000/03IfMT00:T0fMWI00@000000=WIf@3IfMT00000[`3IfMT00:T0fMWI00@00000
0=WIf@3IfMT00000[`3IfMT00:L0fMWI0`0000020=WIf@<00000[@3IfMT00?l0fMWIG@3IfMT00?l0
fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0
fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0
fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT004/0fMWI100000030=WIf@<00000EP3IfMT3
000005T0fMWI100000030=WIf@<00000B`3IfMT004l0fMWI00<000000=WIf@0000000`3IfMT00`00
0000fMWI0=WIf@1B0=WIf@050000003IfMT0fMWI0=WIf@000000G03IfMT00`000000fMWI00000003
0=WIf@030000003IfMT0fMWI04P0fMWI001?0=WIf@030000003IfMT0000000<0fMWI00<000000=WI
f@3IfMT0DP3IfMT01@000000fMWI0=WIf@3IfMT0000005`0fMWI00<000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@180=WIf@00A03IfMT7000000@0fMWI00<000000=WIf@0000000`3IfMT00`00
0000fMWI0=WIf@1B0=WIf@050000003IfMT0fMWI0=WIf@000000G03IfMT00`000000fMWI00000003
0=WIf@030000003IfMT0fMWI04P0fMWI001?0=WIf@030000003IfMT0000000<0fMWI00<000000=WI
f@3IfMT0DP3IfMT01@000000fMWI0=WIf@3IfMT0000005`0fMWI00<000000=WIf@0000000`3IfMT0
0`000000fMWI0=WIf@180=WIf@00B`3IfMT400000080fMWI00D000000=WIf@3IfMT0fMWI0000001D
0=WIf@050000003IfMT0fMWI0=WIf@000000F03IfMT400000080fMWI00D000000=WIf@3IfMT0fMWI
0000001:0=WIf@00C03IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@000000
E03IfMT01@000000fMWI0=WIf@3IfMT0000005T0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000
fMWI0=WIf@3IfMT0000004X0fMWI001<0=WIf@@000000P3IfMT3000005H0fMWI0`00001J0=WIf@@0
00000P3IfMT3000004/0fMWI003o0=WIfEd0fMWI003o0=WIfEd0fMWI003o0=WIfEd0fMWI000>0=WI
f@H000003P3IfMT500000080fMWI0`00003o0=WIfC40fMWI000?0=WIf@050000003IfMT0fMWI0=WI
f@0000003P3IfMT00`000000fMWI0=WIf@02000000030=WIf@000000fMWI0080fMWI00<000000=WI
f@3IfMT0o`3IfMT^0=WIf@003`3IfMT00`000000fMWI0=WIf@0A0=WIf@060000003IfMT000000000
003IfMT000000`3IfMT00`000000fMWI0=WIf@3o0=WIfBh0fMWI000@0=WIf@030000003IfMT0fMWI
0140fMWI0`0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI00D0fMWIl`00000e0=WI
f@004@3IfMT00`000000fMWI0=WIf@0?0=WIf@<000000P3IfMT01@000000fMWI0=WIf@3IfMT00000
00L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
03<0fMWI000B0=WIf@030000003IfMT0fMWI0100fMWI00@000000=WIf@3IfMT000000`3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0G@3IfMT00`00
0000fMWI0=WIf@1M0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0<`3IfMT000h0
fMWI00D000000=WIf@3IfMT0fMWI0000000?0=WIf@030000003IfMT0fMWI0080000000<0fMWI0000
003IfMT00P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0>l0fMWI00<000000=WI
f@3IfMT0<`3IfMT000h0fMWI1P00000?0=WIf@<000000`3IfMT3000000P0fMWI00<000000=WIf@3I
fMT0k`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@3_0=WIf@030000
003IfMT0fMWI03<0fMWI000d0=WIf@800000E`3IfMU1000005P0fMWI00<000000=WIf@3IfMT0<`3I
fMT003@0fMWI00<000000=WIf@3IfMT0E03IfMT2000000030<j]cP000000cZg>01d0cZg>00<00000
0<j]cP3>[Lh0703>[Lh010000000cZg>00000000001F0=WIf@030000003IfMT0fMWI03<0fMWI000d
0=WIf@030000003IfMT0fMWI0580fMWI0P0000030<j]cP030000003>[Lh0cZg>01`0cZg>00<00000
0<j]cP3>[Lh0703>[Lh010000000cZg>0<j]cP3>[Lh2000005@0fMWI00<000000=WIf@3IfMT0<`3I
fMT003@0fMWI00<000000=WIf@3IfMT0D@3IfMT00`000000cZg>0<j]cP040<j]cP030000003>[Lh0
cZg>01/0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP040<j]cP030000003IfMT0
fMWI0540fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0C`3IfMT20000
00L0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>
00D0cZg>0P00001A0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI04d0
fMWI0P0000090<j]cP030000003>[Lh0cZg>01/0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000
cZg>0<j]cP070<j]cP800000C`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@1;0=WIf@8000002`3>[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>01/0cZg>
00<000000<j]cP3>[Lh02@3>[Lh2000004d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<0
00000=WIf@3IfMT0B@3IfMT2000000h0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]
cP0J0<j]cP030000003>[Lh0cZg>00`0cZg>0P00001;0=WIf@030000003IfMT0fMWI03<0fMWI000d
0=WIf@030000003IfMT0fMWI04P0fMWI00<000000<j]cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0J
0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh03P3>[Lh00`000000fMWI0=WIf@18
0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI04H0fMWI0P00000A0<j]
cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP0?0<j]
cP800000B03IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@140=WIf@80
00004`3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>
[Lh04@3>[Lh2000004H0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
@P3IfMT2000001H0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000
003>[Lh0cZg>01@0cZg>0P0000140=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI0400fMWI0P00000H0<j]cP030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh06@3>
[Lh00`000000cZg>0<j]cP0F0<j]cP800000@P3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT0
0`000000fMWI0=WIf@0o0=WIf@030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh06@3>[Lh0
0`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01P0cZg>00<000000=WIf@3IfMT0?`3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0m0=WIf@8000006`3>[Lh00`00
0000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh06@3>[Lh20000
03l0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0>`3IfMT2000001h0
cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>01`0
cZg>0P00000m0=WIf@030000003IfMT0fMWI03<0fMWI000Q0=WIf@@000000`3IfMT3000000T0fMWI
00<000000=WIf@3IfMT0>P3IfMT00`000000cZg>0000000N0<j]cP030000003>[Lh0cZg>01P0cZg>
00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0000003`0fMWI
00<000000=WIf@3IfMT0<`3IfMT002D0fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI03P0fMWI0P0000030<j]cP030000003>[Lh0cZg>01/0cZg>00<0
00000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>01/0cZg>00@0
00000<j]cP3>[Lh0cZg>0P00000j0=WIf@030000003IfMT0fMWI03<0fMWI000U0=WIf@030000003I
fMT0000000<0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0f0=WIf@8000001P3>
[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh05`3>
[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>00@0cZg>0P00000h0=WIf@030000003I
fMT0fMWI03<0fMWI000J0=WIf@L00000103IfMT00`000000fMWI000000030=WIf@030000003IfMT0
fMWI00H0fMWI0`00000e0=WIf@030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>[Lh06`3>[Lh0
0`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh06`3>[Lh0
0`000000cZg>0<j]cP060<j]cP030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0<`3IfMT0
02D0fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
03<0fMWI0P00000:0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`00
0000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh0203>[Lh20000
03D0fMWI00<000000=WIf@3IfMT0<`3IfMT00240fMWI100000020=WIf@050000003IfMT0fMWI0=WI
f@000000203IfMT00`000000fMWI0=WIf@0a0=WIf@800000303>[Lh00`000000cZg>0<j]cP0J0<j]
cP030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0J0<j]
cP030000003>[Lh0cZg>00X0cZg>0P00000c0=WIf@030000003IfMT0fMWI03<0fMWI000R0=WIf@03
0000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@030000003IfMT0fMWI
0300fMWI00<000000<j]cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>
01H0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>
00d0cZg>00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@008P3IfMT400000080
fMWI0`0000090=WIf@030000003IfMT0fMWI02h0fMWI0P00000A0<j]cP030000003>[Lh0cZg>01T0
cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01T0
cZg>00<000000<j]cP3>[Lh03`3>[Lh200000300fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI
00<000000=WIf@3IfMT0;@3IfMT00`000000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>01T0cZg>
00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01T0cZg>
00<000000<j]cP3>[Lh04@3>[Lh00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI03<0fMWI
000d0=WIf@030000003IfMT0fMWI02/0fMWI0P00000E0<j]cP030000003>[Lh0cZg>01P0cZg>00<0
00000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01P0cZg>00<0
00000<j]cP3>[Lh04`3>[Lh2000002d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT0:@3IfMT2000001L0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0E
0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0E
0<j]cP800000:`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0X0=WI
f@030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0E0<j]
cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0H0<j]
cP030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3I
fMT09P3IfMT2000001`0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0E0<j]cP03
0000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0J0<j]cP80
0000:03IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0T0=WIf@800000
7P3>[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0
5@3>[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01`0cZg>0P00000V0=WIf@030000
003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI02<0fMWI00<000000<j]cP3>[Lh07`3>
[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01@0cZg>00<000000<j]cP3>[Lh0503>
[Lh00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01l0cZg>00<000000=WIf@3IfMT08`3I
fMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0R0=WIf@030000003>[Lh0
cZg>0200cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0
cZg>01@0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0
fMWI0280fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT08P3IfMT20000
0280cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>
01@0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0P0<j]cP800000903IfMT00`00
0000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0Q0=WIf@040000003>[Lh0cZg>0000
0280cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>
01@0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP040000003>[Lh0cZg>
000002<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0803IfMT00`00
0000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>01l0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0C0<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0O0<j]cP030000003>[Lh0cZg>0080cZg>00<000000=WIf@3IfMT0803IfMT00`00
0000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0P0=WIf@030000003>[Lh0cZg>00<0
cZg>00<000000<j]cP3>[Lh07`3>[Lh00`000000cZg>0<j]cP0D0<j]cRl000005P3>[Lh00`000000
cZg>0<j]cP0O0<j]cP030000003>[Lh0cZg>00<0cZg>00<000000=WIf@3IfMT0803IfMT00`000000
fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0O0=WIf@030000003>[Lh0cZg>00D0cZg>
00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0B0<j]cP80000000<0cZg>0000003>[Lh0
503>[Lh00`000000cZg>0<j]cP0C0<j]cP040000003>[Lh00000000001@0cZg>00<000000<j]cP3>
[Lh07P3>[Lh00`000000cZg>0<j]cP050<j]cP030000003IfMT0fMWI01l0fMWI00<000000=WIf@3I
fMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000cZg>0<j]cP060<j]cP030000
003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh03`3>[Lh2000000<0cZg>00<000000<j]cP3>[Lh0
4`3>[Lh00`000000cZg>0<j]cP0C0<j]cP040000003>[Lh0cZg>0<j]cP8000004@3>[Lh00`000000
cZg>0<j]cP0N0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000=WIf@3IfMT07`3IfMT00`000000
fMWI0=WIf@0c0=WIf@00=03IfMT2000001l0fMWI00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>
0<j]cP0N0<j]cP030000003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh0103>[Lh00`000000cZg>
0<j]cP0B0<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh0103>[Lh00`000000cZg>
0<j]cP0=0<j]cP030000003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000fMWI
0=WIf@0N0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01d0fMWI00<0
00000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00/0cZg>0P00
00070<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]
cP050<j]cP8000003@3>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00X0cZg>00<0
00000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0M
0=WIf@030000003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh07@3>[Lh00`000000cZg>0<j]cP08
0<j]cP8000002@3>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>0180cZg>00<00000
0<j]cP3>[Lh01`3>[Lh2000000X0cZg>00<000000<j]cP3>[Lh07@3>[Lh00`000000cZg>0<j]cP0;
0<j]cP030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WI
f@3IfMT0703IfMT00`000000cZg>0<j]cP0=0<j]cP030000003>[Lh0cZg>01`0cZg>00<000000<j]
cP3>[Lh01P3>[Lh2000000`0cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0A0<j]
cP030000003>[Lh0cZg>00X0cZg>0P0000080<j]cP030000003>[Lh0cZg>01`0cZg>00<000000<j]
cP3>[Lh03@3>[Lh00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000<j]cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0L0<j]cP03
0000003>[Lh0cZg>00<0cZg>0P00000>0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>
[Lh04@3>[Lh00`000000cZg>0<j]cP0<0<j]cP8000001@3>[Lh00`000000cZg>0<j]cP0L0<j]cP03
0000003>[Lh0cZg>00h0cZg>00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0c0=WIf@00
=03IfMT00`000000fMWI0=WIf@0K0=WIf@030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0
703>[Lh01@000000cZg>0<j]cP3>[Lh000000100cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000
cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00h0cZg>00D000000<j]cP3>[Lh0cZg>0000000N0<j]
cP030000003>[Lh0cZg>0100cZg>00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0c0=WI
f@00=03IfMT00`000000fMWI0=WIf@0J0=WIf@030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>
[Lh06`3>[Lh010000000cZg>00000000000A0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]
cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0?0<j]cP80000000<0cZg>0000003>[Lh0703>[Lh00`00
0000cZg>0<j]cP0B0<j]cP030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0
fMWI00<000000=WIf@3IfMT06P3IfMT00`000000cZg>0<j]cP0C0<j]cP030000003>[Lh0cZg>01X0
cZg>0P00000D0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000
cZg>0<j]cP0B0<j]cP800000703>[Lh00`000000cZg>0<j]cP0C0<j]cP030000003IfMT0fMWI01X0
fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000cZg>
0<j]cP0E0<j]cP030000003>[Lh0cZg>01L0cZg>0P0000000`3>[Lh000000<j]cP0C0<j]cP030000
003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0B0<j]cP040000
003>[Lh00000000001T0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000fMWI0=WIf@0I0=WIf@03
0000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01P0fMWI00<000000<j]cP3>[Lh0
5`3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>0080cZg>00<000000<j]cP3>[Lh0
4@3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0
4@3>[Lh00`000000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0
5`3>[Lh00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI01P0fMWI00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0B0<j]cP8000001@3>
[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh03`3>
[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00<0cZg>0P00000D0<j]cP030000003>
[Lh0cZg>01P0cZg>00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT0
0`000000fMWI0=WIf@0G0=WIf@030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh03`3>[Lh2
000000P0cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0
cZg>00l0cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP060<j]cP8000004@3>[Lh0
0`000000cZg>0<j]cP0J0<j]cP030000003IfMT0fMWI04d0fMWI000d0=WIf@030000003IfMT0fMWI
01L0fMWI00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0<0<j]cP8000002P3>[Lh00`00
0000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`00
0000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00P0cZg>0P00000>0<j]cP030000003>[Lh0cZg>
01/0cZg>00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000
fMWI0=WIf@0F0=WIf@030000003>[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000
cZg>0<j]cP0;0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh03P3>[Lh00`000000
cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000
cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>01d0cZg>00<000000=WIf@3IfMT05P3IfMT00`000000
fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0E0=WIf@030000003>[Lh0cZg>01l0cZg>
00<000000<j]cP3>[Lh01`3>[Lh2000000l0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>
0<j]cP0>0<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>
0<j]cP0=0<j]cP8000002@3>[Lh00`000000cZg>0<j]cP0O0<j]cP030000003IfMT0fMWI01D0fMWI
00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000cZg>0<j]
cP0P0<j]cP030000003>[Lh0cZg>00@0cZg>0P00000A0<j]cP030000003>[Lh0cZg>0100cZg>00<0
00000<j]cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>0100cZg>00<0
00000<j]cP3>[Lh03`3>[Lh2000000H0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WI
f@0E0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01@0fMWI00<00000
0<j]cP3>[Lh08P3>[Lh00`000000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>0180cZg>00<00000
0<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>00h0cZg>00<00000
0<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>0080cZg>00<00000
0<j]cP3>[Lh08P3>[Lh00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WI
f@030000003IfMT0fMWI01@0fMWI00<000000<j]cP3>[Lh08`3>[Lh010000000cZg>00000000000E
0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0=
0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh04`3>[Lh2000000030<j]cP000000
cZg>02@0cZg>00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`00
0000fMWI0=WIf@0C0=WIf@030000003>[Lh0cZg>02D0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`00
0000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`00
0000fMWI0=WIf@190=WIf@00=03IfMT2000001<0fMWI0P00000W0<j]cP8000005`3>[Lh00`000000
cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000
cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>01D0cZg>0P00000X0<j]cP030000003IfMT0fMWI0180
fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT04P3IfMT010000000cZg>
00000000000T0<j]cP040000003>[Lh0cZg>000001L0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`00
0000cZg>0<j]cP0<0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`00
0000cZg>0<j]cP0E0<j]cP040000003>[Lh0cZg>000002@0cZg>0P0000000`3>[Lh000000=WIf@0C
0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI0140fMWI00<000000<j]
cP3>[Lh00P3>[Lh00`000000cZg>0<j]cP0Q0<j]cP050000003>[Lh0cZg>0<j]cP0000005P3>[Lh0
0`000000cZg>0<j]cP0>0<j]cR400000403>[Lh00`000000cZg>0<j]cP0D0<j]cP050000003>[Lh0
cZg>0<j]cP0000008`3>[Lh00`000000cZg>0<j]cP020<j]cP030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000cZg>0<j]cP03
0<j]cP800000803>[Lh00`000000cZg>0<j]cP030<j]cP030000003>[Lh0cZg>01@0cZg>00<00000
0<j]cP3>[Lh0303>[Lh00`000000cZg>0000000>0<j]cP030000003>[Lh0cZg>00`0cZg>00<00000
0<j]cP0000003P3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>00<0cZg>00<00000
0<j]cP3>[Lh07P3>[Lh2000000D0cZg>00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0c
0=WIf@00=03IfMT00`000000fMWI0=WIf@0@0=WIf@030000003>[Lh0cZg>00H0cZg>0P00000M0<j]
cP030000003>[Lh0cZg>00D0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]cP0:0<j]
cP8000000P3>[Lh00`000000cZg>0<j]cP0<0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000<j]
cP3>[Lh00P00000<0<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`00
0000cZg>0<j]cP0K0<j]cP800000203>[Lh00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
03<0fMWI000d0=WIf@030000003IfMT0fMWI00l0fMWI00<000000<j]cP3>[Lh02@3>[Lh00`000000
cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000
cZg>0<j]cP070<j]cP8000001@3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003>[Lh0cZg>00/0
cZg>00<000000<j]cP3>[Lh00`3>[Lh2000000T0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000
cZg>0<j]cP060<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh02@3>[Lh00`000000
fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00l0fMWI
00<000000<j]cP3>[Lh02P3>[Lh2000001T0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>
0<j]cP0C0<j]cP030000003>[Lh0cZg>00D0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000cZg>
0<j]cP0;0<j]cP030000003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000cZg>
0<j]cP050<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>
0<j]cP0G0<j]cP800000303>[Lh00`000000fMWI0=WIf@150=WIf@00=03IfMT00`000000fMWI0=WI
f@0>0=WIf@030000003>[Lh0cZg>00d0cZg>0P00000G0<j]cP030000003>[Lh0cZg>00T0cZg>00<0
00000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]cP030<j]cP800000203>[Lh00`000000cZg>0<j]
cP0;0<j]cP030000003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh01P3>[Lh2000000D0cZg>00<0
00000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>01D0cZg>0P00
000?0<j]cP030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT03P3IfMT00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>01<0cZg>00<00000
0<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>008000002`3>[Lh0
0`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh02@3>[Lh2
00000080cZg>00<000000<j]cP3>[Lh04P3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003>[Lh0
cZg>01<0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0
fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00d0fMWI00<000000<j]cP3>[Lh04@3>[Lh20000
0180cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0A0<j]cP030000003>[Lh00000
00d0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>
00/0cZg>00<000000<j]cP0000004`3>[Lh00`000000cZg>0<j]cP0=0<j]cP030000003>[Lh0cZg>
0100cZg>0P00000C0<j]cP030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0
fMWI00<000000=WIf@3IfMT03@3IfMT00`000000cZg>0<j]cP0C0<j]cP800000403>[Lh00`000000
cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>0100cZg>0P00000>0<j]cP030000003>[Lh0cZg>00X0
cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0<0<j]cP8000004P3>[Lh00`000000
cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>00h0cZg>0P00000E0<j]cP030000003IfMT0fMWI00d0
fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0303IfMT00`000000cZg>
0<j]cP0F0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>
0<j]cP0=0<j]cP80000000<0cZg>0000003>[Lh03@3>[Lh00`000000cZg>0<j]cP0:0<j]cP030000
003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh0303>[Lh010000000cZg>00000000000?0<j]cP03
0000003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh0303>[Lh00`000000cZg>0<j]cP0F0<j]cP03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
303IfMT00`000000cZg>0<j]cP0G0<j]cP800000303>[Lh00`000000cZg>0<j]cP0A0<j]cP030000
003>[Lh0cZg>00X0cZg>0P0000040<j]cP030000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh0
2@3>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh0
0P3>[Lh2000000`0cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0:0<j]cP800000
6@3>[Lh00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI00/0fMWI00<000000<j]cP3>[Lh06P3>[Lh2000000T0cZg>00<000000<j]cP3>[Lh04`3>
[Lh00`000000cZg>0<j]cP070<j]cP8000001`3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003>
[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh02@3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000003>
[Lh0cZg>00D0cZg>0P0000090<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh01`3>
[Lh2000001`0cZg>00<000000=WIf@3IfMT0@@3IfMT003@0fMWI00<000000=WIf@3IfMT02P3IfMT0
0`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>[Lh0503>[Lh0
0`000000cZg>0<j]cP050<j]cP030000003>[Lh0cZg>00L0cZg>00<000000<j]cP3>[Lh02`3>[Lh0
0`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh02`3>[Lh0
0`000000cZg>0<j]cP070<j]cP030000003>[Lh0cZg>00D0cZg>00<000000<j]cP3>[Lh0503>[Lh0
0`000000cZg>0<j]cP060<j]cP030000003>[Lh0cZg>01d0cZg>00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003>[Lh0cZg>
01h0cZg>0P0000050<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh00P3>[Lh20000
00/0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>
00T0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP090<j]cP800000103>[Lh00`00
0000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>00<0cZg>0P00000P0<j]cP030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
cZg>0<j]cP0Q0<j]cP8000000P3>[Lh00`000000cZg>0<j]cP0H0<j]cP040000003>[Lh000000000
00d0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP080<j]cP030000003>[Lh0cZg>
00P0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP0;0<j]cP80000000<0cZg>0000
003>[Lh06@3>[Lh00`000000cZg>0<j]cP02000002<0cZg>00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@090=WIf@030000003>[Lh0cZg>02<0
cZg>00<000000<j]cP0000006`3>[Lh00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>00X0
cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP080<j]cP030000003>[Lh0cZg>00X0
cZg>00<000000<j]cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0000002D0
cZg>00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@080=WIf@030000003>[Lh0cZg>02D0cZg>0P00000K0<j]cP800000403>[Lh00`000000cZg>
0<j]cP090<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>
0<j]cP090<j]cP030000003>[Lh0cZg>00h0cZg>0P00000L0<j]cP030000003>[Lh0cZg>02D0cZg>
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WI
f@080=WIf@030000003>[Lh0cZg>02D0cZg>00@000000<j]cP0000000000603>[Lh010000000cZg>
0<j]cP00000?0<j]cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh01`3>[Lh00`000000
cZg>0<j]cP070<j]cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh03@3>[Lh010000000
cZg>0<j]cP00000H0<j]cP80000000<0cZg>0000003>[Lh09P3>[Lh00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI03<0fMWI000d0=WIf@800000203IfMT00`000000cZg>0<j]cP0U0<j]cP03
0000003>[Lh0cZg>0080cZg>0P00000F0<j]cP050000003>[Lh0cZg>0<j]cP0000003`3>[Lh00`00
0000cZg>0<j]cP080<j]cQL000002P3>[Lh00`000000cZg>0<j]cP0=0<j]cP050000003>[Lh0cZg>
0<j]cP0000005P3>[Lh2000000@0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000fMWI0=WIf@0m
0=WIf@00=03IfMT00`000000fMWI0=WIf@070=WIf@030000003>[Lh0cZg>02D0cZg>00<000000<j]
cP3>[Lh0103>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00<0cZg>00<000000<j]
cP3>[Lh0303>[Lh00`000000cZg>0<j]cP060<j]cP8000005`3IfMT2000000P0cZg>00<000000<j]
cP3>[Lh0303>[Lh00`000000cZg>0<j]cP030<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]
cP3>[Lh0103>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000cZg>0<j]cP0U0<j]cP03
0000003>[Lh0cZg>00H0cZg>0P00000B0<j]cP030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>
[Lh0303>[Lh00`000000cZg>0<j]cP030<j]cP8000006`3IfMT2000000D0cZg>00<000000<j]cP3>
[Lh0303>[Lh00`000000cZg>0<j]cP040<j]cP030000003>[Lh0cZg>0100cZg>0P0000080<j]cP03
0000003>[Lh0cZg>02D0cZg>00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0c0=WIf@00
=03IfMT00`000000fMWI0=WIf@050=WIf@030000003>[Lh0cZg>02D0cZg>00<000000<j]cP3>[Lh0
2@3>[Lh2000000l0cZg>00<000000<j]cP3>[Lh01P3>[Lh00`000000cZg>0<j]cP0<0<j]cP050000
003>[Lh0cZg>0<j]cP0000007`3IfMT01@000000cZg>0<j]cP3>[Lh0000000h0cZg>00<000000<j]
cP3>[Lh01P3>[Lh00`000000cZg>0<j]cP0=0<j]cP8000002`3>[Lh00`000000cZg>0<j]cP0U0<j]
cP030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000cZg>0<j]cP0U0<j]cP030000003>[Lh0cZg>00/0cZg>0P00000<0<j]cP03
0000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh02`3>[Lh010000000cZg>00000000000Q0=WI
f@80000000<0cZg>0000003>[Lh0303>[Lh00`000000cZg>0<j]cP080<j]cP030000003>[Lh0cZg>
00X0cZg>0P00000=0<j]cP030000003>[Lh0cZg>02D0cZg>00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@040=WIf@030000003>[Lh0cZg>02D0
cZg>00<000000<j]cP3>[Lh03P3>[Lh2000000X0cZg>00<000000<j]cP3>[Lh02@3>[Lh00`000000
cZg>0<j]cP0:0<j]cP8000009@3IfMT2000000`0cZg>00<000000<j]cP3>[Lh02@3>[Lh00`000000
cZg>0<j]cP080<j]cP800000403>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000cZg>
0<j]cP0U0<j]cP030000003>[Lh0cZg>0100cZg>0P0000070<j]cP030000003>[Lh0cZg>00/0cZg>
00<000000<j]cP3>[Lh01`3>[Lh2000002T0fMWI0P0000090<j]cP030000003>[Lh0cZg>00/0cZg>
00<000000<j]cP3>[Lh01@3>[Lh200000180cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI0`00
000U0<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh0103>[Lh00`000000cZg>0<j]
cP0<0<j]cP030000003>[Lh0cZg>00@0cZg>0P00000]0=WIf@8000001P3>[Lh00`000000cZg>0<j]
cP0<0<j]cP030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]
cP0S0<j]cP<000001@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@03
0=WIf@030000003>[Lh0cZg>00@000008@3>[Lh00`000000cZg>0<j]cP0D0<j]cP8000000`3>[Lh0
0`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>0080cZg>00<000000=WIf@3IfMT0;`3IfMT0
0`000000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>00h0cZg>00@000000<j]cP3>[Lh0cZg>0P00
000F0<j]cP030000003>[Lh0cZg>01l0cZg>100000020<j]cP030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP04
0<j]cP@00000703>[Lh00`000000cZg>0<j]cP0G0<j]cP80000000<0cZg>0000003>[Lh0403>[Lh0
10000000cZg>00000000000c0=WIf@80000000<0cZg>0000003>[Lh0403>[Lh010000000cZg>0000
0000000I0<j]cP030000003>[Lh0cZg>01X0cZg>100000060<j]cP030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]
cP080<j]cP@00000603>[Lh00`000000cZg>0<j]cP0I0<j]cP8000004P3>[Lh00`000000fMWI0=WI
f@0e0=WIf@030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]
cP0F0<j]cP@000002P3>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0303>[Lh4000001<0cZg>00<00000
0<j]cP3>[Lh06P3>[Lh010000000cZg>00000000000@0<j]cP030000003IfMT0fMWI03D0fMWI00<0
00000<j]cP3>[Lh03P3>[Lh2000000030<j]cP000000cZg>01/0cZg>00<000000<j]cP3>[Lh04@3>
[Lh4000000h0cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT0
0`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>0100cZg>0`00000?0<j]cP030000003>[Lh0
cZg>01X0cZg>00<000000<j]cP3>[Lh00P3>[Lh00`000000cZg>0<j]cP0<0<j]cP030000003IfMT0
fMWI03L0fMWI00<000000<j]cP3>[Lh0303>[Lh00`000000cZg>0<j]cP020<j]cP030000003>[Lh0
cZg>01X0cZg>00<000000<j]cP3>[Lh03@3>[Lh300000180cZg>00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>
01<0cZg>1000000;0<j]cP030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh0103>[Lh20000
00`0cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>0<j]cP0:0<j]cP8000001P3>[Lh00`00
0000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>00T0cZg>1000000E0<j]cP030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
cZg>0<j]cP0G0<j]cP@000001P3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>00H0
cZg>0P0000090<j]cP030000003IfMT0fMWI03T0fMWI00<000000<j]cP3>[Lh01`3>[Lh2000000P0
cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP040<j]cP@000006@3>[Lh00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000<j]cP3>[Lh06`3>[Lh400000080cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>
0<j]cP090<j]cP030000003>[Lh0cZg>00D0cZg>00<000000=WIf@3IfMT0>`3IfMT00`000000cZg>
0<j]cP050<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>
0<j]cP04000001d0cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03I
fMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>01l0cZg>1000000J0<j]cP030000003>
[Lh0cZg>00X0cZg>0P0000050<j]cP030000003IfMT0fMWI03/0fMWI00<000000<j]cP3>[Lh00`3>
[Lh2000000`0cZg>00<000000<j]cP3>[Lh0603>[Lh400000240cZg>00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0
cZg>0200cZg>00<000000<j]cP3>[Lh00`00000F0<j]cP030000003>[Lh0cZg>00d0cZg>0P000002
0<j]cP030000003IfMT0fMWI03d0fMWI00<000000<j]cP3>[Lh00P00000?0<j]cP030000003>[Lh0
cZg>01@0cZg>0`0000020<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>
0200cZg>00<000000<j]cP3>[Lh00`3>[Lh400000140cZg>00<000000<j]cP3>[Lh0403>[Lh00`00
0000cZg>0000000o0=WIf@030000003>[Lh000000180cZg>00<000000<j]cP3>[Lh03`3>[Lh40000
00D0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
03<0fMWI000d0=WIf@800000103IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>00L0
cZg>0`00000>0<j]cP030000003>[Lh0cZg>0140cZg>00<000000=WIf@3IfMT0?`3IfMT00`000000
cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00`0cZg>0`0000090<j]cP030000003>[Lh0cZg>0200
cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh02P3>[Lh3000000X0cZg>
00<000000<j]cP3>[Lh04P3>[Lh00`000000fMWI0=WIf@0o0=WIf@030000003>[Lh0cZg>0180cZg>
00<000000<j]cP3>[Lh0203>[Lh3000000`0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000<j]cP3>[Lh0803>[Lh00`000000cZg>0<j]cP0=0<j]cP@000001P3>[Lh00`000000cZg>0<j]
cP0A0<j]cP030000003IfMT0fMWI0440fMWI00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]
cP040<j]cP@000003`3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P
0<j]cP030000003>[Lh0cZg>0140cZg>0`0000020<j]cP030000003>[Lh0cZg>0180cZg>00<00000
0=WIf@3IfMT0@@3IfMT00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00<000004`3>[Lh0
0`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT0
03@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>
01@0cZg>1000000B0<j]cP030000003IfMT0fMWI04<0fMWI00<000000<j]cP3>[Lh0403>[Lh40000
01H0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0803>[Lh00`000000
cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>00<000003P3>[Lh00`000000fMWI0=WIf@150=WIf@03
0000003>[Lh0cZg>00`0cZg>0`0000020<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>
[Lh0803>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0803>[Lh00`000000cZg>0<j]cP0E0<j]cP030000
003>[Lh0cZg>00<0cZg>1000000:0<j]cP030000003IfMT0fMWI04D0fMWI00<000000<j]cP3>[Lh0
203>[Lh4000000D0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh01`3>
[Lh4000000D0cZg>00<000000=WIf@3IfMT0A`3IfMT00`000000cZg>0<j]cP030<j]cP@000002@3>
[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0
cZg>0200cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0;0<j]cP<000000P3>[Lh0
0`000000fMWI0=WIf@170=WIf@030000003>[Lh0cZg>00<000003@3>[Lh00`000000cZg>0<j]cP0E
0<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c
0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]
cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0>0<j]cP800000B`3IfMT200000100cZg>00<000000<j]
cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP03
0000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@03
0000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0
3`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh0
5@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>
[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>
[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh0
0`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh0
0`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT0
03@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>
01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>
00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000
fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000
cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT000l0fMWI
0`00000G0=WIf@<00000203IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>
00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003IfMT0fMWI04T0fMWI
00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00403IfMT00`000000fMWI0=WI
f@0E0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000
003IfMT0fMWI04T0fMWI00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000
003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00403I
fMT00`000000fMWI0=WIf@0E0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI
0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>
0<j]cP0?0<j]cP030000003IfMT0fMWI04T0fMWI00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>
0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0c0=WIf@00403IfMT00`000000fMWI0=WIf@0E0=WIf@050000003IfMT0fMWI0=WIf@000000
1`3IfMT3000000<0fMWICP00001;0=WIfDh000001@3IfMT00`000000fMWI0=WIf@0c0=WIf@003`3I
fMT00`000000fMWI0000000F0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI
0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>
0<j]cP0?0<j]cP030000003IfMT0fMWI04T0fMWI00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>
0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0c0=WIf@003`3IfMT00`000000fMWI0000000F0=WIf@050000003IfMT0fMWI0=WIf@000000
1`3IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh0
5@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003IfMT0fMWI04T0fMWI00<000000<j]cP3>[Lh0
3`3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@0c0=WIf@003P3IfMT01@000000fMWI0=WIf@3IfMT0000001D0fMWI
00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>
[Lh0803>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000=WIf@3I
fMT0B@3IfMT00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>
[Lh0803>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000=0=WIf@<00000
00@0fMWI00000000000000005@3IfMT3000000P0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000
fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000
cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>
00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>
00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]
cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WI
f@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]
cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<00000
0<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<00000
0<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]
cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000fMWI0=WIf@190=WI
f@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]
cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>
[Lh03`3>[Lh00`000000fMWI0=WIf@190=WIf@030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>
[Lh05@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000
003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh03@3>[Lh3000004/0fMWI0`00000?0<j]cP030000
003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh0803>
[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>00X0cZg>0`0000020<j]cP030000003I
fMT0fMWI04T0fMWI0`3>[Lh3000000`0cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]
cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>01D0cZg>00<00000
0<j]cP3>[Lh01P3>[Lh4000000H0cZg>00<000000=WIf@3IfMT0A`3IfMT00`000000cZg>0<j]cP04
0<j]cP@00000203>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>0200cZg>00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WI
f@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP020<j]
cP@000002P3>[Lh00`000000fMWI0=WIf@170=WIf@030000003>[Lh0cZg>00P0cZg>100000040<j]
cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>
[Lh0803>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh00000008000003`3>[Lh00`000000
fMWI0=WIf@150=WIf@030000003>[Lh0cZg>00d0cZg>0`0000000`3>[Lh000000<j]cP0F0<j]cP03
0000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00
=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh0
4`3>[Lh4000001<0cZg>00<000000=WIf@3IfMT0@`3IfMT00`000000cZg>0<j]cP0A0<j]cP@00000
5@3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>
[Lh0cZg>0100cZg>0`0000020<j]cP030000003>[Lh0cZg>0180cZg>00<000000=WIf@3IfMT0@`3I
fMT00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00<000004P3>[Lh00`000000cZg>0<j]
cP0P0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>00`0cZg>10000006
0<j]cP030000003>[Lh0cZg>0180cZg>00<000000=WIf@3IfMT0@@3IfMT00`000000cZg>0<j]cP0B
0<j]cP030000003>[Lh0cZg>00@0cZg>1000000>0<j]cP030000003>[Lh0cZg>0200cZg>00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WI
f@030000003>[Lh0cZg>0200cZg>00<000000<j]cP3>[Lh02@3>[Lh3000000/0cZg>00<000000<j]
cP3>[Lh04@3>[Lh00`000000fMWI0=WIf@110=WIf@030000003>[Lh0cZg>0140cZg>00<000000<j]
cP3>[Lh02@3>[Lh3000000/0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI03<0fMWI000d0=WIf@800000103IfMT00`000000cZg>0<j]cP0P0<j]cP03
0000003>[Lh0cZg>00H0cZg>0`00000>0<j]cP030000003>[Lh0cZg>0140cZg>0P0000110=WIf@80
00004`3>[Lh00`000000cZg>0<j]cP0<0<j]cP<00000203>[Lh00`000000cZg>0<j]cP0P0<j]cP03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>0080cZg>1000000B0<j]cP030000
003>[Lh0cZg>00h0cZg>0P0000000`3>[Lh000000=WIf@100=WIf@80cZg>0P00000@0<j]cP030000
003>[Lh0cZg>0100cZg>100000040<j]cP030000003>[Lh0cZg>0200cZg>00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@030=WIf@030000003>
[Lh0cZg>0200cZg>00<000000<j]cP0000000P00000F0<j]cP030000003>[Lh0cZg>00d0cZg>00<0
00000<j]cP3>[Lh00P3>[Lh00`000000fMWI0=WIf@0m0=WIf@030000003>[Lh0cZg>0080cZg>00<0
00000<j]cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0D0<j]cP<0000000<0cZg>0000003>[Lh08@3>
[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0
fMWI00<0fMWI00<000000<j]cP3>[Lh07P3>[Lh4000001X0cZg>00<000000<j]cP3>[Lh02P3>[Lh2
000000D0cZg>00<000000=WIf@3IfMT0?@3IfMT00`000000cZg>0<j]cP030<j]cP800000303>[Lh0
0`000000cZg>0<j]cP0H0<j]cP@00000803>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00<0fMWI00<000000<j]cP3>[Lh06P3>[Lh40000
0080cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP070<j]cP800000203>[Lh00`00
0000fMWI0=WIf@0k0=WIf@030000003>[Lh0cZg>00H0cZg>0P0000090<j]cP030000003>[Lh0cZg>
01X0cZg>00<000000<j]cP3>[Lh01000000L0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0F0<j]cP@0
00001`3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>
[Lh02@3>[Lh00`000000fMWI0=WIf@0i0=WIf@030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>
[Lh01P3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>00D0cZg>1000000H0<j]cP03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000cZg>0<j]cP0B0<j]cP@000002`3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000
003>[Lh0cZg>00<0cZg>0P00000<0<j]cP030000003IfMT0fMWI03T0fMWI00<000000<j]cP3>[Lh0
2P3>[Lh2000000D0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP090<j]cP@00000
503>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000<j]cP3>[Lh03P3>[Lh400000100cZg>00<000000<j]cP3>[Lh06@3>
[Lh010000000cZg>0<j]cP3>[Lh2000000l0cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>
0<j]cP0=0<j]cP8000000`3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>00h0cZg>
1000000@0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000cZg>0<j]cP0;0<j]cP<000005@3>[Lh00`000000cZg>0<j]
cP0I0<j]cP030000003>[Lh000000140cZg>00<000000=WIf@3IfMT0=`3IfMT00`000000cZg>0<j]
cP0A0<j]cP030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh04`3>[Lh3000000d0cZg>00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@03
0=WIf@030000003>[Lh0cZg>00L0cZg>1000000H0<j]cP030000003>[Lh0cZg>01T0cZg>0P00000C
0<j]cP800000=@3IfMT2000001<0cZg>0P00000K0<j]cP030000003>[Lh0cZg>01H0cZg>10000009
0<j]cP030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000cZg>0<j]cP030<j]cP@000007@3>[Lh00`000000cZg>0<j]cP0F0<j]
cP80000000<0cZg>0000003>[Lh04@3>[Lh00`000000cZg>0<j]cP0200000340fMWI0P0000020<j]
cP030000003>[Lh0cZg>0100cZg>00@000000<j]cP0000000000603>[Lh00`000000cZg>0<j]cP0K
0<j]cP@000001@3>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000<j]cP0000000`00000Q0<j]cP030000003>[Lh0cZg>
01@0cZg>0P0000040<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh00`3>[Lh20000
02d0fMWI0P0000050<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh00P3>[Lh20000
01H0cZg>00<000000<j]cP3>[Lh07`3>[Lh4000000030<j]cP000000fMWI00@0fMWI00<000000=WI
f@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT00`3IfMT2000002H0cZg>00<000000<j]cP3>
[Lh04P3>[Lh00`000000cZg>0<j]cP040<j]cP030000003>[Lh0cZg>00d0cZg>00<000000<j]cP3>
[Lh01P3>[Lh00`000000fMWI0=WIf@0Y0=WIf@030000003>[Lh0cZg>00H0cZg>00<000000<j]cP3>
[Lh03@3>[Lh00`000000cZg>0<j]cP040<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>
[Lh0903>[Lh2000000D0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000cZg>0<j]cP0U0<j]cP030000003>[Lh0cZg>0100cZg>0P0000080<j]cP030000
003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh0203>[Lh2000002L0fMWI0P00000:0<j]cP030000
003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh01P3>[Lh200000180cZg>00<000000<j]cP3>[Lh0
9@3>[Lh00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000<j]cP3>[Lh09@3>[Lh00`000000cZg>0<j]cP0=0<j]cP8000002P3>
[Lh00`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>00/0cZg>0P00000S0=WIf@8000003@3>
[Lh00`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>00P0cZg>0P00000?0<j]cP030000003>
[Lh0cZg>02D0cZg>00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT0
0`000000fMWI0=WIf@040=WIf@030000003>[Lh0cZg>02D0cZg>00<000000<j]cP3>[Lh02`3>[Lh2
000000d0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP0>0<j]cP8000007`3IfMT2
000000030<j]cP000000cZg>00d0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>0<j]cP0;
0<j]cP8000003@3>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000cZg>0<j]cP0U0<j]
cP030000003>[Lh0cZg>00P0cZg>0P00000@0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000<j]
cP3>[Lh0303>[Lh00`000000cZg>0<j]cP020<j]cP8000006`3IfMT2000000@0cZg>00<000000<j]
cP3>[Lh0303>[Lh00`000000cZg>0<j]cP060<j]cP030000003>[Lh0cZg>00h0cZg>0P00000:0<j]
cP030000003>[Lh0cZg>02D0cZg>00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0c0=WI
f@00=03IfMT00`000000fMWI0=WIf@060=WIf@030000003>[Lh0cZg>02D0cZg>00<000000<j]cP3>
[Lh01@3>[Lh200000180cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000cZg>0<j]cP0<0<j]cP03
0000003>[Lh0cZg>00D0cZg>00<000000=WIf@3IfMT05`3IfMT00`000000cZg>0<j]cP050<j]cP03
0000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000cZg>0<j]cP0@0<j]cP80
00001`3>[Lh00`000000cZg>0<j]cP0U0<j]cP030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000cZg>0<j]cP0U0<j]cP030000
003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]cP030<j]cP030000
003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh01P3>[Lh2000001D0fMWI0P0000080<j]cP030000
003>[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh00`3>[Lh00`000000cZg>0<j]cP0C0<j]cP030000
003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh09@3>[Lh00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI03<0fMWI000d0=WIf@800000203IfMT00`000000cZg>0<j]cP0U0<j]cP040000003>
[Lh0cZg>0<j]cP8000005P3>[Lh00`000000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>00d0cZg>
00<000000<j]cP3>[Lh02@3>[LhE000000/0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000cZg>
0<j]cP020<j]cP030000003>[Lh0cZg>01@0cZg>0P0000030<j]cP030000003>[Lh0cZg>02D0cZg>
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WI
f@070=WIf@030000003>[Lh0cZg>02D0cZg>00@000000<j]cP00000000006@3>[Lh010000000cZg>
0<j]cP00000@0<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh01`3>[Lh00`000000
cZg>0<j]cP070<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh03P3>[Lh010000000
cZg>0<j]cP00000I0<j]cP040000003>[Lh0cZg>000002L0cZg>00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@080=WIf@030000003>[Lh0cZg>
02@0cZg>0P00000K0<j]cP030000003>[Lh000000100cZg>00<000000<j]cP3>[Lh02P3>[Lh00`00
0000cZg>0<j]cP070<j]cP030000003>[Lh0cZg>00L0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`00
0000cZg>0<j]cP0>0<j]cP030000003>[Lh0000001/0cZg>0P00000V0<j]cP030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
cZg>0<j]cP0R0<j]cP80000000<0cZg>0000003>[Lh06`3>[Lh2000000l0cZg>00<000000<j]cP3>
[Lh02P3>[Lh00`000000cZg>0<j]cP080<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>
[Lh02P3>[Lh00`000000cZg>0<j]cP0=0<j]cP800000703>[Lh010000000cZg>00000000000T0<j]
cP030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>0080cZg>00<000000<j]cP3>
[Lh0603>[Lh00`000000cZg>0<j]cP02000000d0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000
cZg>0<j]cP080<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000
cZg>0<j]cP0;0<j]cP8000000P3>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>0080
cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI03<0
fMWI000d0=WIf@030000003IfMT0fMWI00T0fMWI00<000000<j]cP3>[Lh07P3>[Lh2000000D0cZg>
00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP030<j]cP8000002P3>[Lh00`000000cZg>
0<j]cP0;0<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh0203>[Lh00`000000cZg>
0<j]cP0;0<j]cP030000003>[Lh0cZg>00P0cZg>0P0000050<j]cP030000003>[Lh0cZg>01L0cZg>
00<000000<j]cP3>[Lh00`3>[Lh200000200cZg>00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003>[Lh0cZg>01/0cZg>0P00
00080<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh01P3>[Lh2000000P0cZg>00<0
00000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>00T0cZg>00<0
00000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP060<j]cP800000203>[Lh00`000000cZg>0<j]
cP0E0<j]cP030000003>[Lh0cZg>00H0cZg>0P00000M0<j]cP030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000cZg>0<j]cP0I
0<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]cP09
0<j]cP030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP09
0<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP04
0<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]cP09
0<j]cP030000003>[Lh0cZg>01T0cZg>00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0c
0=WIf@00=03IfMT00`000000fMWI0=WIf@0;0=WIf@030000003>[Lh0cZg>01L0cZg>0P00000<0<j]
cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh02`3>[Lh2000000<0cZg>00<000000<j]
cP3>[Lh0303>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]
cP3>[Lh0303>[Lh010000000cZg>0<j]cP3>[Lh2000000d0cZg>00<000000<j]cP3>[Lh04P3>[Lh0
0`000000cZg>0<j]cP0:0<j]cP8000006@3>[Lh00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI00`0fMWI00<000000<j]cP3>[Lh0503>[Lh20000
00l0cZg>00<000000<j]cP3>[Lh0403>[Lh00`000000cZg>0<j]cP0>0<j]cP80000000<0cZg>0000
003>[Lh03@3>[Lh00`000000cZg>0<j]cP090<j]cP030000003>[Lh0cZg>00T0cZg>00<000000<j]
cP3>[Lh0303>[Lh010000000cZg>00000000000@0<j]cP030000003>[Lh0cZg>0100cZg>00<00000
0<j]cP3>[Lh03@3>[Lh2000001H0cZg>00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0c
0=WIf@00=03IfMT00`000000fMWI0=WIf@0<0=WIf@030000003>[Lh0cZg>01<0cZg>00<000000<j]
cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>0140cZg>0P00000=0<j]
cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0;0<j]
cP8000004`3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]
cP3>[Lh04`3>[Lh00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@03
0000003IfMT0fMWI00d0fMWI00<000000<j]cP3>[Lh0403>[Lh2000001<0cZg>00<000000<j]cP3>
[Lh03@3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP3>
[Lh02P3>[Lh00`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>00X0cZg>00<000000<j]cP00
0000503>[Lh00`000000cZg>0<j]cP0=0<j]cP030000003>[Lh0cZg>0140cZg>0P00000B0<j]cP03
0000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
3@3IfMT00`000000cZg>0<j]cP0>0<j]cP8000005P3>[Lh00`000000cZg>0<j]cP0;0<j]cP030000
003>[Lh0cZg>0180cZg>00@000000<j]cP3>[Lh0cZg>0P00000:0<j]cP030000003>[Lh0cZg>00X0
cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP080<j]cP8000000`3>[Lh00`000000
cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh0503>[Lh200000100
cZg>00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@0>0=WIf@030000003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>
0<j]cP0:0<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh00`3>[Lh2000000P0cZg>
00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>0<j]cP0:0<j]cP030000003>[Lh0cZg>00H0cZg>
0P0000050<j]cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh02P3>[Lh00`000000cZg>
0<j]cP0F0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000=WIf@3IfMT03P3IfMT00`000000fMWI
0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0>0=WIf@030000003>[Lh0cZg>00X0cZg>0P00
000J0<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]
cP060<j]cP030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]
cP0;0<j]cP030000003>[Lh0cZg>00@0cZg>00<000000<j]cP3>[Lh01P3>[Lh00`000000cZg>0<j]
cP0C0<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh0603>[Lh2000000`0cZg>00<0
00000=WIf@3IfMT0A03IfMT003@0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000cZg>0<j]cP07
0<j]cP800000703>[Lh00`000000cZg>0<j]cP070<j]cP030000003>[Lh0cZg>01@0cZg>00<00000
0<j]cP3>[Lh01`3>[Lh2000000@0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP0;
0<j]cP030000003>[Lh0cZg>0080cZg>0P0000090<j]cP030000003>[Lh0cZg>01@0cZg>00<00000
0<j]cP3>[Lh01`3>[Lh00`000000cZg>0<j]cP0J0<j]cP8000002@3>[Lh00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI0100fMWI00<000000<j]
cP3>[Lh01@3>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00D0cZg>00<000000<j]
cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0:0<j]cP8000000P3>[Lh00`000000cZg>0<j]cP0;0<j]
cP030000003>[Lh0cZg>00/0cZg>00<000000<j]cP3>[Lh00P00000<0<j]cP030000003>[Lh0cZg>
01@0cZg>00<000000<j]cP3>[Lh01@3>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>
00D0cZg>00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003>[Lh0cZg>00<0cZg>0P00000P0<j]cP030000003>[Lh0cZg>00@0
cZg>00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0=0<j]cP8000003P3>[Lh00`000000
cZg>0<j]cP0<0<j]cP8000003`3>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>00@0
cZg>00<000000<j]cP3>[Lh07P3>[Lh2000000D0cZg>00<000000=WIf@3IfMT0403IfMT00`000000
fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0A0=WIf@030000003>[Lh0cZg>00800000
8`3>[Lh00`000000cZg>0<j]cP020<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0
3P3>[LhO00000100cZg>00<000000<j]cP3>[Lh05@3>[Lh00`000000cZg>0<j]cP020<j]cP030000
003>[Lh0cZg>0240cZg>0P0000020<j]cP030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0
<`3IfMT003@0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000cZg>0000000V0<j]cP040000003>
[Lh0cZg>000001L0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0<0<j]cP030000
003>[Lh0cZg>00`0cZg>00<000000<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0E0<j]cP040000
003>[Lh0cZg>000002P0cZg>00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0c0=WIf@00
=03IfMT2000001<0fMWI00<000000<j]cP3>[Lh09@3>[Lh00`000000cZg>0000000H0<j]cP030000
003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh0303>[Lh00`000000cZg>0<j]cP0<0<j]cP030000
003>[Lh0cZg>00l0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0000000W0<j]cP030000
003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT04P3I
fMT00`000000cZg>0<j]cP0V0<j]cP8000005`3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>
[Lh0cZg>00d0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>
[Lh0cZg>01D0cZg>0P00000X0<j]cP030000003IfMT0fMWI04P0fMWI000d0=WIf@030000003IfMT0
fMWI01<0fMWI00<000000<j]cP3>[Lh0903>[Lh00`000000cZg>0<j]cP02000001D0cZg>00<00000
0<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0=0<j]cP030000003>[Lh0cZg>00d0cZg>00<00000
0<j]cP3>[Lh03`3>[Lh00`000000cZg>0<j]cP0C0<j]cP8000000P3>[Lh00`000000cZg>0<j]cP0T
0<j]cP030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WI
f@3IfMT0503IfMT00`000000cZg>0<j]cP0R0<j]cP030000003>[Lh0cZg>00<0cZg>00<000000<j]
cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>00d0cZg>00<000000<j]
cP3>[Lh03@3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]
cP3>[Lh00`3>[Lh00`000000cZg>0<j]cP0R0<j]cP030000003IfMT0fMWI01@0fMWI00<000000=WI
f@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0503IfMT00`000000cZg>0<j]cP0Q0<j]cP03
0000003>[Lh0cZg>00D0cZg>0P00000A0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>
[Lh03P3>[Lh00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>
[Lh03`3>[Lh2000000L0cZg>00<000000<j]cP3>[Lh08@3>[Lh00`000000fMWI0=WIf@0D0=WIf@03
0000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01D0fMWI00<000000<j]cP3>[Lh0
7`3>[Lh00`000000cZg>0<j]cP080<j]cP8000003P3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000
003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh03P3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000
003>[Lh0cZg>00`0cZg>0P00000:0<j]cP030000003>[Lh0cZg>01l0cZg>00<000000=WIf@3IfMT0
5@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0E0=WIf@030000003>
[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh02`3>[Lh2000000`0cZg>00<000000<j]cP3>[Lh0403>
[Lh00`000000cZg>0<j]cP0>0<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh0403>
[Lh00`000000cZg>0<j]cP0:0<j]cP8000003@3>[Lh00`000000cZg>0<j]cP0N0<j]cP030000003I
fMT0fMWI01D0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT05P3IfMT0
0`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh0203>[Lh0
0`000000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00h0cZg>00<000000<j]cP3>[Lh03P3>[Lh0
0`000000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00P0cZg>00<000000<j]cP3>[Lh03P3>[Lh0
0`000000cZg>0<j]cP0L0<j]cP030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0<`3IfMT0
03@0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>
0100cZg>0P0000070<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh03`3>[Lh00`00
0000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh01@3>[Lh20000
0180cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000fMWI0=WIf@1=0=WIf@00=03IfMT00`000000
fMWI0=WIf@0G0=WIf@030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh04`3>[Lh2000000D0
cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0?0<j]cP030000003>[Lh0cZg>00l0
cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP030<j]cP8000005@3>[Lh00`000000
cZg>0<j]cP0I0<j]cP030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI
00<000000=WIf@3IfMT0603IfMT00`000000cZg>0<j]cP0G0<j]cP030000003>[Lh0cZg>01H0cZg>
00D000000<j]cP3>[Lh0cZg>0000000D0<j]cP030000003>[Lh0cZg>00l0cZg>00<000000<j]cP3>
[Lh03`3>[Lh00`000000cZg>0<j]cP0B0<j]cP050000003>[Lh0cZg>0<j]cP000000603>[Lh00`00
0000cZg>0<j]cP0G0<j]cP030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0
fMWI00<000000=WIf@3IfMT0603IfMT00`000000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01P0
cZg>0P0000000`3>[Lh000000<j]cP0B0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>
[Lh0403>[Lh00`000000cZg>0<j]cP0A0<j]cP040000003>[Lh00000000001X0cZg>00<000000<j]
cP3>[Lh05P3>[Lh00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@03
0000003IfMT0fMWI01T0fMWI00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0K0<j]cP80
00004`3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000003>[Lh0cZg>0100cZg>00<000000<j]cP3>
[Lh04@3>[Lh2000001d0cZg>00<000000<j]cP3>[Lh0503>[Lh00`000000fMWI0=WIf@0I0=WIf@03
0000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01X0fMWI00<000000<j]cP3>[Lh0
4P3>[Lh00`000000cZg>0<j]cP0N0<j]cP8000004@3>[Lh00`000000cZg>0<j]cP0@0<j]cP030000
003>[Lh0cZg>0100cZg>00<000000<j]cP3>[Lh03`3>[Lh2000000030<j]cP000000cZg>01d0cZg>
00<000000<j]cP3>[Lh04P3>[Lh00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI03<0fMWI
000d0=WIf@030000003IfMT0fMWI01X0fMWI00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]
cP0L0<j]cP030000003>[Lh0cZg>0080cZg>0P00000>0<j]cP030000003>[Lh0cZg>0140cZg>00<0
00000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0<0<j]cP800000103>[Lh00`000000cZg>0<j]
cP0L0<j]cP030000003>[Lh0cZg>0140cZg>00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WI
f@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0K0=WIf@030000003>[Lh0cZg>00l0cZg>00<00000
0<j]cP3>[Lh0703>[Lh00`000000cZg>0<j]cP050<j]cP030000003>[Lh0cZg>00/0cZg>00<00000
0<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00/0cZg>00<00000
0<j]cP3>[Lh01@3>[Lh00`000000cZg>0<j]cP0L0<j]cP030000003>[Lh0cZg>00l0cZg>00<00000
0=WIf@3IfMT0D@3IfMT003@0fMWI00<000000=WIf@3IfMT0703IfMT00`000000cZg>0<j]cP0=0<j]
cP030000003>[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh01P3>[Lh2000000/0cZg>00<000000<j]
cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP0A0<j]cP030000003>[Lh0cZg>00T0cZg>0P0000080<j]
cP030000003>[Lh0cZg>01d0cZg>00<000000<j]cP3>[Lh03@3>[Lh00`000000fMWI0=WIf@0L0=WI
f@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI01`0fMWI00<000000<j]cP3>
[Lh0303>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00T0cZg>0P0000090<j]cP03
0000003>[Lh0cZg>0140cZg>00<000000<j]cP3>[Lh04@3>[Lh00`000000cZg>0<j]cP070<j]cP80
00002`3>[Lh00`000000cZg>0<j]cP0M0<j]cP030000003>[Lh0cZg>00`0cZg>00<000000=WIf@3I
fMT0703IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0M0=WIf@030000
003>[Lh0cZg>00X0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0;0<j]cP800000
1P3>[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh0
103>[Lh2000000d0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0:0<j]cP030000
003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI0P00000N0=WIf@030000003>
[Lh0cZg>00T0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP0>0<j]cP800000103>
[Lh00`000000cZg>0<j]cP0B0<j]cP030000003>[Lh0cZg>0180cZg>00<000000<j]cP3>[Lh00P3>
[Lh200000100cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP090<j]cP030000003I
fMT0fMWI01d0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT07P3IfMT0
0`000000cZg>0<j]cP070<j]cP030000003>[Lh0cZg>01h0cZg>00<000000<j]cP3>[Lh04@3>[Lh0
1@000000cZg>0<j]cP3>[Lh0000001@0cZg>00<000000<j]cP3>[Lh04P3>[Lh01@000000cZg>0<j]
cP3>[Lh0000001<0cZg>00<000000<j]cP3>[Lh07P3>[Lh00`000000cZg>0<j]cP070<j]cP030000
003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT07`3I
fMT00`000000cZg>0<j]cP050<j]cP030000003>[Lh0cZg>01l0cZg>00<000000<j]cP3>[Lh04P3>
[Lh3000001D0cZg>00<000000<j]cP3>[Lh04`3>[Lh3000001@0cZg>00<000000<j]cP3>[Lh07`3>
[Lh00`000000cZg>0<j]cP050<j]cP030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0<`3I
fMT003@0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000cZg>0<j]cP040<j]cP030000003>[Lh0
cZg>01l0cZg>00<000000<j]cP3>[Lh05@3>[Lh]000001L0cZg>00<000000<j]cP3>[Lh07`3>[Lh0
0`000000cZg>0<j]cP040<j]cP030000003IfMT0fMWI05D0fMWI000d0=WIf@030000003IfMT0fMWI
0200fMWI00<000000<j]cP3>[Lh00P3>[Lh00`000000cZg>0<j]cP0P0<j]cP030000003>[Lh0cZg>
01D0cZg>00<000000<j]cP3>[Lh04`3>[Lh00`000000cZg>0<j]cP0C0<j]cP030000003>[Lh0cZg>
01D0cZg>00<000000<j]cP3>[Lh0803>[Lh00`000000cZg>0<j]cP020<j]cP030000003IfMT0fMWI
0200fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0803IfMT01@000000
cZg>0<j]cP3>[Lh000000280cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0C0<j]
cP030000003>[Lh0cZg>01<0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000cZg>0<j]cP0P0<j]
cP050000003>[Lh0cZg>0<j]cP0000008P3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`00
0000fMWI0=WIf@0Q0=WIf@030000003>[Lh000000280cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>01@0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0P0<j]cP030000003>[Lh0000002<0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0
fMWI00<000000=WIf@3IfMT08P3IfMT200000280cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000
cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>01@0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000
cZg>0<j]cP0Q0<j]cP030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI
00<000000=WIf@3IfMT0903IfMT00`000000cZg>0<j]cP0N0<j]cP030000003>[Lh0cZg>01L0cZg>
00<000000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>01L0cZg>
00<000000<j]cP3>[Lh07P3>[Lh00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI03<0fMWI
000d0=WIf@030000003IfMT0fMWI02D0fMWI0P00000N0<j]cP030000003>[Lh0cZg>01L0cZg>00<0
00000<j]cP3>[Lh0503>[Lh00`000000cZg>0<j]cP0D0<j]cP030000003>[Lh0cZg>01L0cZg>00<0
00000<j]cP3>[Lh0703>[Lh2000002L0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<00000
0=WIf@3IfMT09`3IfMT2000001/0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0E
0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0I
0<j]cP800000:@3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0Y0=WI
f@030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0E0<j]
cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0G0<j]
cP030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3I
fMT0:P3IfMT2000001L0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0E0<j]cP03
0000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0E0<j]cP80
0000;03IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0/0=WIf@800000
503>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01D0cZg>00<000000<j]cP3>[Lh0
5@3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>0180cZg>0P00000^0=WIf@030000
003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI02h0fMWI00<000000<j]cP3>[Lh04@3>
[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh05P3>
[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>0140cZg>00<000000=WIf@3IfMT0;P3I
fMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@0_0=WIf@800000403>[Lh0
0`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh05P3>[Lh0
0`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>00h0cZg>0P00000a0=WIf@030000003IfMT0
fMWI03<0fMWI000R0=WIf@@000000`3IfMT3000000P0fMWI00<000000=WIf@3IfMT0<@3IfMT00`00
0000cZg>0<j]cP0<0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`00
0000cZg>0<j]cP0F0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh0303>[Lh00`00
0000fMWI0=WIf@0a0=WIf@030000003IfMT0fMWI03<0fMWI000V0=WIf@030000003IfMT0000000<0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0b0=WIf@800000303>[Lh00`000000
cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>01H0cZg>00<000000<j]cP3>[Lh05P3>[Lh00`000000
cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>00X0cZg>0P00000d0=WIf@030000003IfMT0fMWI03<0
fMWI000V0=WIf@030000003IfMT0000000<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@0d0=WIf@8000002@3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>01L0cZg>
00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>00L0cZg>
0P00000f0=WIf@030000003IfMT0fMWI03<0fMWI000V0=WIf@030000003IfMT0000000<0fMWI00<0
00000=WIf@3IfMT01@3IfMT3000003H0fMWI00<000000<j]cP3>[Lh01P3>[Lh00`000000cZg>0<j]
cP0J0<j]cP030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh05`3>[Lh00`000000cZg>0<j]
cP0J0<j]cP030000003>[Lh0cZg>00H0cZg>00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WI
f@0c0=WIf@009P3IfMT00`000000fMWI000000030=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0=`3IfMT2000000D0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0G
0<j]cP030000003>[Lh0cZg>01L0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP03
0<j]cP800000>@3IfMT00`000000fMWI0=WIf@0c0=WIf@008P3IfMT400000080fMWI00D000000=WI
f@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI03T0fMWI0P0000020<j]cP030000003>[Lh0
cZg>01/0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0
cZg>01/0cZg>00<000000<j]cP3>[Lh00P00000k0=WIf@030000003IfMT0fMWI03<0fMWI000S0=WI
f@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0
fMWI03/0fMWI00<000000<j]cP0000007@3>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0
cZg>01P0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0000000m0=WIf@030000003IfMT0
fMWI03<0fMWI000S0=WIf@@000000P3IfMT3000000P0fMWI00<000000=WIf@3IfMT0?03IfMT20000
01d0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000cZg>0<j]cP0H0<j]cP030000003>[Lh0cZg>
01/0cZg>0P00000n0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI03h0
fMWI0P00000K0<j]cP030000003>[Lh0cZg>01P0cZg>00<000000<j]cP3>[Lh0603>[Lh00`000000
cZg>0<j]cP0I0<j]cP800000@03IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@100=WIf@800000603>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01T0cZg>
00<000000<j]cP3>[Lh05P3>[Lh200000480fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<0
00000=WIf@3IfMT0@P3IfMT00`000000cZg>0<j]cP0E0<j]cP030000003>[Lh0cZg>01T0cZg>00<0
00000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0E0<j]cP030000003IfMT0fMWI0480fMWI00<0
00000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0@`3IfMT2000001D0cZg>00<00000
0<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0I0<j]cP030000003>[Lh0cZg>01<0cZg>0P000015
0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI04D0fMWI0P00000C0<j]
cP030000003>[Lh0cZg>01T0cZg>00<000000<j]cP3>[Lh06@3>[Lh00`000000cZg>0<j]cP0A0<j]
cP800000A`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@170=WIf@80
0000403>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>[Lh0cZg>01X0cZg>00<000000<j]cP3>
[Lh03P3>[Lh2000004T0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0
B@3IfMT2000000h0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000
003>[Lh0cZg>00`0cZg>0P00001;0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003I
fMT0fMWI04/0fMWI00<000000<j]cP3>[Lh02`3>[Lh00`000000cZg>0<j]cP0J0<j]cP030000003>
[Lh0cZg>01X0cZg>00<000000<j]cP3>[Lh02`3>[Lh00`000000fMWI0=WIf@1;0=WIf@030000003I
fMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI04`0fMWI0P00000;0<j]cP030000003>[Lh0
cZg>01X0cZg>00<000000<j]cP3>[Lh06P3>[Lh00`000000cZg>0<j]cP090<j]cP800000CP3IfMT0
0`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@1>0=WIf@800000203>[Lh00`00
0000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>01/0cZg>00<000000<j]cP3>[Lh01P3>[Lh20000
0500fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WIf@3IfMT0D03IfMT2000000H0
cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>0<j]cP0K0<j]cP030000003>[Lh0cZg>00@0
cZg>0P00001B0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI0580fMWI
0P0000040<j]cP030000003>[Lh0cZg>01/0cZg>00<000000<j]cP3>[Lh06`3>[Lh00`000000cZg>
0<j]cP020<j]cP800000E03IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WI
f@1D0=WIf@050000003>[Lh0cZg>0<j]cP0000007@3>[Lh00`000000cZg>0<j]cP0K0<j]cP050000
003>[Lh0cZg>0<j]cP000000EP3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI
0=WIf@1E0=WIf@<000007P3>[Lh00`000000cZg>0<j]cP0L0<j]cP<00000E`3IfMT00`000000fMWI
0=WIf@0c0=WIf@00=03IfMT2000005P0fMWI?`00001I0=WIf@030000003IfMT0fMWI03<0fMWI000d
0=WIf@030000003IfMT0fMWI0>l0fMWI00<000000=WIf@3IfMT0<`3IfMT003@0fMWI00<000000=WI
f@3IfMT0k`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT00`000000fMWI0=WIf@3_0=WIf@03
0000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI0>l0fMWI00<000000=WIf@3IfMT0
<`3IfMT003@0fMWI00<000000=WIf@3IfMT0k`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=03IfMT`
000000030=WIf@000000000000@0000000<0fMWI000000000000100000000`3IfMT0000000000004
000000030=WIf@000000000000@0000000<0fMWI000000000000E`0000000`3IfMT0000000000004
000000030=WIf@000000000000@0000000<0fMWI000000000000100000000`3IfMT0000000000004
000000030=WIf@000000000002h00000=@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWI
G@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00?l0fMWIG@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 347}, {347, 0}} -> {-5.00005*^-6, -5.00005*^-6, 
  0.00288187, 0.00288187}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the field along x axis", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T4 = 
      Table[{x, radFld[cyl4, "\<By\>", {x, 0, Lz/2.}]}, {x, \(-rint\)*0.9, 
          rint*0.9, 1}]; \n
    MultipleListPlot[T3, T4, PlotJoined \[Rule] {True, True}, \n\t\t
      PlotRange \[Rule] All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.026455 0.603319 0.670709 [
[.10317 .59082 -12.5 -14 ]
[.10317 .59082 12.5 0 ]
[.23545 .59082 -12.5 -14 ]
[.23545 .59082 12.5 0 ]
[.36772 .59082 -9.5 -14 ]
[.36772 .59082 9.5 0 ]
[.63228 .59082 -5 -14 ]
[.63228 .59082 5 0 ]
[.76455 .59082 -8 -14 ]
[.76455 .59082 8 0 ]
[.89683 .59082 -8 -14 ]
[.89683 .59082 8 0 ]
[.4875 .06675 -29 -7 ]
[.4875 .06675 0 7 ]
[.4875 .20089 -29 -7 ]
[.4875 .20089 0 7 ]
[.4875 .33504 -29 -7 ]
[.4875 .33504 0 7 ]
[.4875 .46918 -29 -7 ]
[.4875 .46918 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .60332 m
.10317 .60957 L
s
gsave
.10317 .59082 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.23545 .60332 m
.23545 .60957 L
s
gsave
.23545 .59082 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.36772 .60332 m
.36772 .60957 L
s
gsave
.36772 .59082 -70.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.63228 .60332 m
.63228 .60957 L
s
gsave
.63228 .59082 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.76455 .60332 m
.76455 .60957 L
s
gsave
.76455 .59082 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.89683 .60332 m
.89683 .60957 L
s
gsave
.89683 .59082 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.12963 .60332 m
.12963 .60707 L
s
.15608 .60332 m
.15608 .60707 L
s
.18254 .60332 m
.18254 .60707 L
s
.20899 .60332 m
.20899 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.28836 .60332 m
.28836 .60707 L
s
.31481 .60332 m
.31481 .60707 L
s
.34127 .60332 m
.34127 .60707 L
s
.39418 .60332 m
.39418 .60707 L
s
.42063 .60332 m
.42063 .60707 L
s
.44709 .60332 m
.44709 .60707 L
s
.47354 .60332 m
.47354 .60707 L
s
.52646 .60332 m
.52646 .60707 L
s
.55291 .60332 m
.55291 .60707 L
s
.57937 .60332 m
.57937 .60707 L
s
.60582 .60332 m
.60582 .60707 L
s
.65873 .60332 m
.65873 .60707 L
s
.68519 .60332 m
.68519 .60707 L
s
.71164 .60332 m
.71164 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.79101 .60332 m
.79101 .60707 L
s
.81746 .60332 m
.81746 .60707 L
s
.84392 .60332 m
.84392 .60707 L
s
.87037 .60332 m
.87037 .60707 L
s
.07672 .60332 m
.07672 .60707 L
s
.05026 .60332 m
.05026 .60707 L
s
.02381 .60332 m
.02381 .60707 L
s
.92328 .60332 m
.92328 .60707 L
s
.94974 .60332 m
.94974 .60707 L
s
.97619 .60332 m
.97619 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.5 .06675 m
.50625 .06675 L
s
gsave
.4875 .06675 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .20089 m
.50625 .20089 L
s
gsave
.4875 .20089 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .33504 m
.50625 .33504 L
s
gsave
.4875 .33504 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .46918 m
.50625 .46918 L
s
gsave
.4875 .46918 -90 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.5 .10029 m
.50375 .10029 L
s
.5 .13382 m
.50375 .13382 L
s
.5 .16736 m
.50375 .16736 L
s
.5 .23443 m
.50375 .23443 L
s
.5 .26796 m
.50375 .26796 L
s
.5 .3015 m
.50375 .3015 L
s
.5 .36857 m
.50375 .36857 L
s
.5 .40211 m
.50375 .40211 L
s
.5 .43564 m
.50375 .43564 L
s
.5 .50271 m
.50375 .50271 L
s
.5 .53625 m
.50375 .53625 L
s
.5 .56978 m
.50375 .56978 L
s
.5 .03322 m
.50375 .03322 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.001 w
.02381 .01472 m
.05026 .07347 L
.07672 .13278 L
.10317 .19033 L
.12963 .24479 L
.15608 .29553 L
.18254 .34229 L
.20899 .385 L
.23545 .42369 L
.2619 .45841 L
.28836 .48925 L
.31481 .51628 L
.34127 .53956 L
.36772 .55915 L
.39418 .57511 L
.42063 .58748 L
.44709 .59629 L
.47354 .60156 L
.5 .60332 L
.52646 .60156 L
.55291 .59629 L
.57937 .58748 L
.60582 .57511 L
.63228 .55915 L
.65873 .53956 L
.68519 .51628 L
.71164 .48925 L
.7381 .45841 L
.76455 .42369 L
.79101 .385 L
.81746 .34229 L
.84392 .29553 L
.87037 .24479 L
.89683 .19033 L
.92328 .13278 L
.94974 .07347 L
.97619 .01472 L
s
.0001 w
.02381 .01472 -1.875 0 Mabsadd m
.02381 .01472 0 2.5 Mabsadd L
.02381 .01472 1.875 0 Mabsadd L
.02381 .01472 0 -2.5 Mabsadd L
.02381 .01472 -1.875 0 Mabsadd L closepath F
.05026 .07347 -1.875 0 Mabsadd m
.05026 .07347 0 2.5 Mabsadd L
.05026 .07347 1.875 0 Mabsadd L
.05026 .07347 0 -2.5 Mabsadd L
.05026 .07347 -1.875 0 Mabsadd L closepath F
.07672 .13278 -1.875 0 Mabsadd m
.07672 .13278 0 2.5 Mabsadd L
.07672 .13278 1.875 0 Mabsadd L
.07672 .13278 0 -2.5 Mabsadd L
.07672 .13278 -1.875 0 Mabsadd L closepath F
.10317 .19033 -1.875 0 Mabsadd m
.10317 .19033 0 2.5 Mabsadd L
.10317 .19033 1.875 0 Mabsadd L
.10317 .19033 0 -2.5 Mabsadd L
.10317 .19033 -1.875 0 Mabsadd L closepath F
.12963 .24479 -1.875 0 Mabsadd m
.12963 .24479 0 2.5 Mabsadd L
.12963 .24479 1.875 0 Mabsadd L
.12963 .24479 0 -2.5 Mabsadd L
.12963 .24479 -1.875 0 Mabsadd L closepath F
.15608 .29553 -1.875 0 Mabsadd m
.15608 .29553 0 2.5 Mabsadd L
.15608 .29553 1.875 0 Mabsadd L
.15608 .29553 0 -2.5 Mabsadd L
.15608 .29553 -1.875 0 Mabsadd L closepath F
.18254 .34229 -1.875 0 Mabsadd m
.18254 .34229 0 2.5 Mabsadd L
.18254 .34229 1.875 0 Mabsadd L
.18254 .34229 0 -2.5 Mabsadd L
.18254 .34229 -1.875 0 Mabsadd L closepath F
.20899 .385 -1.875 0 Mabsadd m
.20899 .385 0 2.5 Mabsadd L
.20899 .385 1.875 0 Mabsadd L
.20899 .385 0 -2.5 Mabsadd L
.20899 .385 -1.875 0 Mabsadd L closepath F
.23545 .42369 -1.875 0 Mabsadd m
.23545 .42369 0 2.5 Mabsadd L
.23545 .42369 1.875 0 Mabsadd L
.23545 .42369 0 -2.5 Mabsadd L
.23545 .42369 -1.875 0 Mabsadd L closepath F
.2619 .45841 -1.875 0 Mabsadd m
.2619 .45841 0 2.5 Mabsadd L
.2619 .45841 1.875 0 Mabsadd L
.2619 .45841 0 -2.5 Mabsadd L
.2619 .45841 -1.875 0 Mabsadd L closepath F
.28836 .48925 -1.875 0 Mabsadd m
.28836 .48925 0 2.5 Mabsadd L
.28836 .48925 1.875 0 Mabsadd L
.28836 .48925 0 -2.5 Mabsadd L
.28836 .48925 -1.875 0 Mabsadd L closepath F
.31481 .51628 -1.875 0 Mabsadd m
.31481 .51628 0 2.5 Mabsadd L
.31481 .51628 1.875 0 Mabsadd L
.31481 .51628 0 -2.5 Mabsadd L
.31481 .51628 -1.875 0 Mabsadd L closepath F
.34127 .53956 -1.875 0 Mabsadd m
.34127 .53956 0 2.5 Mabsadd L
.34127 .53956 1.875 0 Mabsadd L
.34127 .53956 0 -2.5 Mabsadd L
.34127 .53956 -1.875 0 Mabsadd L closepath F
.36772 .55915 -1.875 0 Mabsadd m
.36772 .55915 0 2.5 Mabsadd L
.36772 .55915 1.875 0 Mabsadd L
.36772 .55915 0 -2.5 Mabsadd L
.36772 .55915 -1.875 0 Mabsadd L closepath F
.39418 .57511 -1.875 0 Mabsadd m
.39418 .57511 0 2.5 Mabsadd L
.39418 .57511 1.875 0 Mabsadd L
.39418 .57511 0 -2.5 Mabsadd L
.39418 .57511 -1.875 0 Mabsadd L closepath F
.42063 .58748 -1.875 0 Mabsadd m
.42063 .58748 0 2.5 Mabsadd L
.42063 .58748 1.875 0 Mabsadd L
.42063 .58748 0 -2.5 Mabsadd L
.42063 .58748 -1.875 0 Mabsadd L closepath F
.44709 .59629 -1.875 0 Mabsadd m
.44709 .59629 0 2.5 Mabsadd L
.44709 .59629 1.875 0 Mabsadd L
.44709 .59629 0 -2.5 Mabsadd L
.44709 .59629 -1.875 0 Mabsadd L closepath F
.47354 .60156 -1.875 0 Mabsadd m
.47354 .60156 0 2.5 Mabsadd L
.47354 .60156 1.875 0 Mabsadd L
.47354 .60156 0 -2.5 Mabsadd L
.47354 .60156 -1.875 0 Mabsadd L closepath F
.5 .60332 -1.875 0 Mabsadd m
.5 .60332 0 2.5 Mabsadd L
.5 .60332 1.875 0 Mabsadd L
.5 .60332 0 -2.5 Mabsadd L
.5 .60332 -1.875 0 Mabsadd L closepath F
.52646 .60156 -1.875 0 Mabsadd m
.52646 .60156 0 2.5 Mabsadd L
.52646 .60156 1.875 0 Mabsadd L
.52646 .60156 0 -2.5 Mabsadd L
.52646 .60156 -1.875 0 Mabsadd L closepath F
.55291 .59629 -1.875 0 Mabsadd m
.55291 .59629 0 2.5 Mabsadd L
.55291 .59629 1.875 0 Mabsadd L
.55291 .59629 0 -2.5 Mabsadd L
.55291 .59629 -1.875 0 Mabsadd L closepath F
.57937 .58748 -1.875 0 Mabsadd m
.57937 .58748 0 2.5 Mabsadd L
.57937 .58748 1.875 0 Mabsadd L
.57937 .58748 0 -2.5 Mabsadd L
.57937 .58748 -1.875 0 Mabsadd L closepath F
.60582 .57511 -1.875 0 Mabsadd m
.60582 .57511 0 2.5 Mabsadd L
.60582 .57511 1.875 0 Mabsadd L
.60582 .57511 0 -2.5 Mabsadd L
.60582 .57511 -1.875 0 Mabsadd L closepath F
.63228 .55915 -1.875 0 Mabsadd m
.63228 .55915 0 2.5 Mabsadd L
.63228 .55915 1.875 0 Mabsadd L
.63228 .55915 0 -2.5 Mabsadd L
.63228 .55915 -1.875 0 Mabsadd L closepath F
.65873 .53956 -1.875 0 Mabsadd m
.65873 .53956 0 2.5 Mabsadd L
.65873 .53956 1.875 0 Mabsadd L
.65873 .53956 0 -2.5 Mabsadd L
.65873 .53956 -1.875 0 Mabsadd L closepath F
.68519 .51628 -1.875 0 Mabsadd m
.68519 .51628 0 2.5 Mabsadd L
.68519 .51628 1.875 0 Mabsadd L
.68519 .51628 0 -2.5 Mabsadd L
.68519 .51628 -1.875 0 Mabsadd L closepath F
.71164 .48925 -1.875 0 Mabsadd m
.71164 .48925 0 2.5 Mabsadd L
.71164 .48925 1.875 0 Mabsadd L
.71164 .48925 0 -2.5 Mabsadd L
.71164 .48925 -1.875 0 Mabsadd L closepath F
.7381 .45841 -1.875 0 Mabsadd m
.7381 .45841 0 2.5 Mabsadd L
.7381 .45841 1.875 0 Mabsadd L
.7381 .45841 0 -2.5 Mabsadd L
.7381 .45841 -1.875 0 Mabsadd L closepath F
.76455 .42369 -1.875 0 Mabsadd m
.76455 .42369 0 2.5 Mabsadd L
.76455 .42369 1.875 0 Mabsadd L
.76455 .42369 0 -2.5 Mabsadd L
.76455 .42369 -1.875 0 Mabsadd L closepath F
.79101 .385 -1.875 0 Mabsadd m
.79101 .385 0 2.5 Mabsadd L
.79101 .385 1.875 0 Mabsadd L
.79101 .385 0 -2.5 Mabsadd L
.79101 .385 -1.875 0 Mabsadd L closepath F
.81746 .34229 -1.875 0 Mabsadd m
.81746 .34229 0 2.5 Mabsadd L
.81746 .34229 1.875 0 Mabsadd L
.81746 .34229 0 -2.5 Mabsadd L
.81746 .34229 -1.875 0 Mabsadd L closepath F
.84392 .29553 -1.875 0 Mabsadd m
.84392 .29553 0 2.5 Mabsadd L
.84392 .29553 1.875 0 Mabsadd L
.84392 .29553 0 -2.5 Mabsadd L
.84392 .29553 -1.875 0 Mabsadd L closepath F
.87037 .24479 -1.875 0 Mabsadd m
.87037 .24479 0 2.5 Mabsadd L
.87037 .24479 1.875 0 Mabsadd L
.87037 .24479 0 -2.5 Mabsadd L
.87037 .24479 -1.875 0 Mabsadd L closepath F
.89683 .19033 -1.875 0 Mabsadd m
.89683 .19033 0 2.5 Mabsadd L
.89683 .19033 1.875 0 Mabsadd L
.89683 .19033 0 -2.5 Mabsadd L
.89683 .19033 -1.875 0 Mabsadd L closepath F
.92328 .13278 -1.875 0 Mabsadd m
.92328 .13278 0 2.5 Mabsadd L
.92328 .13278 1.875 0 Mabsadd L
.92328 .13278 0 -2.5 Mabsadd L
.92328 .13278 -1.875 0 Mabsadd L closepath F
.94974 .07347 -1.875 0 Mabsadd m
.94974 .07347 0 2.5 Mabsadd L
.94974 .07347 1.875 0 Mabsadd L
.94974 .07347 0 -2.5 Mabsadd L
.94974 .07347 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .03826 m
.05026 .09294 L
.07672 .14899 L
.10317 .20386 L
.12963 .25609 L
.15608 .30494 L
.18254 .35009 L
.20899 .39141 L
.23545 .42889 L
.2619 .46257 L
.28836 .4925 L
.31481 .51874 L
.34127 .54136 L
.36772 .56039 L
.39418 .5759 L
.42063 .58792 L
.44709 .59648 L
.47354 .60161 L
.5 .60332 L
.52646 .60161 L
.55291 .59648 L
.57937 .58792 L
.60582 .5759 L
.63228 .56039 L
.65873 .54136 L
.68519 .51874 L
.71164 .4925 L
.7381 .46257 L
.76455 .42889 L
.79101 .39141 L
.81746 .35009 L
.84392 .30494 L
.87037 .25609 L
.89683 .20386 L
.92328 .14899 L
.94974 .09294 L
.97619 .03826 L
s
.0001 w
[ ] 0 setdash
.02381 .03826 0 2.5 Mabsadd m
.02381 .03826 -0.56518 .7779 Mabsadd L
.02381 .03826 -2.37764 .77254 Mabsadd L
.02381 .03826 -0.91448 -0.29713 Mabsadd L
.02381 .03826 -1.46946 -2.02254 Mabsadd L
.02381 .03826 0 -0.96154 Mabsadd L
.02381 .03826 1.46946 -2.02254 Mabsadd L
.02381 .03826 .91448 -0.29713 Mabsadd L
.02381 .03826 2.37764 .77254 Mabsadd L
.02381 .03826 .56518 .7779 Mabsadd L
.02381 .03826 0 2.5 Mabsadd L closepath F
.05026 .09294 0 2.5 Mabsadd m
.05026 .09294 -0.56518 .7779 Mabsadd L
.05026 .09294 -2.37764 .77254 Mabsadd L
.05026 .09294 -0.91448 -0.29713 Mabsadd L
.05026 .09294 -1.46946 -2.02254 Mabsadd L
.05026 .09294 0 -0.96154 Mabsadd L
.05026 .09294 1.46946 -2.02254 Mabsadd L
.05026 .09294 .91448 -0.29713 Mabsadd L
.05026 .09294 2.37764 .77254 Mabsadd L
.05026 .09294 .56518 .7779 Mabsadd L
.05026 .09294 0 2.5 Mabsadd L closepath F
.07672 .14899 0 2.5 Mabsadd m
.07672 .14899 -0.56518 .7779 Mabsadd L
.07672 .14899 -2.37764 .77254 Mabsadd L
.07672 .14899 -0.91448 -0.29713 Mabsadd L
.07672 .14899 -1.46946 -2.02254 Mabsadd L
.07672 .14899 0 -0.96154 Mabsadd L
.07672 .14899 1.46946 -2.02254 Mabsadd L
.07672 .14899 .91448 -0.29713 Mabsadd L
.07672 .14899 2.37764 .77254 Mabsadd L
.07672 .14899 .56518 .7779 Mabsadd L
.07672 .14899 0 2.5 Mabsadd L closepath F
.10317 .20386 0 2.5 Mabsadd m
.10317 .20386 -0.56518 .7779 Mabsadd L
.10317 .20386 -2.37764 .77254 Mabsadd L
.10317 .20386 -0.91448 -0.29713 Mabsadd L
.10317 .20386 -1.46946 -2.02254 Mabsadd L
.10317 .20386 0 -0.96154 Mabsadd L
.10317 .20386 1.46946 -2.02254 Mabsadd L
.10317 .20386 .91448 -0.29713 Mabsadd L
.10317 .20386 2.37764 .77254 Mabsadd L
.10317 .20386 .56518 .7779 Mabsadd L
.10317 .20386 0 2.5 Mabsadd L closepath F
.12963 .25609 0 2.5 Mabsadd m
.12963 .25609 -0.56518 .7779 Mabsadd L
.12963 .25609 -2.37764 .77254 Mabsadd L
.12963 .25609 -0.91448 -0.29713 Mabsadd L
.12963 .25609 -1.46946 -2.02254 Mabsadd L
.12963 .25609 0 -0.96154 Mabsadd L
.12963 .25609 1.46946 -2.02254 Mabsadd L
.12963 .25609 .91448 -0.29713 Mabsadd L
.12963 .25609 2.37764 .77254 Mabsadd L
.12963 .25609 .56518 .7779 Mabsadd L
.12963 .25609 0 2.5 Mabsadd L closepath F
.15608 .30494 0 2.5 Mabsadd m
.15608 .30494 -0.56518 .7779 Mabsadd L
.15608 .30494 -2.37764 .77254 Mabsadd L
.15608 .30494 -0.91448 -0.29713 Mabsadd L
.15608 .30494 -1.46946 -2.02254 Mabsadd L
.15608 .30494 0 -0.96154 Mabsadd L
.15608 .30494 1.46946 -2.02254 Mabsadd L
.15608 .30494 .91448 -0.29713 Mabsadd L
.15608 .30494 2.37764 .77254 Mabsadd L
.15608 .30494 .56518 .7779 Mabsadd L
.15608 .30494 0 2.5 Mabsadd L closepath F
.18254 .35009 0 2.5 Mabsadd m
.18254 .35009 -0.56518 .7779 Mabsadd L
.18254 .35009 -2.37764 .77254 Mabsadd L
.18254 .35009 -0.91448 -0.29713 Mabsadd L
.18254 .35009 -1.46946 -2.02254 Mabsadd L
.18254 .35009 0 -0.96154 Mabsadd L
.18254 .35009 1.46946 -2.02254 Mabsadd L
.18254 .35009 .91448 -0.29713 Mabsadd L
.18254 .35009 2.37764 .77254 Mabsadd L
.18254 .35009 .56518 .7779 Mabsadd L
.18254 .35009 0 2.5 Mabsadd L closepath F
.20899 .39141 0 2.5 Mabsadd m
.20899 .39141 -0.56518 .7779 Mabsadd L
.20899 .39141 -2.37764 .77254 Mabsadd L
.20899 .39141 -0.91448 -0.29713 Mabsadd L
.20899 .39141 -1.46946 -2.02254 Mabsadd L
.20899 .39141 0 -0.96154 Mabsadd L
.20899 .39141 1.46946 -2.02254 Mabsadd L
.20899 .39141 .91448 -0.29713 Mabsadd L
.20899 .39141 2.37764 .77254 Mabsadd L
.20899 .39141 .56518 .7779 Mabsadd L
.20899 .39141 0 2.5 Mabsadd L closepath F
.23545 .42889 0 2.5 Mabsadd m
.23545 .42889 -0.56518 .7779 Mabsadd L
.23545 .42889 -2.37764 .77254 Mabsadd L
.23545 .42889 -0.91448 -0.29713 Mabsadd L
.23545 .42889 -1.46946 -2.02254 Mabsadd L
.23545 .42889 0 -0.96154 Mabsadd L
.23545 .42889 1.46946 -2.02254 Mabsadd L
.23545 .42889 .91448 -0.29713 Mabsadd L
.23545 .42889 2.37764 .77254 Mabsadd L
.23545 .42889 .56518 .7779 Mabsadd L
.23545 .42889 0 2.5 Mabsadd L closepath F
.2619 .46257 0 2.5 Mabsadd m
.2619 .46257 -0.56518 .7779 Mabsadd L
.2619 .46257 -2.37764 .77254 Mabsadd L
.2619 .46257 -0.91448 -0.29713 Mabsadd L
.2619 .46257 -1.46946 -2.02254 Mabsadd L
.2619 .46257 0 -0.96154 Mabsadd L
.2619 .46257 1.46946 -2.02254 Mabsadd L
.2619 .46257 .91448 -0.29713 Mabsadd L
.2619 .46257 2.37764 .77254 Mabsadd L
.2619 .46257 .56518 .7779 Mabsadd L
.2619 .46257 0 2.5 Mabsadd L closepath F
.28836 .4925 0 2.5 Mabsadd m
.28836 .4925 -0.56518 .7779 Mabsadd L
.28836 .4925 -2.37764 .77254 Mabsadd L
.28836 .4925 -0.91448 -0.29713 Mabsadd L
.28836 .4925 -1.46946 -2.02254 Mabsadd L
.28836 .4925 0 -0.96154 Mabsadd L
.28836 .4925 1.46946 -2.02254 Mabsadd L
.28836 .4925 .91448 -0.29713 Mabsadd L
.28836 .4925 2.37764 .77254 Mabsadd L
.28836 .4925 .56518 .7779 Mabsadd L
.28836 .4925 0 2.5 Mabsadd L closepath F
.31481 .51874 0 2.5 Mabsadd m
.31481 .51874 -0.56518 .7779 Mabsadd L
.31481 .51874 -2.37764 .77254 Mabsadd L
.31481 .51874 -0.91448 -0.29713 Mabsadd L
.31481 .51874 -1.46946 -2.02254 Mabsadd L
.31481 .51874 0 -0.96154 Mabsadd L
.31481 .51874 1.46946 -2.02254 Mabsadd L
.31481 .51874 .91448 -0.29713 Mabsadd L
.31481 .51874 2.37764 .77254 Mabsadd L
.31481 .51874 .56518 .7779 Mabsadd L
.31481 .51874 0 2.5 Mabsadd L closepath F
.34127 .54136 0 2.5 Mabsadd m
.34127 .54136 -0.56518 .7779 Mabsadd L
.34127 .54136 -2.37764 .77254 Mabsadd L
.34127 .54136 -0.91448 -0.29713 Mabsadd L
.34127 .54136 -1.46946 -2.02254 Mabsadd L
.34127 .54136 0 -0.96154 Mabsadd L
.34127 .54136 1.46946 -2.02254 Mabsadd L
.34127 .54136 .91448 -0.29713 Mabsadd L
.34127 .54136 2.37764 .77254 Mabsadd L
.34127 .54136 .56518 .7779 Mabsadd L
.34127 .54136 0 2.5 Mabsadd L closepath F
.36772 .56039 0 2.5 Mabsadd m
.36772 .56039 -0.56518 .7779 Mabsadd L
.36772 .56039 -2.37764 .77254 Mabsadd L
.36772 .56039 -0.91448 -0.29713 Mabsadd L
.36772 .56039 -1.46946 -2.02254 Mabsadd L
.36772 .56039 0 -0.96154 Mabsadd L
.36772 .56039 1.46946 -2.02254 Mabsadd L
.36772 .56039 .91448 -0.29713 Mabsadd L
.36772 .56039 2.37764 .77254 Mabsadd L
.36772 .56039 .56518 .7779 Mabsadd L
.36772 .56039 0 2.5 Mabsadd L closepath F
.39418 .5759 0 2.5 Mabsadd m
.39418 .5759 -0.56518 .7779 Mabsadd L
.39418 .5759 -2.37764 .77254 Mabsadd L
.39418 .5759 -0.91448 -0.29713 Mabsadd L
.39418 .5759 -1.46946 -2.02254 Mabsadd L
.39418 .5759 0 -0.96154 Mabsadd L
.39418 .5759 1.46946 -2.02254 Mabsadd L
.39418 .5759 .91448 -0.29713 Mabsadd L
.39418 .5759 2.37764 .77254 Mabsadd L
.39418 .5759 .56518 .7779 Mabsadd L
.39418 .5759 0 2.5 Mabsadd L closepath F
.42063 .58792 0 2.5 Mabsadd m
.42063 .58792 -0.56518 .7779 Mabsadd L
.42063 .58792 -2.37764 .77254 Mabsadd L
.42063 .58792 -0.91448 -0.29713 Mabsadd L
.42063 .58792 -1.46946 -2.02254 Mabsadd L
.42063 .58792 0 -0.96154 Mabsadd L
.42063 .58792 1.46946 -2.02254 Mabsadd L
.42063 .58792 .91448 -0.29713 Mabsadd L
.42063 .58792 2.37764 .77254 Mabsadd L
.42063 .58792 .56518 .7779 Mabsadd L
.42063 .58792 0 2.5 Mabsadd L closepath F
.44709 .59648 0 2.5 Mabsadd m
.44709 .59648 -0.56518 .7779 Mabsadd L
.44709 .59648 -2.37764 .77254 Mabsadd L
.44709 .59648 -0.91448 -0.29713 Mabsadd L
.44709 .59648 -1.46946 -2.02254 Mabsadd L
.44709 .59648 0 -0.96154 Mabsadd L
.44709 .59648 1.46946 -2.02254 Mabsadd L
.44709 .59648 .91448 -0.29713 Mabsadd L
.44709 .59648 2.37764 .77254 Mabsadd L
.44709 .59648 .56518 .7779 Mabsadd L
.44709 .59648 0 2.5 Mabsadd L closepath F
.47354 .60161 0 2.5 Mabsadd m
.47354 .60161 -0.56518 .7779 Mabsadd L
.47354 .60161 -2.37764 .77254 Mabsadd L
.47354 .60161 -0.91448 -0.29713 Mabsadd L
.47354 .60161 -1.46946 -2.02254 Mabsadd L
.47354 .60161 0 -0.96154 Mabsadd L
.47354 .60161 1.46946 -2.02254 Mabsadd L
.47354 .60161 .91448 -0.29713 Mabsadd L
.47354 .60161 2.37764 .77254 Mabsadd L
.47354 .60161 .56518 .7779 Mabsadd L
.47354 .60161 0 2.5 Mabsadd L closepath F
.5 .60332 0 2.5 Mabsadd m
.5 .60332 -0.56518 .7779 Mabsadd L
.5 .60332 -2.37764 .77254 Mabsadd L
.5 .60332 -0.91448 -0.29713 Mabsadd L
.5 .60332 -1.46946 -2.02254 Mabsadd L
.5 .60332 0 -0.96154 Mabsadd L
.5 .60332 1.46946 -2.02254 Mabsadd L
.5 .60332 .91448 -0.29713 Mabsadd L
.5 .60332 2.37764 .77254 Mabsadd L
.5 .60332 .56518 .7779 Mabsadd L
.5 .60332 0 2.5 Mabsadd L closepath F
.52646 .60161 0 2.5 Mabsadd m
.52646 .60161 -0.56518 .7779 Mabsadd L
.52646 .60161 -2.37764 .77254 Mabsadd L
.52646 .60161 -0.91448 -0.29713 Mabsadd L
.52646 .60161 -1.46946 -2.02254 Mabsadd L
.52646 .60161 0 -0.96154 Mabsadd L
.52646 .60161 1.46946 -2.02254 Mabsadd L
.52646 .60161 .91448 -0.29713 Mabsadd L
.52646 .60161 2.37764 .77254 Mabsadd L
.52646 .60161 .56518 .7779 Mabsadd L
.52646 .60161 0 2.5 Mabsadd L closepath F
.55291 .59648 0 2.5 Mabsadd m
.55291 .59648 -0.56518 .7779 Mabsadd L
.55291 .59648 -2.37764 .77254 Mabsadd L
.55291 .59648 -0.91448 -0.29713 Mabsadd L
.55291 .59648 -1.46946 -2.02254 Mabsadd L
.55291 .59648 0 -0.96154 Mabsadd L
.55291 .59648 1.46946 -2.02254 Mabsadd L
.55291 .59648 .91448 -0.29713 Mabsadd L
.55291 .59648 2.37764 .77254 Mabsadd L
.55291 .59648 .56518 .7779 Mabsadd L
.55291 .59648 0 2.5 Mabsadd L closepath F
.57937 .58792 0 2.5 Mabsadd m
.57937 .58792 -0.56518 .7779 Mabsadd L
.57937 .58792 -2.37764 .77254 Mabsadd L
.57937 .58792 -0.91448 -0.29713 Mabsadd L
.57937 .58792 -1.46946 -2.02254 Mabsadd L
.57937 .58792 0 -0.96154 Mabsadd L
.57937 .58792 1.46946 -2.02254 Mabsadd L
.57937 .58792 .91448 -0.29713 Mabsadd L
.57937 .58792 2.37764 .77254 Mabsadd L
.57937 .58792 .56518 .7779 Mabsadd L
.57937 .58792 0 2.5 Mabsadd L closepath F
.60582 .5759 0 2.5 Mabsadd m
.60582 .5759 -0.56518 .7779 Mabsadd L
.60582 .5759 -2.37764 .77254 Mabsadd L
.60582 .5759 -0.91448 -0.29713 Mabsadd L
.60582 .5759 -1.46946 -2.02254 Mabsadd L
.60582 .5759 0 -0.96154 Mabsadd L
.60582 .5759 1.46946 -2.02254 Mabsadd L
.60582 .5759 .91448 -0.29713 Mabsadd L
.60582 .5759 2.37764 .77254 Mabsadd L
.60582 .5759 .56518 .7779 Mabsadd L
.60582 .5759 0 2.5 Mabsadd L closepath F
.63228 .56039 0 2.5 Mabsadd m
.63228 .56039 -0.56518 .7779 Mabsadd L
.63228 .56039 -2.37764 .77254 Mabsadd L
.63228 .56039 -0.91448 -0.29713 Mabsadd L
.63228 .56039 -1.46946 -2.02254 Mabsadd L
.63228 .56039 0 -0.96154 Mabsadd L
.63228 .56039 1.46946 -2.02254 Mabsadd L
.63228 .56039 .91448 -0.29713 Mabsadd L
.63228 .56039 2.37764 .77254 Mabsadd L
.63228 .56039 .56518 .7779 Mabsadd L
.63228 .56039 0 2.5 Mabsadd L closepath F
.65873 .54136 0 2.5 Mabsadd m
.65873 .54136 -0.56518 .7779 Mabsadd L
.65873 .54136 -2.37764 .77254 Mabsadd L
.65873 .54136 -0.91448 -0.29713 Mabsadd L
.65873 .54136 -1.46946 -2.02254 Mabsadd L
.65873 .54136 0 -0.96154 Mabsadd L
.65873 .54136 1.46946 -2.02254 Mabsadd L
.65873 .54136 .91448 -0.29713 Mabsadd L
.65873 .54136 2.37764 .77254 Mabsadd L
.65873 .54136 .56518 .7779 Mabsadd L
.65873 .54136 0 2.5 Mabsadd L closepath F
.68519 .51874 0 2.5 Mabsadd m
.68519 .51874 -0.56518 .7779 Mabsadd L
.68519 .51874 -2.37764 .77254 Mabsadd L
.68519 .51874 -0.91448 -0.29713 Mabsadd L
.68519 .51874 -1.46946 -2.02254 Mabsadd L
.68519 .51874 0 -0.96154 Mabsadd L
.68519 .51874 1.46946 -2.02254 Mabsadd L
.68519 .51874 .91448 -0.29713 Mabsadd L
.68519 .51874 2.37764 .77254 Mabsadd L
.68519 .51874 .56518 .7779 Mabsadd L
.68519 .51874 0 2.5 Mabsadd L closepath F
.71164 .4925 0 2.5 Mabsadd m
.71164 .4925 -0.56518 .7779 Mabsadd L
.71164 .4925 -2.37764 .77254 Mabsadd L
.71164 .4925 -0.91448 -0.29713 Mabsadd L
.71164 .4925 -1.46946 -2.02254 Mabsadd L
.71164 .4925 0 -0.96154 Mabsadd L
.71164 .4925 1.46946 -2.02254 Mabsadd L
.71164 .4925 .91448 -0.29713 Mabsadd L
.71164 .4925 2.37764 .77254 Mabsadd L
.71164 .4925 .56518 .7779 Mabsadd L
.71164 .4925 0 2.5 Mabsadd L closepath F
.7381 .46257 0 2.5 Mabsadd m
.7381 .46257 -0.56518 .7779 Mabsadd L
.7381 .46257 -2.37764 .77254 Mabsadd L
.7381 .46257 -0.91448 -0.29713 Mabsadd L
.7381 .46257 -1.46946 -2.02254 Mabsadd L
.7381 .46257 0 -0.96154 Mabsadd L
.7381 .46257 1.46946 -2.02254 Mabsadd L
.7381 .46257 .91448 -0.29713 Mabsadd L
.7381 .46257 2.37764 .77254 Mabsadd L
.7381 .46257 .56518 .7779 Mabsadd L
.7381 .46257 0 2.5 Mabsadd L closepath F
.76455 .42889 0 2.5 Mabsadd m
.76455 .42889 -0.56518 .7779 Mabsadd L
.76455 .42889 -2.37764 .77254 Mabsadd L
.76455 .42889 -0.91448 -0.29713 Mabsadd L
.76455 .42889 -1.46946 -2.02254 Mabsadd L
.76455 .42889 0 -0.96154 Mabsadd L
.76455 .42889 1.46946 -2.02254 Mabsadd L
.76455 .42889 .91448 -0.29713 Mabsadd L
.76455 .42889 2.37764 .77254 Mabsadd L
.76455 .42889 .56518 .7779 Mabsadd L
.76455 .42889 0 2.5 Mabsadd L closepath F
.79101 .39141 0 2.5 Mabsadd m
.79101 .39141 -0.56518 .7779 Mabsadd L
.79101 .39141 -2.37764 .77254 Mabsadd L
.79101 .39141 -0.91448 -0.29713 Mabsadd L
.79101 .39141 -1.46946 -2.02254 Mabsadd L
.79101 .39141 0 -0.96154 Mabsadd L
.79101 .39141 1.46946 -2.02254 Mabsadd L
.79101 .39141 .91448 -0.29713 Mabsadd L
.79101 .39141 2.37764 .77254 Mabsadd L
.79101 .39141 .56518 .7779 Mabsadd L
.79101 .39141 0 2.5 Mabsadd L closepath F
.81746 .35009 0 2.5 Mabsadd m
.81746 .35009 -0.56518 .7779 Mabsadd L
.81746 .35009 -2.37764 .77254 Mabsadd L
.81746 .35009 -0.91448 -0.29713 Mabsadd L
.81746 .35009 -1.46946 -2.02254 Mabsadd L
.81746 .35009 0 -0.96154 Mabsadd L
.81746 .35009 1.46946 -2.02254 Mabsadd L
.81746 .35009 .91448 -0.29713 Mabsadd L
.81746 .35009 2.37764 .77254 Mabsadd L
.81746 .35009 .56518 .7779 Mabsadd L
.81746 .35009 0 2.5 Mabsadd L closepath F
.84392 .30494 0 2.5 Mabsadd m
.84392 .30494 -0.56518 .7779 Mabsadd L
.84392 .30494 -2.37764 .77254 Mabsadd L
.84392 .30494 -0.91448 -0.29713 Mabsadd L
.84392 .30494 -1.46946 -2.02254 Mabsadd L
.84392 .30494 0 -0.96154 Mabsadd L
.84392 .30494 1.46946 -2.02254 Mabsadd L
.84392 .30494 .91448 -0.29713 Mabsadd L
.84392 .30494 2.37764 .77254 Mabsadd L
.84392 .30494 .56518 .7779 Mabsadd L
.84392 .30494 0 2.5 Mabsadd L closepath F
.87037 .25609 0 2.5 Mabsadd m
.87037 .25609 -0.56518 .7779 Mabsadd L
.87037 .25609 -2.37764 .77254 Mabsadd L
.87037 .25609 -0.91448 -0.29713 Mabsadd L
.87037 .25609 -1.46946 -2.02254 Mabsadd L
.87037 .25609 0 -0.96154 Mabsadd L
.87037 .25609 1.46946 -2.02254 Mabsadd L
.87037 .25609 .91448 -0.29713 Mabsadd L
.87037 .25609 2.37764 .77254 Mabsadd L
.87037 .25609 .56518 .7779 Mabsadd L
.87037 .25609 0 2.5 Mabsadd L closepath F
.89683 .20386 0 2.5 Mabsadd m
.89683 .20386 -0.56518 .7779 Mabsadd L
.89683 .20386 -2.37764 .77254 Mabsadd L
.89683 .20386 -0.91448 -0.29713 Mabsadd L
.89683 .20386 -1.46946 -2.02254 Mabsadd L
.89683 .20386 0 -0.96154 Mabsadd L
.89683 .20386 1.46946 -2.02254 Mabsadd L
.89683 .20386 .91448 -0.29713 Mabsadd L
.89683 .20386 2.37764 .77254 Mabsadd L
.89683 .20386 .56518 .7779 Mabsadd L
.89683 .20386 0 2.5 Mabsadd L closepath F
.92328 .14899 0 2.5 Mabsadd m
.92328 .14899 -0.56518 .7779 Mabsadd L
.92328 .14899 -2.37764 .77254 Mabsadd L
.92328 .14899 -0.91448 -0.29713 Mabsadd L
.92328 .14899 -1.46946 -2.02254 Mabsadd L
.92328 .14899 0 -0.96154 Mabsadd L
.92328 .14899 1.46946 -2.02254 Mabsadd L
.92328 .14899 .91448 -0.29713 Mabsadd L
.92328 .14899 2.37764 .77254 Mabsadd L
.92328 .14899 .56518 .7779 Mabsadd L
.92328 .14899 0 2.5 Mabsadd L closepath F
.94974 .09294 0 2.5 Mabsadd m
.94974 .09294 -0.56518 .7779 Mabsadd L
.94974 .09294 -2.37764 .77254 Mabsadd L
.94974 .09294 -0.91448 -0.29713 Mabsadd L
.94974 .09294 -1.46946 -2.02254 Mabsadd L
.94974 .09294 0 -0.96154 Mabsadd L
.94974 .09294 1.46946 -2.02254 Mabsadd L
.94974 .09294 .91448 -0.29713 Mabsadd L
.94974 .09294 2.37764 .77254 Mabsadd L
.94974 .09294 .56518 .7779 Mabsadd L
.94974 .09294 0 2.5 Mabsadd L closepath F
.97619 .03826 0 2.5 Mabsadd m
.97619 .03826 -0.56518 .7779 Mabsadd L
.97619 .03826 -2.37764 .77254 Mabsadd L
.97619 .03826 -0.91448 -0.29713 Mabsadd L
.97619 .03826 -1.46946 -2.02254 Mabsadd L
.97619 .03826 0 -0.96154 Mabsadd L
.97619 .03826 1.46946 -2.02254 Mabsadd L
.97619 .03826 .91448 -0.29713 Mabsadd L
.97619 .03826 2.37764 .77254 Mabsadd L
.97619 .03826 .56518 .7779 Mabsadd L
.97619 .03826 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{372, 229.812},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005d0000iB000`400?l00000o`00003o^@3IfMT0
0`000000fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000
fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000fMWI0=WIf@2h0=WIf@002@3IfMT00`000000fMWI0=WI
f@2]0=WIf@030000003IfMT0fMWI0:d0fMWI00<000000=WIf@3IfMT0203IfMT000P0fMWI0`00002^
0=WIf@030000003IfMT0fMWI0:`0fMWI0`0000090=WIf@001`3IfMT400000:h0fMWI00<000000=WI
f@3IfMT0Z`3IfMT4000000T0fMWI00080=WIf@<00000[P3IfMT00`000000fMWI0=WIf@2/0=WIf@<0
00002@3IfMT000T0fMWI0P00002^0=WIf@030000003IfMT0fMWI0:`0fMWI0P00000:0=WIf@002P3I
fMT00`000000fMWI0=WIf@2/0=WIf@030000003IfMT0fMWI0:`0fMWI00<000000=WIf@3IfMT02@3I
fMT000/0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`000000fMWI0=WIf@2[0=WIf@030000003IfMT0
fMWI00X0fMWI000;0=WIf@030000003IfMT0fMWI0:/0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`00
0000fMWI0=WIf@0:0=WIf@00303IfMT00`000000fMWI0=WIf@2Z0=WIf@800000Z`3IfMT00`000000
fMWI0=WIf@0;0=WIf@001`3IfMT2000000<0fMWI00<000000=WIf@3IfMT0ZP3IfMT00`000000fMWI
0=WIf@2Z0=WIf@050000003IfMT000000=WIf@0000002@3IfMT000P0fMWI0P0000020=WIf@030000
003IfMT0fMWI0:X0fMWI00<000000=WIf@3IfMT0ZP3IfMT00`000000fMWI00000002000000T0fMWI
00070=WIf@@000000P3IfMT00`000000fMWI0=WIf@2Y0=WIf@030000003IfMT0fMWI0:T0fMWI00<0
00000=WIf@3IfMT0100000080=WIf@003@3IfMT00`000000fMWI0=WIf@2Y0=WIf@030000003IfMT0
fMWI0:T0fMWI00<000000=WIf@3IfMT00P00000:0=WIf@002P3IfMT01@000000fMWI0=WIf@3IfMT0
00000:X0fMWI00<000000=WIf@3IfMT0Z03IfMT00`000000fMWI0=WIf@0=0=WIf@003P3IfMT00`00
0000fMWI0=WIf@2X0=WIf@030000003IfMT0fMWI0:P0fMWI00<000000=WIf@3IfMT03@3IfMT000l0
fMWI00<000000=WIf@3IfMT0Y`3IfMT00`000000fMWI0=WIf@2W0=WIf@050000003IfMT0fMWI0=WI
f@000000303IfMT000`0fMWI00@000000=WIf@3IfMT00000Z@3IfMT00`000000fMWI0=WIf@2W0=WI
f@030000003IfMT0fMWI00h0fMWI000<0=WIf@040000003IfMT0fMWI000009<0fMWI0`0000030=WI
f@030000003IfMT0fMWI00<000002P3IfMT00`000000fMWI0=WIf@2W0=WIf@030000003IfMT0fMWI
00h0fMWI000@0=WIf@030000003IfMT0fMWI08l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WI
f@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@2V0=WIf@040000003IfMT0
fMWI000000h0fMWI000=0=WIf@040000003IfMT0fMWI00000940fMWI00D000000=WIf@3IfMT0fMWI
000000040=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@2V0=WIf@03
0000003IfMT0fMWI00l0fMWI000=0=WIf@050000003IfMT0fMWI0=WIf@000000R03IfMT700000003
0=WIf@000000fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT00000
00T0fMWI0`00002U0=WIf@030000003IfMT0fMWI0100fMWI000A0=WIf@030000003IfMT0fMWI08h0
fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@<000002P3IfMT00`000000fMWI0=WIf@2U0=WI
f@040000003IfMT0fMWI000000l0fMWI000?0=WIf@040000003IfMT00000000008l0fMWI00D00000
0=WIf@3IfMT0fMWI000000040=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI
0=WIf@2T0=WIf@8000004P3IfMT000l0fMWI00<000000=WIf@0000000P00002>0=WIf@050000003I
fMT0fMWI0=WIf@000000103IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3I
fMT0X`3IfMT2000001<0fMWI000A0=WIf@<00000S`3IfMT3000000H0fMWI0`00000:0=WIf@030000
003IfMT0fMWI0:<0fMWI0P0000000`3IfMT000000=WIf@0@0=WIf@004P3IfMT200000:D0fMWI00<0
00000=WIf@3IfMT0X`3IfMT2000001<0fMWI000@0=WIf@040000003IfMT0fMWI00000:D0fMWI00<0
00000=WIf@3IfMT0X`3IfMT00`000000fMWI0=WIf@0B0=WIf@00503IfMT00`000000fMWI0=WIf@2R
0=WIf@030000003IfMT0fMWI0:80fMWI00@000000=WIf@3IfMT000004P3IfMT001@0fMWI00<00000
0=WIf@3IfMT0XP3IfMT00`000000fMWI0=WIf@2R0=WIf@040000003IfMT0fMWI00000180fMWI000A
0=WIf@<0000000<0fMWI0000003IfMT0XP3IfMT00`000000fMWI0=WIf@2Q0=WIf@<00000503IfMT0
0180fMWI0P0000000`3IfMT000000=WIf@2R0=WIf@030000003IfMT0fMWI0:40fMWI00@000000=WI
f@00000000004`3IfMT00140fMWI1@00002S0=WIf@030000003IfMT0fMWI0:40fMWI1@00000B0=WI
f@004P3IfMT3000000030=WIf@000000fMWI0:40fMWI00<000000=WIf@3IfMT0X03IfMT010000000
fMWI0=WIf@00000D0=WIf@004P3IfMT01@000000fMWI0=WIf@3IfMT000000:80fMWI0P00002Q0=WI
f@030000003IfMT0000001D0fMWI000G0=WIf@030000003IfMT0fMWI09l0fMWI00<000000=WIf@3I
fMT0W`3IfMT010000000fMWI0=WIf@00000E0=WIf@005@3IfMT00`000000fMWI0000002Q0=WIf@03
0000003IfMT0fMWI09l0fMWI00<000000=WIf@3IfMT05P3IfMT001D0fMWI00@000000=WIf@3IfMT0
0000X03IfMT00`000000fMWI0=WIf@2N0=WIf@030000003IfMT0fMWI01L0fMWI000H0=WIf@030000
003IfMT0fMWI09h0fMWI00<000000=WIf@3IfMT0WP3IfMT00`000000fMWI0000000G0=WIf@005P3I
fMT010000000fMWI0=WIf@00002O0=WIf@030000003IfMT0fMWI09d0fMWI00<000000=WIf@3IfMT0
603IfMT001L0fMWI00<000000=WIf@000000W`3IfMT00`000000fMWI0=WIf@2M0=WIf@030000003I
fMT0fMWI01P0fMWI000J0=WIf@030000003IfMT0fMWI09`0fMWI00<000000=WIf@3IfMT0W03IfMT0
10000000fMWI0=WIf@00000H0=WIf@00603IfMT00`000000fMWI0000002N0=WIf@030000003IfMT0
fMWI09`0fMWI00<000000=WIf@3IfMT06@3IfMT001P0fMWI00<000000=WIf@000000WP3IfMT00`00
0000fMWI0=WIf@2L0=WIf@030000003IfMT0fMWI01T0fMWI000K0=WIf@030000003IfMT0fMWI09/0
fMWI00<000000=WIf@3IfMT0V`3IfMT00`000000fMWI0000000J0=WIf@006`3IfMT2000009`0fMWI
00<000000=WIf@3IfMT0VP3IfMT2000001`0fMWI000I0=WIf@D00000V`3IfMT2000009X0fMWI0`00
000L0=WIf@006`3IfMT3000009/0fMWI00<000000=WIf@3IfMT0V@3IfMT4000001/0fMWI000L0=WI
f@800000V`3IfMT00`000000fMWI0=WIf@2I0=WIf@80000000<0fMWI0000003IfMT06P3IfMT001/0
fMWI00<000000=WIf@000000V`3IfMT00`000000fMWI0=WIf@2I0=WIf@030000003IfMT0fMWI01`0
fMWI000N0=WIf@030000003IfMT0fMWI09P0fMWI00<000000=WIf@3IfMT0V03IfMT00`000000fMWI
0000000M0=WIf@006`3IfMT010000000fMWI00000000002J0=WIf@030000003IfMT0fMWI09P0fMWI
0`00000M0=WIf@006`3IfMT3000000030=WIf@000000fMWI09P0fMWI00<000000=WIf@3IfMT0U`3I
fMT010000000fMWI00000000000M0=WIf@006`3IfMT5000009T0fMWI00<000000=WIf@3IfMT0U`3I
fMT5000001`0fMWI000L0=WIf@050000003IfMT0fMWI0=WIf@000000V03IfMT00`000000fMWI0=WI
f@2F0=WIf@040000003IfMT0fMWI000001h0fMWI000N0=WIf@030000003IfMT0000009P0fMWI00<0
00000=WIf@3IfMT0UP3IfMT00`000000fMWI0=WIf@0O0=WIf@007P3IfMT010000000fMWI0=WIf@00
002G0=WIf@030000003IfMT0fMWI09D0fMWI00<000000=WIf@3IfMT0803IfMT00240fMWI00<00000
0=WIf@3IfMT0U@3IfMT00`000000fMWI0=WIf@2E0=WIf@030000003IfMT000000200fMWI000O0=WI
f@030000003IfMT0000009L0fMWI00<000000=WIf@3IfMT0U@3IfMT00`000000fMWI0=WIf@0P0=WI
f@00803IfMT00`000000fMWI0000002F0=WIf@800000U@3IfMT00`000000fMWI0=WIf@0Q0=WIf@00
8P3IfMT00`000000fMWI0=WIf@2D0=WIf@030000003IfMT0fMWI09@0fMWI00<000000=WIf@000000
8@3IfMT00240fMWI00<000000=WIf@000000U@3IfMT00`000000fMWI0=WIf@2C0=WIf@030000003I
fMT0fMWI0280fMWI000Q0=WIf@030000003IfMT0000009D0fMWI00<000000=WIf@3IfMT0T`3IfMT0
0`000000fMWI0=WIf@0R0=WIf@00903IfMT00`000000fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI
0980fMWI00<000000=WIf@0000008`3IfMT002@0fMWI00<000000=WIf@3IfMT0TP3IfMT00`000000
fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI02<0fMWI000R0=WIf@80000000<0fMWI0000003IfMT0
TP3IfMT00`000000fMWI0=WIf@2A0=WIf@030000003IfMT0fMWI02@0fMWI000U0=WIf@800000TP3I
fMT00`000000fMWI0=WIf@2@0=WIf@80000000<0fMWI0000003IfMT08`3IfMT002D0fMWI0`00002A
0=WIf@030000003IfMT0fMWI08l0fMWI0`0000000`3IfMT000000=WIf@0S0=WIf@00903IfMT40000
07/0fMWI0`0000030=WIf@030000003IfMT0fMWI00<000002P3IfMT00`000000fMWI0=WIf@2>0=WI
f@@000009P3IfMT002D0fMWI0`00001j0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@00
0000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT0S`3IfMT3000002H0fMWI000V0=WI
f@800000NP3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00D000000=WIf@3IfMT0fMWI0000
00090=WIf@030000003IfMT0fMWI08l0fMWI0`00000V0=WIf@009@3IfMT400000740fMWI1`000000
0`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI0000
00090=WIf@<00000SP3IfMT2000002P0fMWI000U0=WIf@@00000N@3IfMT01@000000fMWI0=WIf@3I
fMT0000000@0fMWI1000000:0=WIf@030000003IfMT0fMWI08h0fMWI0`00000W0=WIf@009@3IfMT3
000000030=WIf@000000fMWI07L0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0S@3IfMT00`000000fMWI00000002000002H0fMWI000V
0=WIf@80000000<0fMWI0000003IfMT0M`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI0P00
000;0=WIf@030000003IfMT0fMWI08d0fMWI00<000000=WIf@000000:03IfMT002H0fMWI00D00000
0=WIf@3IfMT0fMWI0000001h0=WIf@<00000203IfMT2000000T0fMWI00<000000=WIf@3IfMT0S03I
fMT00`000000fMWI0000000Y0=WIf@00:P3IfMT00`000000fMWI0=WIf@2<0=WIf@030000003IfMT0
fMWI08`0fMWI00<000000=WIf@000000:@3IfMT002T0fMWI00<000000=WIf@000000S@3IfMT00`00
0000fMWI0=WIf@2;0=WIf@030000003IfMT0fMWI02X0fMWI000Y0=WIf@030000003IfMT0000008d0
fMWI00<000000=WIf@3IfMT0R`3IfMT00`000000fMWI0=WIf@0Z0=WIf@00;03IfMT00`000000fMWI
0=WIf@2:0=WIf@030000003IfMT0fMWI08X0fMWI00@000000=WIf@0000000000:P3IfMT002X0fMWI
00<000000=WIf@000000S03IfMT00`000000fMWI0=WIf@2:0=WIf@030000003IfMT0fMWI02/0fMWI
000Z0=WIf@040000003IfMT0fMWI000008/0fMWI00<000000=WIf@3IfMT0R@3IfMT00`000000fMWI
0=WIf@0/0=WIf@00;@3IfMT00`000000fMWI0=WIf@290=WIf@030000003IfMT0fMWI08T0fMWI00<0
00000=WIf@000000;03IfMT002`0fMWI00<000000=WIf@000000RP3IfMT2000008T0fMWI00<00000
0=WIf@3IfMT0;@3IfMT002`0fMWI00<000000=WIf@000000RP3IfMT00`000000fMWI0=WIf@280=WI
f@030000003IfMT0fMWI02d0fMWI000_0=WIf@030000003IfMT0fMWI08L0fMWI00<000000=WIf@3I
fMT0Q`3IfMT00`000000fMWI0000000^0=WIf@00;@3IfMT010000000fMWI0000000000280=WIf@03
0000003IfMT0fMWI08H0fMWI0P00000`0=WIf@00;P3IfMT4000008L0fMWI00<000000=WIf@3IfMT0
Q@3IfMT300000300fMWI000^0=WIf@@00000Q`3IfMT00`000000fMWI0=WIf@240=WIf@D00000;`3I
fMT002l0fMWI0`0000270=WIf@030000003IfMT0fMWI08D0fMWI0`00000`0=WIf@00;P3IfMT40000
08L0fMWI00<000000=WIf@3IfMT0Q@3IfMT200000340fMWI000_0=WIf@040000003IfMT0fMWI0000
08H0fMWI00<000000=WIf@3IfMT0Q03IfMT400000300fMWI000_0=WIf@@00000QP3IfMT00`000000
fMWI0=WIf@240=WIf@@00000<03IfMT002l0fMWI00D000000=WIf@000000fMWI000000250=WIf@03
0000003IfMT0fMWI08<0fMWI00@000000=WIf@3IfMT00000<@3IfMT003<0fMWI00<000000=WIf@3I
fMT0P`3IfMT00`000000fMWI0=WIf@230=WIf@040000003IfMT0000000000340fMWI000d0=WIf@03
0000003IfMT0fMWI0880fMWI00<000000=WIf@3IfMT0PP3IfMT00`000000fMWI0000000c0=WIf@00
<P3IfMT00`000000fMWI000000240=WIf@800000P`3IfMT00`000000fMWI0=WIf@0c0=WIf@00=@3I
fMT00`000000fMWI0=WIf@210=WIf@030000003IfMT0fMWI0840fMWI00<000000=WIf@000000=03I
fMT003H0fMWI00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@200=WIf@040000003IfMT0
fMWI000003@0fMWI000d0=WIf@030000003IfMT000000880fMWI00<000000=WIf@3IfMT0P03IfMT0
0`000000fMWI0=WIf@0e0=WIf@00=`3IfMT00`000000fMWI0=WIf@1o0=WIf@030000003IfMT0fMWI
07l0fMWI00<000000=WIf@000000=P3IfMT003L0fMWI00<000000=WIf@3IfMT0O`3IfMT00`000000
fMWI0=WIf@1o0=WIf@030000003IfMT0000003H0fMWI000e0=WIf@80000000<0fMWI0000003IfMT0
O`3IfMT00`000000fMWI0=WIf@1n0=WIf@030000003IfMT0fMWI03L0fMWI000h0=WIf@030000003I
fMT0fMWI07h0fMWI00<000000=WIf@3IfMT0OP3IfMT00`000000fMWI0000000g0=WIf@00>@3IfMT0
0`000000fMWI0=WIf@1m0=WIf@030000003IfMT0fMWI07d0fMWI00<000000=WIf@000000>03IfMT0
03L0fMWI00@000000=WIf@0000000000OP3IfMT00`000000fMWI0=WIf@1l0=WIf@800000>P3IfMT0
03T0fMWI0`00001m0=WIf@030000003IfMT0fMWI07/0fMWI1000000i0=WIf@00>03IfMT4000007d0
fMWI00<000000=WIf@3IfMT0NP3IfMT5000003T0fMWI000i0=WIf@<00000O@3IfMT2000007`0fMWI
0`00000j0=WIf@00>@3IfMT3000007d0fMWI00<000000=WIf@3IfMT0N`3IfMT3000003X0fMWI000h
0=WIf@D00000O03IfMT00`000000fMWI0=WIf@1j0=WIf@D00000>@3IfMT003T0fMWI00@000000=WI
f@0000000000O03IfMT00`000000fMWI0=WIf@1j0=WIf@030000003IfMT0000003/0fMWI000k0=WI
f@030000003IfMT0000007/0fMWI00<000000=WIf@3IfMT0N@3IfMT010000000fMWI0=WIf@00000k
0=WIf@00?@3IfMT00`000000fMWI0=WIf@1i0=WIf@030000003IfMT0fMWI07T0fMWI0`00000l0=WI
f@00?03IfMT00`000000fMWI0000001j0=WIf@030000003IfMT0fMWI07P0fMWI00<000000=WIf@3I
fMT0?@3IfMT003d0fMWI00<000000=WIf@000000N@3IfMT00`000000fMWI0=WIf@1g0=WIf@030000
003IfMT0fMWI03h0fMWI000o0=WIf@030000003IfMT0fMWI07L0fMWI00<000000=WIf@3IfMT0M`3I
fMT00`000000fMWI0000000n0=WIf@00?P3IfMT00`000000fMWI0000001h0=WIf@030000003IfMT0
fMWI07H0fMWI00<000000=WIf@3IfMT0?`3IfMT003h0fMWI00<000000=WIf@000000HP3IfMT30000
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
07H0fMWI00<000000=WIf@3IfMT0?`3IfMT00440fMWI00<000000=WIf@3IfMT0GP3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@1e0=WI
f@030000003IfMT000000400fMWI00100=WIf@800000H03IfMT01@000000fMWI0=WIf@3IfMT00000
00@0fMWI1P0000080=WIf@030000003IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0@03IfMT00400
fMWI00<000000=WIf@000000E`3IfMT7000000030=WIf@000000fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT010000000fMWI0=WIf@00000:0=WIf@<00000M03IfMT00`000000fMWI0=WIf@110=WI
f@00@P3IfMT2000005h0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT00000
00X0fMWI00<000000=WIf@3IfMT0M03IfMT200000480fMWI00120=WIf@<00000G@3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI0P00000:0=WIf@030000003IfMT0fMWI0780fMWI0P0000140=WI
f@00@P3IfMT3000005d0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@8000002P3IfMT00`00
0000fMWI0=WIf@1a0=WIf@<00000A03IfMT00480fMWI0`00001N0=WIf@<00000203IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0740fMWI0`0000140=WIf@00@`3IfMT3000007<0fMWI
00<000000=WIf@3IfMT0L@3IfMT3000004@0fMWI00120=WIf@@00000L`3IfMT00`000000fMWI0=WI
f@1a0=WIf@@00000@`3IfMT004<0fMWI00@000000=WIf@3IfMT00000LP3IfMT00`000000fMWI0=WI
f@1`0=WIf@<00000A@3IfMT004<0fMWI00@000000=WIf@0000000000LP3IfMT00`000000fMWI0=WI
f@1`0=WIf@030000003IfMT0fMWI04D0fMWI00160=WIf@800000L@3IfMT00`000000fMWI0=WIf@1_
0=WIf@030000003IfMT0fMWI04H0fMWI00180=WIf@030000003IfMT0fMWI06h0fMWI00<000000=WI
f@3IfMT0KP3IfMT3000004L0fMWI00170=WIf@800000L03IfMT00`000000fMWI0=WIf@1^0=WIf@03
0000003IfMT0fMWI04L0fMWI00170=WIf@030000003IfMT0000006l0fMWI0P00001^0=WIf@030000
003IfMT0fMWI04P0fMWI001:0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0K03I
fMT00`000000fMWI000000190=WIf@00B@3IfMT2000006h0fMWI00<000000=WIf@3IfMT0K03IfMT0
0`000000fMWI0=WIf@190=WIf@00B`3IfMT00`000000fMWI0=WIf@1[0=WIf@030000003IfMT0fMWI
06/0fMWI0P00001;0=WIf@00B`3IfMT00`000000fMWI0=WIf@1[0=WIf@030000003IfMT0fMWI06/0
fMWI0P00001;0=WIf@00B`3IfMT3000006/0fMWI00<000000=WIf@3IfMT0J@3IfMT2000004d0fMWI
001<0=WIf@<00000JP3IfMT00`000000fMWI0=WIf@1X0=WIf@<00000C@3IfMT004/0fMWI1000001Z
0=WIf@030000003IfMT0fMWI06L0fMWI1000001=0=WIf@00C03IfMT3000006X0fMWI00<000000=WI
f@3IfMT0J03IfMT3000004d0fMWI001<0=WIf@@00000J@3IfMT00`000000fMWI0=WIf@1W0=WIf@@0
0000C@3IfMT004d0fMWI00<000000=WIf@000000J@3IfMT00`000000fMWI0=WIf@1W0=WIf@800000
C`3IfMT004d0fMWI00@000000=WIf@0000000000J03IfMT00`000000fMWI0=WIf@1V0=WIf@030000
003IfMT0fMWI04l0fMWI001A0=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0I@3I
fMT200000540fMWI001A0=WIf@030000003IfMT0fMWI06D0fMWI0P00001V0=WIf@800000D@3IfMT0
0540fMWI0P00001V0=WIf@030000003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT0D@3IfMT005<0
fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@1S0=WIf@800000D`3IfMT005<0fMWI
00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@1S0=WIf@030000003IfMT0fMWI0580fMWI
001C0=WIf@800000I03IfMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI05<0fMWI001E
0=WIf@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT0H@3IfMT2000005D0fMWI001E0=WI
f@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT0H@3IfMT00`000000fMWI0=WIf@1D0=WI
f@00E@3IfMT300000640fMWI00<000000=WIf@3IfMT0G`3IfMT2000005L0fMWI001F0=WIf@<00000
H03IfMT00`000000fMWI0=WIf@1M0=WIf@@00000E`3IfMT005H0fMWI0`00001P0=WIf@030000003I
fMT0fMWI05h0fMWI0`00001G0=WIf@00EP3IfMT300000600fMWI00<000000=WIf@3IfMT0GP3IfMT3
000005L0fMWI001F0=WIf@80000000<0fMWI0000003IfMT0GP3IfMT00`000000fMWI0=WIf@1M0=WI
f@<00000F03IfMT005L0fMWI00@000000=WIf@0000000000GP3IfMT2000005d0fMWI00@000000=WI
f@3IfMT00000F03IfMT005/0fMWI00<000000=WIf@3IfMT0F`3IfMT00`000000fMWI0=WIf@1K0=WI
f@800000F`3IfMT005`0fMWI00<000000=WIf@3IfMT0FP3IfMT00`000000fMWI0=WIf@1J0=WIf@03
0000003IfMT0000005/0fMWI001K0=WIf@800000G03IfMT00`000000fMWI0=WIf@1J0=WIf@030000
003IfMT0fMWI05/0fMWI001M0=WIf@030000003IfMT0fMWI05T0fMWI00<000000=WIf@3IfMT0F@3I
fMT2000005d0fMWI001N0=WIf@030000003IfMT0fMWI05P0fMWI00<000000=WIf@3IfMT0F03IfMT2
000005h0fMWI001M0=WIf@<00000F@3IfMT00`000000fMWI0=WIf@1G0=WIf@030000003IfMT0fMWI
05h0fMWI001P0=WIf@800000E`3IfMT00`000000fMWI0=WIf@1E0=WIf@@00000G`3IfMT00600fMWI
0`00001F0=WIf@030000003IfMT0fMWI05@0fMWI0`00001Q0=WIf@00G`3IfMT400000400fMWI0`00
00030=WIf@030000003IfMT0000000<000002P3IfMT00`000000fMWI0=WIf@1C0=WIf@@00000H@3I
fMT00600fMWI0`00000o0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT01@000000fMWI0=WI
f@3IfMT0000000T0fMWI00<000000=WIf@3IfMT0E03IfMT300000640fMWI001O0=WIf@D00000?P3I
fMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI
0=WIf@1C0=WIf@D00000H03IfMT006@0fMWI00<000000=WIf@3IfMT0<`3IfMT7000000030=WIf@00
0000fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@<00000DP3I
fMT2000000030=WIf@000000fMWI0640fMWI001U0=WIf@030000003IfMT0fMWI03X0fMWI00D00000
0=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0D@3I
fMT00`000000fMWI0000001T0=WIf@00I03IfMT00`000000fMWI0000000k0=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0500fMWI00<0
00000=WIf@3IfMT0I@3IfMT006H0fMWI00<000000=WIf@3IfMT0>@3IfMT01@000000fMWI0=WIf@3I
fMT0000000@0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@1@0=WIf@800000
IP3IfMT006H0fMWI0P00000k0=WIf@<000001P3IfMT2000000/0fMWI00<000000=WIf@3IfMT0C`3I
fMT00`000000fMWI0=WIf@1V0=WIf@00I`3IfMT200000500fMWI00<000000=WIf@3IfMT0CP3IfMT0
0`000000fMWI0=WIf@1W0=WIf@00J@3IfMT00`000000fMWI0=WIf@1=0=WIf@030000003IfMT0fMWI
04d0fMWI0P00001Y0=WIf@00J@3IfMT3000004d0fMWI00<000000=WIf@3IfMT0B`3IfMT2000006/0
fMWI001Y0=WIf@@00000C03IfMT00`000000fMWI0=WIf@1:0=WIf@<00000J`3IfMT006X0fMWI0`00
001<0=WIf@030000003IfMT0fMWI04X0fMWI0`00001[0=WIf@00J@3IfMT4000004`0fMWI00<00000
0=WIf@3IfMT0BP3IfMT4000006X0fMWI001Z0=WIf@040000003IfMT0fMWI000004/0fMWI00<00000
0=WIf@3IfMT0B@3IfMT3000006`0fMWI001^0=WIf@030000003IfMT0fMWI04P0fMWI00<000000=WI
f@3IfMT0B03IfMT010000000fMWI0=WIf@00001/0=WIf@00K`3IfMT00`000000fMWI0=WIf@170=WI
f@800000B03IfMT00`000000fMWI0=WIf@1^0=WIf@00L03IfMT00`000000fMWI0=WIf@160=WIf@03
0000003IfMT0fMWI04H0fMWI00<000000=WIf@3IfMT0K`3IfMT00700fMWI0P0000170=WIf@030000
003IfMT0fMWI04D0fMWI00<000000=WIf@3IfMT0L03IfMT00780fMWI00<000000=WIf@3IfMT0A03I
fMT00`000000fMWI0=WIf@140=WIf@800000LP3IfMT007<0fMWI0P0000140=WIf@030000003IfMT0
fMWI0480fMWI0P00001d0=WIf@00L`3IfMT3000004<0fMWI00<000000=WIf@3IfMT0@@3IfMT20000
07D0fMWI001c0=WIf@@00000@P3IfMT00`000000fMWI0=WIf@100=WIf@<00000M@3IfMT007<0fMWI
1@0000110=WIf@030000003IfMT0fMWI03l0fMWI1@00001d0=WIf@00M03IfMT01@000000fMWI0=WI
f@3IfMT000000400fMWI00<000000=WIf@3IfMT0?P3IfMT2000007P0fMWI001h0=WIf@<00000?P3I
fMT00`000000fMWI0=WIf@0l0=WIf@800000NP3IfMT007/0fMWI00<000000=WIf@3IfMT0>`3IfMT0
0`000000fMWI0=WIf@0k0=WIf@030000003IfMT0000007X0fMWI001j0=WIf@<00000?03IfMT00`00
0000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI07/0fMWI001m0=WIf@800000>P3IfMT2000003T0
fMWI0`00001m0=WIf@00O@3IfMT3000003T0fMWI00<000000=WIf@3IfMT0=P3IfMT4000007h0fMWI
001l0=WIf@D00000>03IfMT00`000000fMWI0=WIf@0f0=WIf@@00000OP3IfMT007d0fMWI1@00000g
0=WIf@030000003IfMT0fMWI03D0fMWI1@00001n0=WIf@00OP3IfMT01@000000fMWI0000003IfMT0
000003H0fMWI00<000000=WIf@3IfMT0=03IfMT2000000030=WIf@000000000007l0fMWI001n0=WI
f@030000003IfMT0fMWI0080fMWI0P00000d0=WIf@030000003IfMT0fMWI0380fMWI0`0000230=WI
f@00P`3IfMT00`000000fMWI0000000c0=WIf@030000003IfMT0fMWI0340fMWI0P0000250=WIf@00
Q@3IfMT200000380fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI000000250=WIf@00QP3I
fMT300000300fMWI00<000000=WIf@3IfMT0;@3IfMT3000008P0fMWI00270=WIf@<00000;`3IfMT0
0`000000fMWI0=WIf@0]0=WIf@<00000R03IfMT002H0fMWI0`0000000`3IfMT00000000000020000
02T0fMWI0`0000020=WIf@<00000:03IfMT6000002`0fMWI00<000000=WIf@3IfMT0:`3IfMT50000
02/0fMWI0`0000020=WIf@<00000:@3IfMT3000000030=WIf@000000000000800000903IfMT002L0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W0=WIf@040000003IfMT0fMWI0000
00<0fMWI00<000000=WIf@3IfMT09@3IfMT200000080fMWI0`00000[0=WIf@030000003IfMT0fMWI
02X0fMWI00<000000=WIf@3IfMT00`00000/0=WIf@040000003IfMT0fMWI000000<0fMWI00<00000
0=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0240fMWI000W0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT09`3IfMT010000000fMWI0=WIf@000003
0=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT00P3IfMT2000002X0fMWI00<00000
0=WIf@3IfMT0:03IfMT2000000@0fMWI0P00000/0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0240fMWI000M
0=WIf@L000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01d0fMWI1`000003
0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0803IfMT7000000@0fMWI1000
000X0=WIf@8000009`3IfMT2000000L0fMWI00<000000=WIf@3IfMT0:P3IfMT010000000fMWI0=WI
f@0000030=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@0Q0=WIf@009`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI02L0fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI00<00000
9P3IfMT00`000000fMWI0=WIf@0S0=WIf@@00000203IfMT00`000000fMWI0=WIf@0Z0=WIf@040000
003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0240fMWI000W0=WIf@030000003IfMT0fMWI00@00000:P3IfMT010000000fMWI
0=WIf@0000030=WIf@030000003IfMT0fMWI02L0fMWI100000040=WIf@<000009@3IfMT00`000000
fMWI0=WIf@0S0=WIf@<000001@3IfMT4000002d0fMWI00@000000=WIf@3IfMT000000`3IfMT00`00
0000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00@00000903IfMT002L0fMWI00D000000=WIf@3I
fMT0fMWI0000000/0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0:03IfMT0
0`000000fMWI0=WIf@030=WIf@L000008P3IfMT00`000000fMWI0=WIf@0P0=WIf@L000001@3IfMT0
0`000000fMWI0=WIf@0]0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT09`3I
fMT01@000000fMWI0=WIf@3IfMT0000002H0fMWI000V0=WIf@8000000`3IfMT4000002P0fMWI0P00
00030=WIf@<00000:`3IfMT4000000@0fMWI00<000000=WIf@3IfMT00P3IfMT200000200fMWI00<0
00000=WIf@3IfMT07P3IfMT3000000<0fMWI00<000000=WIf@3IfMT01@3IfMT4000002/0fMWI0P00
00030=WIf@<00000:@3IfMT2000000<0fMWI1000000S0=WIf@00V03IfMT4000001d0fMWI00<00000
0=WIf@3IfMT06@3IfMT5000009X0fMWI002K0=WIf@@000006P3IfMT00`000000fMWI0=WIf@0I0=WI
f@@00000V`3IfMT009X0fMWI2000000G0=WIf@030000003IfMT0fMWI01H0fMWI1`00002K0=WIf@00
V`3IfMT2000000D0fMWI1000000C0=WIf@030000003IfMT0fMWI00l0fMWI00@000000=WIf@3IfMT0
fMWI100000030=WIf@800000W03IfMT00:@0fMWI1@00000@0=WIf@030000003IfMT0fMWI00l0fMWI
1@0000060=WIf@030000003IfMT0fMWI09/0fMWI002T0=WIf@d00000203IfMT00`000000fMWI0=WI
f@050=WIf@<000000P3IfMT900000:D0fMWI002U0=WIf@8000001@3IfMT00`000000fMWI00000006
000000<0fMWI0P0000040=WIf@P000000P3IfMT010000000fMWI0=WIf@3IfMT200000:H0fMWI003o
000007@000000@3IfMT000T0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@060=WI
f@<000001P3IfMT4000000L0fMWI0`0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT0203IfMT002H0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0^0=WIf@03
0000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT01P3IfMT3000000P0fMWI00<000000=WIf@3I
fMT0903IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI02h0fMWI00<000000=WIf@3I
fMT09@3IfMT00;T0fMWI00<000000=WIf@3IfMT0^03IfMT00;T0fMWI00<000000=WIf@3IfMT0^03I
fMT00;T0fMWI00<000000=WIf@3IfMT0^03IfMT00001\
\>"],
  ImageRangeCache->{{{0, 371}, {228.812, 0}} -> {-18.9396, -0.899529, 0.1021, 
  0.00402717}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 824}},
WindowSize->{729, 563},
WindowMargins->{{178, Automatic}, {Automatic, 6}},
ShowCellLabel->False,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5NP?N0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 43, 0, 50, "Title"],
Cell[1755, 51, 51, 3, 54, "Text"],

Cell[CellGroupData[{
Cell[1831, 58, 31, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[1887, 62, 114, 2, 79, "Input"],
Cell[2004, 66, 351, 7, 22, "Print"],
Cell[2358, 75, 126, 2, 37, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2533, 83, 39, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[2597, 87, 120, 3, 35, "Subsubsection"],
Cell[2720, 92, 2430, 64, 546, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5187, 161, 45, 0, 35, "Subsubsection"],
Cell[5235, 163, 3250, 53, 879, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8534, 222, 27, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[8586, 226, 105, 3, 43, "Subsection"],
Cell[8694, 231, 305, 5, 239, "Input"],

Cell[CellGroupData[{
Cell[9024, 240, 370, 9, 95, "Input"],
Cell[9397, 251, 80783, 2158, 296, 31043, 1539, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90217, 2414, 59, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[90301, 2418, 214, 4, 79, "Input"],
Cell[90518, 2424, 46412, 1195, 233, 22271, 892, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[136991, 3626, 68, 0, 27, "Subsection"],
Cell[137062, 3628, 353, 6, 255, "Input"],

Cell[CellGroupData[{
Cell[137440, 3638, 374, 9, 95, "Input"],
Cell[137817, 3649, 64383, 1786, 296, 26968, 1320, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202237, 5440, 52, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[202314, 5444, 238, 5, 95, "Input"],
Cell[202555, 5451, 33760, 922, 238, 14507, 680, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[236364, 6379, 65, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[236454, 6383, 187, 4, 63, "Input"],
Cell[236644, 6389, 113365, 2428, 319, 19709, 1267, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[350070, 8824, 59, 0, 27, "Subsection"],
Cell[350132, 8826, 354, 6, 255, "Input"],

Cell[CellGroupData[{
Cell[350511, 8836, 374, 9, 95, "Input"],
Cell[350888, 8847, 67650, 1810, 296, 25759, 1288, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[418575, 10662, 52, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[418652, 10666, 238, 5, 95, "Input"],
Cell[418893, 10673, 40043, 1006, 238, 16510, 711, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[458985, 11685, 67, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[459077, 11689, 218, 5, 63, "Input"],
Cell[459298, 11696, 138386, 3422, 296, 30452, 2085, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[597745, 15125, 49, 0, 27, "Subsection"],

Cell[CellGroupData[{
Cell[597819, 15129, 1050, 16, 623, "Input"],
Cell[598872, 15147, 115, 2, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[599024, 15154, 319, 8, 63, "Input"],
Cell[599346, 15164, 165161, 5857, 356, 90887, 4936, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[764544, 21026, 52, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[764621, 21030, 242, 5, 95, "Input"],
Cell[764866, 21037, 56041, 1451, 238, 32832, 1160, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

